%define kernel_git_commit 74d056f0b9089eb919c33a3bf55ae507e6f216f9
%define kernel_git_commit 74c661676446c010ea6f46dab7231d98761d66a5
%global __spec_install_pre %{___build_pre}

# Errors in specfile are causing builds to fail. Adding workarounds.
%define _unpackaged_files_terminate_build       0
%define _missing_doc_files_terminate_build      0

Summary: The Linux kernel

# For a stable, released kernel, released_kernel should be 1. For rawhide
# and/or a kernel built from an rc or git snapshot, released_kernel should
# be 0.
%define released_kernel 1
# Versions of various parts

# Polite request for people who spin their own kernel rpms:
# please modify the "buildid" define in a way that identifies
# that the kernel isn't the stock distribution kernel, for example,
# by setting the define to ".local" or ".bz123456"
#
# % define buildid .local

%define distro_build 100
%define signmodules 1

# base_sublevel is the kernel version we're starting with and patching
# on top of -- for example, 2.6.22-rc7-git1 starts with a 2.6.21 base,
# which yields a base_sublevel of 21.
%define base_sublevel 13

## If this is a released kernel ##
%if 0%{?released_kernel}

# Do we have a -stable update to apply?
%define stable_update 0
# Is it a -stable RC?
%define stable_rc 0
# Set rpm version accordingly
%if 0%{?stable_update}
%define stablerev .%{stable_update}
%define stable_base %{stable_update}
%if 0%{?stable_rc}
# stable RCs are incremental patches, so we need the previous stable patch
%define stable_base %(echo $((%{stable_update} - 1)))
%endif
%endif
%define rpmversion 3.8.%{base_sublevel}%{?stablerev}

## The not-released-kernel case ##
%else
# The next upstream release sublevel (base_sublevel+1)
%define upstream_sublevel %(echo $((%{base_sublevel} + 1)))
# The rc snapshot level
%define rcrev 0
# The git snapshot level
%define gitrev 0
# Set rpm version accordingly
%define rpmversion 3.8.%{upstream_sublevel}
%endif
# Nb: The above rcrev and gitrev values automagically define Patch00 and Patch01 below.

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# standard kernel
%define with_up        1
# kernel-smp (only valid for ppc 32-bit, sparc64)
%define with_smp       1
# kernel-kdump
%define with_kdump     0
# kernel-debug
%define with_debug     1
# kernel-doc
%define with_doc       1
# kernel-headers
%define with_headers   0
# dtrace
%define with_dtrace    0
# kernel-firmware
%define with_firmware  0
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# kernel-bootwrapper (for creating zImages from kernel + initrd)
%define with_bootwrapper %{?_without_bootwrapper: 0} %{?!_without_bootwrapper: 1}
# Want to build a the vsdo directories installed
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}

# Build the kernel-doc package, but don't fail the build if it botches.
# Here "true" means "continue" and "false" means "fail the build".
%if 0%{?released_kernel}
%define doc_build_fail false
%else
%define doc_build_fail true
%endif

# Control whether we perform a compat. check against published ABI.
%ifarch sparc64
%define with_kabichk 0
%define fancy_debuginfo 0
%else
%define with_kabichk 1 
%define fancy_debuginfo 1
%endif

# Control whether we build the hmac for fips mode.
%define with_fips      %{?_without_fips:      0} %{?!_without_fips:      1}

%if %{fancy_debuginfo}
BuildRequires: rpm-build >= 4.4.2.1-4
%define debuginfo_args --strict-build-id
%endif

# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the smp kernel (--with smponly):
%define with_smponly   %{?_with_smponly:      1} %{?!_with_smponly:      0}

# should we do C=1 builds with sparse
%define with_sparse	%{?_with_sparse:      1} %{?!_with_sparse:      0}

# Set debugbuildsenabled to 1 for production (build separate debug kernels)
#  and 0 for rawhide (all kernels are debug kernels).
# See also 'make debug' and 'make release'.
%define debugbuildsenabled 1

# Want to build a vanilla kernel build without any non-upstream patches?
# (well, almost none, we need nonintconfig for build purposes). Default to 0 (off).
%define with_vanilla %{?_with_vanilla: 1} %{?!_with_vanilla: 0}

# pkg_release is what we'll fill in for the rpm Release: field
%if 0%{?released_kernel}

%if 0%{?stable_rc}
%define stable_rctag .rc%{stable_rc}
%endif
%define pkg_release 55.1.8%{?dist}uek%{?buildid}

%else

# non-released_kernel
%if 0%{?rcrev}
%define rctag .rc%rcrev
%else
%define rctag .rc0
%endif
%if 0%{?gitrev}
%define gittag .git%gitrev
%else
%define gittag .git0
%endif
%define pkg_release 55.1.8%{?dist}uek%{?buildid}

%endif

# The kernel tarball/base version
%define kversion 3.8.13

%define make_target bzImage

%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if 0%{!?nopatches:1}
%define nopatches 0
%endif

%if %{with_vanilla}
%define nopatches 1
%endif

%define with_bootwrapper 0

%define pkg_release 55.1.8%{?dist}uek%{?buildid}

%define KVERREL %{rpmversion}-%{pkg_release}.%{_target_cpu}

%if !%{debugbuildsenabled}
%define with_debug 0
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug

%define with_pae 0

# if requested, only build base kernel
%if %{with_baseonly}
%define with_smp 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build smp kernel
%if %{with_smponly}
%define with_up 0
%define with_kdump 0
%define with_debug 0
%endif

%define all_x86 i386 i686

%if %{with_vdso_install}
# These arches install vdso/ directories.
%define vdso_arches %{all_x86} x86_64 ppc ppc64
%endif

# Overrides for generic default options

# only ppc need separate smp kernels
%ifnarch ppc alphaev56
%define with_smp 0
%endif

# only build kernel-kdump on ppc64
# (no relocatable kernel support upstream yet)
#FIXME: Temporarily disabled to speed up builds.
#ifnarch ppc64
%define with_kdump 0
#endif

# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%define with_debug 0
%endif

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%endif

# no need to build headers again for these arches,
# they can just use i586 and ppc64 headers
%ifarch ppc64iseries
%define with_headers 0
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define with_paravirt 0
%define with_paravirt_debug 0
%define all_arch_configs kernel-%{version}-*.config
%define with_firmware  %{?_without_firmware:  0} %{?!_without_firmware:  1}
%endif

# bootwrapper is only on ppc
%ifnarch ppc ppc64
%define with_bootwrapper 0
%endif

# sparse blows up on ppc64 alpha and sparc64
%ifarch ppc64 ppc alpha sparc64
%define with_sparse 0
%endif

# Only x86_64 does dtrace
%ifarch x86_64
%define with_dtrace 1
%endif

# Per-arch tweaks

%ifarch %{all_x86}
%define asmarch x86
%define hdrarch i386
%define all_arch_configs kernel-%{version}-i?86*.config
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch x86_64
%define asmarch x86
#%define all_arch_configs kernel-%{version}-x86_64*.config
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64
%define asmarch powerpc
%define hdrarch powerpc
%define all_arch_configs kernel-%{version}-ppc64*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs kernel-%{version}-s390x.config
%define image_install_path boot
%define make_target image
%define kernel_image arch/s390/boot/image
%endif

%ifarch sparc
# We only build sparc headers since we dont support sparc32 hardware
%endif

%ifarch sparc64
%define asmarch sparc
%define all_arch_configs kernel-%{version}-sparc64*.config
%define make_target image
%define kernel_image arch/sparc/boot/image
%define image_install_path boot
%endif

%ifarch ppc
%define asmarch powerpc
%define hdrarch powerpc
%define all_arch_configs kernel-%{version}-ppc{-,.}*config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%endif

%ifarch ia64
%define all_arch_configs kernel-%{version}-ia64*.config
%define image_install_path boot/efi/EFI/redhat
%define make_target compressed
%define kernel_image vmlinux.gz
%endif

%ifarch alpha alphaev56
%define all_arch_configs kernel-%{version}-alpha*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%endif

%ifarch %{arm}
%define all_arch_configs kernel-%{version}-arm*.config
%define image_install_path boot
%define hdrarch arm
%define make_target vmlinux
%define kernel_image vmlinux
%endif

%if %{nopatches}
# XXX temporary until last vdso patches are upstream
%define vdso_arches ppc ppc64
%endif

%define oldconfig_target oldnoconfig

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386; we only do kernel-headers there,
# and we no longer build for 31bit S390. Same for 32bit sparc and arm.
##%define nobuildarches i386 s390 sparc %{arm}
%define nobuildarches s390 sparc %{arm}

%ifarch %nobuildarches
%define with_up 0
%define with_smp 0
%define with_pae 0
%define with_kdump 0
%define with_debuginfo 0
%define _enable_debug_packages 0
%define with_paravirt 0
%define with_paravirt_debug 0
%endif

%define with_pae_debug 0
%if %{with_pae}
%define with_pae_debug %{with_debug}
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
##%define package_conflicts initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, iwl4965-firmware < 228.57.2, selinux-policy-targeted < 1.25.3-14, squashfs-tools < 4.0, wireless-tools < 29-3
%define package_conflicts initscripts < 7.23, udev < 063-6, iptables < 1.3.2-1, ipw2200-firmware < 2.4, selinux-policy-targeted < 1.25.3-14

#
# The ld.so.conf.d file we install uses syntax older ldconfig's don't grok.
#
%define kernel_xen_conflicts glibc < 2.3.5-1, xen < 3.0.1

# upto and including kernel 2.4.9 rpms, the 4Gb+ kernel was called kernel-enterprise
# now that the smp kernel offers this capability, obsolete the old kernel
%define kernel_smp_obsoletes kernel-enterprise < 2.4.10
%define kernel_PAE_obsoletes kernel-smp < 2.6.17, kernel-xen <= 2.6.27-0.2.rc0.git6.fc10
%define kernel_PAE_provides kernel-xen = %{rpmversion}-%{pkg_release}

%ifarch x86_64
%define kernel_obsoletes kernel-xen <= 2.6.27-0.2.rc0.git6.fc10
%define kernel_provides kernel%{?variant}-xen = %{rpmversion}-%{pkg_release}
%endif

# We moved the drm include files into kernel-headers, make sure there's
# a recent enough libdrm-devel on the system that doesn't have those.
%define kernel_headers_conflicts libdrm-devel < 2.4.0-0.15

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, kernel-firmware = %{rpmversion}-%{pkg_release}, %{_sbindir}/new-kernel-pkg
%define initrd_prereq  dracut-kernel >= 004-242.0.3

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: kernel%{?variant} = %{rpmversion}-%{pkg_release}\
Provides: kernel%{?variant}-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:.%{1}}\
Provides: kernel%{?variant}-drm = 4.3.0\
Provides: kernel%{?variant}-drm-nouveau = 12\
Provides: kernel%{?variant}-modeset = 1\
Provides: kernel%{?variant}-uname-r = %{KVERREL}%{?1:.%{1}}\
Provides: oracleasm = 2.0.5\
%ifnarch sparc64\
Provides: x86_energy_perf_policy = %{KVERREL}%{?1:.%{1}}\
%endif\
Provides: perf = %{KVERREL}%{?1:.%{1}}\
#Provides: libperf.a = %{KVERREL}%{?1:.%{1}}\
%ifarch sparc64\
Provides: kernel = %{rpmversion}-%{pkg_release}\
%endif\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): linux-firmware >= 20100806-2\
Requires(post): %{_sbindir}/new-kernel-pkg\
Requires(preun): %{_sbindir}/new-kernel-pkg\
Conflicts: %{kernel_dot_org_conflicts}\
Conflicts: %{package_conflicts}\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}

%define variant %{?build_variant:%{build_variant}}%{!?build_variant:-uek}
Name: kernel%{?variant}
Group: System Environment/Kernel
License: GPLv2
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch %{all_x86} x86_64 paravirt paravirt-debug ppc ppc64 ia64 sparc sparc64 s390x alpha alphaev56 %{arm}
ExclusiveOS: Linux

%kernel_reqprovconf
%ifarch x86_64
Obsoletes: kernel-smp
%endif


#
# List the packages used during the kernel build
#
BuildRequires: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildRequires: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils, gawk
BuildRequires: gcc >= 3.4.2, binutils >= 2.12
BuildRequires: hostname, net-tools
BuildRequires: elfutils-libelf-devel
BuildRequires: python
BuildRequires: flex >= 2.5.19, bison >= 2.3
BuildRequires: pkgconfig
BuildRequires: glib2-devel
BuildRequires: elfutils-devel
%if %{with_doc}
BuildRequires: xmlto
%endif
%if %{with_sparse}
BuildRequires: sparse >= 0.4.1
%endif
%ifnarch noarch
%if %{signmodules}
BuildRequires: openssl
BuildRequires: pesign >= 0.10-4
%endif
%endif
%if %{with_fips}
BuildRequires: hmaccalc
%endif
%if %{with_dtrace}
BuildRequires: libdtrace-ctf-devel
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb

Source0: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-%{kversion}.tar.bz2

%if %{signmodules}
Source10: x509.genkey
%endif

Source13: mod-sign.sh
%define modsign_cmd %{SOURCE13}

Source14: find-provides
Source16: perf
Source17: kabitool
Source18: check-kabi
Source19: extrakeys.pub
Source20: x86_energy_perf_policy
Source21: securebootca.cer
Source22: secureboot.cer

Source1000: config-x86_64
Source1001: config-x86_64-debug
Source1004: config-sparc
Source1005: config-sparc-debug

Source26: Module.kabi_x86_64

Source201: kabi_whitelist_x86_64

Source300: debuginfo-g1.diff
Source301: debuginfo-g1-minusr-old-elfutils.diff

# Here should be only the patches up to the upstream canonical Linus tree.

# For a stable release kernel
%if 0%{?stable_update}
%if 0%{?stable_base}
%define    stable_patch_00  patch-2.6.%{base_sublevel}.%{stable_base}.bz2
Patch00: %{stable_patch_00}
%endif
%if 0%{?stable_rc}
%define    stable_patch_01  patch-2.6.%{base_sublevel}.%{stable_update}-rc%{stable_rc}.bz2
Patch01: %{stable_patch_01}
%endif

# non-released_kernel case
# These are automagically defined by the rcrev and gitrev values set up
# near the top of this spec file.
%else
%if 0%{?rcrev}
Patch00: patch-2.6.%{upstream_sublevel}-rc%{rcrev}.bz2
%if 0%{?gitrev}
Patch01: patch-2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}.bz2
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
Patch00: patch-2.6.%{base_sublevel}-git%{gitrev}.bz2
%endif
%endif
%endif

%if !%{nopatches}
# revert patches place holder
%endif


BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

# Override find_provides to use a script that provides "kernel(symbol) = hash".
# Pass path of the RPM temp dir containing kabideps to find-provides script.
%global _use_internal_dependency_generator 0
%define __find_provides %_sourcedir/find-provides %{_tmppath}
%define __find_requires /usr/lib/rpm/redhat/find-requires kernel

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Obsoletes: kernel-headers
Provides: kernel-headers
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package firmware
Summary: Firmware files used by the Linux kernel
Group: Development/System
# This is... complicated.
# Look at the WHENCE file.
License: GPL+ and GPLv2+ and MIT and Redistributable, no modification permitted
%if "x%{?variant}" != "x"
Provides: kernel-firmware = %{rpmversion}-%{pkg_release}
%endif
%ifarch sparc64
Provides: kernel-firmware = %{rpmversion}-%{pkg_release}
%endif
%description firmware
Kernel firmware includes firmware files required for some devices to
operate.

%package bootwrapper
Summary: Boot wrapper files for generating combined kernel + initrd images
Group: Development/System
Requires: gzip
%description bootwrapper
Kernel-bootwrapper contains the wrapper code which makes bootable "zImage"
files combining both kernel and initial ramdisk.

%package debuginfo-common
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
Provides: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
%description debuginfo-common
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.


#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
AutoReqProv: no\
%description -n %{name}%{?1:-%{1}}-debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVERREL}%{?1:\.%{1}}/.*|/.*%%{KVERREL}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?variant}%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel%{?variant}-xen-devel = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel%{?variant}-devel-%{_target_cpu} = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel%{?variant}-devel = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel%{?variant}-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
%ifarch sparc64\
Provides: kernel-devel = %{version}-%{release}%{?1:.%{1}}\
%endif\
AutoReqProv: no\
Requires(pre): /usr/bin/find\
Requires: elfutils-libelf\
Requires: elfutils-libs\
%if %{with_dtrace}\
Requires: libdtrace-ctf\
%endif\
%description -n kernel%{?variant}%{?1:-%{1}}-devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %1\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
%kernel_reqprovconf\
%{expand:%%kernel_devel_package %1 %{!?-n:%1}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %1}\
%{nil}


# First the auxiliary packages of the main kernel package.
%kernel_devel_package
%kernel_debuginfo_package


# Now, each variant package.

%define variant_summary The Linux kernel compiled for SMP machines
%kernel_variant_package -n SMP smp
%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.


%define variant_summary The Linux kernel compiled for PAE capable machines
%kernel_variant_package PAE
%description PAE
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.


%define variant_summary The Linux kernel compiled with extra debugging enabled for PAE capable machines
%kernel_variant_package PAEdebug
Obsoletes: kernel-PAE-debug
%description PAEdebug
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.


%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.


%define variant_summary A minimal Linux kernel compiled for crash dumps
%kernel_variant_package kdump
%description kdump
This package includes a kdump version of the Linux kernel. It is
required only on machines which will use the kexec-based kernel crash dump
mechanism.


%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}%{with_pae}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

%if %{with_smponly}
%if !%{with_smp}
echo "Cannot build --with smponly, smp build is disabled"
exit 1
%endif
%endif

patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1;
  fi
  if ! egrep "^Patch[0-9]+: $patch\$" %{_specdir}/%{name}*.spec ; then
    [ "${patch:0:10}" != "patch-2.6." ] && echo "Patch $patch not listed in specfile" && exit 1;
  fi
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz) gunzip < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

test_config_file()
{
  TestConfig=$1
  Arch=`head -n 3 .config |grep -e "Linux.*Kernel" |cut -d '/' -f 2 | cut -d ' ' -f 1`
  if [ `make ARCH=$Arch listnewconfig 2>/dev/null | grep -c CONFIG`  -ne 0 ]; then 
	echo "Following config options are unconfigured"
	make ARCH=$Arch listnewconfig 2> /dev/null
	echo "WARNING: Kernel version and config file missmatch"
	echo "WARNING: This options will be unset by default in config file"
  fi
}

# First we unpack the kernel tarball.
# If this isn't the first make prep, we use links to the existing clean tarball
# which speeds things up quite a bit.

# Update to latest upstream.
%if 0%{?released_kernel}
%define vanillaversion 2.6.%{base_sublevel}
# non-released_kernel case
%else
%if 0%{?rcrev}
%define vanillaversion 2.6.%{upstream_sublevel}-rc%{rcrev}
%if 0%{?gitrev}
%define vanillaversion 2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
%define vanillaversion 2.6.%{base_sublevel}-git%{gitrev}
%endif
%endif
%endif

# We can share hardlinked source trees by putting a list of
# directory names of the CVS checkouts that we want to share
# with in .shared-srctree. (Full pathnames are required.)
[ -f .shared-srctree ] && sharedirs=$(cat .shared-srctree)

if [ ! -d kernel-%{kversion}/vanilla-%{vanillaversion} ]; then

  if [ -d kernel-%{kversion}/vanilla-%{kversion} ]; then

    cd kernel-%{kversion}

    # Any vanilla-* directories other than the base one are stale.
    for dir in vanilla-*; do
      [ "$dir" = vanilla-%{kversion} ] || rm -rf $dir &
    done

  else

    # Ok, first time we do a make prep.
    rm -f pax_global_header
    for sharedir in $sharedirs ; do
      if [[ ! -z $sharedir  &&  -d $sharedir/kernel-%{kversion}/vanilla-%{kversion} ]] ; then
        break
      fi
    done
    if [[ ! -z $sharedir  &&  -d $sharedir/kernel-%{kversion}/vanilla-%{kversion} ]] ; then
%setup -q -n kernel-%{kversion} -c -T
      cp -rl $sharedir/kernel-%{kversion}/vanilla-%{kversion} .
    else
%setup -q -n kernel-%{kversion} -c
      mv linux-%{kversion} vanilla-%{kversion}
    fi

  fi

%if "%{kversion}" != "%{vanillaversion}"

  for sharedir in $sharedirs ; do
    if [[ ! -z $sharedir  &&  -d $sharedir/kernel-%{kversion}/vanilla-%{vanillaversion} ]] ; then
      break
    fi
  done
  if [[ ! -z $sharedir  &&  -d $sharedir/kernel-%{kversion}/vanilla-%{vanillaversion} ]] ; then

    cp -rl $sharedir/kernel-%{kversion}/vanilla-%{vanillaversion} .

  else

    cp -rl vanilla-%{kversion} vanilla-%{vanillaversion}
    cd vanilla-%{vanillaversion}

# Update vanilla to the latest upstream.
# (non-released_kernel case only)
%if 0%{?rcrev}
    ApplyPatch patch-2.6.%{upstream_sublevel}-rc%{rcrev}.bz2
%if 0%{?gitrev}
    ApplyPatch patch-2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}.bz2
%endif
%else
# pre-{base_sublevel+1}-rc1 case
%if 0%{?gitrev}
    ApplyPatch patch-2.6.%{base_sublevel}-git%{gitrev}.bz2
%endif
%endif

    cd ..

  fi

%endif

else
  # We already have a vanilla dir.
  cd kernel-%{kversion}
fi

if [ -d linux-%{kversion}.%{_target_cpu} ]; then
  # Just in case we ctrl-c'd a prep already
  rm -rf deleteme.%{_target_cpu}
  # Move away the stale away, and delete in background.
  mv linux-%{kversion}.%{_target_cpu} deleteme.%{_target_cpu}
  rm -rf deleteme.%{_target_cpu} &
fi

cp -rl vanilla-%{vanillaversion} linux-%{kversion}-%{release}
cd linux-%{kversion}-%{release}

# released_kernel with possible stable updates
%if 0%{?stable_base}
ApplyPatch %{stable_patch_00}
%endif
%if 0%{?stable_rc}
ApplyPatch %{stable_patch_01}
%endif

# Copy the RPM find-debuginfo.sh into the buildroot and patch it
# to support -g1.  (This is a patch of *RPM*, not of the kernel,
# so it is not governed by nopatches).  We need to try several patches
# in succession until one works.

cp %{_rpmconfigdir}/find-debuginfo.sh %{_builddir}
patch %{_builddir}/find-debuginfo.sh %{SOURCE301} || \
      { mv -f %{_builddir}/find-debuginfo.sh.orig %{_builddir}/find-debuginfo.sh && \
        patch %{_builddir}/find-debuginfo.sh %{SOURCE300}; }
chmod +x %{_builddir}/find-debuginfo.sh

# only deal with configs if we are going to build for the arch
# %ifnarch %nobuildarches

mkdir -p configs 
%ifarch x86_64
	cp %{SOURCE1001} configs/config-debug 
	cp %{SOURCE1000} configs/config
%endif #ifarch x86_64

%ifarch i686
	cp %{SOURCE1003} configs/config-debug
	cp %{SOURCE1002} configs/config
%endif #ifarch i686

%ifarch sparc64
	cp %{SOURCE1005} configs/config-debug
	cp %{SOURCE1004} configs/config
%endif #ifarch sparc

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

%if %{fancy_debuginfo}
# This override tweaks the kernel makefiles so that we run debugedit on an
# object before embedding it.  When we later run find-debuginfo.sh, it will
# run debugedit again.  The edits it does change the build ID bits embedded
# in the stripped object, but repeating debugedit is a no-op.  We do it
# beforehand to get the proper final build ID bits into the embedded image.
# This affects the vDSO images in vmlinux, and the vmlinux image in bzImage.
export AFTER_LINK=\
'sh -xc "/usr/lib/rpm/debugedit -b $$RPM_BUILD_DIR -d /usr/src/debug \
    				-i $@ > $@.id"'
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3
    InstallName=${4:-vmlinuz}

    # Pick the right config file for the kernel we're building
    Config=kernel-%{version}-%{_target_cpu}${Flavour:+-${Flavour}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Flavour:+.${Flavour}}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{version}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = %{?stablerev}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}/" Makefile
    #perl -p -i -e "s/^SUBLEVEL.*/SUBLEVEL = %{base_sublevel}/" Makefile

    make -s mrproper

    %if %{signmodules}
    	cp %{SOURCE10} .
   	chmod +x scripts/sign-file
    %endif

    if [ "$Flavour" == "debug" ]; then	
	cp configs/config-debug .config
    else
	cp configs/config .config
    fi

    Arch=`head -n 3 .config |grep -e "Linux.*Kernel" |cut -d '/' -f 2 | cut -d ' ' -f 1`
    echo USING ARCH=$Arch 
    make -s ARCH=$Arch %{oldconfig_target} > /dev/null
    make -s ARCH=$Arch V=1 %{?_smp_mflags} $MakeTarget %{?sparse_mflags}
    make -s ARCH=$Arch V=1 %{?_smp_mflags} modules %{?sparse_mflags} || exit 1

    # Start installing the results
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/boot
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    touch $RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi
    %if %{signmodules}
    %ifarch x86_64
    	# Sign the image if we're using EFI
	%pesign -s -i $KernelImage -o $KernelImage.signed -a %{SOURCE21} -c %{SOURCE22} -n oraclesecureboot301
	mv $KernelImage.signed $KernelImage
    %endif
    %endif
    $CopyKernel $KernelImage \
    		$RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer

%if %{with_fips}
    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    sha512hmac $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer | sed -e "s,$RPM_BUILD_ROOT,," > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
%endif

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    # Override $(mod-fw) because we don't want it to install any firmware
    # We'll do that ourselves with 'make firmware_install'
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=
    # check if the modules are being signed

%ifarch %{vdso_arches}
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
    if grep '^CONFIG_XEN=y$' .config >/dev/null; then
      echo > ldconfig-kernel.conf "\
# This directive teaches ldconfig to search in nosegneg subdirectories
# and cache the DSOs there with extra bit 0 set in their hwcap match
# fields.  In Xen guest kernels, the vDSO tells the dynamic linker to
# search in nosegneg subdirectories and to match this extra hwcap bit
# in the ld.so.cache file.
hwcap 0 nosegneg"
    fi
    if [ ! -s ldconfig-kernel.conf ]; then
      echo > ldconfig-kernel.conf "\
# Placeholder file, no vDSO hwcap entries used in this kernel."
    fi
    %{__install} -D -m 444 ldconfig-kernel.conf \
        $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-$KernelVer.conf
%endif
%ifarch %{vdso_arches} sparc64
%ifnarch noarch
# build tools/perf:
    if [ -d tools/perf ]; then
	cd tools/perf
	make all
# and install it:
#	mkdir -p $RPM_BUILD_ROOT/usr/bin/$KernelVer/
	mkdir -p $RPM_BUILD_ROOT/usr/libexec/
	install -m 755 perf $RPM_BUILD_ROOT/usr/libexec/perf.$KernelVer
	#install -m 755 libperf.a $RPM_BUILD_ROOT/lib/modules/$KernelVer/bin/%{_target_cpu}/libperf.a
	cd ../..
    fi
%endif
%ifarch x86_64 %{all_x86}
# build tools/power/x86/x86_energy_perf_policy:
    if [ -d tools/power/x86/x86_energy_perf_policy ]; then
       cd tools/power/x86/x86_energy_perf_policy
       make
# and install it:
       mkdir -p $RPM_BUILD_ROOT/usr/libexec/
       install -m 755 x86_energy_perf_policy $RPM_BUILD_ROOT/usr/libexec/x86_energy_perf_policy.$KernelVer
       cd ../../../../
    fi
%endif
%endif

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
    chmod 0755 %_sourcedir/kabitool
    if [ -e $RPM_SOURCE_DIR/kabi_whitelist_%{_target_cpu}$Flavour ]; then
       cp $RPM_SOURCE_DIR/kabi_whitelist_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/kabi_whitelist
    fi
    rm -f %{_tmppath}/kernel-$KernelVer-kabideps
    %_sourcedir/kabitool -s Module.symvers -o %{_tmppath}/kernel-$KernelVer-kabideps 

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour ]; then
       cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/Module.kabi
       $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
       rm $RPM_BUILD_ROOT/Module.kabi # for now, don't keep it around.
    else
       echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
%ifarch ppc
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    cp -a --parents Kbuild $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents kernel/bounds.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/%{asmarch}/kernel/asm-offsets.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%ifnarch %{sparc}
    cp -a --parents arch/%{asmarch}/kernel/asm-offsets_64.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    cp -a --parents security/selinux/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/ 
    
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config generated crypto keys linux math-emu media uapi net pcmcia rdma rxrpc scsi sound trace video asm-generic drm xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    asmdir=../arch/%{asmarch}/include/asm
    cp -a $asmdir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/
    cd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include 
    ln -s $asmdir asm
    cd -
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf
    cd ..

%if %{fancy_debuginfo}
    if test -s vmlinux.id; then
      cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id
    else
      echo >&2 "*** ERROR *** no vmlinux build ID! ***"
      exit 1
    fi
%endif

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    fgrep /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
      LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
    }

    collect_modules_list networking \
     			 'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|register_netdevice'
    collect_modules_list block \
     			 'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size'
    collect_modules_list drm \
    			 'drm_open|drm_init'
    collect_modules_list modesetting \
    			 'drm_crtc_init'

    # detect missing or incorrect license tags
    rm -f modinfo
    while read i
    do
      echo -n "${i#$RPM_BUILD_ROOT/lib/modules/$KernelVer/} " >> modinfo
      /sbin/modinfo -l $i >> modinfo
    done < modnames

    egrep -v \
    	  'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' \
	  modinfo && exit 1

    rm -f modinfo modnames

%if %{signmodules}
    # Save off the .tmp_versions/ directory.  We'll use it in the 
    # __debug_install_post macro below to sign the right things
    # Also save the signing keys so we actually sign the modules with the
    # right key.
    cp -r .tmp_versions .tmp_versions.sign${Flavour:+.${Flavour}}
    cp signing_key.priv signing_key.priv.sign${Flavour:+.${Flavour}}
    cp signing_key.x509 signing_key.x509.sign${Flavour:+.${Flavour}}
%endif

    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias ccwmap dep ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols usbmap
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

cd linux-%{version}-%{release}

%if %{with_debug}
%if %{with_up}
BuildKernel %make_target %kernel_image debug
%endif
%if %{with_pae}
BuildKernel %make_target %kernel_image PAEdebug
%endif
%endif

%if %{with_pae}
BuildKernel %make_target %kernel_image PAE
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image
%endif

%if %{with_smp}
BuildKernel %make_target %kernel_image smp
%endif

%if %{with_kdump}
BuildKernel vmlinux vmlinux kdump vmlinux
%endif

%if %{with_doc}
# Make the HTML and man pages.
make -j1  htmldocs mandocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

%define __modsign_install_post \
  if [ "%{signmodules}" == "1" ]; then \
    if [ "%{with_pae}" != "0" ]; then \
      mv signing_key.priv.sign.PAE signing_key.priv \
      mv signing_key.x509.sign.PAE signing_key.x509 \
      %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVERREL}.PAE/ \
    fi \
    if [ "%{with_debug}" != "0" ]; then \
      mv signing_key.priv.sign.debug signing_key.priv \
      mv signing_key.x509.sign.debug signing_key.x509 \
      %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVERREL}.debug/ \
    fi \
    if [ "%{with_pae_debug}" != "0" ]; then \
      mv signing_key.priv.sign.PAEdebug signing_key.priv \
      mv signing_key.x509.sign.PAEdebug signing_key.x509 \
      %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVERREL}.PAEdebug/ \
    fi \
    if [ "%{with_up}" != "0" ]; then \
      mv signing_key.priv.sign signing_key.priv \
      mv signing_key.x509.sign signing_key.x509 \
      %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVERREL}/ \
    fi \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
# TEMPORARY HACK: use the debuginfo in the build tree, passing it -g1 so as
# to strip out only debugging sections.
%define debug_package %{nil}
%if %{fancy_debuginfo}
%define __debug_install_post \
  %{_builddir}/find-debuginfo.sh %{debuginfo_args} -g1 %{_builddir}/%{?buildsubdir}\
%{nil}
%endif

%if %{with_debuginfo}

%define __debug_install_post \
  %{_builddir}/find-debuginfo.sh %{debuginfo_args} -g1 %{_builddir}/%{?buildsubdir}\
%{nil}

%ifnarch noarch
%global __debug_package 1
%files debuginfo-common
%defattr(-,root,root)
%dir /usr/src/debug
/usr/src/debug/kernel-%{version}/linux-%{kversion}-%{release}
%dir %{debuginfodir}
%dir %{debuginfodir}/%{image_install_path}
%dir %{debuginfodir}/lib
%dir %{debuginfodir}/lib/modules
%dir %{debuginfodir}/usr/src/kernels
%endif
%endif

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__modsign_install_post}

###
### install
###

%install
cd linux-%{version}-%{release}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{rpmversion}
man9dir=$RPM_BUILD_ROOT%{_datadir}/man/man9

# copy the source over
mkdir -p $docdir
tar -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

# Install man pages for the kernel API.
mkdir -p $man9dir
find Documentation/DocBook/man -name '*.9.gz' -print0 |
xargs -0 --no-run-if-empty %{__install} -m 444 -t $man9dir $m
for f in $man9dir/*.9.gz; do mv "$f" "${f%.9.gz}.9uek.gz"; done
ls $man9dir | grep -q '' || > $man9dir/BROKEN
%endif

%ifnarch noarch
# perf shell wrapper
mkdir -p $RPM_BUILD_ROOT/usr/sbin/
cp $RPM_SOURCE_DIR/perf $RPM_BUILD_ROOT/usr/sbin/perf
chmod 0755 $RPM_BUILD_ROOT/usr/sbin/perf
%endif

%ifarch x86_64 %{all_x86}
# x86_energy_perf_policy shell wrapper
mkdir -p $RPM_BUILD_ROOT/usr/sbin/
cp $RPM_SOURCE_DIR/x86_energy_perf_policy $RPM_BUILD_ROOT/usr/sbin/x86_energy_perf_policy
chmod 0755 $RPM_BUILD_ROOT/usr/sbin/x86_energy_perf_policy
%endif


%if %{with_headers}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Do headers_check but don't die if it fails.
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_check \
     > hdrwarnings.txt || :
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
     	-name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h

# these are provided by drm-devel
rm -rf $RPM_BUILD_ROOT/usr/include/drm
%endif

%if %{with_firmware}
mkdir -p $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}
make INSTALL_FW_PATH=$RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release} firmware_install
%endif

%if %{with_bootwrapper}
make DESTDIR=$RPM_BUILD_ROOT bootwrapper_install WRAPPER_OBJDIR=%{_libdir}/kernel-wrapper WRAPPER_DTSDIR=%{_libdir}/kernel-wrapper/dts
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{kversion}-%{release}.%{_arch}%{?1:.%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*.fc*.*/$f $f\
     done)\
fi\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1}}\
%{_sbindir}/new-kernel-pkg --package kernel%{?1:-%{1}} --mkinitrd --dracut --depmod --update %{KVERREL}%{?1:.%{1}} || exit $?\
%{_sbindir}/new-kernel-pkg --package kernel%{?1:-%{1}} --rpmposttrans %{KVERREL}%{?1:.%{1}} || exit $?\
if [ -x /sbin/weak-modules ]\
then\
    /sbin/weak-modules --add-kernel %{KVERREL}%{?1:.%{1}} || exit $?\
fi\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(uv:r:) \
%{expand:%%kernel_devel_post %{!-u:%{?-v*}}}\
%{expand:%%kernel_variant_posttrans %{!-u:%{?-v*}}}\
%{expand:%%post %{!-u:%{?-v*}}}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
if grep --silent '^hwcap 0 nosegneg$' /etc/ld.so.conf.d/kernel-*.conf 2> /dev/null; then\
  sed -i '/^hwcap 0 nosegneg$/ s/0/1/' /etc/ld.so.conf.d/kernel-*.conf\
fi\
%{_sbindir}/new-kernel-pkg --package kernel%{?-v:-%{-v*}} --install %{KVERREL}%{!-u:%{?-v:.%{-v*}}} || exit $?\
ln -sf /lib/firmware/%{rpmversion}-%{pkg_release} /lib/firmware/%{rpmversion}-%{pkg_release}.%{_target_cpu} \
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1}}\
%{_sbindir}/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}%{?1:.%{1}} || exit $?\
if [ -x /sbin/weak-modules ]\
then\
    /sbin/weak-modules --remove-kernel %{KVERREL}%{?1:.%{1}} || exit $?\
   rm -f /lib/firmware/%{rpmversion}-%{pkg_release}.%{_target_cpu} \
fi\
%{nil}

#
# This macro defines a %%pre script for a kernel package.
#	%%kernel_variant_pre <subpackage>
#
%define kernel_variant_pre() \
%{expand:%%pre %{?1}}\
message="Change references of /dev/hd in /etc/fstab to disk label"\
if [ -f /etc/fstab ]\
then\
awk '($2=="/boot")&&/^\\/dev\\/hd/{print $1}' /etc/fstab | egrep -q "^/dev/hd"\
bdretval=$?\
awk '($2=="/")&&/^\\/dev\\/hd/{print $1}' /etc/fstab | egrep -q "^/dev/hd"\
rdretval=$?\
awk '($2=="/boot")&&/^LABEL=/{print $1}' /etc/fstab | egrep -q "^LABEL="\
blretval=$?\
awk '($2=="/")&&/^LABEL=/{print $1}' /etc/fstab | egrep -q "^LABEL="\
rlretval=$?\
if [ $bdretval == 0 ] || [ $rdretval == 0 ]\
then\
echo -e $message\
exit 1\
elif [ $blretval == 0 ] && [ $rlretval == 0 ]\
then\
grep -v "^#" /etc/fstab | egrep -q "/dev/hd"\
if [ $? == 0 ]\
then\
echo -e $message\
fi\
elif [ $blretval == 0 ] && [ $rdretval != 0 ]\
then\
grep -v "^#" /etc/fstab | egrep -q "/dev/hd"\
if [ $? == 0 ]\
then\
echo -e $message\
fi\
elif [ $bdretval != 0 ] && [ $rlretval == 0 ]\
then\
grep -v "^#" /etc/fstab | egrep -q "/dev/hd"\
if [ $? == 0 ]\
then\
echo -e $message\
fi\
elif [ $bdretval != 0 ] && [ $rdretval != 0 ]\
then\
grep -v "^#" /etc/fstab | egrep -q "/dev/hd"\
if [ $? == 0 ]\
then\
echo -e $message\
fi\
fi\
fi\
%{nil}

%kernel_variant_pre
%kernel_variant_preun
%ifarch x86_64
%kernel_variant_post -u -v uek -r (kernel%{variant}|kernel%{variant}-debug|kernel-ovs)
%else
%kernel_variant_post -u -v uek -r (kernel%{variant}|kernel%{variant}-debug|kernel-ovs)
%endif

%kernel_variant_pre smp
%kernel_variant_preun smp
%kernel_variant_post -v smp

%kernel_variant_pre PAE
%kernel_variant_preun PAE
%kernel_variant_post -v PAE -r (kernel|kernel-smp|kernel-xen)

%kernel_variant_pre debug
%kernel_variant_preun debug
%kernel_variant_post -v debug

%kernel_variant_post -v PAEdebug -r (kernel|kernel-smp|kernel-xen)
%kernel_variant_preun PAEdebug
%kernel_variant_pre PAEdebug

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{with_firmware}
%files firmware
%defattr(-,root,root)
/lib/firmware/*
%doc linux-%{version}-%{release}/firmware/WHENCE
%endif

%if %{with_bootwrapper}
%files bootwrapper
%defattr(-,root,root)
/usr/sbin/*
%{_libdir}/kernel-wrapper
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}
%{_datadir}/man/man9/*
%endif

# This is %{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{1}\
%{expand:%%files %{?2}}\
%defattr(-,root,root)\
/%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?2:.%{2}}\
%if %{with_fips} \
/%{image_install_path}/.vmlinuz-%{KVERREL}%{?2:.%{2}}.hmac \
%endif \
/boot/System.map-%{KVERREL}%{?2:.%{2}}\
/boot/symvers-%{KVERREL}%{?2:.%{2}}.gz\
/boot/config-%{KVERREL}%{?2:.%{2}}\
%dir /lib/modules/%{KVERREL}%{?2:.%{2}}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/kernel\
/lib/modules/%{KVERREL}%{?2:.%{2}}/build\
/lib/modules/%{KVERREL}%{?2:.%{2}}/source\
/lib/modules/%{KVERREL}%{?2:.%{2}}/extra\
/lib/modules/%{KVERREL}%{?2:.%{2}}/updates\
/lib/modules/%{KVERREL}%{?2:.%{2}}/weak-updates\
%ifarch %{vdso_arches}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/vdso\
/etc/ld.so.conf.d/kernel-%{KVERREL}%{?2:.%{2}}.conf\
%endif\
/lib/modules/%{KVERREL}%{?2:.%{2}}/modules.*\
/usr/libexec/perf.%{KVERREL}%{?2:.%{2}}\
/usr/sbin/perf\
%ifnarch sparc64\
/usr/libexec/x86_energy_perf_policy.%{KVERREL}%{?2:.%{2}}\
/usr/sbin/x86_energy_perf_policy\
%endif\
%ghost /boot/initramfs-%{KVERREL}%{?2:.%{2}}.img\
%{expand:%%files %{?2:%{2}-}devel}\
%defattr(-,root,root)\
%dir /usr/src/kernels\
%verify(not mtime) /usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
%if %{with_debuginfo}\
%ifnarch noarch\
%if %{fancy_debuginfo}\
%{expand:%%files -f debuginfo%{?2}.list %{?2:%{2}-}debuginfo}\
%else\
%{expand:%%files %{?2:%{2}-}debuginfo}\
%endif\
%defattr(-,root,root)\
%if !%{fancy_debuginfo}\
%if "%{elf_image_install_path}" != ""\
%{debuginfodir}/%{elf_image_install_path}/*-%{KVERREL}%{?2:.%{2}}.debug\
%endif\
%{debuginfodir}/lib/modules/%{KVERREL}%{?2:.%{2}}\
%{debuginfodir}/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
# % {debuginfodir}/usr/bin/%{KVERREL}%{?2:.%{2}}\
%endif\
%endif\
%endif\
%endif\
%{nil}


%kernel_variant_files %{with_up}
%kernel_variant_files %{with_smp} smp
%if %{with_up}
%kernel_variant_files %{with_debug} debug
%endif
%kernel_variant_files %{with_pae} PAE
%kernel_variant_files %{with_pae_debug} PAEdebug
%kernel_variant_files -k vmlinux %{with_kdump} kdump

%changelog
* Wed Mar 11 2015 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-55.1.8.el7uek] 
- kvm: fix excessive pages un-pinning in kvm_iommu_map error path. (Quentin Casasnovas)  [Orabug: 20687313]  {CVE-2014-3601} {CVE-2014-8369} {CVE-2014-3601} 

* Tue Mar 10 2015 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-55.1.7.el7uek] 
- ttusb-dec: buffer overflow in ioctl (Dan Carpenter)  [Orabug: 20673376]  {CVE-2014-8884} 
- mm: Fix NULL pointer dereference in madvise(MADV_WILLNEED) support (Kirill A. Shutemov)  [Orabug: 20673281]  {CVE-2014-8173} 
- netfilter: conntrack: disable generic tracking for known protocols (Florian Westphal)  [Orabug: 20673239]  {CVE-2014-8160} 
- tracing/syscalls: Ignore numbers outside NR_syscalls' range (Rabin Vincent)  [Orabug: 20673163]  {CVE-2014-7826} 

* Wed Feb 11 2015 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-55.1.6.el7uek] 
- uek-rpm: ol7: update update-el to 7.1 (Guangyu Sun)  [Orabug: 20524579]  

* Wed Jan 28 2015 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-55.1.5.el7uek] 
- [CIFS] Possible null ptr deref in SMB2_tcon (Steve French)  [Orabug: 20433140]  {CVE-2014-7145} 

* Tue Jan 27 2015 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-55.1.4.el7uek] 
- net: sctp: fix NULL pointer dereference in af->from_addr_param on malformed packet (Daniel Borkmann)  [Orabug: 20425332]  {CVE-2014-7841} 

* Fri Dec 19 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-55.1.3.el7uek] 
- ACPI: x2apic entry ignored (Cathy Avery)  [Orabug: 19475776]  
- i40e: relax the firmware API version check (Shannon Nelson)  [Orabug: 20216831]  
- x86, fpu: remove the logic of non-eager fpu mem allocation at the first usage (Annie Li)  [Orabug: 20232585]  
- iommu/{vt-d,amd}: Remove multifunction assumption around grouping (Alex Williamson)  [Orabug: 20192796]  

* Wed Dec 17 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-55.1.2.el7uek] 
- isofs: Fix unbounded recursion when processing relocated directories (Jan Kara)  [Orabug: 20224059]  {CVE-2014-5471} {CVE-2014-5472} 
- x86_64, traps: Stop using IST for #SS (Andy Lutomirski)  [Orabug: 20224027]  {CVE-2014-9090} {CVE-2014-9322} 

* Wed Dec 10 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-55.1.1.el7uek] 
- ALSA: control: Protect user controls against concurrent access (Lars-Peter Clausen)  [Orabug: 20192540]  {CVE-2014-4652} 
- target/rd: Refactor rd_build_device_space + rd_release_device_space (Nicholas Bellinger)  [Orabug: 20192516]  {CVE-2014-4027} 
- HID: logitech: perform bounds checking on device_id early enough (Jiri Kosina)  [Orabug: 20192477]  {CVE-2014-3182} 
- udf: Avoid infinite loop when processing indirect ICBs (Jan Kara)  [Orabug: 20192448]  {CVE-2014-6410} 
- ALSA: control: Make sure that id->index does not overflow (Lars-Peter Clausen)  [Orabug: 20192416]  {CVE-2014-4656} 
- ALSA: control: Handle numid overflow (Lars-Peter Clausen)  [Orabug: 20192367]  {CVE-2014-4656} 
- HID: picolcd: sanity check report size in raw_event() callback (Jiri Kosina)  [Orabug: 20192208]  {CVE-2014-3186} 
- net: sctp: fix remote memory pressure from excessive queueing (Daniel Borkmann)  [Orabug: 20192058]  {CVE-2014-3688} 

* Mon Dec 1 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-55.el7uek] 
- freezer: set PF_SUSPEND_TASK flag on tasks that call freeze_processes (Colin Cross)  [Orabug: 20082843]  

* Thu Nov 13 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-54.el7uek] 
- netfilter: nf_nat: fix oops on netns removal (Florian Westphal)  [Orabug: 19988779]  
- tcp: tsq: restore minimal amount of queueing (Eric Dumazet)  [Orabug: 19909542]  
- qedf: Fixes for compilation issues on oracle uek3r4. (Saurav Kashyap)  [Orabug: 20027243]  
- qla2xxx: fix wrongly report "PCI EEH busy" when get_thermal_temp (Vaughan Cao)  [Orabug: 19916135]  
- Revert "ib_cm: reduce latency when destroying large number of ids" (Guangyu Sun)  [Orabug: 20012864]  
- Revert "rds: avoid duplicate connection drops for active bonding" (Guangyu Sun)  [Orabug: 20012864]  
- xen/pciback: Restore configuration space when detaching from a guest. (Konrad Rzeszutek Wilk)  [Orabug: 19970142]  
- cpufreq: remove race while accessing cur_policy (Bibek Basu)  [Orabug: 19945473]  
- cpufreq: serialize calls to __cpufreq_governor() (Viresh Kumar)  [Orabug: 19945473]  
- cpufreq: don't allow governor limits to be changed when it is disabled (Viresh Kumar)  [Orabug: 19945473]  
- net: sctp: fix panic on duplicate ASCONF chunks (Daniel Borkmann)  [Orabug: 19953088]  {CVE-2014-3687} 
- net: sctp: fix skb_over_panic when receiving malformed ASCONF chunks (Daniel Borkmann)  [Orabug: 19953087]  {CVE-2014-3673} 
- perf/x86: Check all MSRs before passing hw check (George Dunlap)  [Orabug: 19803968]  
- o2dlm: fix NULL pointer dereference in o2dlm_blocking_ast_wrapper (Srinivas Eeda)  [Orabug: 19825227]  
- RDS: add module parameter to allow module unload or not (Wengang Wang)  [Orabug: 19927376]  
- dwarf2ctf: don't use O_PATH in rel_abs_file_name(). (Jamie Iles)  [Orabug: 19957565]  
- dwarf2ctf: don't leak directory fd. (Jamie Iles)  [Orabug: 19957565]  

* Tue Nov 4 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-53.el7uek] 
- net: reset mac header in dev_start_xmit() (Eric Dumazet)  [Orabug: 19951043]  

* Mon Nov 3 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-52.el7uek] 
- xen/efi: rebased version of xen.efi (Jan Beulich)  [Orabug: 19878307]  

* Fri Oct 31 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-51.el7uek] 
- config: enable pm80xx module (Guangyu Sun)  [Orabug: 19890236]  
- free ib_device related resource (Wengang Wang)  [Orabug: 19479464]  
- srq initialization and cleanup -v3.1 (Wengang Wang)  [Orabug: 19010606]  
- rds: avoid duplicate connection drops for active bonding (Ajaykumar Hotchandani)  [Orabug: 19870095]  
- ib_cm: reduce latency when destroying large number of ids (Ajaykumar Hotchandani)  [Orabug: 19870101]  
- IPoIB: Change default IPOIB_RX_RING_SIZE to 2048 (Chien-Hua Yen)  [Orabug: 19870157]  
- ipv6: ip6_dst_check needs to check for expired dst_entries (Hannes Frederic Sowa)  [Orabug: 19073604]  
- netxen: Fix bug in Tx completion path. (Manish Chopra)  [Orabug: 19877613]  
- netxen: Fix BUG "sleeping function called from invalid context" (Manish Chopra)  [Orabug: 19877613]  
- drivers/net: Convert remaining uses of pr_warning to pr_warn (Joe Perches)  [Orabug: 19877613]  
- treewide: Fix typo in printk (Masanari Iida)  [Orabug: 19877613]  
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (Benoit Taine)  [Orabug: 19877613]  
- bnx2fc: upgrade to 2.5.5.1 (Vaughan Cao)  [Orabug: 19892175]  
- bnx2i: upgrade to 2.7.10.31d1 (Vaughan Cao)  [Orabug: 19892173]  
- bnx2x: upgrade to 1.710.51 (Vaughan Cao)  [Orabug: 19877629]  
- cnic: upgrade to 2.5.20b (Vaughan Cao)  [Orabug: 19877628]  
- bnx2: upgrade to 2.2.5i (Vaughan Cao)  [Orabug: 19877628]  
- Update lpfc version for 10.2.8061.0 driver release. (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8061.0: Fix ExpressLane priority setup (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8061.0: Removed obsolete PCI IDs from the driver. (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8061.0: Fix for initializing RRQ bitmap (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8061.0: Fix for cleaning up stale ring flag and sp_queue_event entries. (Dick Kennedy)  [Orabug: 19877605]  
- lpfc: Add iotag memory barrier (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8060.0: Update Copyright on changed files from 8.3.45 patches (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8060.0: Fixed locking for scsi task management commands (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8060.0: Convert runtime references to old xlane cfg param to fof cfg param (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8060: Fix FW dump using sysfs (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8060.0: Fix SLI4 s abort loop to process all FCP rings and under ring_lock (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8060.0: Fixed kernel panic in lpfc_abort_handler (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8060.0: Fix locking for postbufq when freeing (Dick Kennedy)  [Orabug: 19877605]  
- lpfc: remove self-assignments (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 8.3.43: use NULL instead of 0 for pointer (Daeseok Youn)  [Orabug: 19877605]  
- lpfc 10.2.8060.0: Fix locking for lpfc_hba_down_post (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 10.2.8060.0: Fix dynamic transitions of FirstBurst from on to off (Dick Kennedy)  [Orabug: 19877605]  
- lpfc 8.3.45: Fixed crash during driver unload. (James Smart)  [Orabug: 19877605]  
- lpfc 8.3.45: Fixed driver error messages after firmware download (James Smart)  [Orabug: 19877605]  
- lpfc 8.3.45: Fixed missing initialization for task management IOCBs (James Smart)  [Orabug: 19877605]  
- lpfc 8.3.45: Fix sysfs buffer overrun in read of lpfc_fcp_cpu_map for 128 CPUs. (James Smart)  [Orabug: 19877605]  
- lpfc 8.3.45: Incorporate changes to use reason in change_queue_depth function. (James Smart)  [Orabug: 19877605]  
- lpfc 8.3.45: Incorporated support of a low-latency io path (James Smart)  [Orabug: 19877605]  
- lpfc 8.3.45: Added dport mailbox pass through support. (James Smart)  [Orabug: 19877605]  
- be2iscsi : Bump the driver version (John Soni Jose)  [Orabug: 19877611]  
- be2iscsi : Fix kernel panic during reboot/shutdown (John Soni Jose)  [Orabug: 19877611]  
- be2iscsi: Fix processing CQE before connection resources are freed (Jayamohan Kallickal)  [Orabug: 19877611]  
- be2iscsi: Fix updating the boot enteries in sysfs (Jayamohan Kallickal)  [Orabug: 19877611]  
- be2iscsi: Fix the copyright year (Jayamohan Kallickal)  [Orabug: 19877611]  
- be2iscsi: Fix the sparse warning introduced in previous submission (Jayamohan Kallickal)  [Orabug: 19877611]  
- turbostat: fix build breakage (Brian Maly)  [Orabug: 19894618]  
- kvm: vmx: handle invvpid vm exit gracefully (Petr Matousek)  [Orabug: 19906290]  {CVE-2014-3646} 
- nEPT: Nested INVEPT (Nadav Har'El)  [Orabug: 19905739]  {CVE-2014-3645} 
- KVM: x86: Improve thread safety in pit (Andy Honig)  [Orabug: 19905575]  {CVE-2014-3611} 

* Tue Oct 28 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-50.el7uek] 
- NVMe: Do not over allocate for discard requests (Keith Busch)  [Orabug: 19791123]  
- NVMe: Do not open disks that are being deleted (Keith Busch)  [Orabug: 19791123]  
- NVMe: Clear QUEUE_FLAG_STACKABLE (Keith Busch)  [Orabug: 19791123]  
- NVMe: Fix device probe waiting on kthread (Keith Busch)  [Orabug: 19791123]  
- NVMe: Updates for 1.1 spec (Keith Busch)  [Orabug: 19791123]  
- NVMe: Passthrough IOCTL for IO commands (Keith Busch)  [Orabug: 19791123]  
- NVMe: Add revalidate_disk callback (Keith Busch)  [Orabug: 19791123]  
- NVMe: Fix nvmeq waitqueue entry initialization (Keith Busch)  [Orabug: 19791123]  
- NVMe: Translate NVMe status to errno (Keith Busch)  [Orabug: 19791123]  
- NVMe: Fix SG_IO status values (Keith Busch)  [Orabug: 19791123]  
- NVMe: Remove duplicate compat SG_IO code (Keith Busch)  [Orabug: 19791123]  
- NVMe: Reference count pci device (Keith Busch)  [Orabug: 19791123]  
- nvme: Replace rcu_assign_pointer() with RCU_INIT_POINTER() (Andreea-Cristina Bernat)  [Orabug: 19791123]  
- NVMe: Correctly handle IOCTL_SUBMIT_IO when cpus > online queues (Sam Bradshaw)  [Orabug: 19791123]  
- NVMe: Fix filesystem sync deadlock on removal (Keith Busch)  [Orabug: 19791123]  
- NVMe: Add shutdown timeout as module parameter. (Dan McLeran)  [Orabug: 19791123]  
- NVMe: Skip orderly shutdown on failed devices (Keith Busch)  [Orabug: 19791123]  
- NVMe: Whitespace fixes (Keith Busch)  [Orabug: 19791123]  
- NVMe: Handling devices incapable of I/O (Keith Busch)  [Orabug: 19791123]  
- NVMe: Change nvme_enable_ctrl to set EN and manage CC thru ctrl_config. (Dan McLeran)  [Orabug: 19791123]  
- NVMe: Mismatched host/device page size support (Keith Busch)  [Orabug: 19791123]  
- NVMe: Update list of status codes (Matthew Wilcox)  [Orabug: 19791123]  
- NVMe: Async event request (Keith Busch)  [Orabug: 19791123]  
- qlge: Fix compilation warning (Harish Patil)  [Orabug: 19877615]  
- qlge: Fix TSO for non-accelerated vlan traffic (Vlad Yasevich)  [Orabug: 19877615]  
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (Benoit Taine)  [Orabug: 19877615]  
- i40e: Update flow director error messages to reduce user confusion (Carolyn Wyborny)  [Orabug: 19882061]  
- i40evf: enable module build (Brian Maly)  [Orabug: 19528533]  
- i40e/i40evf: Bump build versions (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: Tweak for-loop in i40e_ethtool.c (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: Cleanup if/else statements (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: abstract the close path for better netdev vsis (Shannon Nelson)  [Orabug: 19528533]  
- i40e/i40evf: add tracking to NVM busy state (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Fix an issue with displaying IPv4 FD filters (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Remove a FW workaround (Catherine Sullivan)  [Orabug: 19528533]  
- i40e/i40evf: Bump build versions (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: Enable VF Tx bandwidth setting (Mitch Williams)  [Orabug: 19528533]  
- i40e: Reset the VF upon conflicting VLAN configuration (Greg Rose)  [Orabug: 19528533]  
- i40e: remove open-coded skb_cow_head (Francois Romieu)  [Orabug: 19528533]  
- i40evf: program RSS LUT correctly (Mitch A Williams)  [Orabug: 19528533]  
- i40evf: remove open-coded skb_cow_head (Francois Romieu)  [Orabug: 19528533]  
- i40e: Remove casts of pointer to same type (Joe Perches)  [Orabug: 19528533]  
- i40e/i40evf: Remove addressof casts to same type (Joe Perches)  [Orabug: 19528533]  
- i40e: fix function kernel doc description (Jean Sacren)  [Orabug: 19528533]  
- i40e: Use DEBUG_FD message level for an FD message (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e/i40evf: Add an FD message level (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: check for netdev before debugfs use (Shannon Nelson)  [Orabug: 19528533]  
- i40evf: remove double space after return (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Add functionality for FD SB to drop packets (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Cleanup in FDIR SB ethtool code (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: eeprom integrity check on load and empr (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Make the alloc and free queue vector calls orthogonal (Greg Rose)  [Orabug: 19528533]  
- i40evf: fix oops in watchdog handler (Mitch Williams)  [Orabug: 19528533]  
- i40e: Delete ATR filter on RST (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40evf: clean up init error messages (Mitch Williams)  [Orabug: 19528533]  
- i40evf: don't shut down admin queue on error (Mitch Williams)  [Orabug: 19528533]  
- i40e: Fix a message string (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e/i40evf: Add EEE LPI stats (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e/i40evf: Bump build versions (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: potential array underflow in i40e_vc_process_vf_msg() (Dan Carpenter)  [Orabug: 19528533]  
- i40e/i40evf: reduce context descriptors (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e/i40evf: enable hardware feature head write back (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Patch to enable Ethtool/netdev feature flag for NTUPLE control (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40evf: use min_t (Mitch Williams)  [Orabug: 19528533]  
- i40evf: correctly program RSS HLUT table (Mitch Williams)  [Orabug: 19528533]  
- net/i40e: Avoid double setting of NETIF_F_SG for the HW encapsulation feature mask (Or Gerlitz)  [Orabug: 19528533]  
- i40evf: Rename i40e_ptype_lookup i40evf_ptype_lookup (Eric W Biederman)  [Orabug: 19528533]  
- i40e: Don't receive packets when the napi budget == 0 (Eric W. Biederman)  [Orabug: 19528533]  
- i40e/i40evf: Use correct number of VF vectors (Mitch Williams)  [Orabug: 19528533]  
- i40e: Let MDD events be handled by MDD handler (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Bug fix for FDIR replay logic (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: add missing variable to i40e_ethtool (Brian Maly)  [Orabug: 19528533]  
- i40e: Add code to handle FD table full condition (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Define a new state variable to keep track of feature auto disable (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Fix function comments (Akeem G Abodunrin)  [Orabug: 19528533]  
- i40e: make string references to q be queue (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e/i40evf: Some flow director HW definition fixes (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Fix a bug in the update logic for FDIR SB filter. (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: delete netdev after deleting napi and vectors (Shannon Nelson)  [Orabug: 19528533]  
- i40e/i40evf: Bump pf&vf build versions (Catherine Sullivan)  [Orabug: 19528533]  
- i40e/i40evf: carefully fill tx ring (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: fix nvm version and remove firmware report (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Remove a redundant filter addition (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: count timeout events (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Remove a FW workaround for Number of MSIX vectors (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: clean up comment style (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Prevent overflow due to kzalloc (Akeem G Abodunrin)  [Orabug: 19528533]  
- i40e: Flow Director sideband accounting (Joseph Gasparakis)  [Orabug: 19528533]  
- i40evf: Enable the ndo_set_features netdev op (Greg Rose)  [Orabug: 19528533]  
- i40e and i40evf: Bump driver versions (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: Change MSIX to MSI-X (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: tighten up ring enable/disable flow (Mitch Williams)  [Orabug: 19528533]  
- i40e: remove unnecessary delay (Mitch Williams)  [Orabug: 19528533]  
- i40evf: remove errant space (Mitch A Williams)  [Orabug: 19528533]  
- i40evf: update version and copyright date (Mitch Williams)  [Orabug: 19528533]  
- i40evf: store ring size in ring structs (Mitch Williams)  [Orabug: 19528533]  
- i40evf: don't guess device name (Mitch Williams)  [Orabug: 19528533]  
- i40evf: remove bogus comment (Mitch Williams)  [Orabug: 19528533]  
- i40evf: fix up strings in init task (Mitch Williams)  [Orabug: 19528533]  
- i40evf: get rid of pci_using_dac (Mitch Williams)  [Orabug: 19528533]  
- i40evf: fix multiple crashes on remove (Mitch Williams)  [Orabug: 19528533]  
- i40evf: remove VLAN filters on close (Mitch Williams)  [Orabug: 19528533]  
- i40evf: request reset on tx hang (Mitch Williams)  [Orabug: 19528533]  
- i40e: Use pci_enable_msix_range() instead of pci_enable_msix() (Alexander Gordeev)  [Orabug: 19528533]  
- net: i40evf: Remove duplicate include (Sachin Kamat)  [Orabug: 19528533]  
- i40evf: refactor reset handling (Mitch Williams)  [Orabug: 19528533]  
- i40evf: change type of flags variable (Mitch Williams)  [Orabug: 19528533]  
- i40evf: don't store unnecessary array of strings (Mitch Williams)  [Orabug: 19528533]  
- i40evf: fix bogus comment (Mitch Williams)  [Orabug: 19528533]  
- i40evf: clean up adapter struct (Mitch Williams)  [Orabug: 19528533]  
- i40e: don't handle VF reset on unload (Mitch Williams)  [Orabug: 19528533]  
- i40e: enable extant VFs (Mitch Williams)  [Orabug: 19528533]  
- i40e: reset VFs after PF reset (Mitch Williams)  [Orabug: 19528533]  
- i40e: set VF state to active when reset is complete (Mitch Williams)  [Orabug: 19528533]  
- i40e: remove dead code (Mitch Williams)  [Orabug: 19528533]  
- i40e: Setting i40e_down bit for tx_timeout (Akeem G Abodunrin)  [Orabug: 19528533]  
- i40evf: clean up memsets (Mitch Williams)  [Orabug: 19528533]  
- i40evf: trivial fixes (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: bump driver version (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: spelling error (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: refactor flow director (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: rename defines (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: whitespace fixes (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Change firmware workaround (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: fix compile warning on checksum_local (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: updates to AdminQ interface (Shannon Nelson)  [Orabug: 19528533]  
- i40e: check desc pointer before printing (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Remove autogenerated Module.symvers file. (David S. Miller)  [Orabug: 19528533]  
- i40e: Retain MAC filters on port VLAN deletion (Greg Rose)  [Orabug: 19528533]  
- i40e: Warn admin to reload VF driver on port VLAN configuration (Greg Rose)  [Orabug: 19528533]  
- i40e: Bump version number (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: trivial cleanup (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: whitespace fixes (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: make message meaningful (Mitch Williams)  [Orabug: 19528533]  
- i40e: associate VMDq queue with VM type (Shannon Nelson)  [Orabug: 19528533]  
- i40e: remove extra register write (Mitch Williams)  [Orabug: 19528533]  
- i40e: Bump version (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: fix log message wording (Shannon Nelson)  [Orabug: 19528533]  
- i40e: enable PTP (Jacob Keller)  [Orabug: 19528533]  
- i40e: call clear_pxe after adminq is initialized (Shannon Nelson)  [Orabug: 19528533]  
- i40e: clear qtx_head before enabling Tx queue (Shannon Nelson)  [Orabug: 19528533]  
- i40e: adjust ITR max and min values (Shannon Nelson)  [Orabug: 19528533]  
- i40e: check for possible incorrect ipv6 checksum (Shannon Nelson)  [Orabug: 19528533]  
- i40e: allow VF to remove any MAC filter (Mitch Williams)  [Orabug: 19528533]  
- i40e: do not bail when disabling if Tx queue disable fails (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Setting queue count to 1 using ethtool is valid (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Cleanup Doxygen warnings (Jeff Kirsher)  [Orabug: 19528533]  
- i40e: fix long lines (Mitch Williams)  [Orabug: 19528533]  
- i40e: Bump version (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: Update the Current NVM version Low value (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: drop unused macros (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: use assignment instead of memcpy (Mitch Williams)  [Orabug: 19528533]  
- i40e: Turn flow director off in MFP mode (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: Add a dummy packet template (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: fix spelling errors (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: trivial: formatting and checkpatch fixes (Mitch Williams)  [Orabug: 19528533]  
- i40e: shorten wordy fields (Mitch Williams)  [Orabug: 19528533]  
- i40e: accept pf to pf adminq messages (Shannon Nelson)  [Orabug: 19528533]  
- i40e: remove interrupt on AQ error (Shannon Nelson)  [Orabug: 19528533]  
- i40e: release NVM resource reservation on startup (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Cleanup reconfig rss path (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: disable packet split (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: add a comment on barrier and fix panic on reset (Greg Rose)  [Orabug: 19528533]  
- i40e: Fix MAC format in Write MAC address AQ cmd (Kamil Krawczyk)  [Orabug: 19528533]  
- i40e: Fix GPL header (Greg Rose)  [Orabug: 19528533]  
- i40e: use kernel specific defines (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Re-enable interrupt on ICR0 (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: correctly setup ARQ descriptors (Mitch Williams)  [Orabug: 19528533]  
- i40e: remove redundant AQ enable (Kamil Krawczyk)  [Orabug: 19528533]  
- i40e: Enable/Disable PF switch LB on SR-IOV configure changes (Greg Rose)  [Orabug: 19528533]  
- i40e: whitespace paren and comment tweaks (Shannon Nelson)  [Orabug: 19528533]  
- i40e: rework shadow ram read functions (Shannon Nelson)  [Orabug: 19528533]  
- i40e: check MAC type before any REG access (Shannon Nelson)  [Orabug: 19528533]  
- i40e: move PF ID init from PF reset to SC init (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Reduce range of interrupt reg in reg test (Shannon Nelson)  [Orabug: 19528533]  
- i40e: update firmware api to 1.1 (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Add code to wait for FW to complete in reset path (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Bump version (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: Allow VF to set already assigned MAC address (Greg Rose)  [Orabug: 19528533]  
- i40e: Stop accepting any VLAN tag on VLAN 0 filter set (Greg Rose)  [Orabug: 19528533]  
- i40e: Do not enable broadcast promiscuous by default (Greg Rose)  [Orabug: 19528533]  
- i40e: Expose AQ debugfs hooks (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Do not allow AQ calls from ndo-ops (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: check asq alive before notify (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Admin queue shutdown fixes (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Hide the Port VLAN VLAN ID (Greg Rose)  [Orabug: 19528533]  
- i40e: use correct struct for get and update vsi params (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Fix VF driver MAC address configuration (Greg Rose)  [Orabug: 19528533]  
- i40e: support VFs on PFs other than 0 (Mitch Williams)  [Orabug: 19528533]  
- i40e: acknowledge VFLR when disabling SR-IOV (Mitch Williams)  [Orabug: 19528533]  
- i40e: don't allocate zero size (Mitch Williams)  [Orabug: 19528533]  
- i40e: use struct assign instead of memcpy (Mitch Williams)  [Orabug: 19528533]  
- i40e: Do not enable default port on the VEB (Greg Rose)  [Orabug: 19528533]  
- i40e: avoid unnecessary register read (Mitch Williams)  [Orabug: 19528533]  
- i40e: fix whitespace (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Fix SR-IOV VF port VLAN (Greg Rose)  [Orabug: 19528533]  
- i40e: Record dma buffer info for dummy packets (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: remove un-necessary io-write (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Remove unnecessary prototypes (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: I40E_FLAG_MQ_ENABLED is not used (Neerav Parikh)  [Orabug: 19528533]  
- i40e: Fix ring allocation (Neerav Parikh)  [Orabug: 19528533]  
- i40e: catch unset q_vector (Shannon Nelson)  [Orabug: 19528533]  
- i40e: keep allocated memory in structs (David Cassard)  [Orabug: 19528533]  
- i40e: fix error handling when alloc of vsi array fails (Shannon Nelson)  [Orabug: 19528533]  
- i40e: reinit buffer size each time (Mitch Williams)  [Orabug: 19528533]  
- i40e: use functions to enable and disable icr 0 (Mitch Williams)  [Orabug: 19528533]  
- i40e: add header file flag _I40E_TXRX_H_ (Vasu Dev)  [Orabug: 19528533]  
- i40e: guard against vf message races (Mitch Williams)  [Orabug: 19528533]  
- i40e: fix constant cast issues (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Change the ethtool NVM read method to use AQ (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: fix mac address checking (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Dump the whole NVM, not half (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: report VF MAC addresses correctly (Mitch Williams)  [Orabug: 19528533]  
- i40e: update led set args (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: make a define from a large constant (Mitch Williams)  [Orabug: 19528533]  
- i40e: be more informative (Mitch Williams)  [Orabug: 19528533]  
- i40e: fix error return (Mitch Williams)  [Orabug: 19528533]  
- i40e: remove chatty log messages (Mitch Williams)  [Orabug: 19528533]  
- i40e: remove redundant code (Mitch Williams)  [Orabug: 19528533]  
- i40e: refactor VF reset flow (Mitch Williams)  [Orabug: 19528533]  
- i40e: move i40e_reset_vf (Mitch Williams)  [Orabug: 19528533]  
- i40e: fix curly brace use and return type (Shannon Nelson)  [Orabug: 19528533]  
- i40e: add wake-on-lan support (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Suppress HMC error to Interrupt message level (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: using for_each_set_bit to simplify the code (Wei Yongjun)  [Orabug: 19528533]  
- i40e: make functions static and remove dead code (Stephen Hemminger)  [Orabug: 19528533]  
- i40e: Fix off by one in i40e_dbg_command_write (Alan Cox)  [Orabug: 19528533]  
- i40e: Bump version number (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: Fix wrong mask bits being used in misc interrupt (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: more print_hex_dump use (Shannon Nelson)  [Orabug: 19528533]  
- i40e: fix up scanf decoders (Shannon Nelson)  [Orabug: 19528533]  
- i40e: simplify error messages for dump descriptor (Shannon Nelson)  [Orabug: 19528533]  
- i40e: prevent null pointer exception in dump descriptor (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Fix dump output from debugfs calls (Neerav Parikh)  [Orabug: 19528533]  
- i40e: Remove FCoE in i40e_virtchnl_pf.c code (Neerav Parikh)  [Orabug: 19528533]  
- i40e: support for suspend and resume (Shannon Nelson)  [Orabug: 19528533]  
- i40e: rtnl_lock in reset path fixes (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Add basic support for get/set channels for RSS (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: function to reconfigure RSS queues and rebuild (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: reinit flow for the main VSI (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: use same number of queues as CPUs (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: trivial fixes (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: init flow control settings to disabled (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Tell the stack about our actual number of queues (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: fix pf reset after offline test (Shannon Nelson)  [Orabug: 19528533]  
- i40e: fix up some of the ethtool connection reporting (Brian Maly)  [Orabug: 19528533]  
- i40e: Bump version number (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: remove and fix confusing define name (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: complain about out-of-range descriptor request (Shannon Nelson)  [Orabug: 19528533]  
- i40e: loopback info and set loopback fix (Kamil Krawczyk)  [Orabug: 19528533]  
- i40e: restrict diag test messages (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Add a new variable to track number of pf instances (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: add num_VFs message (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: refactor ethtool tests (Shannon Nelson)  [Orabug: 19528533]  
- i40e: clear test state bit after all ethtool tests (Shannon Nelson)  [Orabug: 19528533]  
- i40e: only set up the rings to be used (Shannon Nelson)  [Orabug: 19528533]  
- i40e: Enable all PCTYPEs except FCOE for RSS. (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: refactor reset code (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: Bump version (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: whitespace (Jeff Kirsher)  [Orabug: 19528533]  
- i40e: enable early hardware support (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Add flag for L2 VEB filtering (Kevin Scott)  [Orabug: 19528533]  
- i40e: get media type during link info (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: check multi-bit state correctly (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: separate TSYNVALID and TSYNINDX fields in Rx descriptor (Jacob Keller)  [Orabug: 19528533]  
- i40e: sync header files with hardware (Anjali Singhai Jain)  [Orabug: 19528533]  
- i40e: restrict diag test length (Kamil Krawczyk)  [Orabug: 19528533]  
- i40e: add support for triggering EMPR (Shannon Nelson)  [Orabug: 19528533]  
- i40e: add interrupt test (Shannon Nelson)  [Orabug: 19528533]  
- i40e: default debug mask setting (Shannon Nelson)  [Orabug: 19528533]  
- i40e: fix debugging messages (Mitch Williams)  [Orabug: 19528533]  
- i40e: properly add VF MAC addresses (Mitch Williams)  [Orabug: 19528533]  
- i40e: retry call on timeout (Shannon Nelson)  [Orabug: 19528533]  
- i40e: select reset counters correctly (Shannon Nelson)  [Orabug: 19528533]  
- i40e: allow one more vector for VFs (Mitch Williams)  [Orabug: 19528533]  
- i40e: firmware version fields offsets update (Anjali Singhai jain)  [Orabug: 19528533]  
- i40e: simplify aq head-tail-len setups (Shannon Nelson)  [Orabug: 19528533]  
- i40e: clear AQ head and tail registers (Shannon Nelson)  [Orabug: 19528533]  
- i40e: register file updates (Anjali Singhai jain)  [Orabug: 19528533]  
- i40e: set pf_id based on device and function numbers (Christopher Pau)  [Orabug: 19528533]  
- i40e: fix null dereference (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: fix error return code in i40e_probe() (Wei Yongjun)  [Orabug: 19528533]  
- i40e: remove unused including <linux/version.h> (Wei Yongjun)  [Orabug: 19528533]  
- i40e: Bump version (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: use pf_id for pf function id in qtx_ctl (Shannon Nelson)  [Orabug: 19528533]  
- i40e: check vsi ptrs before dumping them (Shannon Nelson)  [Orabug: 19528533]  
- i40e: reorder block declarations in debugfs (Shannon Nelson)  [Orabug: 19528533]  
- i40e: tweaking icr0 handling for legacy irq (Shannon Nelson)  [Orabug: 19528533]  
- i40e: refactor fdir setup function (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: fix sign extension issue (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: fix use of untrusted scalar value warning (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: clamp debugfs nvm read command (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: debugfs fixups (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: fixup legacy interrupt handling (Shannon Nelson)  [Orabug: 19528533]  
- i40e: assign correct vector to VF (Mitch Williams)  [Orabug: 19528533]  
- i40e: don't free nonexistent rings (Mitch Williams)  [Orabug: 19528533]  
- i40e: do not flush after re-enabling interrupts (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Bump version (Catherine Sullivan)  [Orabug: 19528533]  
- i40e: Add support for 64 bit netstats (Alexander Duyck)  [Orabug: 19528533]  
- i40e: Move rings from pointer to array to array of pointers (Alexander Duyck)  [Orabug: 19528533]  
- i40e: Replace ring container array with linked list (Alexander Duyck)  [Orabug: 19528533]  
- i40e: Move q_vectors from pointer to array to array of pointers (Alexander Duyck)  [Orabug: 19528533]  
- i40e: Split bytes and packets from Rx/Tx stats (Alexander Duyck)  [Orabug: 19528533]  
- i40e: Add support for Tx byte queue limits (Alexander Duyck)  [Orabug: 19528533]  
- i40e: Drop dead code and flags from Tx hotpath (Alexander Duyck)  [Orabug: 19528533]  
- i40e: clean up Tx fast path (Alexander Duyck)  [Orabug: 19528533]  
- i40e: Do not directly increment Tx next_to_use (Alexander Duyck)  [Orabug: 19528533]  
- i40e: Cleanup Tx buffer info layout (Alexander Duyck)  [Orabug: 19528533]  
- i40e: Drop unused completed stat (Alexander Duyck)  [Orabug: 19528533]  
- i40e: Link code updates (Anjali Singhai)  [Orabug: 19528533]  
- i40e: clean up coccicheck reported errors (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: better return values (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: convert ret to aq_ret (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: small clean ups from review (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: use common failure flow (Jesse Brandeburg)  [Orabug: 19528533]  
- i40e: Fix device ID define names to align to standard (Shannon Nelson)  [Orabug: 19528533]  
- i40evf: conform to UEK kapi (Brian Maly)  [Orabug: 19528533]  
- i40evf: A0 silicon specific (Greg Rose)  [Orabug: 19528533]  
- i40evf: add driver to kernel build system (Greg Rose)  [Orabug: 19528533]  
- i40evf: init code and hardware support (Greg Rose)  [Orabug: 19528533]  
- i40evf: driver core headers (Greg Rose)  [Orabug: 19528533]  
- i40evf: virtual channel interface (Greg Rose)  [Orabug: 19528533]  
- i40evf: core ethtool functionality (Greg Rose)  [Orabug: 19528533]  
- i40evf: transmit and receive functionality (Greg Rose)  [Orabug: 19528533]  
- i40evf: main driver core (Greg Rose)  [Orabug: 19528533]  
- Revert "i40e: upgrade to 1.0.15" (Brian Maly)  [Orabug: 19528533]  
- ixgbe: Look up MAC address on SPARC systems (Martin K. Petersen)  [Orabug: 18182472]  
- cpufreq: intel_pstate: allow driver to be built as a module (Brian Maly)  [Orabug: 19250051]  
- cpufreq: intel_pstate: enable driver in kernel config (Brian Maly)  [Orabug: 19250051]  
- cpufreq: intel_pstate: Remove core_pct rounding (Stratos Karafotis)  [Orabug: 19250051]  
- cpufreq: intel_pstate: Simplify P state adjustment logic. (Stratos Karafotis)  [Orabug: 19250051]  
- cpufreq: intel_pstate: Keep values in aperf/mperf in full precision (Stratos Karafotis)  [Orabug: 19250051]  
- cpufreq: intel_pstate: Disable interrupts during MSRs reading (Stratos Karafotis)  [Orabug: 19250051]  
- cpufreq: intel_pstate: Remove unnecessary type casting in div_s64() call (Stratos Karafotis)  [Orabug: 19250051]  
- cpufreq: intel_pstate: Make intel_pstate_kobject and debugfs_parent locals (Stratos Karafotis)  [Orabug: 19250051]  
- intel_pstate: Set CPU number before accessing MSRs (Vincent Minet)  [Orabug: 19250051]  
- intel_pstate: Correct rounding in busy calculation (Doug Smythies)  [Orabug: 19250051]  
- cpufreq: intel_pstate: Remove duplicate CPU ID check (Stratos Karafotis)  [Orabug: 19250051]  
- cpufreq: intel_pstate: Remove unused member name of cpudata (Stratos Karafotis)  [Orabug: 19250051]  
- intel_pstate: Add CPU IDs for Broadwell processors (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Improve initial busy calculation (Doug Smythies)  [Orabug: 19250051]  
- intel_pstate: add sample time scaling (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Correct rounding in busy calculation (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Remove C0 tracking (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: remove setting P state to MAX on init (Brian Maly)  [Orabug: 19250051]  
- intel_pstate: fix pid_reset to use fixed point values (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: remove unneeded sample buffers (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Change busy calculation to use fixed point math. (Brian Maly)  [Orabug: 19250051]  
- intel_pstate: Remove energy reporting from pstate_sample tracepoint (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Take core C0 time into account for core busy calculation (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Add trace point to report internal state. (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Remove periodic P state boost (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Add X86_FEATURE_APERFMPERF to cpu match parameters. (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Fail initialization if P-state information is missing (Rafael J. Wysocki)  [Orabug: 19250051]  
- intel_pstate: skip the driver if ACPI has power mgmt option (Adrian Huang)  [Orabug: 19250051]  
- cpufreq/intel_pstate: Add static declarations to internal functions (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Refactor driver to support CPUs with different MSR layouts (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Correct calculation of min pstate value (Dirk Brandewie)  [Orabug: 19250051]  
- intel_pstate: Improve accuracy by not truncating until final result (Brennan Shacklett)  [Orabug: 19250051]  
- intel_pstate: Fix type mismatch warning (Rafael J. Wysocki)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Fix max_perf_pct on resume (Brian Maly)  [Orabug: 19250051]  
- intel_pstate: fix no_turbo (Srinivas Pandruvada)  [Orabug: 19250051]  
- intel_pstate: Add Haswell CPU models (Nell Hardcastle)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Change to scale off of max P-state (Brian Maly)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Add additional supported CPU ID (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: use vzalloc() instead of vmalloc()/memset(0) (Wei Yongjun)  [Orabug: 19250051]  
- cpufreq / intel_pstate: remove #ifdef MODULE compile fence (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Remove idle mode PID (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: fix ffmpeg regression (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: use lowest requested max performance (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: remove idle time and duration from sample and calculations (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Optimize intel_pstate_set_policy (Srinivas Pandruvada)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Set timer timeout correctly (Brian Maly)  [Orabug: 19250051]  
- intel-pstate: Use #defines instead of hard-coded values. (Konrad Rzeszutek Wilk)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Fix calculation of current frequency (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Add function to check that all MSRs are valid (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Do not load on VM that does not report max P state. (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Fix intel_pstate_init() error path (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Add kernel command line option disable intel_pstate. (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq / intel_pstate: Fix 32 bit build (Dirk Brandewie)  [Orabug: 19250051]  
- cpufreq/x86: Add P-state driver for sandy bridge. (Dirk Brandewie)  [Orabug: 19250051]  
- xprtrdma: Update RDMA_NOMSG support (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Make FMR the default memory registration mode (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: human-readable completion status (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Display async errors (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Enable pad optimization (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Cap req_cqinit (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Return an errno from rpcrdma_register_external() (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Handle additional connection events (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Remove RPCRDMA_PERSISTENT_REGISTRATION macro (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Make rpcrdma_ep_disconnect() return void (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Schedule reply tasklet once per upcall (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Allocate each struct rpcrdma_mw separately (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Rename frmr_wr (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Disable completions for LOCAL_INV Work Requests (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Disable completions for FAST_REG_MR Work Requests (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Don't post a LOCAL_INV in rpcrdma_register_frmr_external() (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Reset FRMRs after a flushed LOCAL_INV Work Request (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Reset FRMRs when FAST_REG_MR is flushed by a disconnect (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Properly handle exhaustion of the rb_mws list (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Chain together all MWs in same buffer pool (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Back off rkey when FAST_REG_MR fails (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Unclutter struct rpcrdma_mr_seg (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Don't invalidate FRMRs if registration fails (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: On disconnect, don't ignore pending CQEs (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Update rkeys after transport reconnect (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Limit data payload size for ALLPHYSICAL (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Protect ia->ri_id when unmapping/invalidating MRs (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Fix panic in rpcrdma_register_frmr_external() (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Fix DMA-API-DEBUG warning by checking dma_map result (Yan Burman)  [Orabug: 19878552]  
- xprtrdma: Disconnect on registration failure (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Remove BUG_ON() call sites (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Avoid deadlock when credit window is reset (Chuck Lever)  [Orabug: 19878552]  
- SUNRPC: Move congestion window constants to header file (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Reset connection timeout after successful reconnect (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Use macros for reconnection timeout constants (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Allocate missing pagelist (Shirley Ma)  [Orabug: 19878552]  
- xprtrdma: Remove Tavor MTU setting (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Ensure ia->ri_id->qp is not NULL when reconnecting (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Reduce the number of hardway buffer allocations (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Limit work done by completion handler (Chuck Lever)  [Orabug: 19878552]  
- xprtrmda: Reduce calls to ib_poll_cq() in completion handlers (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Reduce lock contention in completion handlers (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: mount reports "Invalid mount option" if memreg mode not supported (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Fall back to MTHCAFMR when FRMR is not supported (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Remove REGISTER memory registration mode (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Fix BOUNCEBUFFERS removal (Chuck Lever)  [Orabug: 19878552]  
- nfs-rdma: Fix for FMR leaks (Allen Andrews)  [Orabug: 19878552]  
- xprtrdma: mind the device's max fast register page list depth (Steve Wise)  [Orabug: 19878552]  
- xprtrdma: Update 16b14d4f (xprtrdma: Split the completion queue) (Chuck Lever)  [Orabug: 19878552]  
- xprtrdma: Revert 87f2934a (xprtrdma: Disable ALLPHYSICAL mode by default) (Chuck Lever)  [Orabug: 19878552]  
- qlcnic: Update version to 5.3.62 (Shahed Shaikh)  [Orabug: 19877622]  
- qlcnic: Fix number of arguments in destroy tx context command (Rajesh Borundia)  [Orabug: 19877622]  
- qlcnic: Fix programming number of arguments in a command. (Rajesh Borundia)  [Orabug: 19877622]  
- qlcnic: Fix ordering of stats in stats buffer. (Manish Chopra)  [Orabug: 19877622]  
- qlcnic: Remove __QLCNIC_DEV_UP bit check to read TX queues statistics. (Manish Chopra)  [Orabug: 19877622]  
- qlcnic: Fix memory corruption while reading stats using ethtool. (Manish Chopra)  [Orabug: 19877622]  
- qlcnic: Use qlcnic_83xx_flash_read32() API instead of lockless version of the API. (Sony Chacko)  [Orabug: 19877622]  
- qlcnic: Add support to run firmware POST (Shahed Shaikh)  [Orabug: 19877622]  
- qlcnic: Use usleep_range() instead of msleep() for sleep less than 20ms (Jitendra Kalsaria)  [Orabug: 19877622]  
- qlcnic: Add support for 0x8830 device ID (Shahed Shaikh)  [Orabug: 19877622]  
- qlcnic: Update Link speed and port type info for 83xx adapter (Jitendra Kalsaria)  [Orabug: 19877622]  
- treewide: Fix typo in printk (Masanari Iida)  [Orabug: 19877622]  
- qlcnic: Fix endianess issue in firmware load from file operation (Shahed Shaikh)  [Orabug: 19877622]  
- qlcnic: Fix endianess issue in FW dump template header (Rajesh Borundia)  [Orabug: 19877622]  
- qlcnic: Fix flash access interface to application (Jitendra Kalsaria)  [Orabug: 19877622]  
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (Benoit Taine)  [Orabug: 19877622]  
- net: ethernet: qlogic: qlcnic: Remove duplicate object file from Makefile (Andreas Ruprecht)  [Orabug: 19877622]  
- qlcnic: Initialize dcbnl_ops before register_netdev (Rajesh Borundia)  [Orabug: 19877622]  
- qlcnic: Set driver version before registering netdev (Rajesh Borundia)  [Orabug: 19877622]  
- qlcnic: Fix update of ethtool stats. (Rajesh Borundia)  [Orabug: 19877622]  
- qlcnic: Update version to 5.3.61 (Harish Patil)  [Orabug: 19877622]  
- qlcnic: Enhance Tx timeout debug data collection. (Harish Patil)  [Orabug: 19877622]  
- qlcnic: Update version to 5.3.60 (Shahed Shaikh)  [Orabug: 19877622]  
- qlcnic: Optimize ring count validations (Shahed Shaikh)  [Orabug: 19877622]  
- qlcnic: Pre-allocate DMA buffer used for minidump collection (Shahed Shaikh)  [Orabug: 19877622]  
- qlcnic: remove duplicate QLC_83XX_GET_LSO_CAPABILITY define (Dan Carpenter)  [Orabug: 19877622]  
- qlcnic: Initialize mailbox cmd structure to zero (Rajesh Borundia)  [Orabug: 19877622]  
- qlcnic: info leak in qlcnic_dcb_peer_app_info() (Dan Carpenter)  [Orabug: 19877622]  
- qlogic: Use time_before() (Manuel Schölling)  [Orabug: 19877622]  
- net: get rid of SET_ETHTOOL_OPS (Wilfried Klaebe)  [Orabug: 19877622]  
- qlcnic: Do not disable SR-IOV on PF unload when VFs are assigned to VMs. (Manish Chopra)  [Orabug: 19877622]  
- qla2xxx: Update driver version to 8.07.00.16.39.0-k. (Saurav Kashyap)  [Orabug: 19876725]  
- qla2xxx: update fc_host for WWPN after cable pull (Himanshu Madhani)  [Orabug: 19876725]  
- qla2xxx: Move warning message to debug level. (Sawan Chandak)  [Orabug: 19876725]  
- qla2xxx: Fail adapter initialization on load ram failure. (Chad Dupuis)  [Orabug: 19876725]  
- qla2xxx: Disable PCI device in shutdown handler. (Chad Dupuis)  [Orabug: 19876725]  
- qla2xxx: Mark port lost when we receive an RSCN for it. (Chad Dupuis)  [Orabug: 19876725]  
- qla2xxx: Restore WWPN in case of Loop Dead. (Hiral Patel)  [Orabug: 19876725]  
- qla2xxx: Honor FCP_RSP retry delay timer field. (Chad Dupuis)  [Orabug: 19876725]  
- qla2xxx: Add missing ISP27xx checks to optrom code. (Alex Vechersky)  [Orabug: 19876725]  
- qla2xxx: Force use of mailbox interface for flash access commands for ISP27xx. (Chad Dupuis)  [Orabug: 19876725]  
- qla2xxx: Fix mismatch is checks to free sysfs nodes. (Nigel Kirkland)  [Orabug: 19876725]  
- qla2xxx: Disable laser for ISP2031 while unloading driver. (Himanshu Madhani)  [Orabug: 19876725]  
- qla2xxx: Enable DPORT using NVRAM parameters. (Himanshu Madhani)  [Orabug: 19876725]  
- qla2xxx: Declaration error cause stack corruption. (Quinn Tran)  [Orabug: 19876725]  
- qla2xxx: Add fix in driver unload for pending activity. (Sawan Chandak)  [Orabug: 19876725]  
- qla2xxx: Fix duplicate log message ID. (Himanshu Madhani)  [Orabug: 19876725]  
- qla2xxx: Allow user to change ql2xfdmienable value (Himanshu Madhani)  [Orabug: 19876725]  
- qla2xxx: Fix driver version string message. (Himanshu Madhani)  [Orabug: 19876725]  
- qla2xxx: Allow nvram bit to enable D-PORT (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Allow nvram bit to enable FA-WWN (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Remove restriction on starting remote device discovery on port update. (Chad Dupuis)  [Orabug: 19876725]  
- qla2xxx: Move mailbox failure messages to a default debug level. (Chad Dupuis)  [Orabug: 19876725]  
- qla2xxx: Correction to FA-WWN for un-acquiring portname. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Add scatter/gather table size module parameter. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Add ql2xasynclogin module parameter. (Chad Dupuis)  [Orabug: 19876725]  
- qla2xxx: fix incorrect debug printk (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Add D-Port functionality. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Add FA-WWN functionality. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Add FDMI-2 functionality. (Himanshu Madhani)  [Orabug: 19876725]  
- qla2xxx: ISPFx00 unexpected resets during adapter boot sequence. (Jan Kulich)  [Orabug: 19876725]  
- qla2xxx: Incorrect linked list semantic in qlafx00_get_fcport(). (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Incorrect debug level on mailbox command print 0x1111. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Fix potential return count bug in qla2xxx_get_vpd_field(). (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: ISP27xx fwdump template error print simplification. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: ISP25xx multiqueue shadow register crash fix. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: ISPFX00 avoid writing semaphore register in request_irqs(). (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Add endianizer to T10 PI max_payload_size modifier. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: Remove wait for online from host reset handler. (Saurav Kashyap)  [Orabug: 19876725]  
- qla2xxx: Do logins from a chip reset in DPC thread instead of the error handler thread. (Chad Dypuis)  [Orabug: 19876725]  
- qla2xxx: Enable fast flash access for ISP83xx. (Chad Dupuis)  [Orabug: 19876725]  
- qla2xxx: Add ISP27xx fwdump template entry T275 (insert buffer) (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: ISP27xx fwdump template fix insertbuf() routine. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: ISP27xx fwdump template remove high frequency debug logs. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: ISP27xx optimize fwdump entry table lookup. (Joe Carnuccio)  [Orabug: 19876725]  
- qla2xxx: ISP27xx add tests for incomplete template. (Joe Carnuccio)  [Orabug: 19876725]  
- crypto: sha - Handle unaligned input data in generic sha256 and sha512. (David S. Miller)  [Orabug: 19680098]  
- ocfs2: don't fire quorum before connection established (Junxiao Bi)  [Orabug: 19549715]  
- ocfs2: fix null handle in ocfs2_write_zero_page (Junxiao Bi)  [Orabug: 19547845]  
- ocfs2: fix deadlock due to wrong locking order (Junxiao Bi)  [Orabug: 19547845]  
- xfs: fix uflags detection at xfs_fs_rm_xquota (Jie Liu)  [Orabug: 19815141]  
- genhd: fix leftover might_sleep() in blk_free_devt() (Jens Axboe)  [Orabug: 19854768]  

* Tue Oct 21 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-49.el7uek] 
- vio: fix reuse of vio_dring slot (Dwight Engen)  [Orabug: 19441666]  
- sunvdc: limit each sg segment to a page (Dwight Engen)  [Orabug: 19347817]  
- sunvdc: syncronize with upstream commit (Dwight Engen)  [Orabug: 19867684]  
- mlx4_vnic: Add correct typecasting to pointers in vnic_get_frag_header() (Ashish Samant)  [Orabug: 19824501]  
- [SCSI] Generate uevents on certain unit attention codes (Ewan D. Milne)  [Orabug: 19670019]  
- be2net: enable PCIe error reporting on VFs too (Kalesh AP)  [Orabug: 19825384]  
- be2net: send a max of 8 EQs to be_cmd_modify_eqd() on Lancer (Kalesh AP)  [Orabug: 19825384]  
- be2net: fix port-type reporting in get_settings (Ravikumar Nelavelli)  [Orabug: 19825384]  
- be2net: add ethtool "-m" option support (Mark Leonard)  [Orabug: 19825384]  
- be2net: use v1 of SET_FLOW_CONTROL command (Suresh Reddy)  [Orabug: 19825384]  
- be2net: fix RX fragment posting for jumbo frames (Ajit Khaparde)  [Orabug: 19825384]  
- be2net: replace strcpy with strlcpy (Vasundhara Volam)  [Orabug: 19825384]  
- be2net: fix some log messages (Vasundhara Volam)  [Orabug: 19825384]  
- be2net: query max_tx_qs for BE3 super-nic profile from FW (Suresh Reddy)  [Orabug: 19825384]  
- be2net: make be_cmd_get_regs() return a status (Vasundhara Volam)  [Orabug: 19825384]  
- be2net: define BE_MAX_MTU (Kalesh AP)  [Orabug: 19825384]  
- be2net: remove unncessary gotos (Kalesh AP)  [Orabug: 19825384]  
- be2net: fix log messages in lancer FW download path (Kalesh AP)  [Orabug: 19825384]  
- be2net: Add a dma_mapping_error counter in ethtool (Vasundhara Volam)  [Orabug: 19825384]  
- be2net: Add TX completion error statistics in ethtool (Kalesh AP)  [Orabug: 19825384]  
- be2net: add a description for counter rx_input_fifo_overflow_drop (Sathya Perla)  [Orabug: 19825384]  
- be2net: add a few log messages (Sathya Perla)  [Orabug: 19825384]  
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (Benoit Taine)  [Orabug: 19825384]  
- be2net: support deleting FW dump via ethtool (only for Lancer) (Kalesh AP)  [Orabug: 19825384]  
- be2net: ignore VF mac address setting for the same mac (Vasundhara Volam)  [Orabug: 19825384]  
- be2net: Issue shutdown event to ocrdma driver (Devesh Sharma)  [Orabug: 19825384]  
- be2net: update driver version to 10.4 (Sathya Perla)  [Orabug: 19825384]  
- be2net: use adapter->flags to track SRIOV state (Vasundhara Volam)  [Orabug: 19825384]  
- be2net: use be_max_vfs() macro to access max-vfs (Vasundhara Volam)  [Orabug: 19825384]  
- be2net: use "if (!foo)" test style (Kalesh AP)  [Orabug: 19825384]  
- be2net: remove unused structures in be_cmds.h (Kalesh AP)  [Orabug: 19825384]  
- be2net: reduce arguments passed to FW-cmd routines (Kalesh AP)  [Orabug: 19825384]  
- be2net: update UE bit description strings (Vasundhara Volam)  [Orabug: 19825384]  
- be2net: fix return status of some ndo methods (Kalesh AP)  [Orabug: 19825384]  
- be2net: fix return status of some ethtool methods (Kalesh AP)  [Orabug: 19825384]  
- be2net: return -ENOMEM for memory allocation failures (Kalesh AP)  [Orabug: 19825384]  
- be2net: return -ETIMEDOUT when a FW-cmd times out (Kalesh AP)  [Orabug: 19825384]  
- be2net: fix error status for FW-download (Kalesh AP)  [Orabug: 19825384]  
- be2net: use -ENETDOWN error status when interface is down (Kalesh AP)  [Orabug: 19825384]  
- be2net: set EQ DB clear-intr bit in be_open() (Suresh Reddy)  [Orabug: 19825384]  
- be2net: re-enable vlan filtering mode asap (Kalesh AP)  [Orabug: 19825384]  
- be2net: read VF's capabilities from GET_PROFILE_CONFIG cmd (Vasundhara Volam)  [Orabug: 19825384]  
- be2net: remove be_cmd_get_profile_config_mbox/mccq() variants (Vasundhara Volam)  [Orabug: 19825384]  
- megaraid: Fail resume if MSI-X re-initialization failed (Alexander Gordeev)  [Orabug: 19664513]  
- megaraid_sas: Add missing initial call to megasas_get_ld_vf_affiliation(). (Adam Radford)  [Orabug: 19664513]  
- megaraid_sas: Fix LD/VF affiliation parsing (Adam Radford)  [Orabug: 19664513]  
- Revert "megaraid_sas: Fix LD/VF affiliation parsing" (Martin K. Petersen)  [Orabug: 19664513]  
- sparc64: vcc driver changes (Bijan Mottahedeh)  [Orabug: 19404981]  
- SPARC64: Virtual Logical Domain Channel (VLDC) Driver: Update #1 (Aaron Young)  [Orabug: 19623083]  
- SPARC64: Virtual Logical Domain Channel (VLDC) Driver (Aaron Young)  [Orabug: 19424085]  
- sparc64: ds support for "sp-token" service and ioctl interface to get token (Liam Merwick)  [Orabug: 19774592]  
- HID: magicmouse: sanity check report size in raw_event() callback (Jiri Kosina)  [Orabug: 19849350]  {CVE-2014-3184} 
- USB: whiteheat: Added bounds checking for bulk command response (James Forshaw)  [Orabug: 19849331]  {CVE-2014-3185} 
- HID: fix a couple of off-by-ones (Jiri Kosina)  [Orabug: 19849311]  {CVE-2014-3181} 
- ALSA: control: Don't access controls outside of protected regions (Lars-Peter Clausen)  [Orabug: 19817689]  {CVE-2014-4653} {CVE-2014-4654} {CVE-2014-4655} 
- ALSA: control: Fix replacing user controls (Lars-Peter Clausen)  [Orabug: 19817671]  {CVE-2014-4653} {CVE-2014-4654} {CVE-2014-4655} 
- kvm: iommu: fix the third parameter of kvm_iommu_put_pages (CVE-2014-3601) (Michael S. Tsirkin)  [Orabug: 19817515]  {CVE-2014-3601} 
- ixgbe: upgrade to version 3.22.3 and merge patches based on 3.21.2 (Ethan Zhao)  [Orabug: 19528458]  
- sparc: Add support for seek and shorter read to /dev/mdesc (Khalid Aziz)  [Orabug: 19797906]  
- cciss: Fallback to MSI rather than to INTx if MSI-X failed (Alexander Gordeev)  [Orabug: 19692099]  
- drivers/block/cciss.c:cciss_init_one(): use proper errnos (Andrew Morton)  [Orabug: 19692099]  
- cciss: return 0 from driver probe function on success, not 1 (Stephen M. Cameron)  [Orabug: 19692099]  
- cpufreq: Use rwsem for protecting critical sections (Viresh Kumar)  [Orabug: 19482546]  
- Drivers: hv: vmbus: Cleanup hv_post_message() (K. Y. Srinivasan)  [Orabug: 19727050]  
- Drivers: hv: vmbus: Cleanup vmbus_close_internal() (K. Y. Srinivasan)  [Orabug: 19727050]  
- storvsc: get rid of overly verbose warning messages (K. Y. Srinivasan)  [Orabug: 19727050]  
- Drivers: hv: vmbus: Cleanup vmbus_post_msg() (K. Y. Srinivasan)  [Orabug: 19727050]  
- Drivers: hv: vmbus: Cleanup vmbus_teardown_gpadl() (K. Y. Srinivasan)  [Orabug: 19727050]  
- Drivers: hv: vmbus: Cleanup vmbus_establish_gpadl() (K. Y. Srinivasan)  [Orabug: 19727050]  
- Drivers: hv: vmbus: Fix a bug in vmbus_open() (K. Y. Srinivasan)  [Orabug: 19727050]  
- Drivers: hv: vmbus: Enable interrupt driven flow control (K. Y. Srinivasan)  [Orabug: 19727050]  
- Drivers: hv: vmbus: Negotiate version 3.0 when running on ws2012r2 hosts (K. Y. Srinivasan)  [Orabug: 19727047]  
- hyperv: import some definition due to compatiblility (Vaughan Cao)  [Orabug: 19230208]  
- net: hyperv: fix netvsc_select_queue definition (Vaughan Cao)  [Orabug: 19230208]  
- hyperv: Add hash value into RNDIS Per-packet info (Haiyang Zhang)  [Orabug: 19230208]  
- Drivers: hv: vmbus: Implement per-CPU mapping of relid to channel (K. Y. Srinivasan)  [Orabug: 19230208]  
- Drivers: hv: Eliminate the channel spinlock in the callback path (K. Y. Srinivasan)  [Orabug: 19230208]  
- hyperv: Properly handle checksum offload (KY Srinivasan)  [Orabug: 19230208]  
- hyperv: Enable sendbuf mechanism on the send path (KY Srinivasan)  [Orabug: 19230208]  
- hyperv: Simplify the send_completion variables (Haiyang Zhang)  [Orabug: 19230208]  
- hyperv: Remove recv_pkt_list and lock (Haiyang Zhang)  [Orabug: 19230208]  
- hyperv: Add support for virtual Receive Side Scaling (vRSS) (Haiyang Zhang)  [Orabug: 19230208]  
- Drivers: net: hyperv: Address UDP checksum issues (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: net: hyperv: Negotiate suitable ndis version for offload support (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: net: hyperv: Allocate memory for all possible per-pecket information (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: net: hyperv: Enable large send offload (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: net: hyperv: Enable send side checksum offload (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: net: hyperv: Enable receive side IP checksum offload (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: net: hyperv: Enable offloads on the host (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: net: hyperv: Cleanup the send path (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: net: hyperv: Enable scatter gather I/O (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: hv: vmbus: Increase the limit on the number of pfns we can handle (K. Y. Srinivasan)  [Orabug: 19230208]  
- hyperv: Add latest NetVSP versions to auto negotiation (Haiyang Zhang)  [Orabug: 19230208]  
- Drivers: net: hyperv: Cleanup the netvsc receive callback functio (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: net: hyperv: Cleanup the receive path (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: net: hyperv: Get rid of the rndis_filter_packet structure (KY Srinivasan)  [Orabug: 19230208]  
- Drivers: hv: vmbus: Support per-channel driver state (K. Y. Srinivasan)  [Orabug: 19230208]  
- bnx2fc: Improve stats update mechanism (Neil Horman)  [Orabug: 19692103]  
- bnx2fc: do not scan uninitialized lists in case of error. (Maurizio Lombardi)  [Orabug: 19692103]  
- bnx2fc: fix memory leak in bnx2fc_allocate_hash_table() (Maurizio Lombardi)  [Orabug: 19692103]  
- bnx2fc: fix memory leak and potential NULL pointer dereference. (Maurizio Lombardi)  [Orabug: 19692103]  
- bnx2fc: remove unused variable hash_table_size (Maurizio Lombardi)  [Orabug: 19692103]  
- bnx2i: Rebranding bnx2i driver (Vikas Chaudhary)  [Orabug: 19692103]  
- bnx2i: fix custom stats length (Mike Christie)  [Orabug: 19692103]  
- bnx2x: Configure device endianity on driver load and reset endianity on removal. (Manish Chopra)  [Orabug: 19692103]  
- net: ethernet: broadcom: bnx2x: Remove redundant #ifdef (Rasmus Villemoes)  [Orabug: 19692103]  
- bnx2x: Revert UNDI flushing mechanism (Yuval Mintz)  [Orabug: 19692103]  
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (Benoit Taine)  [Orabug: 19692103]  
- bnx2x: fix set_setting for some PHYs (Yaniv Rosner)  [Orabug: 19692103]  
- bnx2x: Fail probe of VFs using an old incompatible driver (Yuval Mintz)  [Orabug: 19692103]  
- bnx2x: Fix the MSI flags (Yijing Wang)  [Orabug: 19692103]  
- drivers/net/ethernet/broadcom/bnx2x/bnx2x_sriov.c: remove null test before kfree (Fabian Frederick)  [Orabug: 19692103]  
- bnx2x: Enlarge the dorq threshold for VFs (Ariel Elior)  [Orabug: 19692103]  
- bnx2x: Check for UNDI in uncommon branch (Yuval Mintz)  [Orabug: 19692103]  
- bnx2x: Fix 1G-baseT link (Yaniv Rosner)  [Orabug: 19692103]  
- bnx2x: Fix link for KR with swapped polarity lane (Yaniv Rosner)  [Orabug: 19692103]  
- bnx2x: Fix kernel crash and data miscompare after EEH recovery (wenxiong@linux.vnet.ibm.com)  [Orabug: 19692103]  
- bnx2x: Adapter not recovery from EEH error injection (wenxiong@linux.vnet.ibm.com)  [Orabug: 19692103]  
- bnx2x: update MAINTAINERS for bnx2x and e-mail addresses (Ariel Elior)  [Orabug: 19692103]  
- bnx2x: Convert return 0 to return rc (Joe Perches)  [Orabug: 19692103]  
- bnx2x: fix build when BNX2X_SRIOV is not enabled (Randy Dunlap)  [Orabug: 19692103]  
- bnx2x: Fix UNDI driver unload (Yuval Mintz)  [Orabug: 19692103]  
- bnx2x: Fix failure to configure VF multicast filters (Narender Kumar)  [Orabug: 19692103]  
- bnx2x: Fix vlan credit issues for VFs (Yuval Mintz)  [Orabug: 19692103]  
- bnx2x: Memory leak during VF removal (Yuval Mintz)  [Orabug: 19692103]  
- net: bnx2x: include irq.h for irqreturn_t definitions (Josh Boyer)  [Orabug: 19692103]  
- bnx2x: Fix possible memory leak on iov error flow (Yuval Mintz)  [Orabug: 19692103]  
- bnx2x: Fix compilation when CONFIG_BNX2X_SRIOV is not set (Yuval Mintz)  [Orabug: 18505568]  
- bnx2x: Don't allow VFs to become promiscuous (Yuval Mintz)  [Orabug: 18505568]  
- bnx2x: Don't show port statistics for VFs (Yuval Mintz)  [Orabug: 18505568]  
- bnx2x: Remove the sriov VFOP mechanism (Yuval Mintz)  [Orabug: 18505568]  
- bnx2x: Don't receive packets when the napi budget == 0 (Eric W. Biederman)  [Orabug: 18505568]  
- bnx2x: save RAM in kdump kernel by disabling TPA (Michal Schmidt)  [Orabug: 18505568]  
- bnx2x: save RAM in kdump kernel by using a single queue (Michal Schmidt)  [Orabug: 18505568]  
- bnx2x: clamp num_queues to prevent passing a negative value (Michal Schmidt)  [Orabug: 18505568]  
- cnic : Cleanup CONFIG_IPV6 & VLAN check (Anish Bhatt)  [Orabug: 19692103]  
- cnic: Rebranding cnic driver. (Jitendra Kalsaria)  [Orabug: 19692103]  
- cnic: Fix missing ISCSI_KEVENT_IF_DOWN message (Michael Chan)  [Orabug: 19692103]  
- cnic: Don't take cnic_dev_lock in cnic_alloc_uio_rings() (Michael Chan)  [Orabug: 19692103]  
- cnic: Don't take rcu_read_lock in cnic_rcv_netevent() (Michael Chan)  [Orabug: 19692103]  
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (Benoit Taine)  [Orabug: 19692103]  
- bnx2: Rebranding bnx2 driver. (Jitendra Kalsaria)  [Orabug: 19692103]  
- bnx2: Don't receive packets when the napi budget == 0 (Eric W. Biederman)  [Orabug: 19692103]  
- bnx2: Call dev_kfree_skby_any instead of dev_kfree_skb. (Eric W. Biederman)  [Orabug: 19692103]  
- bnx2: Make module parameters readable (James M Leddy)  [Orabug: 19692103]  
- tg3: prevent ifup/ifdown during PCI error recovery (Ivan Vecera)  [Orabug: 19692103]  
- tg3: fix return value in tg3_get_stats64 (Govindarajulu Varadarajan)  [Orabug: 19692103]  
- tg3: Fix race condition in tg3_get_stats64() (Michael Chan)  [Orabug: 19692103]  
- PCI: Remove DEFINE_PCI_DEVICE_TABLE macro use (Benoit Taine)  [Orabug: 19692103]  
- tg3: Modify tg3_tso_bug() to handle multiple TX rings (Prashant Sreedharan)  [Orabug: 19692103]  
- tg3: Change nvram command timeout value to 50ms (Prashant Sreedharan)  [Orabug: 19692103]  
- tg3: Clear NETIF_F_TSO6 flag before doing software GSO (Prashant Sreedharan)  [Orabug: 19692103]  
- tg3: Override clock, link aware and link idle mode during NVRAM dump (Prashant Sreedharan)  [Orabug: 19692103]  
- tg3: Prevent page allocation failure during TSO workaround (Michael Chan)  [Orabug: 19692103]  
- tg3: Don't modify ip header fields when doing GSO (Michael Chan)  [Orabug: 19692103]  
- tg3: update rx_jumbo_pending ring param only when jumbo frames are enabled (Ivan Vecera)  [Orabug: 19692103]  
- tg3: remove open-coded skb_cow_head. (françois romieu)  [Orabug: 19692103]  
- tg3: remove empty MDIO bus reset function (Florian Fainelli)  [Orabug: 19692103]  
- tg3: Do not include vlan acceleration features in vlan_features (Vlad Yasevich)  [Orabug: 19692103]  
- tg3: Call dev_kfree_skby_any instead of dev_kfree_skb. (Eric W. Biederman)  [Orabug: 19692103]  
- hpsa: fix bad -ENOMEM return value in hpsa_big_passthru_ioctl (Stephen M. Cameron)  [Orabug: 19692082]  
- hpsa: remove online devices from offline device list (Stephen M. Cameron)  [Orabug: 19692082]  
- hpsa: fix non-x86 builds (Arnd Bergmann)  [Orabug: 19692082]  
- hpsa: do not unconditionally copy sense data (Robert Elliott)  [Orabug: 19692082]  
- hpsa: fix 6-byte READ/WRITE with 0 length data xfer (Stephen M. Cameron)  [Orabug: 19692082]  
- hpsa: make hpsa_init_one return -ENOMEM if allocation of h->lockup_detected fails (Stephen M. Cameron)  [Orabug: 19692082]  
- sparc: Fix dependency for CONFIG_SPARC_ADI (Khalid Aziz)  [Orabug: 19706013]  
- ctf: handle srcdir-relative paths properly. (Nick Alcock)  [Orabug: 19712731]  

* Tue Sep 23 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-48.el7uek] 
- x86/xen: don't copy bogus duplicate entries into kernel page tables (Stefan Bader)  [Orabug: 19672707]  
- xen/gntalloc: safely delete grefs in add_grefs() undo path (David Vrabel)  [Orabug: 19672707]  
- xen/gntalloc: fix oops after runnning out of grant refs (David Vrabel)  [Orabug: 19672707]  
- xen/balloon: cancel ballooning if adding new memory failed (David Vrabel)  [Orabug: 19672707]  
- xen/manage: Always freeze/thaw processes when suspend/resuming (Ross Lagerwall)  [Orabug: 19672707]  
- x86/xen: use vmap() to map grant table pages in PVH guests (David Vrabel)  [Orabug: 19672707]  
- x86/xen: resume timer irqs early (David Vrabel)  [Orabug: 19672707]  
- xen-pciback: Document the 'quirks' sysfs file (Konrad Rzeszutek Wilk)  [Orabug: 19672707]  
- xen/pciback: Fix error return code in xen_pcibk_attach() (Wei Yongjun)  [Orabug: 19672707]  
- xen/events: drop negativity check of unsigned parameter (Andrey Utkin)  [Orabug: 19672707]  
- xen/setup: Remove Identity Map Debug Message (Matt Rushton)  [Orabug: 19672707]  
- xen/events/fifo: remove a unecessary use of BM() (Frediano Ziglio)  [Orabug: 19672707]  
- xen/events/fifo: ensure all bitops are properly aligned even on x86 (David Vrabel)  [Orabug: 19672707]  
- xen/events/fifo: reset control block and local HEADs on resume (David Vrabel)  [Orabug: 19672707]  
- xen/grant-table: remove support for V2 tables (David Vrabel)  [Orabug: 19672707]  
- x86/xen: safely map and unmap grant frames when in atomic context (David Vrabel)  [Orabug: 19672707]  
- OVMAPI: Memory leak in ovmapi_read_name_value (Sasha Levin)  [Orabug: 19672517]  
- OVMAPI: Sanity check value size before handling it (Sasha Levin)  [Orabug: 19672529]  
- block: Fix dev_t minor allocation lifetime (Keith Busch)  [Orabug: 19566288]  
- PCI: hotplug: Use global PCI rescan-remove locking (Rafael J. Wysocki)  [Orabug: 19593327]  
- PCI: Add global pci_lock_rescan_remove() (Rafael J. Wysocki)  [Orabug: 19593327]  
- sparc: Allow memory corruption detection to be enabled by default (Khalid Aziz)  [Orabug: 19348168]  
- sparc: Add support for Application Data Integrity (ADI) on M7 (Khalid Aziz)  [Orabug: 19348168]  
- Make kernel-uek-doc not obsolete and not conflict with kernel-doc (John Haxby)  [Orabug: 18922080]  
- module: fix sprintf format specifier in param_get_byte() (Christoph Jaeger)  [Orabug: 19647215]  
- mm: make snapshotting pages for stable writes a per-bio operation (Darrick J. Wong)  [Orabug: 19502094]  
- xfs: growfs overruns AGFL buffer on V4 filesystems (Dave Chinner)  [Orabug: 19427033]  
- Revert "xen/events: remove unnecessary call to bind_evtchn_to_cpu()" (Zhenzhong Duan)  [Orabug: 19261720]  
- ocfs2: reflink: fix slow unlink for refcounted file (Junxiao Bi)  [Orabug: 18106641]  
- xfs: fix Q_XQUOTARM ioctl (Eric Sandeen)  [Orabug: 19207913]  
- sunvnet: Avoid sending superfluous LDC messages. (Sowmini Varadhan)  [Orabug: 19621729]  
- sunvnet: only use connected ports when sending (David L Stevens)  [Orabug: 19621274]  
- sunvnet: Schedule maybe_tx_wakeup() as a tasklet from ldc_rx path (Sowmini Varadhan)  [Orabug: 19359251]  
- sunvnet: Do not spin in an infinite loop when vio_ldc_send() returns EAGAIN (Sowmini Varadhan)  [Orabug: 19359251]  
- sunvnet: Do not ask for an ACK for every dring transmit (Sowmini Varadhan)  [Orabug: 19359251]  
- sunvnet: clean up objects created in vnet_new() on vnet_exit() (Sowmini Varadhan)  [Orabug: 19441826]  
- sparc64: ldc_connect() should not return EINVAL when handshake is in progress. (Sowmini Varadhan)  [Orabug: 19588198]  

* Fri Sep 12 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-47.el7uek] 
- CVE-2014-3535: NULL pointer dereference in VxLAN packet logging. (Sasha Levin)  [Orabug: 19613111]  
- ixgbevf: fix cards found counter when unbound one NIC (Ethan Zhao)  [Orabug: 19063958]  
- ixgbevf: upgrade to version 2.15.3 (Ethan Zhao)  [Orabug: 19528471]  
- i40e: upgrade to 1.0.15 (Ethan Zhao)  [Orabug: 19493068]  
- mlx4_ib: Fix endianness in blueflame post_send. (Shamir Rabinovitch)  [Orabug: 18918544]  
- sparc64: Virtual Console Concentrator driver (Bijan Mottahedeh)  [Orabug: 19337243]  
- x86, efivars: firmware bug workarounds should be in platform code (Matt Fleming)  [Orabug: 19520640]  
- sdp: fix keepalive functionality (Shamir Rabinovitch)  [Orabug: 19467625]  

* Sat Sep 6 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-46.el7uek] 
- sctp: fix possible seqlock seadlock in sctp_packet_transmit() (Eric Dumazet)  [Orabug: 19572988]  
- iovec: make sure the caller actually wants anything in memcpy_fromiovecend (Sasha Levin)  [Orabug: 19573414]  
- net: sctp: inherit auth_capable on INIT collisions (Daniel Borkmann)  [Orabug: 19573413]  
- tcp: Fix integer-overflow in TCP vegas (Christoph Paasch)  [Orabug: 19573412]  
- tcp: Fix integer-overflows in TCP veno (Christoph Paasch)  [Orabug: 19573411]  
- net: sendmsg: fix NULL pointer dereference (Andrey Ryabinin)  [Orabug: 19573410]  
- bnx2x: fix crash during TSO tunneling (Dmitry Kravkov)  [Orabug: 19573409]  
- lib/btree.c: fix leak of whole btree nodes (Minfei Huang)  [Orabug: 19573408]  
- timer: Fix lock inversion between hrtimer_bases.lock and scheduler locks (Jan Kara)  [Orabug: 19573407]  
- printk: rename printk_sched to printk_deferred (John Stultz)  [Orabug: 19573406]  
- mm, thp: do not allow thp faults to avoid cpuset restrictions (David Rientjes)  [Orabug: 19573405]  
- cfg80211: fix mic_failure tracing (Eliad Peller)  [Orabug: 19573404]  
- crypto: af_alg - properly label AF_ALG socket (Milan Broz)  [Orabug: 19573403]  
- x86/efi: Include a .bss section within the PE/COFF headers (Michael Brown)  [Orabug: 19573402]  
- mm: hugetlb: fix copy_hugetlb_page_range() (Naoya Horiguchi)  [Orabug: 19573401]  
- blkcg: don't call into policy draining if root_blkg is already gone (Tejun Heo)  [Orabug: 19573400]  
- block: don't assume last put of shared tags is for the host (Christoph Hellwig)  [Orabug: 19573399]  
- drm/radeon: avoid leaking edid data (Alex Deucher)  [Orabug: 19573398]  
- ipv4: fix buffer overflow in ip_options_compile() (Eric Dumazet)  [Orabug: 19573397]  
- dns_resolver: Null-terminate the right string (Ben Hutchings)  [Orabug: 19573396]  
- dns_resolver: assure that dns_query() result is null-terminated (Manuel Schölling)  [Orabug: 19573395]  
- net: sctp: fix information leaks in ulpevent layer (Daniel Borkmann)  [Orabug: 19573394]  
- igmp: fix the problem when mc leave group (dingtianhong)  [Orabug: 19573393]  
- tcp: Fix divide by zero when pushing during tcp-repair (Christoph Paasch)  [Orabug: 19573392]  
- bnx2x: fix possible panic under memory stress (Eric Dumazet)  [Orabug: 19573391]  
- ipv4: irq safe sk_dst_[re]set() and ipv4_sk_update_pmtu() fix (Eric Dumazet)  [Orabug: 19573390]  
- ipv4: fix dst race in sk_dst_get() (Eric Dumazet)  [Orabug: 19573389]  
- 8021q: fix a potential memory leak (Li RongQing)  [Orabug: 19573388]  
- net: sctp: check proc_dointvec result in proc_sctp_do_auth (Daniel Borkmann)  [Orabug: 19573387]  
- shmem: fix splicing from a hole while it's punched (Hugh Dickins)  [Orabug: 19573386]  
- shmem: fix faulting into a hole, not taking i_mutex (Hugh Dickins)  [Orabug: 19573385]  {CVE-2014-4171} 
- shmem: fix faulting into a hole while it's punched (Hugh Dickins)  [Orabug: 19573384]  
- ext4: fix unjournalled bg descriptor while initializing inode bitmap (Theodore Ts'o)  [Orabug: 19573383]  
- cpuset,mempolicy: fix sleeping function called from invalid context (Gu Zheng)  [Orabug: 19573382]  
- mm: fix crashes from mbind() merging vmas (Hugh Dickins)  [Orabug: 19573381]  
- hugetlb: fix copy_hugetlb_page_range() to handle migration/hwpoisoned entry (Naoya Horiguchi)  [Orabug: 19573380]  
- md: flush writes before starting a recovery. (NeilBrown)  [Orabug: 19573379]  
- nfsd: fix rare symlink decoding bug (J. Bruce Fields)  [Orabug: 19573378]  
- Bluetooth: Fix locking of hdev when calling into SMP code (Johan Hedberg)  [Orabug: 19573377]  
- rt2x00: disable TKIP on USB (Stanislaw Gruszka)  [Orabug: 19573376]  
- USB: ftdi_sio: fix null deref at port probe (Johan Hovold)  [Orabug: 19573375]  
- virtio-scsi: avoid cancelling uninitialized work items (Paolo Bonzini)  [Orabug: 19573374]  
- netfilter: ipt_ULOG: fix info leaks (Mathias Krause)  [Orabug: 19573373]  
- ipvs: Fix panic due to non-linear skb (Peter Christensen)  [Orabug: 19573372]  
- reiserfs: call truncate_setsize under tailpack mutex (Jeff Mahoney)  [Orabug: 19573371]  
- nfsd4: fix FREE_STATEID lockowner leak (J. Bruce Fields)  [Orabug: 19573370]  
- pNFS: Handle allocation errors correctly in filelayout_alloc_layout_hdr() (Trond Myklebust)  [Orabug: 19573369]  
- SUNRPC: Fix a module reference leak in svc_handle_xprt (Trond Myklebust)  [Orabug: 19573368]  
- UBIFS: Remove incorrect assertion in shrink_tnc() (hujianyang)  [Orabug: 19573367]  
- UBIFS: fix an mmap and fsync race condition (hujianyang)  [Orabug: 19573365]  
- mtip32xx: Remove dfs_parent after pci unregister (Asai Thambi S P)  [Orabug: 19573364]  
- Btrfs: use right type to get real comparison (Liu Bo)  [Orabug: 19573363]  
- fs: btrfs: volumes.c: Fix for possible null pointer dereference (Rickard Strandqvist)  [Orabug: 19573362]  
- Btrfs: fix double free in find_lock_delalloc_range (Chris Mason)  [Orabug: 19573361]  
- target: Explicitly clear ramdisk_mcp backend pages (Nicholas A. Bellinger)  [Orabug: 19573360]  
- target: Report correct response length for some commands (Roland Dreier)  [Orabug: 19573358]  
- iscsi-target: Fix ABORT_TASK + connection reset iscsi_queue_req memory leak (Nicholas Bellinger)  [Orabug: 19573357]  
- ext4: fix wrong assert in ext4_mb_normalize_request() (Maurizio Lombardi)  [Orabug: 19573356]  
- ext4: fix zeroing of page during writeback (Jan Kara)  [Orabug: 19573355]  
- mm: vmscan: clear kswapd's special reclaim powers before exiting (Johannes Weiner)  [Orabug: 19573354]  
- mm: fix sleeping function warning from __put_anon_vma (Hugh Dickins)  [Orabug: 19573353]  
- ipv4: fix a race in ip4_datagram_release_cb() (Eric Dumazet)  [Orabug: 19573352]  
- net: force a list_del() in unregister_netdevice_many() (Eric Dumazet)  [Orabug: 19573351]  
- auditsc: audit_krule mask accesses need bounds checking (Andy Lutomirski)  [Orabug: 19573350]  
- mm/compaction: make isolate_freepages start at pageblock boundary (Vlastimil Babka)  [Orabug: 19573349]  
- mm: compaction: detect when scanners meet in isolate_freepages (Vlastimil Babka)  [Orabug: 19573348]  
- mm: compaction: reset cached scanner pfn's before reading them (Vlastimil Babka)  [Orabug: 19573347]  
- target: Fix alua_access_state attribute OOPs for un-configured devices (Nicholas Bellinger)  [Orabug: 19573346]  
- fs,userns: Change inode_capable to capable_wrt_inode_uidgid (Andy Lutomirski)  [Orabug: 19573345]  {CVE-2014-4014} 
- mm: rmap: fix use-after-free in __put_anon_vma (Andrey Ryabinin)  [Orabug: 19573344]  
- mm/memory-failure.c: fix memory leak by race between poison and unpoison (Naoya Horiguchi)  [Orabug: 19573343]  
- perf: Fix race in removing an event (Peter Zijlstra)  [Orabug: 19573342]  
- perf: Prevent false warning in perf_swevent_add (Jiri Olsa)  [Orabug: 19573341]  
- iommu/amd: Fix interrupt remapping for aliased devices (Alex Williamson)  [Orabug: 19573340]  
- libceph: fix corruption when using page_count 0 page in rbd (Chunwei Chen)  [Orabug: 19573338]  
- dm crypt: fix cpu hotplug crash by removing per-cpu structure (Mikulas Patocka)  [Orabug: 19573337]  
- percpu: make pcpu_alloc_chunk() use pcpu_mem_free() instead of kfree() (Jianyu Zhan)  [Orabug: 19573336]  
- nfsd4: remove lockowner when removing lock stateid (J. Bruce Fields)  [Orabug: 19573335]  
- nfsd4: warn on finding lockowner without stateid's (J. Bruce Fields)  [Orabug: 19573334]  
- NFSD: Call ->set_acl with a NULL ACL structure if no entries (Kinglong Mee)  [Orabug: 19573333]  
- NFSd: call rpc_destroy_wait_queue() from free_client() (Trond Myklebust)  [Orabug: 19573331]  
- NFSd: Move default initialisers from create_client() to alloc_client() (Trond Myklebust)  [Orabug: 19573330]  
- media: media-device: fix infoleak in ioctl media_enum_entities() (Salva Peiró)  [Orabug: 19573329]  {CVE-2014-1739} 
- crypto: crypto_wq - Fix late crypto work queue initialization (Tim Chen)  [Orabug: 19573328]  
- posix_acl: handle NULL ACL in posix_acl_equiv_mode (Christoph Hellwig)  [Orabug: 19573327]  
- md: avoid possible spinning md thread at shutdown. (NeilBrown)  [Orabug: 19573326]  
- hrtimer: Set expiry time before switch_hrtimer_base() (Viresh Kumar)  [Orabug: 19573325]  
- hrtimer: Prevent remote enqueue of leftmost timers (Leon Ma)  [Orabug: 19573324]  
- hrtimer: Prevent all reprogramming if hang detected (Stuart Hayes)  [Orabug: 19573323]  
- hwpoison, hugetlb: lock_page/unlock_page does not match for handling a free hugepage (Chen Yucong)  [Orabug: 19573322]  
- x86, mm, hugetlb: Add missing TLB page invalidation for hugetlb_cow() (Anthony Iliopoulos)  [Orabug: 19573321]  
- timer: Prevent overflow in apply_slack (Jiri Bohac)  [Orabug: 19573319]  
- mm: make fixup_user_fault() check the vma access rights too (Linus Torvalds)  [Orabug: 19573318]  
- ipv4: initialise the itag variable in __mkroute_input (Li RongQing)  [Orabug: 19573317]  
- ip6_tunnel: fix potential NULL pointer dereference (Susant Sahani)  [Orabug: 19573316]  
- macvlan: Don't propagate IFF_ALLMULTI changes on down interfaces. (Peter Christensen)  [Orabug: 19573315]  
- ipv4: fib_semantics: increment fib_info_cnt after fib_info allocation (Sergey Popovich)  [Orabug: 19573314]  
- tcp_cubic: fix the range of delayed_ack (Liu Yu)  [Orabug: 19573313]  
- rtnetlink: Only supply IFLA_VF_PORTS information when RTEXT_FILTER_VF is set (David Gibson)  [Orabug: 19573312]  
- rtnetlink: Warn when interface's information won't fit in our packet (David Gibson)  [Orabug: 19573311]  
- net: sctp: cache auth_enable per endpoint (Vlad Yasevich)  [Orabug: 19573309]  
- vlan: Fix lockdep warning when vlan dev handle notification (dingtianhong)  [Orabug: 19573303]  
- ip6_gre: don't allow to remove the fb_tunnel_dev (Nicolas Dichtel)  [Orabug: 19573299]  
- bonding: Remove debug_fs files when module init fails (Thomas Richter)  [Orabug: 19573298]  
- l2tp: take PMTU from tunnel UDP socket (Dmitry Petukhov)  [Orabug: 19573284]  
- USB: serial: fix sysfs-attribute removal deadlock (Johan Hovold)  [Orabug: 19573279]  
- mm: use paravirt friendly ops for NUMA hinting ptes (Mel Gorman)  [Orabug: 19573259]  
- mm/hugetlb.c: add cond_resched_lock() in return_unused_surplus_pages() (Mizuma, Masayoshi)  [Orabug: 19573242]  
- netfilter: Can't fail and free after table replacement (Thomas Graf)  [Orabug: 19573228]  
- netfilter: nf_conntrack: reserve two bytes for nf_ct_ext->len (Andrey Vagin)  [Orabug: 19573152]  
- be2iscsi : Bump the driver version (John Soni Jose)  [Orabug: 19530726]  
- be2iscsi: Fix memory leak in mgmt_set_ip() (Maurizio Lombardi)  [Orabug: 19530726]  
- bnx2i, be2iscsi: fix custom stats length (Mike Christie)  [Orabug: 19530726]  
- be2iscsi: remove potential junk pointer free (Tomas Henzl)  [Orabug: 19530726]  
- be2iscsi: add an missing goto in error path (Tomas Henzl)  [Orabug: 19530726]  
- be2iscsi: Fix destroy MCC-CQ before MCC-EQ is destroyed (Jayamohan Kallickal)  [Orabug: 19530726]  
- be2iscsi: Fix memory corruption in MBX path (Jayamohan Kallickal)  [Orabug: 19530726]  
- be2iscsi: Fix TCP parameters while connection offloading. (Jayamohan Kallickal)  [Orabug: 19530726]  
- be2iscsi: Fix interrupt Coalescing mechanism. (Jayamohan Kallickal)  [Orabug: 19530726]  
- be2iscsi: Fix exposing Host in sysfs after adapter initialization is complete (Jayamohan Kallickal)  [Orabug: 19530726]  
- be2iscsi: Fix retrieving MCCQ_WRB in non-embedded Mbox path (Jayamohan Kallickal)  [Orabug: 19530726]  

* Wed Sep 3 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-45.el7uek] 
- x86: xen: Sync the CMOS RTC as well as the Xen wallclock (David Vrabel)  [Orabug: 18859022]  
- x86: xen: Sync the wallclock when the system time is set (David Vrabel)  [Orabug: 18859023]  
- timekeeping: Indicate that clock was set in the pvclock gtod notifier (David Vrabel)  [Orabug: 18859024]  
- timekeeping: Pass flags instead of multiple bools to timekeeping_update() (David Vrabel)  [Orabug: 18859057]  
- xen: Remove clock_was_set() call in the resume path (David Vrabel)  [Orabug: 18859058]  
- hrtimers: Support resuming with two or more CPUs online (but stopped) (David Vrabel)  [Orabug: 18859026]  
- x86: Fix vrtc_get_time/set_mmss to use new timespec interface (John Stultz)  [Orabug: 18859027]  
- x86: Increase precision of x86_platform.get/set_wallclock() (David Vrabel)  [Orabug: 18859028]  
- x86: Do full rtc synchronization with ntp (Prarit Bhargava)  [Orabug: 18859028]  
- mptsas: do not call __mptsas_probe in kthread (Vaughan Cao)  [Orabug: 19027314]  
- Revert "mptsas: do not call __mptsas_probe in kthread" (Vaughan Cao)  [Orabug: 19027314]  
- igbvf: upgrade to intel version 2.3.5 (Ethan Zhao)  [Orabug: 19139458]  
- ext3: partial revert of 4df3347b (Dave Kleikamp)  [Orabug: 19220057]  
- ocfs2: fix journal commit deadlock (Junxiao Bi)  [Orabug: 19249791]  
- hpsa: fix wrongly set page code regardless of EVPD value (Vaughan Cao)  [Orabug: 19309888]  
- [random] Partially revert 6d7c7e49: random: make 'add_interrupt_randomness() (John Sobecki)  [Orabug: 19357973]  
- config: turn on CONFIG_FW_LOADER_USER_HELPER (Navi Tansaraviput)  [Orabug: 19431631]  
- microcode: Use request_firmware_direct() (Takashi Iwai)  [Orabug: 19431631]  
- firmware: Introduce request_firmware_direct() (Takashi Iwai)  [Orabug: 19431631]  
- firmware: Make user-mode helper optional (Takashi Iwai)  [Orabug: 19431631]  
- firmware: Refactoring for splitting user-mode helper code (Takashi Iwai)  [Orabug: 19431631]  
- oracleasm: claim FMODE_EXCL access on disk during asm_open (Srinivas Eeda)  [Orabug: 19454829]  
- drivers: base: remove unneeded variable (Seth Jennings)  [Orabug: 19441989]  
- drivers/base: Use attribute groups to create sysfs memory files (Nathan Fontenot)  [Orabug: 19441989]  

* Fri Aug 8 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-44.el7uek] 
- net: Use netlink_ns_capable to verify the permisions of netlink messages (Eric W. Biederman)  [Orabug: 19404229]  {CVE-2014-0181} 
- net: Add variants of capable for use on netlink messages (Eric W. Biederman)  [Orabug: 19404229]  
- net: Add variants of capable for use on on sockets (Eric W. Biederman)  [Orabug: 19404229]  
- netlink: Rename netlink_capable netlink_allowed (Eric W. Biederman)  [Orabug: 19404229]  
- sctp: Fix sk_ack_backlog wrap-around problem (Xufeng Zhang)  [Orabug: 19404238]  {CVE-2014-4667} 
- Revert "xen/fb: allow xenfb initialization for hvm guests" (Vaughan Cao)  [Orabug: 19320529]  

* Thu Jul 31 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-43.el7uek] 
- init: fix in-place parameter modification regression (Krzysztof Mazur)  [Orabug: 18954967]  
- drivers: scsi: storvsc: Correctly handle TEST_UNIT_READY failure (K. Y. Srinivasan)  [Orabug: 19280065]  
- drivers: scsi: storvsc: Set srb_flags in all cases (K. Y. Srinivasan)  [Orabug: 19280065]  
- Drivers: scsi: storvsc: Implement a timedout handler (K. Y. Srinivasan)  [Orabug: 19280065]  
- Drivers: scsi: storvsc: Fix a bug in handling VMBUS protocol version (K. Y. Srinivasan)  [Orabug: 19280065]  
- Drivers: scsi: storvsc: Filter commands based on the storage protocol version (K. Y. Srinivasan)  [Orabug: 19280065]  
- Drivers: scsi: storvsc: Set cmd_per_lun to reflect value supported by the Host (K. Y. Srinivasan)  [Orabug: 19280065]  
- Drivers: scsi: storvsc: Change the limits to reflect the values on the host (K. Y. Srinivasan)  [Orabug: 19280065]  

* Tue Jul 29 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-42.el7uek] 
- filter: prevent nla extensions to peek beyond the end of the message (Mathias Krause)  [Orabug: 19315780]  {CVE-2014-3144} {CVE-2014-3145} 

* Mon Jul 28 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-41.el7uek] 
- rds: Lost locking in loop connection freeing (Pavel Emelyanov)  [Orabug: 19124446]  
- ocfs2/o2net: incorrect to terminate accepting connections loop upon rejecting an invalid one (Tariq Saeed)  [Orabug: 19296823]  
- xen/pciback: Don't deadlock when unbinding. (Konrad Rzeszutek Wilk)  [Orabug: 19296592]  
- PCI: Split out pci_dev lock/unlock and save/restore (Alex Williamson)  [Orabug: 19296592]  

* Wed Jul 16 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-40.el7uek] 
- l2tp: fix an unprivileged user to kernel privilege escalation (Sasha Levin)  [Orabug: 19228689]  {CVE-2014-4943} {CVE-2014-4943} 
- ptrace,x86: force IRET path after a ptrace_stop() (Tejun Heo)  [Orabug: 19222017]  {CVE-2014-4699} 
- mpt3sas: Rework the MSI-X code to work on systems with many processors (Martin K. Petersen)  [Orabug: 18182490]  
- mpt2sas: Rework the MSI-X code to work on systems with many processors (Martin K. Petersen)  [Orabug: 18182490]  
- mpt3sas: Bump mpt3sas driver version to 04.100.00.00 (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt3sas: Added Reply Descriptor Post Queue (RDPQ) Array support (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt3sas: Bump mpt3sas driver version to 03.100.00.00 (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt3sas: Added OEM branding Strings (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt3sas: MPI2.5 Rev H (2.5.3) specifications (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt3sas: Copyright in driver sources is updated for year the 2014 (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt3sas: Clear PFA Status on SGPIO when PFA Drive is Removed or Replaced (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt3sas: MPI2.5 Rev G (2.5.2) specifications (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt3sas: Remove use of DEF_SCSI_QCMD (Matthew Wilcox)  [Orabug: 19015667]  
- mpt3sas: Remove uses of serial_number (Matthew Wilcox)  [Orabug: 19015667]  
- Allow MPT Fusion SAS 3.0 driver to be built into the kernel (Greg Kroah-Hartman)  [Orabug: 19015667]  
- mpt3sas: Remove phys on topology change (Jan Vesely)  [Orabug: 19015667]  
- mpt3sas: Added a driver module parameter max_msix_vectors (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt3sas: fix cleanup on controller resource mapping failure (Joe Lawrence)  [Orabug: 19015667]  
- Revert "mpt3sas: update from v02.100.00.00 to v3.00.00.00" (Martin K. Petersen)  [Orabug: 19015667]  
- Revert "mpt3sas: Rework the MSI-X code to work on systems with many processors" (Martin K. Petersen)  [Orabug: 19015667]  
- mpt2sas: Added module parameter 'unblock_io' to unblock IO's during disk addition (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: Bump mpt2sas driver version to 18.100.00.00 (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: Get IOC_FACTS information using handshake protocol only after HBA card gets into READY or Operational state (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: Added Reply Descriptor Post Queue (RDPQ) Array support (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: For >2TB volumes, DirectDrive support sends IO's with LBA bit 31 to IR FW instead of DirectDrive (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: Copyright in driver sources is updated for year the 2014 (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: Clear PFA Status on SGPIO when PFA Drive is Removed or Replaced (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: Bump mpt2sas driver version to 17.100.00.00 (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: MPI2 Rev Y (2.00.17) and Rev Z (2.00.18) specifications (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: Added driver module parameter max_msix_vectors (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: Add free smids to the head, not tail of list (Matthew Wilcox)  [Orabug: 19015667]  
- mpt2sas: Remove use of DEF_SCSI_QCMD (Matthew Wilcox)  [Orabug: 19015667]  
- mpt2sas: Remove uses of serial_number (Matthew Wilcox)  [Orabug: 19015667]  
- mpt2sas: Don't disable device twice at suspend. (Tyler Stachecki)  [Orabug: 19015667]  
- mpt2sas: Remove phys on topology change. (Jan Vesely)  [Orabug: 19015667]  
- mpt2sas: Bump driver version to v16.100.00.00 (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: Fix for kernel panic when driver loads with HBA connected to non LUN 0 configured expander (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: when Async scanning is enabled then while scanning, devices are removed but their transport layer entries are not removed (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: Infinite loop can occur if MPI2_IOCSTATUS_CONFIG_INVALID_PAGE is not returned (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: The copyright in driver sources is updated for the year 2013 (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: MPI2 Rev X (2.00.16) specifications (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: Change in MPI2_RAID_ACTION_SYSTEM_SHUTDOWN_INITIATED notification methodology (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: Null pointer deference possibility in mpt2sas_ctl_event_callback function (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: fix cleanup on controller resource mapping failure (Joe Lawrence)  [Orabug: 19015667]  
- mpt2sas: fix for unused variable 'event_data' warning (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: Bump driver vesion to v15.100.00.00 (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: Calulate the Reply post queue depth calculation as per the MPI spec (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: fix firmware failure with wrong task attribute (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: Fix for device scan following host reset could get stuck in a infinite loop (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: Update the timing requirements for issuing a Hard Reset (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: MPI2 Rev W (2.00.15) specification (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: Fix for issue Missing delay not getting set during system bootup (Reddy, Sreekanth)  [Orabug: 19015667]  
- mpt2sas: Add support for OEM specific controller (Sreekanth Reddy)  [Orabug: 19015667]  
- mpt2sas: fix for driver fails EEH, recovery from injected pci bus error (Sreekanth Reddy)  [Orabug: 19015667]  
- Revert "mpt2sas: update to LSI version 16.05.01.00" (Martin K. Petersen)  [Orabug: 19015667]  
- Revert "mpt2sas: update from 16.05.01.00 to 17.00.00.00" (Martin K. Petersen)  [Orabug: 19015667]  
- Revert "mpt2sas: Rework the MSI-X code to work on systems with many processors" (Martin K. Petersen)  [Orabug: 19015667]  
- megaraid_sas: Version and Changelog update (Adam Radford)  [Orabug: 19015667]  
- megaraid_sas: Fix LD/VF affiliation parsing (Adam Radford)  [Orabug: 19015667]  
- megaraid_sas: Remove unused variables in megasas_instance (Adam Radford)  [Orabug: 19015667]  
- megaraid_sas: Fix reset_mutex leak (Adam Radford)  [Orabug: 19015667]  
- megaraid_sas: fix a small problem when reading state value from hw (Tomas Henzl)  [Orabug: 19015667]  
- megaraid_sas: Version and Changelog update (Adam Radford)  [Orabug: 19015667]  
- megaraid_sas: Add Dell PowerEdge VRTX SR-IOV VF support (Adam Radford)  [Orabug: 19015667]  
- megaraid_sas: Return leaked MPT frames to MPT frame pool (Adam Radford)  [Orabug: 19015667]  
- megaraid_sas: Fix megasas_ioc_init_fusion (Adam Radford)  [Orabug: 19015667]  
- megaraid_sas: Load correct raid context timeout (Adam Radford)  [Orabug: 19015667]  
- megaraid_sas: Performance boost fixes (Sumit.Saxena@lsi.com)  [Orabug: 19015667]  
- megaraid_sas: Set 32-bit DMA mask (Sumit.Saxena@lsi.com)  [Orabug: 19015667]  
- megaraid_sas: Big endian code related fixes (Sumit.Saxena@lsi.com)  [Orabug: 19015667]  
- megaraid_sas: Don't wait forever for non-IOCTL DCMDs (Sumit.Saxena@lsi.com)  [Orabug: 19015667]  
- megaraid_sas: check return value for megasas_get_pd_list() (Hannes Reinecke)  [Orabug: 19015667]  
- megaraid_sas_fusion: Return correct error value in megasas_get_ld_map_info() (Hannes Reinecke)  [Orabug: 19015667]  
- megaraid_sas_fusion: correctly pass queue info pointer (Hannes Reinecke)  [Orabug: 19015667]  
- megaraid: missing bounds check in mimd_to_kioc() (Dan Carpenter)  [Orabug: 19015667]  
- megaraid: Use resource_size_t for PCI resources, not long (Ben Collins)  [Orabug: 19015667]  

* Mon Jul 14 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-39.el7uek] 
- PCI: Work around Ivytown NTB BAR size issue (Jon Mason)  [Orabug: 18127862]  
- cgroup: make cgroup_path() not print double slashes (Tejun Heo)  [Orabug: 18510637]  
- xen: Introduce 'xen_nopv' to disable PV extensions for HVM guests. (Konrad Rzeszutek Wilk)  [Orabug: 19033747]  
- spec: reenable pesign module signing (Guangyu Sun)  [Orabug: 19065003]  
- [ocfs2]: refcount: take rw_lock in ocfs2_reflink (Wengang Wang)  [Orabug: 19154247]  
- cifs: bugfix for unreclaimed writeback pages in cifs_writev_requeue() (Ouyang Maochun)  [Orabug: 18447168]  
- xfs: add CRCs to attr leaf blocks (Dave Chinner)  [Orabug: 18504299]  
- xfs: add CRCs to dir2/da node blocks (Dave Chinner)  [Orabug: 18504299]  
- xfs: shortform directory offsets change for dir3 format (Dave Chinner)  [Orabug: 18504299]  
- xfs: add CRC checking to dir2 leaf blocks (Dave Chinner)  [Orabug: 18504299]  
- xfs: add CRC checking to dir2 data blocks (Dave Chinner)  [Orabug: 18504299]  
- xfs: add CRC checking to dir2 free blocks (Dave Chinner)  [Orabug: 18504299]  
- xfs: add CRC checks to block format directory blocks (Dave Chinner)  [Orabug: 18504299]  
- xfs: add CRC checks to remote symlinks (Dave Chinner)  [Orabug: 18504299]  
- xfs: split out symlink code into it's own file. (Dave Chinner)  [Orabug: 18504299]  
- xfs: add version 3 inode format with CRCs (Christoph Hellwig)  [Orabug: 18504299]  
- xfs: add CRC checks for quota blocks (Christoph Hellwig)  [Orabug: 18504299]  
- xfs: add CRC checks to the AGI (Dave Chinner)  [Orabug: 18504299]  
- xfs: add CRC checks to the AGFL (Christoph Hellwig)  [Orabug: 18504299]  
- xfs: add CRC checks to the AGF (Dave Chinner)  [Orabug: 18504299]  
- xfs: add support for large btree blocks (Christoph Hellwig)  [Orabug: 18504299]  
- xfs: xfs_iomap_prealloc_size() tracepoint (Brian Foster)  [Orabug: 18504299]  
- xfs: add quota-driven speculative preallocation throttling (Brian Foster)  [Orabug: 18504299]  
- xfs: xfs_dquot prealloc throttling watermarks and low free space (Brian Foster)  [Orabug: 18504299]  
- xfs: pass xfs_dquot to xfs_qm_adjust_dqlimits() instead of xfs_disk_dquot_t (Brian Foster)  [Orabug: 18504299]  
- xfs: push rounddown_pow_of_two() to after prealloc throttle (Brian Foster)  [Orabug: 18504299]  
- xfs: reorganize xfs_iomap_prealloc_size to remove indentation (Brian Foster)  [Orabug: 18504299]  
- xfs: take inode version into account in XFS_LITINO (Christoph Hellwig)  [Orabug: 18504299]  
- xfs: rearrange some code in xfs_bmap for better locality (Dave Chinner)  [Orabug: 18504299]  
- xfs: don't verify buffers after IO errors (Dave Chinner)  [Orabug: 18504299]  
- xfs: limit speculative prealloc size on sparse files (Dave Chinner)  [Orabug: 18504299]  
- xfs: memory barrier before wake_up_bit() (Alex Elder)  [Orabug: 18504299]  
- xfs: refactor space log reservation for XFS_TRANS_ATTR_SET (Jeff Liu)  [Orabug: 18504299]  
- xfs: make use of XFS_SB_LOG_RES() at xfs_fs_log_dummy() (Jeff Liu)  [Orabug: 18504299]  
- xfs: make use of XFS_SB_LOG_RES() at xfs_mount_log_sb() (Jeff Liu)  [Orabug: 18504299]  
- xfs: make use of XFS_SB_LOG_RES() at xfs_log_sbcount() (Jeff Liu)  [Orabug: 18504299]  
- xfs: introduce XFS_SB_LOG_RES() for transactions that modify sb on disk (Jeff Liu)  [Orabug: 18504299]  
- xfs: calculate XFS_TRANS_QM_QUOTAOFF_END space log reservation at mount time (Jeff Liu)  [Orabug: 18504299]  
- xfs: calculate XFS_TRANS_QM_QUOTAOFF space log reservation at mount time (Jeff Liu)  [Orabug: 18504299]  
- xfs: calculate XFS_TRANS_QM_DQALLOC space log reservation at mount time (Jeff Liu)  [Orabug: 18504299]  
- xfs: calcuate XFS_TRANS_QM_SETQLIM space log reservation at mount time (Jeff Liu)  [Orabug: 18504299]  
- xfs: calculate xfs_qm_write_sb_changes() space log reservation at mount time (Jeff Liu)  [Orabug: 18504299]  
- xfs: calculate XFS_TRANS_QM_SBCHANGE space log reservation at mount time (Jeff Liu)  [Orabug: 18504299]  
- xfs: make use of xfs_calc_buf_res() in xfs_trans.c (Jeff Liu)  [Orabug: 18504299]  
- xfs: add a helper to figure out the space log reservation per item (Jeff Liu)  [Orabug: 18504299]  
- xfs: fix fs/xfs/xfs_log.c:1740:39: error: 'B_TRUE' undeclared (Ben Myers)  [Orabug: 18504299]  
- xfs: Remove boolean_t typedef completely. (Thiago Farina)  [Orabug: 18504299]  
- fs/xfs remove obsolete simple_strto<foo> (Abhijit Pawar)  [Orabug: 18504299]  
- xfs: don't zero structure members after a memset(0) (Eric Sandeen)  [Orabug: 18504299]  
- xfs remove the XFS_TRANS_DEBUG routines (Mark Tinguely)  [Orabug: 18504299]  
- spec: list linux-firmware as a dependency (Guangyu Sun)  [Orabug: 18539100]  
- kbuild/ctf: Fix out-of-tree module build when CONFIG_CTF=n. (Nick Alcock)  [Orabug: 19078361]  
- dtrace: support order-only-prerequisites for sdtstub generation (Kris Van Hees)  [Orabug: 18906444]  
- qlcnic: Add SRIOV helper function to determine if VFs are assigned to guest (Vaughan Cao)  [Orabug: 19167877]  
- qlcnic: make Kconfig changes (Vaughan Cao)  [Orabug: 19167877]  
- qlcnic: sysfs interface for PCI BAR access (Sony Chacko)  [Orabug: 19167877]  
- qlcnic: Update version to 5.3.59 (Rajesh Borundia)  [Orabug: 19167877]  
- qlcnic: Collect firmware dump using DMA on 82xx adapters (Shahed Shaikh)  [Orabug: 19167877]  
- qlcnic: Add mac learning support to SR-IOV VF. (Rajesh Borundia)  [Orabug: 19167877]  
- qlcnic: Add support to process commands in atomic context (Rajesh Borundia)  [Orabug: 19167877]  
- qlcnic: Allow SR-IOV VF probe in hypervisor. (Rajesh Borundia)  [Orabug: 19167877]  
- qlcnic: Set real_num_{tx|rx}_queues properly (Shahed Shaikh)  [Orabug: 19167877]  
- qlcnic: Fix panic while dumping TX queues on TX timeout (Manish Chopra)  [Orabug: 19167877]  
- qlcnic: Update version to 5.3.58 (Jitendra Kalsaria)  [Orabug: 19167877]  
- qlcnic: Limit vNIC support in legacy interrupt mode (Sucheta Chakraborty)  [Orabug: 19167877]  
- qlcnic: Add driver logs in error path. (Sucheta Chakraborty)  [Orabug: 19167877]  
- qlcnic: Allow setting TX interrupt coalescing parameters from VF. (Sucheta Chakraborty)  [Orabug: 19167877]  
- qlcnic: Add hwmon-sysfs interface to export board temperature. (Harish Patil)  [Orabug: 19167877]  
- qlcnic: Optimize MAC learning code (Shahed Shaikh)  [Orabug: 19167877]  
- qlcnic: Fix memory leak. (Rajesh Borundia)  [Orabug: 19167877]  
- qlcnic: Reset firmware API lock at driver load time (Sony Chacko)  [Orabug: 19167877]  
- qlcnic: Fix MSI-X initialization code (Alexander Gordeev)  [Orabug: 19167877]  
- qlcnic: Do not disable SR-IOV when VFs are assigned to VMs (Manish Chopra)  [Orabug: 19167877]  
- qlcnic: Fix QLogic application/driver interface for virtual NIC configuration (Jitendra Kalsaria)  [Orabug: 19167877]  
- qlcnic: Fix PVID configuration on eSwitch port. (Jitendra Kalsaria)  [Orabug: 19167877]  
- qlcnic: Fix max ring count calculation (Shahed Shaikh)  [Orabug: 19167877]  
- qlcnic: Fix to send INIT_NIC_FUNC as first mailbox. (Sucheta Chakraborty)  [Orabug: 19167877]  
- qlcnic: Fix panic due to uninitialzed delayed_work struct in use. (Sucheta Chakraborty)  [Orabug: 19167877]  
- net: qlcnic: include irq.h for irq definitions (Josh Boyer)  [Orabug: 19167877]  
- qlcnic: Remove casts of pointer to same type (Joe Perches)  [Orabug: 19167877]  
- qlcnic: Update version to 5.3.57 (Shahed Shaikh)  [Orabug: 19167877]  
- qlcnic: dcb: a couple off by one bugs (Dan Carpenter)  [Orabug: 19167877]  
- qlcnic: Fix number of rings when we fall back from msix to legacy. (Rajesh Borundia)  [Orabug: 19167877]  
- qlcnic: Allow any VLAN to be configured from VF. (Sucheta Chakraborty)  [Orabug: 19167877]  
- qlcnic: Fix usage of use_msi and use_msi_x module parameters (Shahed Shaikh)  [Orabug: 19167877]  
- qlcnic: Fix function return error check (Shahed Shaikh)  [Orabug: 19167877]  
- qlcnic: Update version to 5.3.56 (Shahed Shaikh)  [Orabug: 19167877]  
- qlcnic: Enhance semaphore lock access failure error message (Harish Patil)  [Orabug: 19167877]  
- qlcnic: Allow vlan0 traffic (Rajesh Borundia)  [Orabug: 19167877]  
- qlcnic: Enhance driver message in failed state. (Sucheta Chakraborty)  [Orabug: 19167877]  
- qlcnic: Updates to QLogic application/driver interface for virtual NIC configuration (Jitendra Kalsaria)  [Orabug: 19167877]  
- qlcnic: Re-factor firmware minidump template header handling (Shahed Shaikh)  [Orabug: 19167877]  
- qlcnic: Cleanup qlcnic_enable_msix() return values (Alexander Gordeev)  [Orabug: 19167877]  
- qlcnic: Reverse patches till 5.3.55. (Sucheta Chakraborty)  [Orabug: 19167877]  
- qla4xxx: Update driver verion to v5.04.00.06.06.02-uek3 (Tej Parkash)  [Orabug: 19144350]  
- qla4xxx: Use kmemdup instead of kmalloc + memcpy (Benoit Taine)  [Orabug: 19144350]  
- qla4xxx: Fix smatch warning in func qla4xxx_conn_get_param (Adheer Chandravanshi)  [Orabug: 19144350]  
- qla4xxx: Fix smatch warning in func qla4xxx_get_ep_param (Adheer Chandravanshi)  [Orabug: 19144350]  
- qla4xxx: Fix memory leak for ha->saved_acb (Nilesh Javali)  [Orabug: 19144350]  
- qla4xxx: Export sysfs DDBs from DPC handler (Nilesh Javali)  [Orabug: 19144350]  
- qla4xxx: Disable INTx interrupt for ISP82XX (Tej Parkash)  [Orabug: 19144350]  
- hpsa: add previously missing pci_device_id (Vaughan Cao)  [Orabug: 19137821]  
- hpsa: fix handling of hpsa_volume_offline return value (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: return -ENOMEM not -1 on kzalloc failure in hpsa_get_device_id (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: remove messages about volume status VPD inquiry page not supported (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: report check condition even if no sense data present for ioaccel2 mode (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: remove bad unlikely annotation from device list updating code (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: fix event filtering to prevent excessive rescans with old firmware (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: kill annoying messages about SSD Smart Path retries (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: define extended_report_lun_entry data structure (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: Rearrange start_io to avoid one unlock/lock sequence in main io path (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: avoid unnecessary readl on every command submission (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: use per-cpu variable for lockup_detected (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: set irq affinity hints to route MSI-X vectors across CPUs (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: allocate reply queues individually (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: choose number of reply queues more intelligently. (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: remove dev_dbg() calls from hot paths (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: use gcc aligned attribute instead of manually padding structs (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: change doorbell reset delay to ten seconds (Justin Lindley)  [Orabug: 19137821]  
- hpsa: allow passthru ioctls to work with bidirectional commands (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: remove unused fields from struct ctlr_info (Stephen M. Cameron)  [Orabug: 19137821]  
- hpsa: fix bad comparison of signed with unsigned in hpsa_update_scsi_devices (Joe Handzik)  [Orabug: 19137821]  
- hpsa: do not ignore failure of sense controller parameters command (Joe Handzik)  [Orabug: 19137821]  
- hpsa: fix memory leak in hpsa_hba_mode_enabled (Joe Handzik)  [Orabug: 19137821]  
- hpsa: Checking for a NULL return from a kzalloc call (Joe Handzik)  [Orabug: 19137821]  
- hpsa: unnecessary type conversion for physdev_list (Vaughan Cao)  [Orabug: 19137821]  
- hpsa: detect_controller_lockup don't need return value (Vaughan Cao)  [Orabug: 19137821]  
- hpsa: fixup MSI-X registration (Hannes Reinecke)  [Orabug: 19137821]  
- xen/microcode: Use dummy microcode_ops for non initial domain guest (Zhenzhong Duan)  [Orabug: 19053626]  
- hyperv: Change the receive buffer size for legacy hosts (Haiyang Zhang)  [Orabug: 19050496]  
- be2net: fix qnq mode detection on VFs (Suresh Reddy)  [Orabug: 19006455]  
- be2net: cleanup MCC async event processing code (Sathya Perla)  [Orabug: 19006455]  
- be2net: move async cmd processing to a separate routine (Sathya Perla)  [Orabug: 19006455]  
- be2net: re-factor MCCQ error status handling code (Kalesh AP)  [Orabug: 19006455]  
- be2net: support flashing new regions on Skyhawk-R (Vasundhara Volam)  [Orabug: 19006455]  
- be2net: skip multicast promiscuos setting in already set (Kalesh AP)  [Orabug: 19006455]  
- be2net: enable interrupts in EEH resume (Kalesh AP)  [Orabug: 19006455]  
- net: get rid of SET_ETHTOOL_OPS (Wilfried Klaebe)  [Orabug: 19006455]  
- be2net: use MCCQ instead of MBOX in be_cmd_rss_config() (Kalesh AP)  [Orabug: 19006455]  
- be2net: include rx-compl error counter in ethtool stats (Kalesh AP)  [Orabug: 19006455]  
- be2net: remove unused code in be_cmd_vlan_config() (Kalesh AP)  [Orabug: 19006455]  
- be2net: covert vlan array to bit-map (Ravikumar Nelavelli)  [Orabug: 19006455]  
- be2net: fix line wrap and function call indentation in be_ethtool.c (Sathya Perla)  [Orabug: 19006455]  
- be2net: fix function call indentation in be_cmds.c (Sathya Perla)  [Orabug: 19006455]  
- be2net: fix line wrap and function call indentation in be_main.c (Sathya Perla)  [Orabug: 19006455]  
- be2net: Fix invocation of be_close() after be_clear() (Kalesh AP)  [Orabug: 19006455]  
- be2net: Fix to reap TX compls till HW doesn't respond for some time (Vasundhara Volam)  [Orabug: 19006455]  
- selinux: correctly label /proc inodes in use before the policy is loaded (Paul Moore)  [Orabug: 18823621]  
- mm, hugetlb: improve page-fault scalability (Davidlohr Bueso)  [Orabug: 18757256]  
- config: build TPM HW Random Number Generator as module (Guangyu Sun)  [Orabug: 18502024]  
- cpufreq: Drop rwsem lock around CPUFREQ_GOV_POLICY_EXIT (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Preserve sysfs files across suspend/resume (Srivatsa S. Bhat)  [Orabug: 18464169]  
- cpufreq, ondemand: Remove leftover debug line (Borislav Petkov)  [Orabug: 18464169]  
- cpufreq: Issue CPUFREQ_GOV_POLICY_EXIT notifier before dropping policy refcount (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: governors: Fix CPUFREQ_GOV_POLICY_{INIT|EXIT} notifiers (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Revert incorrect commit 5800043 (Rafael J. Wysocki)  [Orabug: 18464169]  
- cpufreq: Don't call __cpufreq_governor() for drivers without target() (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: convert cpufreq_driver to using RCU (Nathan Zimmer)  [Orabug: 18464169]  
- cpufreq: Call __cpufreq_governor() with correct policy->cpus mask (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Correct header guards typo (Borislav Petkov)  [Orabug: 18464169]  
- cpufreq: Fix unsigned variable being checked for negative value (jhbird.choi@samsung.com)  [Orabug: 18464169]  
- cpufreq: conservative: Fix the logic in frequency decrease checking (Stratos Karafotis)  [Orabug: 18464169]  
- cpufreq: conservative: Fix sampling_down_factor functionality (Stratos Karafotis)  [Orabug: 18464169]  
- cpufreq: governors: Calculate iowait time only when necessary (Stratos Karafotis)  [Orabug: 18464169]  
- cpufreq: conservative: Fix relation when decreasing frequency (Namhyung Kim)  [Orabug: 18464169]  
- cpufreq: conservative: Break out earlier on the lowest frequency (Namhyung Kim)  [Orabug: 18464169]  
- cpufreq: governors: Avoid unnecessary per cpu timer interrupts (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: ondemand: Don't update sample_type if we don't evaluate load again (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: governor: Set MIN_LATENCY_MULTIPLIER to 20 (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: governor: Implement per policy instances of governors (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Add per policy governor-init/exit infrastructure (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Convert the cpufreq_driver_lock to a rwlock (Nathan Zimmer)  [Orabug: 18464169]  
- cpufreq: acpi-cpufreq: Don't set policy->related_cpus from .init() (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: stats: do cpufreq_cpu_put() corresponding to cpufreq_cpu_get() (viresh kumar)  [Orabug: 18464169]  
- cpufreq_stats: do not remove sysfs files if frequency table is not present (Dirk Brandewie)  [Orabug: 18464169]  
- cpufreq: Do not track governor name for scaling drivers with internal governors. (Dirk Brandewie)  [Orabug: 18464169]  
- cpufreq: Only call cpufreq_out_of_sync() for driver that implement cpufreq_driver.target() (Dirk Brandewie)  [Orabug: 18464169]  
- cpufreq: Retrieve current frequency from scaling drivers with internal governors (Dirk Brandewie)  [Orabug: 18464169]  
- cpufreq: Fix locking issues (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Create a macro for unlock_policy_rwsem{read,write} (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Remove unused HOTPLUG_CPU code (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: governors: Fix WARN_ON() for multi-policy platforms (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: ondemand: Replace down_differential tuner with adj_up_threshold (Stratos Karafotis)  [Orabug: 18464169]  
- cpufreq / stats: Get rid of CPUFREQ_STATDEVICE_ATTR (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Don't check cpu_online(policy->cpu) (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Don't remove sysfs link for policy->cpu (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: governors: Reset tunables only for cpufreq_unregister_governor() (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: governors: Remove code redundancy between governors (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: governors: Get rid of dbs_data->enable field (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: governors: fix misuse of cdbs.cpu (Fabio Baltieri)  [Orabug: 18464169]  
- cpufreq: governors: implement generic policy_is_shared (Fabio Baltieri)  [Orabug: 18464169]  
- cpufreq: governors: clean timer init and exit code (Fabio Baltieri)  [Orabug: 18464169]  
- cpufreq: Simplify cpufreq_add_dev() (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Revert "cpufreq: Don't use cpu removed during cpufreq_driver_unregister" (Viresh Kumar)  [Orabug: 18464169]  
- powernow-k8: Cleanup init function (Borislav Petkov)  [Orabug: 18464169]  
- powernow-k8: Cleanup module request (Borislav Petkov)  [Orabug: 18464169]  
- cpufreq: Add a get_current_driver helper (Borislav Petkov)  [Orabug: 18464169]  
- cpufreq: Make acpi-cpufreq link first (Borislav Petkov)  [Orabug: 18464169]  
- acpi-cpufreq: Do not load on K8 (Matthew Garrett)  [Orabug: 18464169]  
- cpufreq: handle cpufreq being disabled for all exported function. (Dirk Brandewie)  [Orabug: 18464169]  
- cpufreq: Simplify __cpufreq_remove_dev() (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Don't use cpu removed during cpufreq_driver_unregister (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Notify governors when cpus are hot-[un]plugged (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: Manage only online cpus (Viresh Kumar)  [Orabug: 18464169]  
- cpufreq: ondemand: use all CPUs in update_sampling_rate (Fabio Baltieri)  [Orabug: 18464169]  
- cpufreq: conservative: call dbs_check_cpu only when necessary (Fabio Baltieri)  [Orabug: 18464169]  
- cpufreq: ondemand: call dbs_check_cpu only when necessary (Fabio Baltieri)  [Orabug: 18464169]  
- cpufreq: handle SW coordinated CPUs (Rickard Andersson)  [Orabug: 18464169]  
- PM / tracing: remove deprecated power trace API (Paul Gortmaker)  [Orabug: 18464169]  
- xen/balloon: set ballooned out pages as invalid in p2m (David Vrabel)  [Orabug: 19182632]  
- xen/manage: fix potential deadlock when resuming the console (David Vrabel)  [Orabug: 19182632]  
- xen/grant-table: fix suspend for non-PV guests (David Vrabel)  [Orabug: 19182632]  
- x86/xen: no need to explicitly register an NMI callback (David Vrabel)  [Orabug: 19182632]  
- Revert "xen/pvh: Update E820 to work with PVH (v2)" (David Vrabel)  [Orabug: 19182632]  
- x86/xen: fix memory setup for PVH dom0 (David Vrabel)  [Orabug: 19182632]  
- x86/xen: map foreign pfns for autotranslated guests (Mukesh Rathor)  [Orabug: 19182632]  
- xen-acpi-processor: Don't display errors when we get -ENOSYS (Konrad Rzeszutek Wilk)  [Orabug: 19182632]  
- xen/pciback: Document the entry points for 'pcistub_put_pci_dev' (Konrad Rzeszutek Wilk)  [Orabug: 19182632]  
- xen/pciback: Document when the 'unbind' and 'bind' functions are called. (Konrad Rzeszutek Wilk)  [Orabug: 19182632]  
- xen-pciback: Document when we FLR an PCI device. (Konrad Rzeszutek Wilk)  [Orabug: 19182632]  
- xen-pciback: First reset, then free. (Konrad Rzeszutek Wilk)  [Orabug: 19182632]  
- xen-pciback: Cleanup up pcistub_put_pci_dev (Konrad Rzeszutek Wilk)  [Orabug: 19182632]  
- x86/xen: do not use _PAGE_IOMAP in xen_remap_domain_mfn_range() (David Vrabel)  [Orabug: 19182632]  
- x86/xen: set regions above the end of RAM as 1:1 (David Vrabel)  [Orabug: 19182632]  
- x86/xen: only warn once if bad MFNs are found during setup (David Vrabel)  [Orabug: 19182632]  
- x86/xen: compactly store large identity ranges in the p2m (David Vrabel)  [Orabug: 19182632]  
- x86/xen: fix set_phys_range_identity() if pfn_e > MAX_P2M_PFN (David Vrabel)  [Orabug: 19182632]  
- x86/xen: rename early_p2m_alloc() and early_p2m_alloc_middle() (David Vrabel)  [Orabug: 19182632]  
- xen/x86: set panic notifier priority to minimum (Radim Krčmář)  [Orabug: 19182632]  
- xen: refactor suspend pre/post hooks (David Vrabel)  [Orabug: 19182632]  
- xen-blkback: defer freeing blkif to avoid blocking xenwatch (Valentin Priescu)  [Orabug: 19182632]  
- xen blkif.h: fix comment typo in discard-alignment (Olaf Hering)  [Orabug: 19182632]  
- xen/blkback: disable discard feature if requested by toolstack (Olaf Hering)  [Orabug: 19182632]  
- xen-blkfront: remove type check from blkfront_setup_discard (Olaf Hering)  [Orabug: 19182632]  
- net: flow_dissector: fail on evil iph->ihl (Jason Wang)  [Orabug: 18681886]  {CVE-2013-4348} 
- netxen: fix ethtool rx_dropped information in ethtool get_ethtool_stats() (Ethan Zhao)  [Orabug: 19140643]  
- ixgbevf: upgrade to intel version 2.14.2 (Ethan Zhao)  [Orabug: 19139349]  
- ixgbe: upgrade to intel version 3.21.2 and merge patches based on 3.19.1 (Ethan Zhao)  [Orabug: 19137937]  
- net: get rid of SET_ETHTOOL_OPS (Wilfried Klaebe)  [Orabug: 19167879]  
- qlge: Convert /n to 
 (Joe Perches)  [Orabug: 19167879]  
- qlge: remove open-coded skb_cow_head. (françois romieu)  [Orabug: 19167879]  
- qlge: Use pci_enable_msix_range() instead of pci_enable_msix() (Alexander Gordeev)  [Orabug: 19167879]  
- qlge: Get rid of an redundant assignment (Alexander Gordeev)  [Orabug: 19167879]  
- drivers/net: delete non-required instances of include <linux/init.h> (Paul Gortmaker)  [Orabug: 19167879]  
- qlge: Fix vlan netdev features. (Vaughan Cao)  [Orabug: 19167879]  
- qlge: make local function static (stephen hemminger)  [Orabug: 19167879]  
- net: get rid of SET_ETHTOOL_OPS (Wilfried Klaebe)  [Orabug: 19167878]  
- netxen: Use pci_enable_msix_range() instead of pci_enable_msix() (Alexander Gordeev)  [Orabug: 19167878]  
- net: netxen: slight optimization of addr compare (dingtianhong)  [Orabug: 19167878]  
- netxen: Correct off-by-one errors in bounds checks (David Gibson)  [Orabug: 19167878]  
- ethernet: Fix FSF address in file headers (Jeff Kirsher)  [Orabug: 19167878]  
- net: netxen: remove unnecessary pci_set_drvdata() (Jingoo Han)  [Orabug: 19167878]  
- net:drivers/net: Miscellaneous conversions to ETH_ALEN (Joe Perches)  [Orabug: 19167878]  
- PCI/MSI: Add pci_enable_msi_range() and pci_enable_msix_range() (Alexander Gordeev)  [Orabug: 19167878]  
- igb: upgrade from 5.0.6 to 5.2.5 (Ethan Zhao)  [Orabug: 19137922]  
- e1000e: upgrade to intel version 3.1.0.2 and merge patches based on 2.5.4 (Ethan Zhao)  [Orabug: 19137899]  
- intel_idle: fix IVT idle state table setting (Christoph Jaeger)  [Orabug: 18899422]  
- intel_idle: fine-tune IVT residency targets (Len Brown)  [Orabug: 18899460]  
- intel_idle: Add CPU model 54 (Atom N2000 series) (Jan Kiszka)  [Orabug: 18911404]  
- intel_idle: support Bay Trail (Len Brown)  [Orabug: 18899457]  
- intel_idle: allow sparse sub-state numbering, for Bay Trail (Len Brown)  [Orabug: 18899452]  
- intel_idle: remove superfluous dev->state_count initialization (Bartlomiej Zolnierkiewicz)  [Orabug: 18899449]  
- intel_idle: do C1E promotion disable quirk for hotplugged CPUs (Bartlomiej Zolnierkiewicz)  [Orabug: 18899445]  
- intel_idle: close avn_cstates array with correct marker (Jiang Liu)  [Orabug: 18909669]  
- Revert "intel_idle: mark states tables with __initdata tag" (Jiang Liu)  [Orabug: 18899443]  
- x86 idle: Repair large-server 50-watt idle-power regression (Len Brown)  [Orabug: 18899435]  
- intel_idle: Fixed C6 state on Avoton/Rangeley processors (Bockholdt Arne)  [Orabug: 18899432]  
- soreuseport: fix up kabi breakage after backporting soreuseport (Chuck Anderson)  [Orabug: 18459758]  
- udp: fix two sparse errors (Eric Dumazet)  [Orabug: 18459758]  
- soreuseport: fix use of uid in tb->fastuid (Tom Herbert)  [Orabug: 18459758]  
- Remove leftover #endif after introducing SO_REUSEPORT (Thomas Graf)  [Orabug: 18459758]  
- soreuseport: UDP/IPv6 implementation (Tom Herbert)  [Orabug: 18459758]  
- soreuseport: TCP/IPv6 implementation (Tom Herbert)  [Orabug: 18459758]  
- soreuseport: UDP/IPv4 implementation (Tom Herbert)  [Orabug: 18459758]  
- soreuseport: TCP/IPv4 implementation (Tom Herbert)  [Orabug: 18459758]  
- soreuseport: infrastructure (Tom Herbert)  [Orabug: 18459758]  
- pci: fix kabi break due to pci reset nofity backport (Jerry Snitselaar)  [Orabug: 19080834]  

* Fri Jun 20 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-38.el7uek] 
- NVMe: Fix START_STOP_UNIT Scsi->NVMe translation. (Dan McLeran)  [Orabug: 18940591]  
- NVMe: Use Log Page constants in SCSI emulation (Matthew Wilcox)  [Orabug: 18940591]  
- NVMe: Define Log Page constants (Matthew Wilcox)  [Orabug: 18940591]  
- NVMe: Fix hot cpu notification dead lock (Keith Busch)  [Orabug: 18940591]  
- NVMe: Rename io_timeout to nvme_io_timeout (Matthew Wilcox)  [Orabug: 18940591]  
- NVMe: Use last bytes of f/w rev SCSI Inquiry (Keith Busch)  [Orabug: 18940591]  
- NVMe: Adhere to request queue block accounting enable/disable (Sam Bradshaw)  [Orabug: 18940591]  
- NVMe: Fix nvme get/put queue semantics (Keith Busch)  [Orabug: 18940591]  
- NVMe: Delete NVME_GET_FEAT_TEMP_THRESH (Matthew Wilcox)  [Orabug: 18940591]  
- NVMe: Make admin timeout a module parameter (Keith Busch)  [Orabug: 18940591]  
- NVMe: Make iod bio timeout a parameter (Keith Busch)  [Orabug: 18940591]  
- NVMe: Prevent possible NULL pointer dereference (Santosh Y)  [Orabug: 18940591]  
- NVMe: Fix the buffer size passed in GetLogPage(CDW10.NUMD) (Indraneel Mukherjee)  [Orabug: 18940591]  
- NVMe: Enable BUILD_BUG_ON checks (Matthew Wilcox)  [Orabug: 18940591]  
- NVMe: Add tracepoints (Keith Busch)  [Orabug: 18940591]  
- NVMe: Protect against badly formatted CQEs (Keith Busch)  [Orabug: 18940591]  
- NVMe: Improve error messages (Matthew Wilcox)  [Orabug: 18940591]  
- NVMe: Update copyright headers (Matthew Wilcox)  [Orabug: 18940591]  
- NVMe: Implement PCIe reset notification callback (Martin K. Petersen)  [Orabug: 18940591]  
- PCI: Notify driver before and after device reset (Martin K. Petersen)  [Orabug: 18940591]  
- floppy: don't write kernel-only members to FDRAWCMD ioctl output (Matthew Daley)  [Orabug: 19028442]  {CVE-2014-1738} 
- floppy: ignore kernel-only members in FDRAWCMD ioctl input (Matthew Daley)  [Orabug: 19028435]  {CVE-2014-1737} 
- [SCSI] sd: notify block layer when using temporary change to cache_type (Vaughan Cao)  [Orabug: 18829236]  
- [SCSI] sd: Fix parsing of 'temporary ' cache mode prefix (Ben Hutchings)  [Orabug: 18829236]  
- drivers: net: xen-netfront: fix array initialization bug (Vincenzo Maffione)   
- xen-netback: Fix handling of skbs requiring too many slots (Zoltan Kiss)   
- xen-netback: fix race between napi_complete() and interrupt handler (David Vrabel)   
- xen-netback: Fix grant ref resolution in RX path (Zoltan Kiss)   
- xen-netback: Trivial format string fix (Zoltan Kiss)   
- xen-netback: Grant copy the header instead of map and memcpy (Zoltan Kiss)   
- xen-netback: Rename map ops (Zoltan Kiss)   
- xen-netback: BUG_ON in xenvif_rx_action() not catching overflow (Paul Durrant)   
- Revert "xen/mmu: Move the setting of pvops.write_cr3 to later phase in bootup." (Konrad Rzeszutek Wilk)   
- xen-netback: worse-case estimate in xenvif_rx_action is underestimating (Paul Durrant)   
- xen-netback: remove pointless clause from if statement (Paul Durrant)   
- xen-netback: Functional follow-up patch for grant mapping series (Zoltan Kiss)   
- xen-netback: Non-functional follow-up patch for grant mapping series (Zoltan Kiss)   
- xen-netback: Stop using xenvif_tx_pending_slots_available (Zoltan Kiss)   
- xen-netback: Proper printf format for ptrdiff_t is 't'. (David S. Miller)   
- Revert "xen-netback: Aggregate TX unmap operations" (Zoltan Kiss)   
- xen-netback: use skb_is_gso in xenvif_start_xmit (Wei Liu)   
- Xen-netback: Fix issue caused by using gso_type wrongly (Annie Li)   
- xen-netback: Aggregate TX unmap operations (Zoltan Kiss)   
- xen-netback: Timeout packets in RX path (Zoltan Kiss)   
- xen-netback: Handle guests with too many frags (Zoltan Kiss)   
- xen-netback: Add stat counters for zerocopy (Zoltan Kiss)   
- xen-netback: Remove old TX grant copy definitons and fix indentations (Zoltan Kiss)   
- xen-netback: Introduce TX grant mapping (Zoltan Kiss)   
- xen-netback: Handle foreign mapped pages on the guest RX path (Zoltan Kiss)   
- xen-netback: Minor refactoring of netback code (Zoltan Kiss)   
- xen-netback: Use skb->cb for pending_idx (Zoltan Kiss)   
- Revert "Xen-netback: Fix issue caused by using gso_type wrongly" (Annie Li)   
- arm64: introduce virt_to_pfn (Stefano Stabellini)   
- xen/events/fifo: correctly align bitops (Vladimir Murzin)   
- arm/xen: Remove definiition of virt_to_pfn in asm/xen/page.h (Julien Grall)   
- xen/manage: Poweroff forcefully if user-space is not yet up. (Konrad Rzeszutek Wilk)   
- xen/xenbus: Avoid synchronous wait on XenBus stalling shutdown/restart. (Konrad Rzeszutek Wilk)   
- xen-pciback: silence an unwanted debug printk (Dan Carpenter)   
- xen: fix memory leak in __xen_pcibk_add_pci_dev() (Daeseok Youn)   
- xen/acpi-processor: fix enabling interrupts on syscore_resume (Stanislaw Gruszka)   
- xen/grant-table: Refactor gnttab_[un]map_refs to avoid m2p_override (Zoltan Kiss)   
- xen: remove XEN_PRIVILEGED_GUEST (Michael Opdenacker)   
- xen/xenbus: remove unused xenbus_bind_evtchn() (David Vrabel)   
- xen/events: remove unnecessary call to bind_evtchn_to_cpu() (David Vrabel)   
- xen/events: remove the unused resend_irq_on_evtchn() (David Vrabel)   
- drivers:xen-selfballoon:reset 'frontswap_inertia_counter' after frontswap_shrink (Bob Liu)   
- drivers: xen: Include appropriate header file in pcpu.c (Rashika Kheria)   
- drivers: xen: Mark function as static in platform-pci.c (Rashika Kheria)   
- xen-blkif: drop struct blkif_request_segment_aligned (Roger Pau Monne)   
- xen-blkback: fix shutdown race (Roger Pau Monne)   
- xen/balloon: flush persistent kmaps in correct position (Wei Liu)   
- ia64/xen: Remove Xen support for ia64 even more (Paul Bolle)   
- xen: install xen/gntdev.h and xen/gntalloc.h (David Vrabel)   
- xen/events: bind all new interdomain events to VCPU0 (David Vrabel)   
- xen/pvh: set CR4 flags for APs (Mukesh Rathor)   
- Revert "xen/grant-table: Avoid m2p_override during mapping" (Konrad Rzeszutek Wilk)   
- xen/pvh: Fix misplaced kfree from xlated_setup_gnttab_pages (Dave Jones)   
- drivers: xen: deaggressive selfballoon driver (Bob Liu)   
- xen/grant-table: Avoid m2p_override during mapping (Zoltan Kiss)   
- xen/gnttab: Use phys_addr_t to describe the grant frame base address (Julien Grall)   
- xen: swiotlb: handle sizeof(dma_addr_t) != sizeof(phys_addr_t) (Ian Campbell)   
- arm/xen: Initialize event channels earlier (Julien Grall)   
- xen/pvh: Set X86_CR0_WP and others in CR0 (v2) (Roger Pau Monne)   
- MAINTAINERS: add git repository for Xen (David Vrabel)   
- xen/pvh: Use 'depend' instead of 'select'. (Konrad Rzeszutek Wilk)   
- xen: delete new instances of __cpuinit usage (Paul Gortmaker)   
- xen/fb: allow xenfb initialization for hvm guests (Stefano Stabellini)   
- xen/evtchn_fifo: fix error return code in evtchn_fifo_setup() (Wei Yongjun)   
- xen-platform: fix error return code in platform_pci_init() (Wei Yongjun)   
- xen/pvh: remove duplicated include from enlighten.c (Wei Yongjun)   
- xen/pvh: Fix compile issues with xen_pvh_domain() (Konrad Rzeszutek Wilk)   
- xen: Use dev_is_pci() to check whether it is pci device (Yijing Wang)   
- xen/grant-table: Force to use v1 of grants. (Konrad Rzeszutek Wilk)   
- xen/pvh: Support ParaVirtualized Hardware extensions (v3). (Mukesh Rathor)   
- xen/pvh: Piggyback on PVHVM XenBus. (Mukesh Rathor)   
- xen/pvh: Piggyback on PVHVM for grant driver (v4) (Konrad Rzeszutek Wilk)   
- xen/grant: Implement an grant frame array struct (v3). (Konrad Rzeszutek Wilk)   
- xen/grant-table: Refactor gnttab_init (Konrad Rzeszutek Wilk)   
- xen/grants: Remove gnttab_max_grant_frames dependency on gnttab_init. (Konrad Rzeszutek Wilk)   
- xen/pvh: Piggyback on PVHVM for event channels (v2) (Mukesh Rathor)   
- xen/pvh: Update E820 to work with PVH (v2) (Mukesh Rathor)   
- xen/pvh: Secondary VCPU bringup (non-bootup CPUs) (Mukesh Rathor)   
- xen/pvh: Load GDT/GS in early PV bootup code for BSP. (Mukesh Rathor)   
- xen/pvh: Setup up shared_info. (Mukesh Rathor)   
- xen/pvh/mmu: Use PV TLB instead of native. (Mukesh Rathor)   
- xen/pvh: MMU changes for PVH (v2) (Mukesh Rathor)   
- xen/mmu: Cleanup xen_pagetable_p2m_copy a bit. (Konrad Rzeszutek Wilk)   
- xen/mmu/p2m: Refactor the xen_pagetable_init code (v2). (Konrad Rzeszutek Wilk)   
- xen/pvh: Don't setup P2M tree. (Konrad Rzeszutek Wilk)   
- xen/pvh: Early bootup changes in PV code (v4). (Mukesh Rathor)   
- xen/pvh/x86: Define what an PVH guest is (v3). (Mukesh Rathor)   
- xen/p2m: Check for auto-xlat when doing mfn_to_local_pfn. (Mukesh Rathor)   
- xen/events: use the FIFO-based ABI if available (David Vrabel)   
- xen/x86: set VIRQ_TIMER priority to maximum (David Vrabel)   
- xen/events: allow event channel priority to be set (David Vrabel)   
- xen/events: Add the hypervisor interface for the FIFO-based event channels (David Vrabel)   
- xen/evtchn: support more than 4096 ports (David Vrabel)   
- xen/events: add xen_evtchn_mask_all() (David Vrabel)   
- xen/events: Refactor evtchn_to_irq array to be dynamically allocated (David Vrabel)   
- xen/events: add a evtchn_op for port setup (David Vrabel)   
- xen/events: allow setup of irq_info to fail (David Vrabel)   
- xen/events: add struct evtchn_ops for the low-level port operations (David Vrabel)   
- xen/events: move 2-level specific code into its own file (David Vrabel)   
- xen/events: move drivers/xen/events.c into drivers/xen/events/ (David Vrabel)   
- xen/events: replace raw bit ops with functions (Wei Liu)   
- xen/events: introduce test_and_set_mask() (Wei Liu)   
- xen/events: remove unnecessary init_evtchn_cpu_bindings() (David Vrabel)   
- xen/events: refactor retrigger_dynirq() and resend_irq_on_evtchn() (David Vrabel)   
- xen/pci: Fix build on non-x86 (Ben Hutchings)   
- xen: simplify balloon_first_page() with list_first_entry_or_null() (Jie Liu)   
- asm/xen/page.h: remove redundant semicolon (Wei Liu)   
- xen: balloon: enable for ARM (Ian Campbell)   
- xen/pvhvm: Remove the xen_platform_pci int. (Konrad Rzeszutek Wilk)   
- xen/pvhvm: If xen_platform_pci=0 is set don't blow up (v4). (Konrad Rzeszutek Wilk)   
- Revert "xen-blkback: fix shutdown race" (Konrad Rzeszutek Wilk)   
- block: xen-blkfront: Fix possible NULL ptr dereference (Felipe Pena)   
- xen-blkfront: Silence pfn maybe-uninitialized warning (Tim Gardner)   
- xen-blkfront: restore the non-persistent data path (Roger Pau Monne)   
- xen/balloon: Seperate the auto-translate logic properly (v2) (Konrad Rzeszutek Wilk)   
- xen/block: Correctly define structures in public headers on ARM32 and ARM64 (Julien Grall)   
- arm: xen: foreign mapping PTEs are special. (Ian Campbell)   
- xen/arm64: do not call the swiotlb functions twice (Stefano Stabellini)   
- xen: privcmd: do not return pages which we have failed to unmap (Ian Campbell)   
- XEN: Grant table address, xen_hvm_resume_frames, is a phys_addr not a pfn (Eric Trudeau)   
- xen/gnttab: leave lazy MMU mode in the case of a m2p override failure (Matt Wilson)   
- xen/arm: p2m_init and p2m_lock should be static (Stefano Stabellini)   
- arm/xen: Export phys_to_mach to fix Xen module link errors (Josh Boyer)   
- swiotlb-xen: add missing xen_dma_map_page call (Stefano Stabellini)   
- xen/arm: pfn_to_mfn and mfn_to_pfn return the argument if nothing is in the p2m (Stefano Stabellini)   
- arm,arm64/include/asm/io.h: define struct bio_vec (Stefano Stabellini)   
- swiotlb-xen: missing include dma-direction.h (Stefano Stabellini)   
- pci-swiotlb-xen: call pci_request_acs only ifdef CONFIG_PCI (Stefano Stabellini)   
- xen: delete new instances of added __cpuinit (Paul Gortmaker)   
- xen/mcfg: Call PHYSDEVOP_pci_mmcfg_reserved for MCFG areas. (Konrad Rzeszutek Wilk)   
- xen: remove deprecated IRQF_DISABLED (Michael Opdenacker)   
- x86/xen: remove deprecated IRQF_DISABLED (Michael Opdenacker)   
- swiotlb-xen: fix error code returned by xen_swiotlb_map_sg_attrs (Stefano Stabellini)   
- swiotlb-xen: static inline xen_phys_to_bus, xen_bus_to_phys, xen_virt_to_bus and range_straddles_page_boundary (Stefano Stabellini)   
- grant-table: call set_phys_to_machine after mapping grant refs (Stefano Stabellini)   
- arm,arm64: do not always merge biovec if we are running on Xen (Stefano Stabellini)   
- swiotlb: print a warning when the swiotlb is full (Stefano Stabellini)   
- swiotlb-xen: use xen_dma_map/unmap_page, xen_dma_sync_single_for_cpu/device (Stefano Stabellini)   
- xen: introduce xen_dma_map/unmap_page and xen_dma_sync_single_for_cpu/device (Stefano Stabellini)   
- tracing/events: Fix swiotlb tracepoint creation (Thierry Reding)   
- swiotlb-xen: use xen_alloc/free_coherent_pages (Stefano Stabellini)   
- xen: introduce xen_alloc/free_coherent_pages (Stefano Stabellini)   
- arm64/xen: get_dma_ops: return xen_dma_ops if we are running as xen_initial_domain (Stefano Stabellini)   
- arm/xen: get_dma_ops: return xen_dma_ops if we are running as xen_initial_domain (Stefano Stabellini)   
- swiotlb-xen: introduce xen_swiotlb_set_dma_mask (Stefano Stabellini)   
- xen/arm,arm64: enable SWIOTLB_XEN (Stefano Stabellini)   
- xen: make xen_create_contiguous_region return the dma address (Stefano Stabellini)   
- xen/x86: allow __set_phys_to_machine for autotranslate guests (Stefano Stabellini)   
- arm/xen,arm64/xen: introduce p2m (Stefano Stabellini)   
- arm64: define DMA_ERROR_CODE (Stefano Stabellini)   
- arm: make SWIOTLB available (Stefano Stabellini)   
- tracing/events: Add bounce tracing to swiotbl (Zoltan Kiss)   
- xen/hvc: If we use xen_raw_printk let it also work on HVM guests. (Konrad Rzeszutek Wilk)   
- xen/mmu: Correct PAT MST setting. (Konrad Rzeszutek Wilk)   
- balloon/pv-superpage: We shouldn't enable this on HVM guests (Konrad Rzeszutek Wilk)   
- Fix balloon driver to work properly with balloon_hugepages but no superpage flag (Dave McCracken)   
- Add support for pv hugepages and support for huge balloon pages. (Dave McCracken)   
- xen: Fix possible user space selector corruption (Frediano Ziglio)   
- xen/balloon: don't alloc page while non-preemptible (David Vrabel)   
- xen/balloon: remove BUG_ON in increase_reservation (Wei Liu)   
- xen/balloon: ensure preemption is disabled when using a scratch page (David Vrabel)   
- xen/smp: Update pv_lock_ops functions before alternative code starts under PVHVM (Konrad Rzeszutek Wilk)   
- xen/spinlock: Fix locking path engaging too soon under PVHVM. (Konrad Rzeszutek Wilk)   
- xen/arm: disable cpuidle and cpufreq when linux is running as dom0 (Julien Grall)   
- xen/p2m: Don't call get_balloon_scratch_page() twice, keep interrupts disabled for multicalls (Boris Ostrovsky)   
- hvc_xen: Remove unnecessary __GFP_ZERO from kzalloc (Joe Perches)   
- xen/balloon: don't set P2M entry for auto translated guest (Wei Liu)   
- xen/evtchn: double free on error (Dan Carpenter)   
- Xen: Fix retry calls into PRIVCMD_MMAPBATCH*. (Andres Lagar-Cavilla)   
- xen/m2p: use GNTTABOP_unmap_and_replace to reinstate the original mapping (Stefano Stabellini)   
- xen: fix ARM build after 6efa20e4 (Stefano Stabellini)   
- MAINTAINERS: Remove Jeremy from the Xen subsystem. (Konrad Rzeszutek Wilk)   
- xen/events: document behaviour when scanning the start word for events (David Vrabel)   
- x86/xen: during early setup, only 1:1 map the ISA region (David Vrabel)   
- x86/xen: disable premption when enabling local irqs (David Vrabel)   
- swiotlb-xen: replace dma_length with sg_dma_len() macro (Stefano Stabellini)   
- swiotlb: replace dma_length with sg_dma_len() macro (EunBong Song)   
- xen/balloon: set a mapping for ballooned out pages (Stefano Stabellini)   
- Revert "Add support for pv hugepages and support for huge balloon pages." (Konrad Rzeszutek Wilk)   
- Revert "Fix balloon driver to work properly with balloon_hugepages but no superpage flag" (Konrad Rzeszutek Wilk)   
- xen/evtchn: improve scalability by using per-user locks (David Vrabel)   
- xen/p2m: avoid unneccesary TLB flush in m2p_remove_override() (David Vrabel)   
- MAINTAINERS: Add in two extra co-maintainers of the Xen tree. (Konrad Rzeszutek Wilk)   
- MAINTAINERS: Update the Xen subsystem's with proper mailing list. (Konrad Rzeszutek Wilk)   
- xen: replace strict_strtoul() with kstrtoul() (Jingoo Han)   
- xen: Support 64-bit PV guest receiving NMIs (Konrad Rzeszutek Wilk)   
- xen-blkfront: improve aproximation of required grants per request (Roger Pau Monne)   
- xen-blkfront: revoke foreign access for grants not mapped by the backend (Roger Pau Monne)   
- xen/microcode: Fix compile warning. (Konrad Rzeszutek Wilk)   
- xen/events: mask events when changing their VCPU binding (David Vrabel)   
- xen/events: initialize local per-cpu mask for all possible events (David Vrabel)   
- x86/xen: do not identity map UNUSABLE regions in the machine E820 (David Vrabel)   
- xen/tmem: do not allow XEN_TMEM on ARM64 (Stefano Stabellini)   
- xen/arm: enable PV control for ARM (Julien Grall)   
- xen/arm64: Don't compile cpu hotplug (Julien Grall)   
- xenbus: frontend resume cleanup (Aurelien Chartier)   

* Mon Jun 9 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-37.el7uek] 
- e1000: fix possible reset_task running after adapter down (Vladimir Davydov)  [Orabug: 18257498]  
- e1000: fix lockdep warning in e1000_reset_task (Vladimir Davydov)  [Orabug: 18257474]  
- e1000: prevent oops when adapter is being closed and reset simultaneously (yzhu1)  [Orabug: 18257442]  
- tools/power turbostat: display C8, C9, C10 residency (Kristen Carlson Accardi)  [Orabug: 18520774]  
- turbostat: run on HSX (Len Brown)  [Orabug: 18520774]  
- tools/power turbostat: support Haswell (Jerry Snitselaar)  [Orabug: 18520774]  
- net: fix kernel deadlock with interface rename and netdev name retrieval. (Nicolas Schichan)  [Orabug: 18906608]  
- dtrace: ensure that building outside src tree works (Kris Van Hees)  [Orabug: 18691341]  
- futex: Make lookup_pi_state more robust (Thomas Gleixner)  [Orabug: 18918595]  {CVE-2014-3153} 
- futex: Always cleanup owner tid in unlock_pi (Thomas Gleixner)  [Orabug: 18918595]  {CVE-2014-3153} 
- futex: Validate atomic acquisition in futex_lock_pi_atomic() (Thomas Gleixner)  [Orabug: 18918595]  {CVE-2014-3153} 
- futex: Forbid uaddr == uaddr2 in futex_requeue(..., requeue_pi=1) (Thomas Gleixner)  [Orabug: 18918595]  {CVE-2014-3153} {CVE-2014-3153} 
- futex: Prevent attaching to kernel threads (Thomas Gleixner)  [Orabug: 18923481]  
- futex: Add another early deadlock detection check (Thomas Gleixner)  [Orabug: 18923479]  
- lockd: ensure we tear down any live sockets when socket creation fails during lockd_up (Jeff Layton)  [Orabug: 18918179]  
- libceph: resend all writes after the osdmap loses the full flag (Josh Durgin)  [Orabug: 18918180]  
- dm thin: fix dangling bio in process_deferred_bios error path (Mike Snitzer)  [Orabug: 18918178]  
- dm transaction manager: fix corruption due to non-atomic transaction commit (Joe Thornber)  [Orabug: 18918177]  
- locks: allow __break_lease to sleep even when break_time is 0 (Jeff Layton)  [Orabug: 18918176]  
- iwlwifi: dvm: take mutex when sending SYNC BT config command (Emmanuel Grumbach)  [Orabug: 18918175]  
- virtio_balloon: don't softlockup on huge balloon changes. (Rusty Russell)  [Orabug: 18918174]  
- drivers/tty/hvc: don't free hvc_console_setup after init (Tomoki Sekiyama)  [Orabug: 18918173]  
- usb: musb: avoid NULL pointer dereference (Felipe Balbi)  [Orabug: 18918172]  
- ext4: use i_size_read in ext4_unaligned_aio() (Theodore Ts'o)  [Orabug: 18918171]  
- ext4: fix jbd2 warning under heavy xattr load (Jan Kara)  [Orabug: 18918169]  
- ocfs2: do not put bh when buffer_uptodate failed (alex chen)  [Orabug: 18918168]  
- hung_task: check the value of "sysctl_hung_task_timeout_sec" (Liu Hua)  [Orabug: 18918167]  
- mm: hugetlb: fix softlockup when a large number of hugepages are freed. (Mizuma, Masayoshi)  [Orabug: 18918166]  
- mm: try_to_unmap_cluster() should lock_page() before mlocking (Vlastimil Babka)  [Orabug: 18918165]  
- reiserfs: fix race in readdir (Jeff Mahoney)  [Orabug: 18918164]  
- x86/efi: Correct EFI boot stub use of code32_start (Matt Fleming)  [Orabug: 18918162]  
- iscsi-target: Fix ERL=2 ASYNC_EVENT connection pointer bug (Nicholas Bellinger)  [Orabug: 18918161]  
- nfsd: set timeparms.to_maxval in setup_callback_client (Jeff Layton)  [Orabug: 18918160]  
- NFSD: Traverse unconfirmed client through hash-table (Kinglong Mee)  [Orabug: 18918158]  
- nfsd4: fix setclientid encode size (J. Bruce Fields)  [Orabug: 18918157]  
- nfsd: check passed socket's net matches NFSd superblock's one (Stanislav Kinsbursky)  [Orabug: 18918156]  
- nfsd: notify_change needs elevated write count (J. Bruce Fields)  [Orabug: 18918155]  
- nfsd4: fix test_stateid error reply encoding (J. Bruce Fields)  [Orabug: 18918154]  
- nfsd4: buffer-length check for SUPPATTR_EXCLCREAT (J. Bruce Fields)  [Orabug: 18918153]  
- nfsd4: session needs room for following op to error out (J. Bruce Fields)  [Orabug: 18918152]  
- USB: fix crash during hotplug of PCI USB controller card (Alan Stern)  [Orabug: 18918151]  
- ftrace/x86: One more missing sync after fixup of function modification failure (Petr Mladek)  [Orabug: 18918150]  
- wait: fix reparent_leader() vs EXIT_DEAD->EXIT_ZOMBIE race (Oleg Nesterov)  [Orabug: 18918148]  
- sparc: PCI: Fix incorrect address calculation of PCI Bridge windows on Simba-bridges (oftedal)  [Orabug: 18918147]  
- jffs2: remove from wait queue after schedule() (Li Zefan)  [Orabug: 18918146]  
- jffs2: avoid soft-lockup in jffs2_reserve_space_gc() (Li Zefan)  [Orabug: 18918144]  
- jffs2: Fix crash due to truncation of csize (Ajesh Kunhipurayil Vijayan)  [Orabug: 18918143]  
- jffs2: Fix segmentation fault found in stress test (Kamlakant Patel)  [Orabug: 18918142]  
- ext4: fix error return from ext4_ext_handle_uninitialized_extents() (Eric Whitney)  [Orabug: 18918141]  
- pid_namespace: pidns_get() should check task_active_pid_ns() != NULL (Oleg Nesterov)  [Orabug: 18918139]  
- Char: ipmi_bt_sm, fix infinite loop (Jiri Slaby)  [Orabug: 18918137]  
- isdnloop: several buffer overflows (Dan Carpenter)  [Orabug: 18918136]  
- vxlan: fix potential NULL dereference in arp_reduce() (David Stevens)  [Orabug: 18918133]  
- net: socket: error on a negative msg_namelen (Matthew Leach)  [Orabug: 18918132]  
- tcp: tcp_release_cb() should release socket ownership (Eric Dumazet)  [Orabug: 18918130]  
- inet: frag: make sure forced eviction removes all frags (Florian Westphal)  [Orabug: 18918129]  
- bridge: multicast: add sanity check for query source addresses (Linus Lüssing)  [Orabug: 18918127]  
- net: sctp: fix skb leakage in COOKIE ECHO path of chunk->auth_chunk (Daniel Borkmann)  [Orabug: 18918126]  
- cpuidle: Check the result of cpuidle_get_driver() against NULL (Daniel Fu)  [Orabug: 18918124]  
- mm: close PageTail race (David Rientjes)  [Orabug: 18918123]  
- ext4: atomically set inode->i_flags in ext4_set_inode_flags() (Theodore Ts'o)  [Orabug: 18918122]  
- sched/autogroup: Fix race with task_groups list (Gerald Schaefer)  [Orabug: 18918121]  
- e100: Fix "disabling already-disabled device" warning (Michele Baldessari)  [Orabug: 18918120]  
- KVM: VMX: fix use after free of vmx->loaded_vmcs (Marcelo Tosatti)  [Orabug: 18918119]  
- KVM: x86: handle invalid root_hpa everywhere (Marcelo Tosatti)  [Orabug: 18918117]  
- KVM: MMU: handle invalid root_hpa at __direct_map (Marcelo Tosatti)  [Orabug: 18918116]  
- Fix mountpoint reference leakage in linkat (Oleg Drokin)  [Orabug: 18917998]  
- jiffies: Avoid undefined behavior from signed overflow (Paul E. McKenney)  [Orabug: 18917997]  
- x86, fpu: Check tsk_used_math() in kernel_fpu_end() for eager FPU (Suresh Siddha)  [Orabug: 18917996]  
- SCSI: isci: correct erroneous for_each_isci_host macro (Lukasz Dorau)  [Orabug: 18917994]  
- SCSI: isci: fix reset timeout handling (Dan Williams)  [Orabug: 18917993]  
- mm/compaction: break out of loop on !PageBuddy in isolate_freepages_block (Laura Abbott)  [Orabug: 18917992]  
- vmxnet3: fix netpoll race condition (Neil Horman)  [Orabug: 18917990]  
- NFS: Fix a delegation callback race (Trond Myklebust)  [Orabug: 18917989]  
- firewire: net: fix use after free (Stefan Richter)  [Orabug: 18917988]  
- cpuset: fix a race condition in __cpuset_node_allowed_softwall() (Li Zefan)  [Orabug: 18917986]  
- genirq: Remove racy waitqueue_active check (Chuansheng Liu)  [Orabug: 18917985]  
- x86/amd/numa: Fix northbridge quirk to assign correct NUMA node (Daniel J Blueman)  [Orabug: 18917984]  
- drm/ttm: don't oops if no invalidate_caches() (Rob Clark)  [Orabug: 18917982]  
- mac80211: clear sequence/fragment number in QoS-null frames (Johannes Berg)  [Orabug: 18917981]  
- mac80211: fix AP powersave TX vs. wakeup race (Emmanuel Grumbach)  [Orabug: 18917979]  
- sfc: check for NULL efx->ptp_data in efx_ptp_event (Edward Cree)  [Orabug: 18917978]  
- sched: Fix double normalization of vruntime (George McCollister)  [Orabug: 18917977]  
- ocfs2 syncs the wrong range... (Al Viro)  [Orabug: 18917976]  
- ocfs2: fix quota file corruption (Jan Kara)  [Orabug: 18917975]  
- dm thin: fix the error path for the thin device constructor (Mike Snitzer)  [Orabug: 18917974]  
- i7300_edac: Fix device reference count (Jean Delvare)  [Orabug: 18917973]  
- quota: Fix race between dqput() and dquot_scan_active() (Jan Kara)  [Orabug: 18917972]  
- perf: Fix hotplug splat (Peter Zijlstra)  [Orabug: 18917971]  
- workqueue: ensure @task is valid across kthread_stop() (Lai Jiangshan)  [Orabug: 18917969]  
- usb: ehci: fix deadlock when threadirqs option is used (Stanislaw Gruszka)  [Orabug: 18917967]  
- i7core_edac: Fix PCI device reference count (Jean Delvare)  [Orabug: 18917966]  
- ACPI / PCI: Fix memory leak in acpi_pci_irq_enable() (Tomasz Nowicki)  [Orabug: 18917965]  
- cpufreq: powernow-k8: Initialize per-cpu data-structures properly (Srivatsa S. Bhat)  [Orabug: 18917964]  
- perf/x86: Fix event scheduling (Peter Zijlstra)  [Orabug: 18917963]  
- x86: dma-mapping: fix GFP_ATOMIC macro usage (Marek Szyprowski)  [Orabug: 18917962]  
- SUNRPC: Fix races in xs_nospace() (Trond Myklebust)  [Orabug: 18917961]  
- net: use __GFP_NORETRY for high order allocations (Eric Dumazet)  [Orabug: 18917959]  
- ipv4: fix counter in_slow_tot (Duan Jiong)  [Orabug: 18917958]  
- bonding: 802.3ad: make aggregator_identifier bond-private (Jiri Bohac)  [Orabug: 18917957]  
- tcp: tsq: fix nonagle handling (John Ogness)  [Orabug: 18917955]  
- net: fix 'ip rule' iif/oif device rename (Maciej Żenczykowski)  [Orabug: 18917953]  
- ipv4: Fix runtime WARNING in rtmsg_ifa() (Geert Uytterhoeven)  [Orabug: 18917949]  
- 9p/trans_virtio.c: Fix broken zero-copy on vmalloc() buffers (Richard Yao)  [Orabug: 18917946]  
- CIFS: Fix too big maxBuf size for SMB3 mounts (Pavel Shilovsky)  [Orabug: 18917864]  
- ext4: don't leave i_crtime.tv_sec uninitialized (Theodore Ts'o)  [Orabug: 18917863]  
- ext4: fix online resize with a non-standard blocks per group setting (Theodore Ts'o)  [Orabug: 18917862]  
- ext4: fix online resize with very large inode tables (Theodore Ts'o)  [Orabug: 18917643]  
- modsign: Ksplice certificate for module signing (Sasha Levin)  [Orabug: 18793405]  

* Wed May 28 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-36.el7uek] 
- ocfs2: make ocfs2 do not log ENOENT error (Xiaowei.Hu)   
- Btrfs: return EPERM when deleting a default subvolume (Guangyu Sun)  [Orabug: 17661944]  
- i2c: i801: SMBus patch for Intel Avoton DeviceIDs (Seth Heasley)  [Orabug: 17983409]  
- ata_piix: IDE-mode SATA patch for Intel Avoton DeviceIDs (Seth Heasley)  [Orabug: 17983409]  
- i2c: iSMT: add Intel Avoton DeviceIDs (Seth Heasley)  [Orabug: 17983409]  
- allow for more than one data extent when creating xattr (Tariq Saeed)  [Orabug: 18108070]  
- tools / power turbostat: Support Silvermont (Len Brown)  [Orabug: 18349316]  
- intel_idle: Support Intel Atom Processor C2000 Product Family (Len Brown)  [Orabug: 18349316]  
- ocfs2: quorum: add a log for node not fenced (Junxiao Bi)  [Orabug: 18363396]  
- ocfs2: o2net: set tcp user timeout to max value (Junxiao Bi)  [Orabug: 18363396]  
- ocfs2: o2net: don't shutdown connection when idle timeout (Junxiao Bi)  [Orabug: 18363396]  
- fix ext4_sync_file deadlock in uek3 (Darrick J. Wong)  [Orabug: 18389351]  
- block: properly stack underlying max_segment_size to DM device (Mike Snitzer)  [Orabug: 18611974]  
- Revert "tcp: tsq: restore minimal amount of queueing" (Guangyu Sun)  [Orabug: 18621531]  
- x86, mm: Probe memory block size for generic x86 64bit (Yinghai Lu)  [Orabug: 18650337]  
- memblock, numa: binary search node id (Yinghai Lu)  [Orabug: 18650337]  
- mm: speedup in __early_pfn_to_nid (Russ Anderson)  [Orabug: 18650337]  
- netfilter: nf_nat: fix access to uninitialized buffer in IRC NAT helper (Daniel Borkmann)  [Orabug: 18681787]  {CVE-2014-1690} 
- ath9k_htc: properly set MAC address and BSSID mask (Mathy Vanhoef)  [Orabug: 18681788]  {CVE-2013-4579} 
- perf/ftrace: Fix paranoid level for enabling function tracer (Steven Rostedt)  [Orabug: 18681870]  {CVE-2013-2930} 
- ext4: fix memory leakage in mext_check_coverage (Dmitry Monakhov)  [Orabug: 18684170]  
- ext4: defragmentation code cleanup (Dmitry Monakhov)  [Orabug: 18684170]  
- block: Enable sysfs nomerge control for I/O requests in the plug list (Alireza Haghdoost)  [Orabug: 18736016]  
- config ol7: enable netfilter reverse path filter support (Jerry Snitselaar)  [Orabug: 18845282]  
- spec: fix symbolic link to build directory (Jerry Snitselaar)  [Orabug: 18835306]  

* Tue May 13 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-35.el7uek] 
- n_tty: Fix n_tty_write crash when echoing in raw mode (Peter Hurley)  [Orabug: 18754908]  {CVE-2014-0196} {CVE-2014-0196} 

* Thu May 8 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-34.el7uek] 
- aacraid: missing capable() check in compat ioctl (Dan Carpenter)  [Orabug: 18721960]  {CVE-2013-6383} 
- vhost: fix total length when packets are too short (Michael S. Tsirkin)  [Orabug: 18721975]  {CVE-2014-0077} 

* Thu May 1 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-33.el7uek] 
- dtrace: ensure one can try to get user pages without locking or faulting (Kris Van Hees)  [Orabug: 18653173]  
- ipv6: don't set DST_NOCOUNT for remotely added routes (Sabrina Dubroca)  [Orabug: 18681501]  {CVE-2014-2309} 
- kvm: x86: fix emulator buffer overflow (CVE-2014-0049) (Andrew Honig)  [Orabug: 18681519]  {CVE-2014-0049} 
- ib_core: fmr pool hard lock up when cache enabled (Shamir Rabinovitch)  [Orabug: 18408531]  
- bnx2x: disable PTP clock support (Jerry Snitselaar)  [Orabug: 18605376]  
- x86, mm: Revert back good_end setting for 64bit (Brian Maly)  [Orabug: 17648536]  
- IB/sdp: disable APM by default (Shamir Rabinovitch)  [Orabug: 18443201]  
- vxlan: kernel panic when bringing up vxlan (Venkat Venkatsubra)  [Orabug: 18295741]  
- ocfs2: call ocfs2_update_inode_fsync_trans when updating any inode (Darrick J. Wong)  [Orabug: 18257094]  
- ocfs2: improve fsync efficiency and fix deadlock between aio_write and sync_file (Darrick J. Wong)  [Orabug: 18257094]  
- Revert "ocfs2: fix i_mutex deadlock between aio_write and sync_file" (Jerry Snitselaar)  [Orabug: 18257094]  
- config: align with rhck (Jerry Snitselaar)  [Orabug: 18685975]  
- config: disable atmel drivers for ol7 (Jerry Snitselaar)  [Orabug: 18665656]  
- config: enable support for squashfs features (Jerry Snitselaar)  [Orabug: 18655723]  
- qla4xxx: Update driver verion to v5.04.00.05.06.02-uek3 (Tej Parkash)  [Orabug: 18552248]  
- net: ipv4: current group_info should be put after using. (Wang, Xiaoming)  [Orabug: 18603519]  {CVE-2014-2851} 

* Sat Apr 12 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-32.el7uek] 
- mm / dtrace: Allow DTrace to entirely disable page faults. (Nick Alcock)  [Orabug: 18412802]  
- mm: allow __get_user_pages() callers to avoid triggering page faults. (Nick Alcock)  [Orabug: 18412802]  
- config: enable nfs client support for rdma (Jerry Snitselaar)  [Orabug: 18560595]  
- NFS: Fix negative overflow in SETATTR timestamps (Chuck Lever)  [Orabug: 18476361]  
- NFS: Transfer full int64 for NFSv4 SETATTR timestamps (Chuck Lever)  [Orabug: 18476361]  
- NFS: Block file size updates during async READ (Chuck Lever)  [Orabug: 18391310]  
- NFS: Use an RPC/RDMA long request for NFS symlink operations (Chuck Lever)  [Orabug: 18261861]  
- SUNRPC: Support long RPC/RDMA requests (Chuck Lever)  [Orabug: 18261861]  
- xprtrdma: Split the completion queue (Chuck Lever)  [Orabug: 18560595]  
- xprtrdma: Make rpcrdma_ep_destroy() return void (Chuck Lever)  [Orabug: 18560595]  
- xprtrdma: Simplify rpcrdma_deregister_external() synopsis (Chuck Lever)  [Orabug: 18560595]  
- xprtrdma: Remove support for MEMWINDOWS registration mode (Chuck Lever)  [Orabug: 18560595]  
- xprtrdma: Disable ALLPHYSICAL mode by default (Chuck Lever)  [Orabug: 18560595]  
- xprtrdma: Remove BOUNCEBUFFERS memory registration mode (Chuck Lever)  [Orabug: 18560595]  
- SUNRPC: RPC/RDMA must invoke xprt_wake_pending_tasks() in process context (Chuck Lever)  [Orabug: 18560595]  
- xprtrdma: add separate Kconfig options for NFSoRDMA client and server support (Jeff Layton)  [Orabug: 18560595]  
- NFS: incorrect "port=" value in /proc/mounts (Chuck Lever)  [Orabug: 18560595]  
- NFS: advertise only supported callback netids (Chuck Lever)  [Orabug: 18560595]  
- SUNRPC: remove KERN_INFO from dprintk() call sites (Chuck Lever)  [Orabug: 18560595]  
- SUNRPC: Fix large reads on NFS/RDMA (Chuck Lever)  [Orabug: 18560595]  
- fnic: Failing to queue aborts due to Q full cause terminate driver timeout (Simha)  [Orabug: 18548644]  
- net: enic: include irq.h for irqreturn_t definitions (Josh Boyer)  [Orabug: 18548634]  
- enic: Call dev_kfree_skb_any instead of dev_kfree_skb. (Eric W. Biederman)  [Orabug: 18548634]  
- enic: Don't receive packets when the napi budget == 0 (Eric W. Biederman)  [Orabug: 18548634]  
- net: enic: slight optimization of addr compare (dingtianhong)  [Orabug: 18548634]  
- net: enic: remove unnecessary pci_set_drvdata() (Jingoo Han)  [Orabug: 18548634]  
- driver/net: enic: update enic maintainers and driver (govindarajulu.v)  [Orabug: 18548634]  
- driver/net: enic: Exposing symbols for Cisco's low latency driver (govindarajulu.v)  [Orabug: 18548634]  
- driver/net: enic: Try DMA 64 first, then failover to DMA (govindarajulu.v)  [Orabug: 18548634]  
- driver/net: enic: record q_number and rss_hash for skb (govindarajulu.v)  [Orabug: 18548634]  
- driver/net: enic: Add multi tx support for enic (govindarajulu.v)  [Orabug: 18548634]  
- drivers/net: enic: Generate notification of hardware crash (Neel Patel)  [Orabug: 18548634]  
- drivers/net: enic: Add an interface for USNIC to interact with firmware (Neel Patel)  [Orabug: 18548634]  
- drivers/net: enic: Adding support for Cisco Low Latency NIC (Neel Patel)  [Orabug: 18548634]  
- drivers/net: enic: Move ethtool code to a separate file (Neel Patel)  [Orabug: 18548634]  
- drivers/net: enic: release rtnl_lock on error-path (Konstantin Khlebnikov)  [Orabug: 18548634]  
- enic: be less verbose about non-critical firmware errors (Stefan Assmann)  [Orabug: 18548634]  
- enic: change sprintf() to snprintf() (Dan Carpenter)  [Orabug: 18548634]  
- dtrace: implement omni-present cyclics (Kris Van Hees)  [Orabug: 18323501]  
- Update .gitignore with generated SDT files. (Nick Alcock)  [Orabug: 17851716]  
- dtrace: avoid unreliable entries in stack() output (Kris Van Hees)  [Orabug: 18323450]  
- drm/i915: hsw: replace !is_pch_edp() with port==PORT_A (Imre Deak)  [Orabug: 18429992]  
- drm/i915: IVB/HSW have 32 fence register (Ville Syrjälä)  [Orabug: 18429992]  
- drm/i915: Configure GAM_ECOCHK appropriatly for Gen7 (Ville Syrjälä)  [Orabug: 18429992]  
- drm/i915: use lower aux clock divider on non-ULT HSW (Jani Nikula)  [Orabug: 18429992]  
- drm/i915: HSW PM Frequency bits fix (Rodrigo Vivi)  [Orabug: 18429992]  
- drm/i915: there's no PIPESTAT on HAS_PCH_SPLIT platforms (Paulo Zanoni)  [Orabug: 18429992]  
- drm/i915: there's no DSPPOS register on gen4+ (Paulo Zanoni)  [Orabug: 18429992]  
- drm/i915: reorganize intel_lvds_supported (Paulo Zanoni)  [Orabug: 18429992]  
- drm/i915: fix DSPADDR Gen check (Paulo Zanoni)  [Orabug: 18429992]  
- drm/i915: there's no DSPADDR register on Haswell (Paulo Zanoni)  [Orabug: 18429992]  
- drm/i915: there's no DSPSIZE register on gen4+ (Paulo Zanoni)  [Orabug: 18429992]  
- drm/i915: Use cpu_transcoder for HSW_TVIDEO_DIP_* instead of pipe (Rodrigo Vivi)  [Orabug: 18429992]  
- PM: intel_powerclamp: enable driver in defconfigs (Brian Maly)  [Orabug: 18429987]  
- intel_powerclamp: Fix cstate counter detection. (Yuxuan Shui)  [Orabug: 18429987]  
- thermal/intel_powerclamp: Add newer CPU models (Jacob Pan)  [Orabug: 18429987]  
- PM: Introduce Intel PowerClamp Driver (Jacob Pan)  [Orabug: 18429987]  
- tick: export nohz tick idle symbols for module use (Jacob Pan)  [Orabug: 18429987]  
- x86/nmi: export local_touch_nmi() symbol for modules (Jacob Pan)  [Orabug: 18429987]  
- ioatdma: disable RAID on non-Atom platforms and reenable unaligned copies (Brice Goglin)  [Orabug: 18430022]  
- ioatdma: ioat3_alloc_sed can be static (Fengguang Wu)  [Orabug: 18430022]  
- ioatdma: Adding write back descriptor error status support for ioatdma 3.3 (Dave Jiang)  [Orabug: 18430022]  
- ioatdma: S1200 platforms ioatdma channel 2 and 3 falsely advertise RAID cap (Dave Jiang)  [Orabug: 18430022]  
- ioatdma: Adding support for 16 src PQ ops and super extended descriptors (Dave Jiang)  [Orabug: 18430022]  
- ioatdma: skip silicon bug workaround for pq_align for cb3.3 (Dave Jiang)  [Orabug: 18430022]  
- ioatdma: Removing PQ val disable for cb3.3 (Dave Jiang)  [Orabug: 18430022]  
- ioatdma: channel reset scheme fixup on Intel Atom S1200 platforms (Dave Jiang)  [Orabug: 18430022]  
- ioatdma: Add 64bit chansts register read for ioat v3.3. (Dave Jiang)  [Orabug: 18430022]  
- ioatdma: Adding PCI IDs for Intel Atom S1200 product family ioatdma devices (Dave Jiang)  [Orabug: 18430022]  
- ioatdma: Adding Haswell devid for ioatdma (Dave Jiang)  [Orabug: 18430022]  
- ioatdma: allow all channels to have irq coalescing support (Dave Jiang)  [Orabug: 18430022]  
- ioatdma: make debug output more readable (Dave Jiang)  [Orabug: 18430022]  
- ioat/dca: Update DCA BIOS workarounds to use TAINT_FIRMWARE_WORKAROUND (Alexander Duyck)  [Orabug: 18430022]  
- dmaengine: ioat - fix spare sparse complain (Fengguang Wu)  [Orabug: 18430022]  
- ioatdma: fix race between updating ioat->head and IOAT_COMPLETION_PENDING (Dave Jiang)  [Orabug: 18430022]  
- ioat: remove chanerr mask setting for IOAT v3.x (Dave Jiang)  [Orabug: 18430022]  
- PCI: Remove Intel Haswell D3 delays (Todd E Brandt)  [Orabug: 18559933]  
- hyperv-fb: kick off efifb early (Gerd Hoffmann)  [Orabug: 18276803]  
- hyperv-fb: add support for generation 2 virtual machines. (Gerd Hoffmann)  [Orabug: 18276803]  
- vmbus: use resource for hyperv mmio region (Gerd Hoffmann)  [Orabug: 18276803]  
- vmbus: add missing breaks (Gerd Hoffmann)  [Orabug: 18276803]  
- Drivers: hv: fcopy_open() can be static (Fengguang Wu)  [Orabug: 18276803]  
- Drivers: hv: Implement the file copy service (K. Y. Srinivasan)  [Orabug: 18276803]  
- hv: Add hyperv.h to uapi headers (Bjarke Istrup Pedersen)  [Orabug: 18276803]  
- Drivers: hv: Ballon: Make pressure posting thread sleep interruptibly (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Cleanup the packet send path (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Extract the mmio information from DSDT (K. Y. Srinivasan)  [Orabug: 18276803]  
- add support for Hyper-V reference time counter (Vadim Rozenfeld)  [Orabug: 18276803]  
- hyperv: enable framebuffer and keyboard drivers (Jerry Snitselaar)  [Orabug: 18276803]  
- Drivers: hv: remove HV_DRV_VERSION (Olaf Hering)  [Orabug: 18276803]  
- x86, hyperv: Move a variable to avoid an unused variable warning (H. Peter Anvin)  [Orabug: 18276803]  
- x86, hyperv: Fix build error due to missing <asm/apic.h> include (David Rientjes)  [Orabug: 18276803]  
- x86, hyperv: Correctly guard the local APIC calibration code (K. Y. Srinivasan)  [Orabug: 18276803]  
- x86, hyperv: Get the local APIC timer frequency from the hypervisor (K. Y. Srinivasan)  [Orabug: 18276803]  
- x86: Correctly detect hypervisor (Jason Wang)  [Orabug: 18276803]  
- x86, hyperv: Handle Xen emulation of Hyper-V more gracefully (K. Y. Srinivasan)  [Orabug: 18276803]  
- X86: Handle Hyper-V vmbus interrupts as special hypervisor interrupts (K. Y. Srinivasan)  [Orabug: 18276803]  
- X86: Add a check to catch Xen emulation of Hyper-V (K. Y. Srinivasan)  [Orabug: 18276803]  
- Input: hyperv-keyboard - pass through 0xE1 prefix (K. Y. Srinivasan)  [Orabug: 18276803]  
- Input: add a driver to support Hyper-V synthetic keyboard (K. Y. Srinivasan)  [Orabug: 18276803]  
- [SCSI] storvsc: NULL pointer dereference fix (Ales Novak)  [Orabug: 18276803]  
- [SCSI] storvsc: Increase the value of STORVSC_MAX_IO_REQUESTS (K. Y. Srinivasan)  [Orabug: 18276803]  
- [SCSI] storvsc: Support FC devices (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Add the GUID fot synthetic fibre channel device (K. Y. Srinivasan)  [Orabug: 18276803]  
- [SCSI] storvsc: Implement multi-channel support (K. Y. Srinivasan)  [Orabug: 18276803]  
- [SCSI] storvsc: Update the storage protocol to win8 level (K. Y. Srinivasan)  [Orabug: 18276803]  
- [SCSI] storvsc: Increase the value of scsi timeout for storvsc devices (K. Y. Srinivasan)  [Orabug: 18276803]  
- [SCSI] storvsc: Handle dynamic resizing of the device (K. Y. Srinivasan)  [Orabug: 18276803]  
- [SCSI] storvsc: Restructure error handling code on command completion (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: scsi: storvsc: Use the consolidated GUID definition (K. Y. Srinivasan)  [Orabug: 18276803]  
- HID: hyperv: make sure input buffer is big enough (David Herrmann)  [Orabug: 18276803]  
- HID: hyperv: convert alloc+memcpy to memdup (Thomas Meyer)  [Orabug: 18276803]  
- Drivers: hid: hid-hyperv: Use consolidated GUID definitions (K. Y. Srinivasan)  [Orabug: 18276803]  
- hyperv: Move state setting for link query (Haiyang Zhang)  [Orabug: 18276803]  
- hyperv: Fix the carrier status setting (Haiyang Zhang)  [Orabug: 18276803]  
- hyperv: Fix race between probe and open calls (Haiyang Zhang)  [Orabug: 18276803]  
- hyperv: Fix the NETIF_F_SG flag setting in netvsc (Haiyang Zhang)  [Orabug: 18276803]  
- Fix the VLAN_TAG_PRESENT in netvsc_recv_callback() (Haiyang Zhang)  [Orabug: 18276803]  
- hyperv: Fix vlan_proto setting in netvsc_recv_callback() (Haiyang Zhang)  [Orabug: 18276803]  
- hyperv: Fix a compiler warning in netvsc_send() (Haiyang Zhang)  [Orabug: 18276803]  
- hyperv: Fix a kernel warning from netvsc_linkstatus_callback() (Haiyang Zhang)  [Orabug: 18276803]  
- Drivers: net: hyperv: Use the consolidated GUID definition (K. Y. Srinivasan)  [Orabug: 18276803]  
- hyperv-fb: add blanking support (Gerd Hoffmann)  [Orabug: 18276803]  
- hyperv-fb: add pci stub (Gerd Hoffmann)  [Orabug: 18276803]  
- drivers/video: add Hyper-V Synthetic Video Frame Buffer Driver (Haiyang Zhang)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Don't timeout during the initial connection with host (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Specify the target CPU that should receive notification (K. Y. Srinivasan)  [Orabug: 18276803]  
- hyperv: Add support for physically discontinuous receive buffer (Haiyang Zhang)  [Orabug: 18276803]  
- drivers: hv: Mark the function hv_synic_free_cpu() as static in hv.c (Rashika Kheria)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Fix a bug in channel rescind code (K. Y. Srinivasan)  [Orabug: 18276803]  
- drivers: hv: Fix wrong check for synic_event_page (Felipe Pena)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Terminate vmbus version negotiation on timeout (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: util: Correctly support ws2008R2 and earlier (K. Y. Srinivasan)  [Orabug: 18276803]  
- hv: vmbus: fix vmbus_recvpacket_raw() return code (Dan Carpenter)  [Orabug: 18276803]  
- hv: Change variable type to bool (Peter Senna Tschudin)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Do not attempt to negoatiate a new version prematurely (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Fix a bug in the handling of channel offers (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Do not post pressure status if interrupted (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Fix a bug in the hot-add code (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: vmbus: incorrect device name is printed when child device is unregistered (Fernando Soto)  [Orabug: 18276803]  
- Drivers: hv: balloon: Initialize the transaction ID just before sending the packet (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: util: Fix a bug in version negotiation code for util services (K. Y. Srinivasan)  [Orabug: 18276803]  
- drivers: hv: allocate synic structures before hv_synic_init() (Jason Wang)  [Orabug: 18276803]  
- drivers: hv: check interrupt mask before read_index (Jason Wang)  [Orabug: 18276803]  
- drivers: hv: switch to use mb() instead of smp_mb() (Jason Wang)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Implement multi-channel support (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Fix a bug in get_vp_index() (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Fix a bug in hv_need_to_signal() (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Notify the host of permanent hot-add failures (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Support 2M page allocations for ballooning (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Permit Linux to specify hot-add alignment requirements (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: make local functions static (Wei Yongjun)  [Orabug: 18276803]  
- Drivers: hv: Add a new driver to support host initiated backup (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Handle channel rescind message correctly (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Implement hot-add functionality (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Make the balloon driver not unloadable (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Execute hot-add code in a separate context (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Execute balloon inflation in a separate context (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Do not request completion notification (K. Y. Srinivasan)  [Orabug: 18276803]  
- driver: hv: remove cast for kmalloc return value (Zhang Yanfei)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Use the new infrastructure for delivering VMBUS interrupts (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Prevent the host from ballooning the guest too low (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Add a parameter to delay pressure reporting (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: balloon: Make adjustments to the pressure report (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Use consolidated GUID definitions (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: vmbus: Consolidate all offer GUID definitions in hyperv.h (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Bind all vmbbus interrupts to the boot CPU (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: vmbus_flow_handler() can be static (Fengguang Wu)  [Orabug: 18276803]  
- Drivers: hv: remove unused variable in vmbus_recvpacket_raw() (Wei Yongjun)  [Orabug: 18276803]  
- Drivers: hv: Cleanup and consolidate reporting of build/version info (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Capture the host build information (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Implement flow management on the send side (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Enable protocol negotiation with win8 hosts (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Add a check to deal with spurious interrupts (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Handle vmbus interrupts concurrently on all cpus (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Manage event tasklets on per-cpu basis (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Get rid of unnecessary request for offers (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Get rid of the unused global signaling state (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Add code to distribute channel interrupt load (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Modify the interrupt handling code to support win8 and beyond (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Add state to manage incoming channel interrupt load (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Setup a mapping for Hyper-V's notion cpu ID (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Cleanup vmbus_set_event() to support win7 and beyond (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Manage signaling state on a per-connection basis (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Move vmbus version definitions to hyperv.h (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Change the signature of vmbus_set_event() (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Change the signature for hv_signal_event() (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Save and export negotiated vmbus version (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Extend/modify vmbus_channel_offer_channel for win7 and beyond (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Update the ring buffer structure to match win8 functionality (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Support handling multiple VMBUS versions (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Get rid of hv_get_ringbuffer_interrupt_mask() (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Optimize the signaling on the write path (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Optimize signaling in the read path (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Turn off batched reading for util drivers (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Add state to manage batched reading (K. Y. Srinivasan)  [Orabug: 18276803]  
- Drivers: hv: Implement routines for read side signaling optimization (K. Y. Srinivasan)  [Orabug: 18276803]  
- hv: hv_balloon: remove duplicated include from hv_balloon.c (Wei Yongjun)  [Orabug: 18276803]  
- x86, kvm: Switch to use hypervisor_cpuid_base() (Jason Wang)  [Orabug: 18276803]  
- x86: Introduce hypervisor_cpuid_base() (Jason Wang)  [Orabug: 18276803]  
- x86, mm: Create slow_virt_to_phys() (Dave Hansen)  [Orabug: 18276803]  
- x86, mm: Pagetable level size/shift/mask helpers (Dave Hansen)  [Orabug: 18276803]  
- mm: export split_page() (K. Y. Srinivasan)  [Orabug: 18276803]  
- x86, hyperv: HYPERV depends on X86_LOCAL_APIC (H. Peter Anvin)  [Orabug: 18276803]  
- qla2xxx: Update the driver version to 8.07.00.08.39.0-k1. (Saurav Kashyap)  [Orabug: 18524767]  
- qla2xxx: Remove ISP8044 ID from the pci table. (Saurav Kashyap)  [Orabug: 18524767]  
- qla2xxx: Remove mapped vp index iterator macro dead code. (Himanshu Madhani)  [Orabug: 18524767]  
- qla2xxx: Add MBC option for fast SFP data access. (Joe Carnuccio)  [Orabug: 18524767]  
- qla2xxx: Fix ISPFX00 not displaying the correct FW version after FW update through sysfs Interface. (Armen Baloyan)  [Orabug: 18524767]  
- qla2xxx: Fix beacon blink logic for ISP26xx/83xx. (Himanshu Madhani)  [Orabug: 18524767]  
- qla2xxx: Don't check for firmware hung during the reset context for ISP82XX. (Tej Prakash)  [Orabug: 18524767]  
- qla2xxx: Fixup looking for a space in the outstanding_cmds array in qla2x00_alloc_iocbs(). (Chad Dupuis)  [Orabug: 18524767]  
- qla2xxx: Delay driver unload if there is any pending activity going on. (Sawan Chandak)  [Orabug: 18524767]  
- qla2xxx: ISP27xx queue index shadow registers. (Joe Carnuccio)  [Orabug: 18524767]  
- qla2xxx: ISP27xx firmware dump template spec updates (including T274). (Joe Carnuccio)  [Orabug: 18524767]  
- qla2xxx: Reduce the time we wait for a command to complete during SCSI error handling. (Chad Dupuis)  [Orabug: 18524767]  
- qla2xxx: Check the QLA8044_CRB_DRV_ACTIVE_INDEX register when we are not the owner of the reset. (Hiral Patel)  [Orabug: 18524767]  
- qla2xxx: Clear loop_id for ports that are marked lost during fabric scanning. (Chad Dupuis)  [Orabug: 18524767]  
- qla2xxx: Adjust adapter reset routine to the changes in firmware specification for ISPFx00. (Armen Baloyan)  [Orabug: 18524767]  
- qla2xxx: Avoid escalating the SCSI error handler if the command is not found in firmware. (Chad Dupuis)  [Orabug: 18524767]  
- qla2xxx: IOCB data should be copied to I/O mem using memcpy_toio. (Atul Deshmukh)  [Orabug: 18524767]  
- qla2xxx: Use proper log message for flash lock failed error for ISP82XX. (Atul Deshmukh)  [Orabug: 18524767]  
- qla2xxx: Remove configure VFs mailbox command call. (Chad Dupuis)  [Orabug: 18524767]  
- qla2xxx: ISP8044 poll ipmdio bus timeout improvement. (Joe Carnuccio)  [Orabug: 18524767]  
- qla2xxx: Poll during initialization for ISP25xx and ISP83xx. (Giridhar Malavali)  [Orabug: 18524767]  
- qla2xxx: Fix build errors related to invalid print fields on some architectures. (Chad Dupuis)  [Orabug: 18524767]  
- qla2xxx: Include <delay.h> file for msleep declartion in qla_nx2.c file. (Atul Deshmukh)  [Orabug: 18524767]  
- qla2xxx: Use proper log message for flash lock failed error. (Atul Deshmukh)  [Orabug: 18524767]  
- qla2xxx: Decrease pci access for response queue processing for ISPFX00. (Armen Baloyan)  [Orabug: 18524767]  
- qla2xxx: Use jiffies instead of struct timeval and gettimeofday(). (Atul Deshmukh)  [Orabug: 18524767]  
- qla2xxx: Update entry type 270 to match spec update. (Joe Carnuccio)  [Orabug: 18524767]  
- qla2xxx: Enable fw_dump_size for helga (Hiral Patel)  [Orabug: 18524767]  
- qla2xxx: Remove unnecessary code from qlafx00_intr_handler (Hiral Patel)  [Orabug: 18524767]  
- qla2xxx: Introduce fw_dump_flag to track fw dump progress (Hiral Patel)  [Orabug: 18524767]  
- qla2xxx: Remove unnecessary delays from fw dump code path (Hiral Patel)  [Orabug: 18524767]  
- qla2xxx: Track the process when the ROM_LOCK failure happens (Hiral Patel)  [Orabug: 18524767]  
- qla2xxx: Correction to 27xx template entry types 256 and 258. (Joe Carnuccio)  [Orabug: 18524767]  
- qla2xxx: Add 8044 serdes bsg interface. (Joe Carnuccio)  [Orabug: 18524767]  
- qla2xxx: Fix P3P max debug ID. (Chad Dupuis)  [Orabug: 18524767]  
- qla2xxx: Check for peg alive counter and clear any outstanding mailbox command. (Giridhar Malavali)  [Orabug: 18524767]  
- qla2xxx: Support of new Helga minidump opcodes QLA8044_RDDFE(38), QLA8044_RDMDIO(39),QLA8044_POLLWR(40). (Pratik Mohanty)  [Orabug: 18524767]  
- qla2xxx: Allow the next firmware dump if the previous dump capture fails for ISP8044. (Saurav Kashyap)  [Orabug: 18524767]  
- qla2xxx: Add pci device id 0x2271. (Joe Carnuccio)  [Orabug: 18524767]  
- qla2xxx: Issue abort command for outstanding commands during cleanup when only firmware is alive. (Giridhar Malavali)  [Orabug: 18524767]  
- qla2xxx: Log when device state is moved to failed state. (Giridhar Malavali)  [Orabug: 18524767]  
- qla2xxx: Fix sparse warnings in qla_mr.c (Armen Baloyan)  [Orabug: 18524767]  
- qla2xxx: Correct operations for ISP27xx template types 270 and 271. (Joe Carnuccio)  [Orabug: 18524767]  
- qla2xxx: Add and use 32Gbps FC-GS definitions. (Chad Dupuis)  [Orabug: 18524767]  
- qla2xxx: Do not schedule reset when one is already active when receiving an invalid status handle. (Chad Dupuis)  [Orabug: 18524767]  
- qla2xxx: Add IOCB Abort command asynchronous handling (Armen Baloyan)  [Orabug: 18524767]  
- qla2xxx: Add ISP2701 to PCI ID table. (Sawan Chandak)  [Orabug: 18524767]  
- Update qlge driver to v1.00.00.34 (Sucheta Chakraborty)  [Orabug: 18552225]  
- [SCSI] hpsa: update driver version to 3.4.4-1 (Stephen M. Cameron)  [Orabug: 18524766]  
- [SCSI] hpsa: fix bad endif placement in RAID 5 mapper code (Stephen M. Cameron)  [Orabug: 18524766]  
- [SCSI] hpsa: Do not zero fields of ioaccel2 command structure twice (Stephen M. Cameron)  [Orabug: 18524766]  
- [SCSI] hpsa: Add hba mode to the hpsa driver (Stephen M. Cameron)  [Orabug: 18524766]  
- [SCSI] hpsa: remove unused struct request from CommandList (Stephen M. Cameron)  [Orabug: 18524766]  
- [SCSI] hpsa: increase the probability of a reported success after a device reset (Tomas Henzl)  [Orabug: 18524766]  
- [SCSI] hpsa: bring format-in-progress drives online when ready (Stephen M. Cameron)  [Orabug: 18524766]  
- [SCSI] hpsa: remove unused kthread.h header (Stephen M. Cameron)  [Orabug: 18524766]  
- bonding: Inactive slaves should keep inactive flag's value (zheng.li)  [Orabug: 18345482]  
- dtrace: fix leaking psinfo objects (Kris Van Hees)  [Orabug: 18383027]  
- xen/pvhvm: Support more than 32 VCPUs when migrating. (Konrad Rzeszutek Wilk)  [Orabug: 18552664]  
- xen/microcode: Only load under initial domain. (Konrad Rzeszutek Wilk)  [Orabug: 18379824]  
- audit: Make testing for a valid loginuid explicit. (Eric W. Biederman)  [Orabug: 18346901]  
- audit: make validity checking generic (Eric Paris)  [Orabug: 18346901]  
- audit: allow checking the type of audit message in the user filter (Eric Paris)  [Orabug: 18346901]  
- i40e: enable CONFIG_I40E by default (Brian Maly)  [Orabug: 18429973]  
- i40e: add kcompat calls (Brian Maly)  [Orabug: 18429973]  
- i40e: include i40e in kernel proper (Jesse Brandeburg)  [Orabug: 18429973]  
- i40e: debugfs interface (Jesse Brandeburg)  [Orabug: 18429973]  
- i40e: init code and hardware support (Jesse Brandeburg)  [Orabug: 18429973]  
- i40e: implement virtual device interface (Jesse Brandeburg)  [Orabug: 18429973]  
- i40e: driver core headers (Jesse Brandeburg)  [Orabug: 18429973]  
- i40e: driver ethtool core (Jesse Brandeburg)  [Orabug: 18429973]  
- i40e: transmit, receive, and NAPI (Jesse Brandeburg)  [Orabug: 18429973]  
- i40e: main driver core (Jesse Brandeburg)  [Orabug: 18429973]  
-     ocfs2: pass "new" parameter to ocfs2_init_xattr_bucket (Wengang Wang)  [Orabug: 18447765]  
- qlcnic: make Kconfig changes to enable HWMON feature (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: sysfs interface for PCI BAR access (Sony Chacko)  [Orabug: 18524762]  
- qlcnic: Update version to 5.3.55.6 (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Optimize MAC learning code (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Update version to 5.3.55.5 (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Update QLogic application/driver interface for virtual NIC configuration (Jitendra Kalsaria)  [Orabug: 18524762]  
- qlcnic: Fix NULL pointer dereference bug (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Add hwmon-sysfs interface to export board temperature. (Harish Patil)  [Orabug: 18524762]  
- qlcnic: Update version to 5.3.55.4 (Giri Reddy)  [Orabug: 18524762]  
- qlcnic: Update version to 5.3.55.3 (Jitendra Kalsaria)  [Orabug: 18524762]  
- qlcnic: Fix PVID configuration on eSwitch port. (Jitendra Kalsaria)  [Orabug: 18524762]  
- qlcnic: Optimize ring count validations (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Limit VNIC support in legacy interrupt mode (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Add driver logs in error path. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Fix panic due to uninitialzed delayed_work struct in use. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Allow setting TX interrupt coalescing parameters from VF. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Update version to 5.3.55.2 (Jitendra Kalsaria)  [Orabug: 18524762]  
- qlcnic: Re-factor firmware minidump template header handling (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Fix virtual NIC function count. (Jitendra Kalsaria)  [Orabug: 18524762]  
- qlcnic: Fix semaphore lock access failure error msg (Harish Patil)  [Orabug: 18524762]  
- qlcnic: reset firmware API lock at driver load (Sony Chacko)  [Orabug: 18524762]  
- qlcnic: Allow vlan0 traffic (Rajesh Borundia)  [Orabug: 18524762]  
- qlcnic: Fix mixed mode interrupt related change (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Update version to 5.3.55.1 (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Fix number of rings when we fall back from msix to legacy. (Rajesh Borundia)  [Orabug: 18524762]  
- qlcnic: Allow newer QCC to work with 8 NPAR function. (Jitendra Kalsaria)  [Orabug: 18524762]  
- qlcnic: Use use_msi and use_msi_x module parameteres correctly (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Fix driver log message. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Allow any VLAN to be configured from VF. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: update version to 5.3.55 (Himanshu Madhani)  [Orabug: 18524762]  
- qlcnic: Fix loopback test failure (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Fix tx timeout. (Rajesh Borundia)  [Orabug: 18524762]  
- qlcnic: Fix initialization of vlan list. (Rajesh Borundia)  [Orabug: 18524762]  
- qlcnic: Correct off-by-one errors in bounds checks (Manish Chopra)  [Orabug: 18524762]  
- qlcnic: Enhance logic to calculate msix vectors. (Himanshu Madhani)  [Orabug: 18524762]  
- qlcnic: Refactor interrupt coalescing code for all adapters. (Himanshu Madhani)  [Orabug: 18524762]  
- qlcnic: Update poll controller code path (Manish chopra)  [Orabug: 18524762]  
- qlcnic: Interrupt code cleanup (Manish chopra)  [Orabug: 18524762]  
- qlcnic: Enhance Tx timeout debugging. (Himanshu Madhani)  [Orabug: 18524762]  
- qlcnic: Use bool for rx_mac_learn. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: fix sparse warnings (Fengguang Wu)  [Orabug: 18524762]  
- qlcnic: remove unused code (stephen hemminger)  [Orabug: 18524762]  
- qlcnic: make local functions static (stephen hemminger)  [Orabug: 18524762]  
- net: qlcnic: fix warning for incorrect type in argument (dingtianhong)  [Orabug: 18524762]  
- qlcnic: Update version to 5.3.54 (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Enable IPv6 LRO even if IP address is not programmed (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Fix SR-IOV cleanup code path (Manish Chopra)  [Orabug: 18524762]  
- qlcnic: Enable beaconing for 83xx/84xx Series adapter. (Himanshu Madhani)  [Orabug: 18524762]  
- qlcnic: Do MAC learning for SRIOV PF. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Turn on promiscous mode for SRIOV PF. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Enable VF flood bit on PF. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Restrict VF from configuring any VLAN mode. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Convert vmalloc/memset to kcalloc (Joe Perches)  [Orabug: 18524762]  
- qlcnic: Fix ethtool statistics length calculation (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Fix bug in TX statistics (Manish Chopra)  [Orabug: 18524762]  
- qlcnic: Fix bug in Tx completion path (Shahed Shaikh)  [Orabug: 18524762]  
- qlcnic: Fix resource allocation for TX queues (Manish Chopra)  [Orabug: 18524762]  
- qlcnic: Fix loopback diagnostic test (Manish Chopra)  [Orabug: 18524762]  
- net: qlcnic: slight optimization of addr compare (dingtianhong)  [Orabug: 18524762]  
- drivers: net: Mark functions as static in qlcnic_83xx_hw.c (Rashika Kheria)   
- drivers: net: Mark functions as static in qlcnic_io.c (Rashika Kheria)   
- qlcnic: update version to 5.3.53 (Manish Chopra)  [Orabug: 18524762]  
- qlcnic: Refactor support for 16 virtual NIC patch. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: sriov vlan code refactor. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Allow single Tx/Rx queue for all adapters. (Himanshu Madhani)  [Orabug: 18524762]  
- qlcnic: Refactor initialize nic code path. (Sucheta Chakraborty)  [Orabug: 18524762]  
- qlcnic: Dump mailbox registers when mailbox command times out. (Manish chopra)  [Orabug: 18524762]  
- qlcnic: Fix mailbox processing during diagnostic test (Manish chopra)  [Orabug: 18524762]  
- qlcnic: Allow firmware dump collection when auto firmware recovery is disabled (Manish Chopra)  [Orabug: 18524762]  
- qlcnic: Fix usage of netif_tx_{wake, stop} api during link change. (Himanshu Madhani)  [Orabug: 18524762]  
- treewide: Fix typo in printk (Masanari Iida)  [Orabug: 18524762]  
- qlcnic: Revert sysfs interface patch for PCI BAR access (Sucheta Chakraborty)  [Orabug: 18524762]  
- xen-netback: disable rogue vif in kthread context (Wei Liu)  [Orabug: 18528832]  
- bfa: brocade bfa driver version 3.2.23.0 (Chuck Anderson)  [Orabug: 18552345]  
- bna: brocade bna driver version 3.2.23.0 (Chuck Anderson)  [Orabug: 18552390]  
- benet: Call dev_kfree_skby_any instead of kfree_skb. (Eric W. Biederman)  [Orabug: 18531060]  
- be2net: update driver version to 10.2 (Sathya Perla)  [Orabug: 18531060]  
- be2net: Fix vlans_added counter (Vasundhara Volam)  [Orabug: 18531060]  
- be2net: Create multiple TXQs on RSS capable multi-channel BE3-R interfaces (Vasundhara Volam)  [Orabug: 18531060]  
- be2net: fix pmac_id[] allocation size (Ravikumar Nelavelli)  [Orabug: 18531060]  
- be2net: log LPVID used in multi-channel configs (Ravikumar Nelavelli)  [Orabug: 18531060]  
- be2net: Use GET_PROFILE_CONFIG cmd for BE3-R to query max-vfs (Suresh Reddy)  [Orabug: 18531060]  
- be2net: do external loopback test only when it is requested (Ivan Vecera)  [Orabug: 18531060]  
- be2net: dma_sync each RX frag before passing it to the stack (Sathya Perla)  [Orabug: 18531060]  
- be2net: isolate TX workarounds not applicable to Skyhawk-R (Vasundhara Volam)  [Orabug: 18531060]  
- be2net: Fix skb double free in be_xmit_wrokarounds() failure path (Vasundhara Volam)  [Orabug: 18531060]  
- be2net: clear promiscuous bits in adapter->flags while disabling promiscuous mode (Somnath kotur)  [Orabug: 18531060]  
- be2net: Fix to reset transparent vlan tagging (Somnath Kotur)  [Orabug: 18531060]  
- be2net: refactor multi-channel config code for Skyhawk-R chip (Vasundhara Volam)  [Orabug: 18531060]  
- be2net: Update copyright year (Vasundhara Volam)  [Orabug: 18531060]  
- be2net: Log a kernel message when UE is detected in BE & Skyhawk (Somnath Kotur)  [Orabug: 18531060]  
- qla4xxx: Check for correct return status (Vikas Chaudhary)  [Orabug: 18552248]  
- qla4xxx: qla4xxx: Move qla4_8xxx_ms_mem_write_128b to ql4_nx.c (Vikas Chaudhary)  [Orabug: 18552248]  
- qla4xxx: Added PEX DMA Support for ISP8022 Adapter (Tej Parkash)  [Orabug: 18552248]  
- qla4xxx: Add support of 0xFF capture mask for minidump (Tej Parkash)  [Orabug: 18552248]  
- qla4xxx: Change default capture to firmware defined capture mask (Tej Parkash)  [Orabug: 18552248]  
- qla4xxx: Do not wait for IO completion, after issuing stop_firmware (Tej Parkash)  [Orabug: 18552248]  
- tg3: update from 3.134f to 3.136e (Jerry Snitselaar)  [Orabug: 18505595]  
- bnx2x: update from 1.78.80 to 1.710.10 (Jerry Snitselaar)  [Orabug: 18505568]  
- bnx2fc: update from 2.4.1e to 2.4.2e (Jerry Snitselaar)  [Orabug: 18505607]  
- cnic: update from 2.5.18c to 2.5.18d (Jerry Snitselaar)  [Orabug: 18505589]  
- bnx2: update from 2.2.4g to 2.2.5f (Jerry Snitselaar)  [Orabug: 18505581]  
- SPEC: add version dependency for dracut on ol6 (Jerry Snitselaar)  [Orabug: 18438953]  
- SPEC: don't build kernel-uek-headers (Jerry Snitselaar)  [Orabug: 12321095]  
- NVMe: Retry failed commands with non-fatal errors (Keith Busch)   
- NVMe: Add getgeo to block ops (Keith Busch)   
- NVMe: Start-stop nvme_thread during device add-remove. (Dan McLeran)   
- NVMe: Make I/O timeout a module parameter (Keith Busch)   
- NVMe: CPU hot plug notification (Keith Busch)   
- NVMe: per-cpu io queues (Keith Busch)   
- NVMe: Replace DEFINE_PCI_DEVICE_TABLE (Matthew Wilcox)   
- NVMe: Fix divide-by-zero in nvme_trans_io_get_num_cmds (Keith Busch)   
- NVMe: IOCTL path RCU protect queue access (Keith Busch)   
- NVMe: RCU protected access to io queues (Keith Busch)   
- NVMe: Initialize device reference count earlier (Keith Busch)   
- NVMe: Add CONFIG_PM_SLEEP to suspend/resume functions (Jingoo Han)   
- NVMe: Namespace use after free on surprise removal (Keith Busch)   
- NVMe: Correct uses of INIT_WORK (Matthew Wilcox)   
- NVMe: Include device and queue numbers in interrupt name (Matthew Wilcox)   
- NVMe: Add a pci_driver shutdown method (Keith Busch)   
- NVMe: Disable admin queue on init failure (Keith Busch)   
- NVMe: Dynamically allocate partition numbers (Matthew Wilcox)   
- NVMe: Async IO queue deletion (Keith Busch)   
- NVMe: Surprise removal handling (Keith Busch)   
- NVMe: Abort timed out commands (Keith Busch)   
- NVMe: Schedule reset for failed controllers (Keith Busch)   
- NVMe: Device resume error handling (Keith Busch)   
- NVMe: Cache dev->pci_dev in a local pointer (Matthew Wilcox)   
- NVMe: Fix lockdep warnings (Matthew Wilcox)   
- NVMe: compat SG_IO ioctl (Keith Busch)   
- NVMe: Avoid shift operation when writing cq head doorbell (Haiyan Hu)   
- NVMe: Split header file into user-visible and kernel-visible pieces (Matthew Wilcox)   
- ixgbevf: Don't output NIC name before registered. (Ethan Zhao)  [Orabug: 18451591]  
- Btrfs: create the uuid tree on remount rw (Josef Bacik)  [Orabug: 18414854]  
- RDS: Fix slowdown when doing massively parallel workload (Bang Nguyen)  [Orabug: 18362849]  
- PCI: Drop "irq" param from *_restore_msi_irqs() (Zhenzhong Duan)  [Orabug: 18355744]  
- PCI: Add x86_msi.msi_mask_irq() and msix_mask_irq() (Zhenzhong Duan)  [Orabug: 18355746]  
- pciehp: only wait command complete for really hotplug control (Yinghai Lu)  [Orabug: 18308863]  
- ocfs2: dlm: fix recovery hung (Junxiao Bi)  [Orabug: 18285345]  
- IPC: bugfix for msgrcv with msgtyp < 0 (Svenning Sørensen)  [Orabug: 18251383]  
- reboot: migrate shutdown/reboot to boot cpu (Robin Holt)  [Orabug: 18380043]  
- CPU hotplug: provide a generic helper to disable/enable CPU hotplug (Srivatsa S. Bhat)  [Orabug: 18380043]  
- sparc64: don't treat 64-bit syscall return codes as 32-bit (Dave Kleikamp)  [Orabug: 18471474]  

* Tue Mar 25 2014 Guangyu Sun <guangyu.sun@oracle.com> [3.8.13-31.el7uek] 
- SPEC: remove device-mapper-multipath version dependency from ol7 kernel-uek.spec (Guangyu Sun)  [Orabug: 18438931]  
- netfilter: nf_conntrack_dccp: fix skb_header_pointer API usages (Daniel Borkmann)  [Orabug: 18421673]  {CVE-2014-2523} 
- cifs: ensure that uncached writes handle unmapped areas correctly (Jeff Layton)  [Orabug: 18461067]  {CVE-2014-0069} {CVE-2014-0069} 
- net: sctp: fix sctp_sf_do_5_1D_ce to verify if we/peer is AUTH capable (Daniel Borkmann)  [Orabug: 18461065]  {CVE-2014-0101} 
- vhost-net: insufficient handling of error conditions in get_rx_bufs() (Guangyu Sun)  [Orabug: 18461050]  {CVE-2014-0055} 
- rds/rdma_cm: send RDMA_CM_EVENT_ADDR_CHANGE event for active bonding (Ajaykumar Hotchandani)  [Orabug: 18421511]  
- dtrace: don't use ktime_get() in dtrace_gethrtime() (Kris Van Hees)  [Orabug: 18376038]  
- Xen-netback: Fix issue caused by using gso_type wrongly (Annie Li)  [Orabug: 18347192]  

* Sat Mar 15 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-30.el7uek] 
- Btrfs: add mount option to force UUID tree checking (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: check UUID tree during mount if required (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: introduce uuid-tree-gen field (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: fill UUID tree initially (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: maintain subvolume items in the UUID tree (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: create UUID tree if required (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: support printing UUID tree elements (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: introduce a tree for items that map UUIDs to something (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: don't allow a subvol to be deleted if it is the default subovl (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: fix a crash of clone with inline extents's split (Liu Bo)  [Orabug: 18383584]  
- Btrfs: use right clone root offset for compressed extents (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: fix max_inline mount option (Mitch Harder)  [Orabug: 18383584]  
- Btrfs: fix data corruption when reading/updating compressed extents (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: setup inode location during btrfs_init_inode_locked (Chris Mason)  [Orabug: 18383584]  
- Btrfs: improve inode hash function/inode lookup (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: don't use ram_bytes for uncompressed inline items (Chris Mason)  [Orabug: 18383584]  
- Btrfs: fix btrfs_search_slot_for_read backwards iteration (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: add a reschedule point in btrfs_find_all_roots() (Wang Shilong)  [Orabug: 18383584]  
- Btrfs: make send's file extent item search more efficient (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: fix protection between walking backrefs and root deletion (Wang Shilong)  [Orabug: 18383584]  
- btrfs: fix warning while merging two adjacent extents (Gui Hecheng)  [Orabug: 18383584]  
- btrfs: fix defrag 32-bit integer overflow (Justin Maggard)  [Orabug: 18383584]  
- btrfs: call permission checks earlier in ioctls and return EPERM (David Sterba)  [Orabug: 18383584]  
- Btrfs: change the members' order of btrfs_space_info structure to reduce the cache miss (Miao Xie)  [Orabug: 18383584]  
- Btrfs: fix wrong search path initialization before searching tree root (Wang Shilong)  [Orabug: 18383584]  
- Btrfs: flush the dirty pages of the ordered extent aggressively during logging csum (Miao Xie)  [Orabug: 18383584]  
- Btrfs: faster file extent item search in clone ioctl (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: fix an oops when we fail to relocate tree blocks (Wang Shilong)  [Orabug: 18383584]  
- Btrfs: reduce btree node locking duration on item update (Filipe David Borba Manana)  [Orabug: 18383584]  
- fs/btrfs: Integer overflow in btrfs_ioctl_resize() (Wenliang Fan)  [Orabug: 18383584]  
- Btrfs: fix a warning when iput a file (Wang Shilong)  [Orabug: 18383584]  
- Btrfs: fix deadlock when iterating inode refs and running delayed inodes (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: more efficient push_leaf_right (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: fix pass of transid with wrong endianness in send.c (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: fix extent_map block_len after merging (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: fix max dir item size calculation (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: more efficient extent state insertions (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: add missing extent state caching calls (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: faster and more efficient extent map insertion (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: fix extent boundary check in bio_readpage_error (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: avoid unnecessary ordered extent cache resets (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: fix very slow inode eviction and fs unmount (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: eliminate the exceptional root_tree refs=0 (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: improve forever loop when doing balance relocation (Wang Shilong)  [Orabug: 18383584]  
- Btrfs: fix ordered extent check in btrfs_punch_hole (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: skip building backref tree for uuid and quota tree when doing balance relocation (Wang Shilong)  [Orabug: 18383584]  
- Btrfs: fix an oops when doing balance relocation (Wang Shilong)  [Orabug: 18383584]  
- Btrfs: don't clear the default compression type (Miao Xie)  [Orabug: 18383584]  
- btrfs: fix bio_size_ok() for max_sectors > 0xffff (Akinobu Mita)  [Orabug: 18383584]  
- Btrfs: don't wait for ordered data outside desired range (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: avoid heavy operations in btrfs_commit_super (Liu Bo)  [Orabug: 18383584]  
- Btrfs: fix __btrfs_start_workers retval (Ilya Dryomov)  [Orabug: 18383584]  
- Btrfs: only drop modified extents if we logged the whole inode (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: make sure to copy everything if we rename (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: don't BUG_ON() if we get an error walking backrefs (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: don't wait for all the async delalloc when shrinking delalloc (Miao Xie)  [Orabug: 18383584]  
- Btrfs: fix the confusion between delalloc bytes and metadata bytes (Miao Xie)  [Orabug: 18383584]  
- Btrfs: pick up the code for the item number calculation in flush_space() (Miao Xie)  [Orabug: 18383584]  
- Btrfs: wait for the ordered extent only when we want (Miao Xie)  [Orabug: 18383584]  
- Btrfs: check file extent type before anything else (Josef Bacik)  [Orabug: 18383584]  
- btrfs: Pack struct btrfs_device (Dulshani Gunawardhana)  [Orabug: 18383584]  
- btrfs: Replace multiple atomic_inc() with atomic_add() (Rashika)  [Orabug: 18383584]  
- Btrfs: fix csum search offset/length calculation in log tree (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: wait on ordered extents at the last possible moment (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: fix verification of dir_item (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: make sure the delalloc workers actually flush compressed writes (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: do not bug_on if we try to cow a free space cache inode (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: stop using vfs_read in send (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: Don't allocate inode that is already in use (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: fix btrfs_prev_leaf() previous key computation (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: btrfs_add_ordered_operation: Fix last modified transaction comparison. (chandan)  [Orabug: 18383584]  
- Btrfs: init device stats for new devices (Stefan Behrens)  [Orabug: 18383584]  
- Btrfs: disallow 'btrfs {balance,replace} cancel' on ro mounts (Ilya Dryomov)  [Orabug: 18383584]  
- Btrfs: don't leak ioctl args in btrfs_ioctl_dev_replace (Ilya Dryomov)  [Orabug: 18383584]  
- Btrfs: nuke a bogus rw_devices decrement in __btrfs_close_devices (Ilya Dryomov)  [Orabug: 18383584]  
- btrfs: Fix memory leakage in the tree-log.c (Geyslan G. Bem)  [Orabug: 18383584]  
- Btrfs: fix up seek_hole/seek_data handling (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: fix hole check in log_one_extent (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: handle a missing extent for the first file extent (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: fix memory leaks on transaction commit failure (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: fix the dev-replace suspend sequence (Ilya Dryomov)  [Orabug: 18383584]  
- Btrfs: fix a use-after-free bug in btrfs_dev_replace_finishing (Ilya Dryomov)  [Orabug: 18383584]  
- Btrfs: eliminate races in worker stopping code (Ilya Dryomov)  [Orabug: 18383584]  
- Btrfs: limit delalloc pages outside of find_delalloc_range (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: fix crash of compressed writes (Liu Bo)  [Orabug: 18383584]  
- Btrfs: actually limit the size of delalloc range (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: fixup error handling in btrfs_reloc_cow (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: fix race between removing a dev and writing sbs (Filipe David Borba Manana)  [Orabug: 18383584]  
- Btrfs: fix send to deal with sparse files properly (Josef Bacik)  [Orabug: 18383584]  
- Btrfs: fix memory leak of orphan block rsv (Filipe David Borba Manana)  [Orabug: 18383584]  
- sparc: report correct hw capabilities for athena (Jose Marchesi)  [Orabug: 18314966]  
- xen-netback: reset network header before passing skb to checksum funtion (Annie Li)  [Orabug: 18379272]  
- xen-netfront: reset skb network header before checksum (Wei Liu)  [Orabug: 18379272]  
- xen-netfront: handle backend CLOSED without CLOSING (David Vrabel)  [Orabug: 18379272]  
- xen-netfront: add support for IPv6 offloads (Paul Durrant)  [Orabug: 18379272]  
- xen-netfront: fix missing rx_refill_timer when allocate memory failed (Ma JieYue)  [Orabug: 18379272]  
- xen-netback: Fix Rx stall due to race condition (Zoltan Kiss)  [Orabug: 18379272]  
- xen-netfront: use new skb_checksum_setup function (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: use new skb_checksum_setup function (Paul Durrant)  [Orabug: 18379272]  
- net: add skb_checksum_setup (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: stop vif thread spinning if frontend is unresponsive (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: Include header for vmalloc (Josh Boyer)  [Orabug: 18379272]  
- xen-netback: fix guest-receive-side array sizes (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: fix some error return code (Wei Yongjun)  [Orabug: 18379272]  
- xen-netback: add gso_segs calculation (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: fix fragments error handling in checksum_setup_ip() (Wei Yongjun)  [Orabug: 18379272]  
- xen-netback: fix gso_prefix check (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: napi: don't prematurely request a tx event (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: napi: fix abuse of budget (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: make sure skb linear area covers checksum field (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: improve guest-receive-side flow control (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: fix fragment detection in checksum setup (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: clear vif->task on disconnect (Paul Durrant)  [Orabug: 18379272]  
- xen-netback: include definition of csum_ipv6_magic (Andy Whitcroft)  [Orabug: 18379272]  
- xen-netback: stop the VIF thread before unbinding IRQs (David Vrabel)  [Orabug: 18379272]  
- xen-netback: use jiffies_64 value to calculate credit timeout (Wei Liu)  [Orabug: 18379272]  

* Sat Mar 8 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-29.el7uek] 
- kabi: update Module.kabi_x86_64 for ol7 (Jerry Snitselaar)  [Orabug: 18155943]  
- config: enable FANOTIFY for ol7 (Jerry Snitselaar)  [Orabug: 17843511]  
- config: update config for ol7 (Jerry Snitselaar)  [Orabug: 18340231]  
- config: disable CONFIG_PCI_IOAPIC (Jerry Snitselaar)  [Orabug: 18363152]  
- scsi: hpsa, add all PCI ID's that HP has in svn (Mike Miller)  [Orabug: 18285553]  
- scsi: hpsa, remove cancelled ID's and add a new one (Mike Miller)  [Orabug: 18285553]  
- scsi: hpsa, add new PCI Ids (Mike Miller)  [Orabug: 18285553]  
- hpsa: Add support for a few HP Storage controllers (Stephen M. Cameron)  [Orabug: 18285553]  
- pci: add HP/3PAR vendor id to pci_ids.h (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa add sysfs debug switch for raid map debugging messages (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: improve error messages for driver initiated commands (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: only do device rescan for certain events (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: when switching out of accel mode await only accel command completions (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: add controller base data-at-rest encryption compatibility ioaccel2 (Scott Teel)  [Orabug: 18285553]  
- hpsa: update source file copyrights (Scott Teel)  [Orabug: 18285553]  
- hpsa: retry certain ioaccel error cases on the RAID path (Scott Teel)  [Orabug: 18285553]  
- hpsa: do not inquire for unsupported ioaccel status vpd page (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: allow VPD page zero to be queried (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: rescan devices on ioaccel2 error (Scott Teel)  [Orabug: 18285553]  
- hpsa: allow user to disable accelerated i/o path (Scott Teel)  [Orabug: 18285553]  
- hpsa: complete the ioaccel raidmap code (Scott Teel)  [Orabug: 18285553]  
- hpsa: make device update copy the raid map also (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: add task management for ioaccel mode 2 (Scott Teel)  [Orabug: 18285553]  
- hpsa: teach hpsa_device_reset to do either target or lun reset (Scott Teel)  [Orabug: 18285553]  
- hpsa: get ioaccel mode 2 i/o working (Scott Teel)  [Orabug: 18285553]  
- hpsa: initialize controller to perform io accelerator mode 2 (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: get physical device handles for io accel mode 2 as well as mode 1 (Mike MIller)  [Orabug: 18285553]  
- hpsa: do ioaccel mode 2 resource allocations (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: Acknowledge controller events in ioaccell mode 2 as well as mode 1 (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: add ioaccel mode 2 structure definitions (Mike Miller)  [Orabug: 18285553]  
- hpsa: complain if physical or logical aborts are not supported (Scott Teel)  [Orabug: 18285553]  
- hpsa: add hp_ssd_smart_path_enabled sysfs attribute (Scott Teel)  [Orabug: 18285553]  
- hpsa: do not rescan controllers known to be locked up (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: poll controller to detect device change event (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: update raid offload status on device rescan (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: add ioaccell mode 1 RAID offload support. (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: fix task management for mode-1 ioaccell path (Scott Teel)  [Orabug: 18285553]  
- hpsa: only allow REQ_TYPE_FS to use fast path (Stephen M. Cameron)  [Orabug: 18285553]  
- hpsa: add support for 'fastpath' i/o (Matt Gates)  [Orabug: 18285553]  
- hpsa: mark last scatter gather element as the last (Matt Gates)  [Orabug: 18285553]  
- hpsa: use extended report luns command for HP SSD SmartPath (Matt Gates)  [Orabug: 18285553]  
- [SCSI] hpsa: allow SCSI mid layer to handle unit attention (Matt Gates)  [Orabug: 18285553]  
- [SCSI] hpsa: do not require board "not ready" status after hard reset (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: enable unit attention reporting (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: rename scsi prefetch field (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: use workqueue instead of kernel thread for lockup detection (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: remove P822se PCI ID (Mike Miller)  [Orabug: 18285553]  
- [SCSI] hpsa: prevent stalled i/o (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: cap CCISS_PASSTHRU at 20 concurrent commands. (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: add MSA 2040 to list of external target devices (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: fix memory leak in CCISS_BIG_PASSTHRU ioctl (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: remove unneeded include of seq_file.h (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: add 5 second delay after doorbell reset (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: do not attempt to flush the cache on locked up controllers (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: return 0 from driver probe function on success, not 1 (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: do not discard scsi status on aborted commands (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] Disable WRITE SAME for RAID and virtual host adapter drivers (Martin K. Petersen)  [Orabug: 18285553]  
- SCSI: remove unnecessary pci_set_drvdata() (Jingoo Han)  [Orabug: 18285553]  
- [SCSI] hpsa: remove unused Smart Array ID (Mike Miller)  [Orabug: 18285553]  
- [SCSI] hpsa: bump driver version to reflect changes (Mike Miller)  [Orabug: 18285553]  
- [SCSI] hpsa: housekeeping patch for device_id and product arrays (Mike Miller)  [Orabug: 18285553]  
- [SCSI] hpsa: add HP Smart Array Gen8 names (Mike Miller)  [Orabug: 18285553]  
- [SCSI] hpsa: add HP Smart Array Gen9 PCI ID's (Mike Miller)  [Orabug: 18285553]  
- hpsa: Convert retrun typos to return (Joe Perches)  [Orabug: 18285553]  
- [SCSI] hpsa: fix warning with smp_processor_id() in preemptible (John Kacur)  [Orabug: 18285553]  
- [SCSI] hpsa: remove unneeded variable (Tomas Henzl)  [Orabug: 18285553]  
- [SCSI] hpsa: fix a race in cmd_free/scsi_done (Tomas Henzl)  [Orabug: 18285553]  
- [SCSI] hpsa: check for dma_mapping_error in hpsa_passthru ioctls (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: reorganize error handling in hpsa_passthru_ioctl (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: check for dma_mapping_error in hpsa_map_sg_chain_block (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: Check for dma_mapping_error for all code paths using fill_cmd (Stephen M. Cameron)  [Orabug: 18285553]  
- [SCSI] hpsa: Check for dma_mapping_error in hpsa_map_one (Shuah Khan)  [Orabug: 18285553]  
- Revert "hpsa: upgrade to 3.4.2-5" (Vaughan Cao)  [Orabug: 18285553]  
- Revert "hpsa: fix compilation error of __dev* markings" (Vaughan Cao)  [Orabug: 18285553]  
- Revert "[SCSI] hpsa: fix a race in cmd_free/scsi_done" (Vaughan Cao)  [Orabug: 18285553]  
- Revert "[SCSI] hpsa: fix warning with smp_processor_id() in preemptible" (Vaughan Cao)  [Orabug: 18285553]  
- Revert "hpsa: Convert retrun typos to return" (Vaughan Cao)  [Orabug: 18285553]  
- Revert "[SCSI] hpsa: add HP Smart Array Gen9 PCI ID's" (Vaughan Cao)  [Orabug: 18285553]  
- Revert "hpsa: add HP Smart Array Gen8 name P822se" (Vaughan Cao)  [Orabug: 18285553]  
- Revert "[SCSI] hpsa: housekeeping patch for device_id and product arrays" (Vaughan Cao)  [Orabug: 18285553]  
- Revert "[SCSI] hpsa: remove unneeded variable" (Vaughan Cao)  [Orabug: 18285553]  
- Revert hpsa part of "[SCSI] Disable WRITE SAME for RAID and virtual host adapter drivers" (Vaughan Cao)  [Orabug: 18285553]  
- kabi: remove mcount for ol7 (Jerry Snitselaar)  [Orabug: 18155943]  
- [SCSI] iscsi_tcp: consider session state in iscsi_sw_sk_state_check (Chris Leech)  [Orabug: 17585443]  
- tools/power turbostat: decode MSR_IA32_POWER_CTL (Len Brown)  [Orabug: 18263969]  
- x86, AMD: Enable WC+ memory type on family 10 processors (Boris Ostrovsky)  [Orabug: 18263969]  
- intel_idle: remove stop/start critical timings (Daniel Lezcano)  [Orabug: 18263969]  
- intel_idle: initial C8, C9, C10 support (Len Brown)  [Orabug: 18263969]  
- intel_idle: additional Haswell CPU-id (Len Brown)  [Orabug: 18263969]  
- intel_idle: export both C1 and C1E (Len Brown)  [Orabug: 18263969]  
- intel_idle: remove assumption of one C-state per MWAIT flag (Len Brown)  [Orabug: 18263969]  
- intel_idle: remove use and definition of MWAIT_MAX_NUM_CSTATES (Len Brown)  [Orabug: 18263969]  
- intel_idle: support Haswell (Len Brown)  [Orabug: 18263969]  
- intel_idle: stop using driver_data for static flags (Len Brown)  [Orabug: 18263969]  
- scsi: not abort scan process if one inquiry returns not_ready (Hannes Reinecke)  [Orabug: 18271070]  
- ixgbe: set driver_max_VFs should be done before enabling SRIOV (Ethan Zhao)  [Orabug: 17482349]  
- ixgbe: Look up MAC address on SPARC systems (Martin K. Petersen)  [Orabug: 18182472]  
- ixgbe: upgrade to intel version 3.19.1 (Ethan Zhao)  [Orabug: 18278142]  
- e1000e: upgrade to intel version 3.0.4 and merge patches based on 2.5.4 (ethan.zhao)  [Orabug: 18278358]  
- igbvf: upgrade to intel version 2.3.3 (Ethan Zhao)  [Orabug: 18278378]  
- igb: upgrade to intel version 5.1.2 and merge patches based on 5.0.6 (Ethan Zhao)  [Orabug: 18278407]  
- ixgbevf: upgrade to intel version 2.12.1 (Ethan Zhao)  [Orabug: 18278415]  
- be2iscsi : Bump the driver version (John Soni Jose)  [Orabug: 18206635]  
- be2iscsi : Fix DMA Out of SW-IOMMU space error (Jayamohan Kallickal)  [Orabug: 18206635]  
- be2iscsi: Fix scsi_cmnd leakage in driver. (Jayamohan Kallickal)  [Orabug: 18206635]  
- be2iscsi: Fix the session cleanup when reboot/shutdown happens (Jayamohan Kallickal)  [Orabug: 18206635]  
- be2iscsi: Fix doorbell format for EQ/CQ/RQ s per SLI spec. (Jayamohan Kallickal)  [Orabug: 18206635]  
- be2iscsi: Fix port speed typo in driver. (Jayamohan Kallickal)  [Orabug: 18206635]  
- be2iscsi: Fix handling timed out MBX completion from FW (Jayamohan Kallickal)  [Orabug: 18206635]  
- be2iscsi: fix memory leak in error path (Geyslan G. Bem)  [Orabug: 18206635]  
- kexec: increase reservation size for crashkernel=auto (Brian Maly)  [Orabug: 18222081]  
- mm/hugetlb.c: defer PageHeadHuge() symbol export (Andrea Arcangeli)  [Orabug: 18364682]  
- mm/swap.c: reorganize put_compound_page() (Andrew Morton)  [Orabug: 18364682]  
- mm/hugetlb.c: simplify PageHeadHuge() and PageHuge() (Andrew Morton)  [Orabug: 18364682]  
- mm: hugetlbfs: use __compound_tail_refcounted in __get_page_tail too (Andrea Arcangeli)  [Orabug: 18364682]  
- mm: tail page refcounting optimization for slab and hugetlbfs (Andrea Arcangeli)  [Orabug: 18364682]  
- mm: thp: optimize compound_trans_huge (Andrea Arcangeli)  [Orabug: 18364682]  
- mm: hugetlbfs: move the put/get_page slab and hugetlbfs optimization in a faster path (Andrea Arcangeli)  [Orabug: 18364682]  
- mm: hugetlb: use get_page_foll() in follow_hugetlb_page() (Andrea Arcangeli)  [Orabug: 18364682]  
- mm: hugetlbfs: fix hugetlbfs optimization (Andrea Arcangeli)  [Orabug: 18364682]  
- mm: fix aio performance regression for database caused by THP (Khalid Aziz)  [Orabug: 18364682]  
- dwarf2ctf: spot non-struct/union/enum children of DW_TAG_structure_type. (Nick Alcock)  [Orabug: 18117464]  
- dwarf2ctf: capture all DIEs with structs/enums as their ultimate supertype. (Nick Alcock)  [Orabug: 18117464]  
- dwarf2ctf: Handle structure and union offsets in form DW_FORM_data1. (Nick Alcock)  [Orabug: 18117464]  
- dwarf2ctf: cater for elfutils 0.156 change in dwfl_report_elf() prototype. (Nick Alcock)  [Orabug: 18117421]  
- SPEC: Add respun RPM find-debuginfo.sh patch. (Nick Alcock)  [Orabug: 18117371]  
- build: add ol7 support (Jerry Snitselaar)  [Orabug: 18155943]  
- net,via-rhine: Fix tx_timeout handling (Richard Weinberger)  [Orabug: 18348669]  
- power: max17040: Fix NULL pointer dereference when there is no platform_data (Krzysztof Kozlowski)  [Orabug: 18348667]  
- md/raid5: Fix CPU hotplug callback registration (Oleg Nesterov)  [Orabug: 18348666]  
- ftrace/x86: Use breakpoints for converting function graph caller (Steven Rostedt (Red Hat))  [Orabug: 18348665]  
- staging:iio:ad799x fix error_free_irq which was freeing an irq that may not have been requested (Hartmut Knaack)  [Orabug: 18348664]  
- vt: Fix secure clear screen (Petr Písař)  [Orabug: 18348663]  
- lockd: send correct lock when granting a delayed lock. (NeilBrown)  [Orabug: 18348662]  
- mac80211: fix fragmentation code, particularly for encryption (Johannes Berg)  [Orabug: 18348661]  
- xen/p2m: check MFN is in range before using the m2p table (David Vrabel)  [Orabug: 18348660]  
- xen-blkfront: handle backend CLOSED without CLOSING (David Vrabel)  [Orabug: 18348659]  
- mxl111sf: Fix compile when CONFIG_DVB_USB_MXL111SF is unset (Dave Jones)  [Orabug: 18348658]  
- x86: mm: change tlb_flushall_shift for IvyBridge (Mel Gorman)  [Orabug: 18348657]  
- mm: __set_page_dirty uses spin_lock_irqsave instead of spin_lock_irq (KOSAKI Motohiro)  [Orabug: 18348655]  
- mm: __set_page_dirty_nobuffers() uses spin_lock_irqsave() instead of spin_lock_irq() (KOSAKI Motohiro)  [Orabug: 18348653]  
- Btrfs: disable snapshot aware defrag for now (Josef Bacik)  [Orabug: 18348652]  
- SELinux: Fix kernel BUG on empty security contexts. (Stephen Smalley)  [Orabug: 18348651]  
- timekeeping: Avoid possible deadlock from clock_was_set_delayed (John Stultz)  [Orabug: 18348650]  
- rtc-cmos: Add an alarm disable quirk (Borislav Petkov)  [Orabug: 18348648]  
- ftrace: Have function graph only trace based on global_ops filters (Steven Rostedt)  [Orabug: 18348647]  
- ftrace: Fix synchronization location disabling and freeing ftrace_ops (Steven Rostedt)  [Orabug: 18348646]  
- ftrace: Synchronize setting function_trace_op with ftrace_trace_function (Steven Rostedt)  [Orabug: 18348645]  
- i2c: i801: SMBus patch for Intel Coleto Creek DeviceIDs (Seth Heasley)  [Orabug: 18348643]  
- mfd: lpc_ich: iTCO_wdt patch for Intel Coleto Creek DeviceIDs (Seth Heasley)  [Orabug: 18348642]  
- mfd: lpc_ich: Add support for Intel Avoton SoC (James Ralston)  [Orabug: 18348641]  
- mm, oom: base root bonus on current usage (David Rientjes)  [Orabug: 18348640]  
- dm space map common: make sure new space is used during extend (Joe Thornber)  [Orabug: 18348639]  
- dm: wait until embedded kobject is released before destroying a device (Mikulas Patocka)  [Orabug: 18348638]  
- dm thin: initialize dm_thin_new_mapping returned by get_next_mapping (Mike Snitzer)  [Orabug: 18348637]  
- dm thin: fix discard support to a previously shared block (Joe Thornber)  [Orabug: 18348636]  
- sunrpc: Fix infinite loop in RPC state machine (Weston Andros Adamson)  [Orabug: 18348635]  
- nfs4: fix discover_server_trunking use after free (Weston Andros Adamson)  [Orabug: 18348634]  
- NFSv4.1: Handle errors correctly in nfs41_walk_client_list (Trond Myklebust)  [Orabug: 18348633]  
- nfs4.1: properly handle ENOTSUP in SECINFO_NO_NAME (Weston Andros Adamson)  [Orabug: 18348632]  
- NFSv4: OPEN must handle the NFS4ERR_IO return code correctly (Trond Myklebust)  [Orabug: 18348631]  
- IB/qib: Fix QP check when looping back to/from QP1 (Ira Weiny)  [Orabug: 18348629]  
- ore: Fix wrong math in allocation of per device BIO (Boaz Harrosh)  [Orabug: 18348628]  
- mm/memory-failure.c: shift page lock from head page to tail page after thp split (Naoya Horiguchi)  [Orabug: 18348627]  
- mm/page-writeback.c: do not count anon pages as dirtyable memory (Johannes Weiner)  [Orabug: 18348626]  
- mm/page-writeback.c: fix dirty_balance_reserve subtraction from dirtyable memory (Johannes Weiner)  [Orabug: 18348625]  
- fuse: fix pipe_buf_operations (Miklos Szeredi)  [Orabug: 18348624]  
- intel-iommu: fix off-by-one in pagetable freeing (Alex Williamson)  [Orabug: 18348623]  
- SELinux: Fix memory leak upon loading policy (Tetsuo Handa)  [Orabug: 18348622]  
- x86, cpu, amd: Add workaround for family 16h, erratum 793 (Borislav Petkov)  [Orabug: 18348621]  {CVE-2013-6885} 
- btrfs: restrict snapshotting to own subvolumes (David Sterba)  [Orabug: 18348620]  
- SCSI: bfa: Chinook quad port 16G FC HBA claim issue (Vijaya Mohan Guvva)  [Orabug: 18348619]  
- ip6tnl: fix double free of fb_tnl_dev on exit (Nicolas Dichtel)  [Orabug: 18348617]  
- sit: fix double free of fb_tunnel_dev on exit (Nicolas Dichtel)  [Orabug: 18348604]  
- xen-netfront: fix resource leak in netfront (Annie Li)  [Orabug: 18348558]  
- net: Fix memory leak if TPROXY used with TCP early demux (Holger Eitzenberger)  [Orabug: 18348557]  
- fib_frontend: fix possible NULL pointer dereference (Oliver Hartkopp)  [Orabug: 18348556]  
- net: avoid reference counter overflows on fib_rules in multicast forwarding (Hannes Frederic Sowa)  [Orabug: 18348555]  
- ieee802154: Fix memory leak in ieee802154_add_iface() (Christian Engelmayer)  [Orabug: 18348554]  
- ext4: avoid clearing beyond i_blocks when truncating an inline data file (Theodore Ts'o)  [Orabug: 18348552]  
- mfd: max77686: Fix regmap resource leak on driver remove (Krzysztof Kozlowski)  [Orabug: 18348551]  
- perf kvm: Fix kvm report without guestmount. (Dongsheng Yang)  [Orabug: 18348550]  
- tty/serial: at91: Handle shutdown more safely (Marek Roszko)  [Orabug: 18348549]  
- b43legacy: Fix unload oops if firmware is not available (Larry Finger)  [Orabug: 18348548]  
- b43: Fix unload oops if firmware is not available (Larry Finger)  [Orabug: 18348547]  
- USB: fix race between hub_disconnect and recursively_mark_NOTATTACHED (Alan Stern)  [Orabug: 18348546]  
- USB: Nokia 502 is an unusual device (Mikhail Zolotaryov)  [Orabug: 18348544]  
- USB: pl2303: fix data corruption on termios updates (Johan Hovold)  [Orabug: 18348543]  
- x86, x32: Correct invalid use of user timespec in the kernel (PaX Team)  [Orabug: 18348539]  {CVE-2014-0038} 
- e752x_edac: Fix pci_dev usage count (Aristeu Rozanski)  [Orabug: 18348485]  
- md/raid5: fix long-standing problem with bitmap handling on write failure. (NeilBrown)  [Orabug: 18348517]  
- md/raid5: Fix possible confusion when multiple write errors occur. (NeilBrown)  [Orabug: 18317253]  
- md/raid10: fix two bugs in handling of known-bad-blocks. (NeilBrown)  [Orabug: 18317251]  
- md/raid10: fix bug when raid10 recovery fails to recover a block. (NeilBrown)  [Orabug: 18317250]  
- SELinux: Fix possible NULL pointer dereference in selinux_inode_permission() (Steven Rostedt)  [Orabug: 18317248]  
- GFS2: Increase i_writecount during gfs2_setattr_chown (Bob Peterson)  [Orabug: 18317246]  
- sched: Fix hrtimer_cancel()/rq->lock deadlock (Ben Segall)  [Orabug: 18317243]  
- sched: Fix cfs_bandwidth misuse of hrtimer_expires_remaining (Ben Segall)  [Orabug: 18317242]  
- sched: Fix race on toggling cfs_bandwidth_used (Ben Segall)  [Orabug: 18317241]  
- ACPI / TPM: fix memory leak when walking ACPI namespace (Jiang Liu)  [Orabug: 18317240]  
- mfd: rtsx_pcr: Disable interrupts before cancelling delayed works (Thomas Gleixner)  [Orabug: 18317239]  
- bridge: use spin_lock_bh() in br_multicast_set_hash_max (Curt Brune)  [Orabug: 18317233]  
- net: llc: fix use after free in llc_ui_recvmsg (Daniel Borkmann)  [Orabug: 18317232]  
- vlan: Fix header ops passthru when doing TX VLAN offload. (David S. Miller)  [Orabug: 18317228]  
- net: inet_diag: zero out uninitialized idiag_{src,dst} fields (Daniel Borkmann)  [Orabug: 18317227]  
- netvsc: don't flush peers notifying work during setting mtu (Jason Wang)  [Orabug: 18317225]  
- tg3: Initialize REG_BASE_ADDR at PCI config offset 120 to 0 (Nat Gurumoorthy)  [Orabug: 18317223]  
- virtio: delete napi structures from netdev before releasing memory (Andrey Vagin)  [Orabug: 18317222]  
- ext4: fix bigalloc regression (Eric Whitney)  [Orabug: 18317221]  
- libceph: potential NULL dereference in ceph_osdc_handle_map() (Dan Carpenter)  [Orabug: 18317219]  
- ceph: cleanup types in striped_read() (Dan Carpenter)  [Orabug: 18317218]  
- ceph: fix null pointer dereference (Nathaniel Yazdani)  [Orabug: 18317217]  
- ceph: avoid accessing invalid memory (Sasha Levin)  [Orabug: 18317215]  
- ceph: Free mdsc if alloc mdsc->mdsmap failed. (majianpeng)  [Orabug: 18317213]  
- ceph: improve error handling in ceph_mdsmap_decode (Emil Goode)  [Orabug: 18317212]  
- selinux: process labeled IPsec TCP SYN-ACK packets properly in selinux_ip_postroute() (Paul Moore)  [Orabug: 18317209]  
- selinux: look for IPsec labels on both inbound and outbound packets (Paul Moore)  [Orabug: 18317203]  
- jbd2: don't BUG but return ENOSPC if a handle runs out of space (Theodore Ts'o)  [Orabug: 18317197]  
- Input: allocate absinfo data when setting ABS capability (Dmitry Torokhov)  [Orabug: 18317196]  
- mm/memory-failure.c: transfer page count from head page to tail page after split thp (Naoya Horiguchi)  [Orabug: 18317192]  
- mm/hugetlb: check for pte NULL pointer in __page_check_address() (Jianguo Wu)  [Orabug: 18317187]  
- sched: fix the theoretical signal_wake_up() vs schedule() race (Oleg Nesterov)  [Orabug: 18317179]  
- rtlwifi: pci: Fix oops on driver unload (Larry Finger)  [Orabug: 18317163]  
- radiotap: fix bitmap-end-finding buffer overrun (Johannes Berg)  [Orabug: 18317162]  
- libata, freezer: avoid block device removal while system is frozen (Tejun Heo)  [Orabug: 18317160]  
- tg3: Expand 4g_overflow_test workaround to skb fragments of any size. (Nithin Sujir)  [Orabug: 18317159]  
- ceph: Avoid data inconsistency due to d-cache aliasing in readpage() (Li Wang)  [Orabug: 18317158]  
- sched/rt: Fix rq's cpupri leak while enqueue/dequeue child RT entities (Kirill Tkhai)  [Orabug: 18317157]  
- ext4: add explicit casts when masking cluster sizes (Theodore Ts'o)  [Orabug: 18317154]  
- ext4: check for overlapping extents in ext4_valid_extent_entries() (Eryu Guan)  [Orabug: 18317153]  
- ext4: fix use-after-free in ext4_mb_new_blocks (Junho Ryu)  [Orabug: 18317152]  
- selinux: selinux_setprocattr()->ptrace_parent() needs rcu_read_lock() (Oleg Nesterov)  [Orabug: 18317151]  
- NFSv4 wait on recovery for async session errors (Andy Adamson)  [Orabug: 18317022]  
- dm table: fail dm_table_create on dm_round_up overflow (Mikulas Patocka)  [Orabug: 18317004]  
- dm delay: fix a possible deadlock due to shared workqueue (Mikulas Patocka)  [Orabug: 18317003]  
- dm snapshot: avoid snapshot space leak on crash (Mikulas Patocka)  [Orabug: 18317001]  
- dm bufio: initialize read-only module parameters (Mikulas Patocka)  [Orabug: 18316999]  
- Btrfs: fix access_ok() check in btrfs_ioctl_send() (Dan Carpenter)  [Orabug: 18316998]  
- selinux: handle TCP SYN-ACK packets correctly in selinux_ip_postroute() (Paul Moore)  [Orabug: 18316996]  
- selinux: handle TCP SYN-ACK packets correctly in selinux_ip_output() (Paul Moore)  [Orabug: 18316973]  
- xfs: underflow bug in xfs_attrlist_by_handle() (Dan Carpenter)  [Orabug: 18316969]  
- KVM: Improve create VCPU parameter (CVE-2013-4587) (Andy Honig)  [Orabug: 18316968]  {CVE-2013-4587} 
- lib/genalloc.c: fix overflow of ending address of memory chunk (Joonyoung Shim)  [Orabug: 18316967]  
- irq: Enable all irqs unconditionally in irq_resume (Laxman Dewangan)  [Orabug: 18316962]  
- SCSI: bfa: Fix crash when symb name set for offline vport (Vijaya Mohan Guvva)  [Orabug: 18316956]  
- crypto: ccm - Fix handling of zero plaintext when computing mac (Horia Geanta)  [Orabug: 18316955]  
- elevator: acquire q->sysfs_lock in elevator_change() (Tomoki Sekiyama)  [Orabug: 18316954]  
- elevator: Fix a race in elevator switching and md device initialization (Tomoki Sekiyama)  [Orabug: 18316952]  
- iommu/vt-d: Fixed interaction of VFIO_IOMMU_MAP_DMA with IOMMU address limits (Julian Stecklina)  [Orabug: 18316951]  
- video: kyro: fix incorrect sizes when copying to userspace (Sasha Levin)  [Orabug: 18316950]  
- mmc: block: fix a bug of error handling in MMC driver (KOBAYASHI Yoshitake)  [Orabug: 18316947]  
- ipv6: fix possible seqlock deadlock in ip6_finish_output2 (Hannes Frederic Sowa)  [Orabug: 18316946]  
- inet: fix possible seqlock deadlocks (Eric Dumazet)  [Orabug: 18316945]  
- net: 8139cp: fix a BUG_ON triggered by wrong bytes_compl (Yang Yingliang)  [Orabug: 18316943]  
- af_packet: block BH in prb_shutdown_retire_blk_timer() (Veaceslav Falico)  [Orabug: 18316941]  
- packet: fix use after free race in send path when dev is released (Daniel Borkmann)  [Orabug: 18316940]  
- bridge: flush br's address entry in fdb when remove the bridge dev (Ding Tianhong)  [Orabug: 18316938]  
- net: core: Always propagate flag changes to interfaces (Vlad Yasevich)  [Orabug: 18316926]  
- ipv4: fix race in concurrent ip_route_input_slow() (Alexei Starovoitov)  [Orabug: 18316919]  
- tcp: don't update snd_nxt, when a socket is switched from repair mode (Andrey Vagin)  [Orabug: 18316917]  
- xfrm: Release dst if this dst is improper for vti tunnel (fan.du)  [Orabug: 18316915]  
- ipv6: fix leaking uninitialized port number of offender sockaddr (Hannes Frederic Sowa)  [Orabug: 18316914]  
- net: clamp ->msg_namelen instead of returning an error (Dan Carpenter)  [Orabug: 18316912]  
- net: add BUG_ON if kernel advertises msg_namelen > sizeof(struct sockaddr_storage) (Hannes Frederic Sowa)  [Orabug: 18316910]  
- net: rework recvmsg handler msg_name and msg_namelen logic (Hannes Frederic Sowa)  [Orabug: 18316909]  {CVE-2013-7266} 
- ipv4: fix possible seqlock deadlock (Eric Dumazet)  [Orabug: 18316907]  
- connector: improved unaligned access error fix (Chris Metcalf)  [Orabug: 18316904]  
- isdnloop: use strlcpy() instead of strcpy() (Dan Carpenter)  [Orabug: 18316901]  
- net-tcp: fix panic in tcp_fastopen_cache_set() (Eric Dumazet)  [Orabug: 18316900]  
- tcp: tsq: restore minimal amount of queueing (Eric Dumazet)  [Orabug: 18316897]  
- net/mlx4_en: Fixed crash when port type is changed (Amir Vadai)  [Orabug: 18316894]  
- netfilter: nf_conntrack: use RCU safe kfree for conntrack extensions (Michal Kubecek)  [Orabug: 18316869]  
- cfg80211: fix scheduled scan pointer access (Johannes Berg)  [Orabug: 18316866]  
- tracing: Allow events to have NULL strings (Steven Rostedt (Red Hat))  [Orabug: 18316771]  
- cpuset: Fix memory allocator deadlock (Peter Zijlstra)  [Orabug: 18316769]  
- drm/ttm: Handle in-memory region copies (Jakob Bornecrantz)  [Orabug: 18316663]  
- selinux: correct locking in selinux_netlbl_socket_connect) (Paul Moore)  [Orabug: 18316649]  
- audit: fix info leak in AUDIT_GET requests (Mathias Krause)  [Orabug: 18316647]  
- dm mpath: fix race condition between multipath_dtr and pg_init_done (Shiva Krishna Merla)  [Orabug: 18316645]  
- ext4: avoid bh leak in retry path of ext4_expand_extra_isize_ea() (Theodore Ts'o)  [Orabug: 18316644]  
- loop: fix crash when using unassigned loop device (Mikulas Patocka)  [Orabug: 18316643]  
- loop: fix crash if blk_alloc_queue fails (Mikulas Patocka)  [Orabug: 18316642]  
- IB/ipath: Convert ipath_user_sdma_pin_pages() to use get_user_pages_fast() (Jan Kara)  [Orabug: 18316640]  
- iscsi-target: chap auth shouldn't match username with trailing garbage (Eric Seppanen)  [Orabug: 18316621]  
- iscsi-target: fix extract_param to handle buffer length corner case (Eric Seppanen)  [Orabug: 18316550]  
- ipc, msg: fix message length check for negative values (Mathias Krause)  [Orabug: 18316548]  
- vsprintf: check real user/group id for %pK (Ryan Mallon)  [Orabug: 18316546]  
- devpts: plug the memory leak in kill_sb (Ilija Hadzic)  [Orabug: 18316542]  
- usb: hub: Clear Port Reset Change during init/resume (Julius Werner)  [Orabug: 18316538]  
- block: fix a probe argument to blk_register_region (Mikulas Patocka)  [Orabug: 18316508]  
- block: fix race between request completion and timeout handling (Jeff Moyer)  [Orabug: 18316506]  
- rt2x00: check if device is still available on rt2x00mac_flush() (Stanislaw Gruszka)  [Orabug: 18316475]  
- aacraid: prevent invalid pointer dereference (Mahesh Rajashekhara)  [Orabug: 18316366]  
- libertas: potential oops in debugfs (Dan Carpenter)  [Orabug: 18316318]  
- usb: fail on usb_hub_create_port_device() errors (Krzysztof Mazur)  [Orabug: 18299092]  
- usb: fix cleanup after failure in hub_configure() (Krzysztof Mazur)  [Orabug: 18298829]  
- tracing: Fix potential out-of-bounds in trace_get_user() (Steven Rostedt)  [Orabug: 18297890]  
- aerdrv: Move cper_print_aer() call out of interrupt context (Lance Ortiz)  [Orabug: 18316330]  
- aerdrv: Cleanup log output for AER (Lance Ortiz)  [Orabug: 18316330]  
- ocfs2: dlm: fix lock migration crash (Junxiao Bi)  [Orabug: 18149842]  
- RDS: bind hash table size increase, add per-bucket rw lock (Bang Nguyen)  [Orabug: 18276846]  

* Fri Feb 21 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-28.el6uek] 
- [SCSI] Return ENODATA on medium error (Hannes Reinecke)  [Orabug: 17649168]  
- igb: init sriov_totalvfs to 7 (Greg Rose)  [Orabug: 17804898]  
- async: fix insert entry in ascending list (Vaughan Cao)  [Orabug: 17976960]  
- [SCSI] scsi_dh_alua: ALUA check sense should retry device internal reset unit attention (Stewart, Sean)  [Orabug: 18079298]  
- mtd: Allow removal of partitioning modules (Lubomir Rintel)  [Orabug: 18166681]  
- sparc64: Setup sysfs to mark LDOM sockets, cores and threads correctly. (chris hyser)  [Orabug: 17423360]  
- be2net: Fix be_vlan_add/rem_vid() routines (Somnath Kotur)  [Orabug: 18182801]  
- be2net: add dma_mapping_error() check for dma_map_page() (Ivan Vecera)  [Orabug: 18182801]  
- be2net: update driver version to 10.0.x (Sathya Perla)  [Orabug: 18182801]  
- be2net: cleanup wake-on-lan code (Suresh Reddy)  [Orabug: 18182801]  
- be2net: use GET_MAC_LIST cmd to query mac-address from a pmac-id (Suresh Reddy)  [Orabug: 18182801]  
- be2net: do not use frag index in the RX-compl entry (Suresh Reddy)  [Orabug: 18182801]  
- be2net: Remove "10Gbps" from driver description string (Suresh Reddy)  [Orabug: 18182801]  
- be2net: fix incorrect setting of cmd_privileges for VFs (Suresh Reddy)  [Orabug: 18182801]  
- be2net: ignore mac-addr set call for an already programmed mac-addr (Vasundhara Volam)  [Orabug: 18182801]  
- be2net: do not call be_set/get_fw_log_level() on Skyhawk-R (Vasundhara Volam)  [Orabug: 18182801]  
- be2net: Log the profile-id used by FW during driver initialization (Vasundhara Volam)  [Orabug: 18182801]  
- be2net: don't set "pport" field when querying "pvid" (Vasundhara Volam)  [Orabug: 18182801]  
- be2net: Use MCC_CREATE_EXT_V1 cmd for Skyhawk-R (Vasundhara Volam)  [Orabug: 18182801]  
- be2net: fix max_evt_qs calculation for BE3 in SR-IOV config (Suresh Reddy)  [Orabug: 18182801]  
- be2net: increase the timeout value for loopback-test FW cmd (Suresh Reddy)  [Orabug: 18182801]  
- be2net: disable RSS when number of RXQs is reduced to 1 via set-channels (Vasundhara Volam)  [Orabug: 18182801]  
- net: benet: slight optimization of addr compare (dingtianhong)  [Orabug: 18182801]  
- be2net: Free/delete pmacs (in be_clear()) only if they exist (Somnath Kotur)  [Orabug: 18182801]  
- be2net: Fix Lancer error recovery to distinguish FW download (Somnath Kotur)  [Orabug: 18182801]  
- be2net: Avoid programming permenant MAC by BE3-R VFs (Ajit Khaparde)  [Orabug: 18182801]  
- be2net: set coalesce-wm in CQ_CREATE_V2 cmd (Ajit Khaparde)  [Orabug: 18182801]  
- be2net: Disabling and enabling interrupts in suspend and resume (Ajit Khaparde)  [Orabug: 18182801]  
- be2net: Delete secondary unicast MAC addresses during be_close (Ajit Khaparde)  [Orabug: 18182801]  
- be2net: Fix unconditional enabling of Rx interface options (Ajit Khaparde)  [Orabug: 18182801]  
- net/benet: Make lancer_wait_ready() static (Gavin Shan)  [Orabug: 18182801]  
- net/benet: Remove interface type (Gavin Shan)  [Orabug: 18182801]  
- qla2xxx: Correct the port number assignment for ISP82XX. (Saurav Kashyap)  [Orabug: 18280331]  
- fnic: fnic driver crashes on FLOGI Rejection (Simha)  [Orabug: 18280309]  
- qla4xxx: Initialize hardware queue for ISP40XX (Dan Duval)  [Orabug: 18277969]  
- qla4xxx: Fix memory leak in func qla4_84xx_config_acb() (Dan Duval)  [Orabug: 18280232]  
- inet: fix addr_len/msg->msg_namelen assignment in recv_error and rxpmtu functions (Hannes Frederic Sowa)  [Orabug: 18247287]  {CVE-2013-7263} {CVE-2013-7265} 
- inet: prevent leakage of uninitialized memory to user in recv syscalls (Hannes Frederic Sowa)  [Orabug: 18238377]  {CVE-2013-7263} {CVE-2013-7265} 
- exec/ptrace: fix get_dumpable() incorrect tests (Kees Cook)  [Orabug: 18238348]  {CVE-2013-2929} 

* Thu Feb 13 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-27.el6uek] 
- sxge, hxge: don't build on sparc and add depend on x86 (Jerry Snitselaar)  [18200531]  
- sxge: add support for ovm auto-migration for 15 VMs (Joyce Yu)  [18154721]  
- mpt3sas: Rework the MSI-X code to work on systems with many processors (Martin K. Petersen)  [18182490]  
- mpt2sas: Rework the MSI-X code to work on systems with many processors (Martin K. Petersen)  [18182490]  
- ixgbe: Look up MAC address on SPARC systems (Martin K. Petersen)  [18182472]  
- xfs: ensure proper alignment of i/o buffer (Dave Kleikamp)  [18182411]  
- loop: inherit queue limits from underlying device (Dave Kleikamp)  [17449357]  
- xfs: allow logical-sector sized O_DIRECT (Eric Sandeen)  [17449357]  
- xfs: rename xfs_buftarg structure members (Eric Sandeen)  [17449357]  
- xfs: clean up xfs_buftarg (Eric Sandeen)  [17449357]  
- rcu: Reject memory-order-induced stall-warning false positives (Paul E. McKenney)  [18158540]  
- xen-blkback: fix shutdown race (Roger Pau Monne)  [18141271]  
- xen-blkback: fix memory leaks (Roger Pau Monne)  [18141271]  
- xen-blkback: fix memory leak when persistent grants are used (Matt Rushton)  [18141271]  
- srp: disable fmr-pool cache to fix cpu lock-up. (Shamir Rabinovitch)  [18158334]  

* Mon Jan 27 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-26.el6uek] 
- spec: Don't remove crashkernel=auto setting (Jerry Snitselaar) [Orabug: 18137993]  

* Sat Jan 25 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-25.el6uek] 
- ocfs2: fix i_mutex deadlock between aio_write and sync_file (Darrick J. Wong) [Orabug: 18068931]  
- Revert "x86, mm: Revert back good_end setting for 64bit" (Jerry Snitselaar) [Orabug: 18128986]  

* Thu Jan 23 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-24.el6uek] 
- tg3: remove spin_lock_bh() in tg3_get_stats64() to fix dead lock (Ethan Zhao) [Orabug: 18070676]  
- net/core: use GFP_NOWAIT allocation flag in rtmsg_ifinfo() to fix lockup warning (Ethan Zhao) [Orabug: 18070676]  
- mptsas: do not call __mptsas_probe in kthread (Jerry Snitselaar) [Orabug: 18120337]  
- config: enable CONFIG_KEXEC_AUTO_RESERVE (Jerry Snitselaar) [Orabug: 17616874]  
- Btrfs: allow compressed extents to be merged during defragment (Liu Bo) [Orabug: 18098511]  
- Btrfs: reset ret in record_one_backref (Josef Bacik) [Orabug: 18098511]  
- Btrfs: fix a crash when running balance and defrag concurrently (Liu Bo) [Orabug: 18098511]  
- Btrfs: fix a bug of snapshot-aware defrag to make it work on partial extents (Liu Bo) [Orabug: 18098511]  
- Btrfs: get better concurrency for snapshot-aware defrag work (Liu Bo) [Orabug: 18098511]  
- Btrfs: snapshot-aware defrag (Liu Bo) [Orabug: 18098511]  
- btrfs: add cancellation points to defrag (David Sterba) [Orabug: 18098511]  
- qla4xxx: Updated driver version to 5.04.00.02.06.02-uek3 (Vikas Chaudhary) [Orabug: 18103905]  
- qla4xxx: Fix memory leak in qla4xxx_destroy_ddb (Vikas Chaudhary) [Orabug: 18103905]  
- x86: add support for crashkernel=auto (Brian Maly)   
- x86, mm: Revert back good_end setting for 64bit (Yinghai Lu) [Orabug: 17648536]  

* Thu Jan 16 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-23.el6uek] 
- [SCSI] storvsc: avoid usage of WRITE_SAME (Olaf Hering) [Orabug: 18037923]  
- Fix balloon driver to work properly with balloon_hugepages but no superpage flag (Dave McCracken)   
- config: disable BUILD_DOCSRC (Jerry Snitselaar) [Orabug: 17504426]  
- ext4: Fix non-O_SYNC AIO DIO unwritten extent conversion after dio finishes (Darrick J. Wong) [Orabug: 18069802]  
- memcg: don't initialize kmem-cache destroying work for root caches (Andrey Vagin) [Orabug: 17791895]  
- ocfs2: ocfs2 punch hole retrun EINVAL if the length argument in ioctl is negative (Tariq Saeed) [Orabug: 14789508]  
- writeback: fix data corruption on NFS (Jan Kara) [Orabug: 16677609]  
- Btrfs: handle a bogus chunk tree nicely (Josef Bacik) [Orabug: 17334825]  
- Drivers: hv: Execute shutdown in a thread context (K. Y. Srinivasan) [Orabug: 18053264]  
- Increase scsi_mod parameter max_report_luns to 1023. (Zhigang Wang) [Orabug: 17445498]  
- NFSv4.1 Fix gdia_maxcount calculation to fit in ca_maxresponsesize (Andy Adamson) [Orabug: 17419831]  
- config: disable fragile PSTORE options (Ethan Zhao) [Orabug: 17928723]  
- ocfs2/o2net: o2net_listen_data_ready should do nothing if socket state is not TCP_LISTEN (Tariq Saeed) [Orabug: 17330860]  
- qla4xxx: Updated driver version to 5.04.00.01.06.02-uek3 (Tej Parkash) [Orabug: 18050491]  
- qla4xxx: Fix sparse warnings (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Handle IPv6 AEN notifications (Nilesh Javali) [Orabug: 18050491]  
- qla4xxx: Update print statements in func qla4xxx_do_dpc() (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Update print statements in func qla4xxx_eh_abort() (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Update print statements in qla4xxx_mailbox_command() (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Updated print for device login, logout path (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Remove unused code from qla4xxx_set_ifcb() (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Fix failure of mbox 0x31 (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Reduce rom-lock contention during reset recovery. (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Fix pending IO completion in reset path before initiating chip reset (Tej Parkash) [Orabug: 18050491]  
- qla4xxx: Fix processing response queue during probe (Tej Parkash) [Orabug: 18050491]  
- qla4xxx: Fix failure of IDC Time Extend mailbox command (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Clear DDB index map upon connection close failure (Nilesh Javali) [Orabug: 18050491]  
- qla4xxx: Return correct error status from func qla4xxx_request_irqs() (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Fixed AER reset sequence for ISP83xx/ISP84xx (Tej Parkash) [Orabug: 18050491]  
- qla4xxx: Correctly handle msleep_interruptible (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Rename ACB_STATE macros with IP_ADDRSTATE macros (Nilesh Javali) [Orabug: 18050491]  
- qla4xxx: Improve loopback failure messages (Nilesh Javali) [Orabug: 18050491]  
- qla4xxx: Use IDC_CTRL bit1 directly instead of AF_83XX_NO_FWDUMP flag. (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Fix comments in code (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: Print WARN_ONCE() if iSCSI function presence bit removed (Vikas Chaudhary) [Orabug: 18050491]  
- qla4xxx: ISP8xxx: Correct retry of adapter initialization (Nilesh Javali) [Orabug: 18050491]  
- qla4xxx: Recreate chap data list during get chap operation (Adheer Chandravanshi) [Orabug: 18050491]  
- qla4xxx: Add support for ISCSI_PARAM_LOCAL_IPADDR sysfs attr (Adheer Chandravanshi) [Orabug: 18050491]  
- libiscsi: Add local_ipaddr parameter in iscsi_conn struct (Adheer Chandravanshi) [Orabug: 18050491]  
- IB/iser: Add Discovery support (Or Gerlitz) [Orabug: 18050491]  
- scsi_transport_iscsi: Export ISCSI_PARAM_LOCAL_IPADDR attr for iscsi_connection (Adheer Chandravanshi) [Orabug: 18050491]  
- qla4xxx: Add host statistics support (Lalit Chandivade) [Orabug: 18050491]  
- scsi_transport_iscsi: Add host statistics support (Lalit Chandivade) [Orabug: 18050491]  
- qla4xxx: Added support for Diagnostics MBOX command (Vikas Chaudhary) [Orabug: 18050491]  
- ocfs2: update inode size after zeroed the hole (Junxiao Bi) [Orabug: 18043432]  

* Tue Jan 7 2014 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-22.el6uek] 
- Revert "sparc64: Fix __copy_{to,from}_user_inatomic defines." (Dave Kleikamp) [Orabug: 18038851]  
- sparc64: prevent solaris control domain warnings about Domain Service handles (chris hyser) [Orabug: 18038829]  
- libfcoe: Make fcoe_sysfs optional / fix fnic NULL exception (ethan.zhao) [Orabug: 17960129]  
- scsi/fnic: update to version 1.6.0.8 from 1.5.0.45 (ethan.zhao) [Orabug: 17960129]  
- sctp: sctp_close: fix release of bindings for deferred call_rcu's (Daniel Borkmann) [Orabug: 17886746]  
- dtrace: vtimestamp implementation (Kris Van Hees) [Orabug: 17741477]  
- dtrace: implement SDT in kernel modules (Kris Van Hees) [Orabug: 17851716]  
- qla4xxx: Driver not able to collect minidump in ISP84xx (Tej Parkash) [Orabug: 17960365]  
- Modify UEFI anti-bricking code (Matthew Garrett) [Orabug: 17792954]  
- ocfs2: make 'buffered' as the default coherency option (Wengang Wang) [Orabug: 17988729]  
- Fixing kABI breakages in struct sock (Thomas Tanaka) [Orabug: 17901058]  
- tcp: TSQ can use a dynamic limit (Eric Dumazet) [Orabug: 17901058]  
- tcp: TSO packets automatic sizing (Eric Dumazet) [Orabug: 17901058]  
- bonding: fix two race conditions in bond_store_updelay/downdelay (Nikolay Aleksandrov) [Orabug: 17931850]  
- Update lpfc version for 8.3.7.34.4p driver release (Gairy Grannum)   
- Fixed unassigned variable in ELS timeout message (James Smart)   
- Fixed incorrect allocation of iDiags directories/files in debugfs (James Smart)   
- Fix Crash in lpfc_els_timeout_handler (James Smart)   
- Fix kernel panics from corrupted ndlp list. (James Smart)   
- Fix Crash in lpfc_els_timeout_handler (James Smart)   
- Fix Crash in lpfc_els_timeout_handler (James Smart)   
- [SCSI] lpfc: Fix typo on NULL assignment (Felipe Pena)   
- Fixed stopped FCF discovery on failed FCF record read. (James Smart)   
- Fixed IO hang when in msi mode. (James Smart)   
- tg3: update to broadcom version v3.134f (Jerry Snitselaar) [Orabug: 18037870]  
- bnx2x: update to broadcom version 1.78.80 (Jerry Snitselaar) [Orabug: 18037860]  
- PCI: Use pci_wait_for_pending_transaction() instead of for loop (Casey Leedom) [Orabug: 18037860]  
- PCI: Add pci_wait_for_pending_transaction() (Casey Leedom) [Orabug: 18037860]  
- bnx2i: update to broadcom version 2.7.8.2b (Jerry Snitselaar) [Orabug: 18037845]  
- bnx2fc: update to broadcom verison 2.4.1e (Jerry Snitselaar) [Orabug: 18037838]  
- cnic: update to broadcom version 2.5.18c (Jerry Snitselaar) [Orabug: ]  
- bnx2: update to broadcom version 2.2.4g (Jerry Snitselaar) [Orabug: ]  
- qla2xxx: update from mainline 8.05.00.03.39.0-k to qlogic version 8.06.00.14.39.0-k (Guangyu Sun) [Orabug: 17952066]  

* Fri Dec 20 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-21.el6uek] 
- be2iscsi: Bump driver version (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix SGL posting for unaligned ICD values (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix AER handling in driver (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Invalidate WRB in Abort/Reset Path (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix Insufficient Buffer Error returned in MBX Completion (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix log level for protocol specific logs (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix MSIx creation for SKH-R adapter (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Display Port Identifier for each iSCSI function (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Dispaly CID available for connection offload (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix chute cleanup during drivers unload. (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix connection offload to support Dual Chute. (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix CID allocation/freeing to support Dual chute mode (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix WRB_Q posting to support Dual Chute mode (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix SGL Initilization and posting Pages for Dual Chute (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix Template HDR support for Dual Chute mode (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix changes in ASYNC Path for SKH-R adapter (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Config parameters update for Dual Chute Support (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix soft lock up issue during UE or if FW taking time to respond (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix locking mechanism in Unsol Path (Brian Maly) [Orabug: 17799766]  
- Subject: [PATCH 04/23] be2iscsi: Fix negotiated parameters upload to FW (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix repeated issue of MAC ADDR get IOCTL (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix the MCCQ count leakage (Brian Maly) [Orabug: 17799766]  
- be2iscsi: Fix Template HDR IOCTL (Brian Maly) [Orabug: 17799766]  
- cifs: enable SMB2 support (Jerry Snitselaar) [Orabug: 17486287]  
- [SCSI] Derive the FLUSH_TIMEOUT from the basic I/O timeout (James Bottomley) [Orabug: 17853273]  
- hyperv: Fix RNDIS send_completion code path (Haiyang Zhang) [Orabug: 17784576]  
- [SCSI] fix kabi break (Jerry Snitselaar) [Orabug: 17940334]  
- [SCSI] Disable WRITE SAME for RAID and virtual host adapter drivers (Martin K. Petersen) [Orabug: 17940334]  
- qlcnic: update to qlogic version 5.3.52.3 (Sucheta Chakraborty) [Orabug: 17937392]  
- netxen: update to qlogic version 4.0.82 (Sucheta Chakraborty) [Orabug: 17937454]  
- be2net: Warn users of possible broken functionality on BE2 cards with very old FW versions with latest driver (Somnath Kotur) [Orabug: 17937784]  
- net: be2net: remove unnecessary pci_set_drvdata() (Jingoo Han) [Orabug: 17937784]  
- be2net: Rework PCIe error report log messaging (Ajit Khaparde) [Orabug: 17937784]  
- be2net: change the driver version number to 4.9.224.0 (Ajit Khaparde) [Orabug: 17937784]  
- be2net: Display RoCE specific counters in ethtool -S (Ajit Khaparde) [Orabug: 17937784]  
- be2net: Call version 2 of GET_STATS ioctl for Skyhawk-R (Ajit Khaparde) [Orabug: 17937784]  
- be2net: add a counter for pkts dropped in xmit path (Sathya Perla) [Orabug: 17937784]  
- be2net: fix adaptive interrupt coalescing (Sathya Perla) [Orabug: 17937784]  
- be2net: call ENABLE_VF cmd for Skyhawk-R too (Vasundhara Volam) [Orabug: 17937784]  
- be2net: Create single TXQ on BE3-R 1G ports (Vasundhara Volam) [Orabug: 17937784]  
- be2net: Call be_vf_setup() even when VFs are enbaled from previous load (Vasundhara Volam) [Orabug: 17937784]  
- be2net: Fix to display the VLAN priority for a VF (Ajit Khaparde) [Orabug: 17937784]  
- be2net: Fix to configure VLAN priority for a VF interface. (Ajit Khaparde) [Orabug: 17937784]  
- be2net: Fix to allow VLAN configuration on VF interfaces. (Ajit Khaparde) [Orabug: 17937784]  
- be2net: Fix number of VLANs supported in UMC mode for BE3-R. (Ajit Khaparde) [Orabug: 17937784]  
- be2net: Fix VLAN promiscuous mode programming (Ajit Khaparde) [Orabug: 17937784]  
- be2net: Fix the size of be_nic_res_desc structure (Ajit Khaparde) [Orabug: 17937784]  
- be2net: Fix to prevent Tx stall on SH-R when packet size < 32 (Ajit Khaparde) [Orabug: 17937784]  
- emulex: Remove extern from function prototypes (Joe Perches) [Orabug: 17937784]  
- be2net: missing variable initialization (Antonio Alecrim Jr) [Orabug: 17937784]  
- be2net: set and query VEB/VEPA mode of the PF interface (Ajit Khaparde) [Orabug: 17937784]  
- drivers:net: Convert dma_alloc_coherent(...__GFP_ZERO) to dma_zalloc_coherent (Joe Perches) [Orabug: 17937784]  
- be2net: implement ethtool set/get_channel hooks (Sathya Perla) [Orabug: 17937784]  
- be2net: refactor be_setup() to consolidate queue creation routines (Sathya Perla) [Orabug: 17937784]  
- be2net: Fix be_cmd_if_create() to use MBOX if MCCQ is not created (Sathya Perla) [Orabug: 17937784]  
- be2net: refactor be_get_resources() code (Sathya Perla) [Orabug: 17937784]  
- be2net: Fixup profile management routines (Vasundhara Volam) [Orabug: 17937784]  
- be2net: use EQ_CREATEv2 for SH-R (Sathya Perla) [Orabug: 17937784]  
- be2net: Check for POST state in suspend-resume sequence (Sarveshwar Bandi) [Orabug: 17937784]  
- be2net: fix disabling TX in be_close() (Sathya Perla) [Orabug: 17937784]  
- be2net: Clear any capability flags that driver is not interested in. (Sarveshwar Bandi) [Orabug: 17937784]  
- be2net: Initialize "status" in be_cmd_get_die_temperature() (Vasundhara Volam) [Orabug: 17937784]  
- be2net: fixup log msgs for async events (Vasundhara Volam) [Orabug: 17937784]  
- be2net: Missing changes from "fix a Tx stall bug caused by a specific ipv6 packet" (Ravikumar Nelavelli) [Orabug: 17937784]  
- be2net: Fix displaying supported speeds for BE2 (Vasundhara Volam) [Orabug: 17937784]  
- be2net: don't limit max MAC and VLAN counts (Vasundhara Volam) [Orabug: 17937784]  
- be2net: Do not call get_die_temperature cmd for VF (Vasundhara Volam) [Orabug: 17937784]  
- be2net: Adding more speeds reported by get_settings (Vasundhara Volam) [Orabug: 17937784]  
- be2net: Staticize local functions (Jingoo Han) [Orabug: 17937784]  
- be2net: don't use dev_err when AER enabling fails (Ivan Vecera) [Orabug: 17937784]  
- be2net: delete primary MAC address while unloading (Sathya Perla) [Orabug: 17937784]  
- be2net: use SET/GET_MAC_LIST for SH-R (Sathya Perla) [Orabug: 17937784]  
- be2net: refactor MAC-addr setup code (Sathya Perla) [Orabug: 17937784]  
- be2net: fix pmac_id for BE3 VFs (Sathya Perla) [Orabug: 17937784]  
- be2net: allow VFs to program MAC and VLAN filters (Sathya Perla) [Orabug: 17937784]  
- be2net: fix MAC address modification for VF (Sathya Perla) [Orabug: 17937784]  
- [SCSI] sd: Reduce buffer size for vpd request (Bernd Schubert) [Orabug: 17940334]  
- [SCSI] sd: fix array cache flushing bug causing performance problems (James Bottomley) [Orabug: 17940334]  
- [SCSI] Fix race between starved list and device removal (James Bottomley) [Orabug: 17940334]  
- [SCSI] enable destruction of blocked devices which fail LUN scanning (Bart Van Assche) [Orabug: 17940334]  
- ixgbevf: upgrade from 2.8.7 to 2.11.3 (ethan.zhao) [Orabug: 17718254]  
- igb: set default RSS to 0 for performance tuning (ethan.zhao) [Orabug: 175934190]  
- igb: upgrade from 4.3.0 to 5.0.6 (ethan.zhao) [Orabug: 17711645]  
- e1000e: Avoid kernel crash during shutdown (Li Zhang) [Orabug: 17854071]  
- e1000e: upgrade from 2.4.14 to 2.5.4 (ethan.zhao) [Orabug: 17718216]  
- Btrfs: skip subvol entries when checking if we've created a dir already (Josef Bacik) [Orabug: 17661845]  
- Btrfs: fix incorrect inode acl reset (Filipe David Borba Manana) [Orabug: 17669341]  
- Btrfs: allow running defrag in parallel to administrative tasks (Stefan Behrens) [Orabug: 17886022]  
- zram: allow request end to coincide with disksize (Sergey Senozhatsky) [Orabug: 17879183]  
- configfs: fix race between dentry put and lookup (Junxiao Bi) [Orabug: 17931342]  
- xfs: fix sgid inheritance for subdirectories inheriting default acls [V3] (Carlos Maiolino) [Orabug: 17354234]  
- Revert "sg: use rwsem to solve race during exclusive open" (Jerry Snitselaar) [Orabug: 17579131]  
- Revert "sg: no need sg_open_exclusive_lock" (Jerry Snitselaar) [Orabug: 17579131]  
- Revert "sg: checking sdp->detached isn't protected when open" (Jerry Snitselaar) [Orabug: 17579131]  
- Revert "sg: push file descriptor list locking down to per-device locking" (Jerry Snitselaar) [Orabug: 17579131]  
- NVMe: Merge issue on character device bring-up (Keith Busch) [Orabug: 17940296]  
- NVMe: Handle ioremap failure (Keith Busch) [Orabug: 17940296]  
- NVMe: Add pci suspend/resume driver callbacks (Keith Busch) [Orabug: 17940296]  
- NVMe: Use normal shutdown (Keith Busch) [Orabug: 17940296]  
- NVMe: Separate controller init from disk discovery (Keith Busch) [Orabug: 17940296]  
- NVMe: Separate queue alloc/free from create/delete (Keith Busch) [Orabug: 17940296]  
- NVMe: Group pci related actions in functions (Keith Busch) [Orabug: 17940296]  
- NVMe: Disk stats for read/write commands only (Keith Busch) [Orabug: 17940296]  
- NVMe: Bring up cdev on set feature failure (Keith Busch) [Orabug: 17940296]  
- NVMe: Fix checkpatch issues (Keith Busch) [Orabug: 17940296]  
- NVMe: Namespace IDs are unsigned (Matthew Wilcox) [Orabug: 17940296]  
- NVMe: Call nvme_process_cq from submission path (Matthew Wilcox) [Orabug: 17940296]  
- NVMe: Remove "process_cq did something" message (Matthew Wilcox) [Orabug: 17940296]  
- NVMe: Return correct value from interrupt handler (Matthew Wilcox) [Orabug: 17940296]  
- NVMe: Disk IO statistics (Keith Busch) [Orabug: 17940296]  
- NVMe: Restructure MSI / MSI-X setup (Matthew Wilcox) [Orabug: 17940296]  
- NVMe: Use kzalloc instead of kmalloc+memset (Tushar Behera) [Orabug: 17940296]  
- [SCSI] megaraid_sas: Fix synchronization problem between sysPD IO path and AEN path (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: fixes for few endianess issues (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: addded support for big endian architecture (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Version and Changelog update (Adam Radford) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Add High Availability clustering support using shared Logical Disks (Adam Radford) [Orabug: 17940378]  
- scsi/megaraid fixed several typos in comments (Matthias Schid) [Orabug: 17940378]  
- [SCSI] megaraid_sas: megaraid_sas driver init fails in kdump kernel (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: fix a bug for 64 bit arches (Dan Carpenter) [Orabug: 17940378]  
- [SCSI] megaraid_sas: fix memory leak if SGL has zero length entries (Bjørn Mork) [Orabug: 17940378]  
- [SCSI] megaraid: minor cut and paste error fixed. (James Georgas) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Changelog and driver version update (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Add support to differentiate between iMR vs MR Firmware (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Add support for Uneven Span PRL11 (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Add support for Extended MSI-x vectors for 12Gb/s controller (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Set IoFlags to enable Fast Path for JBODs for 12 Gb/s controllers (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Add support to display Customer branding details in syslog (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Add support for MegaRAID Fury (device ID-0x005f) 12Gb/s controllers (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Set IO request timeout value provided by OS timeout for Tape devices (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Free event detail memory without device ID check (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Update balance count in driver to be in sync of firmware (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Fix the interrupt mask for Gen2 controller (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Return DID_ERROR for SCSI IO, when controller is in critical h/w error (Sumit.Saxena@lsi.com) [Orabug: 17940378]  
- [SCSI] megaraid_sas: release lock on error path (Dan Carpenter) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Use correct #define for MSI-X capability (Bjorn Helgaas) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Version and Changelog update (Adam Radford) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Dont load DevHandle unless FastPath enabled (Adam Radford) [Orabug: 17940378]  
- [SCSI] megaraid_sas: Add 4k FastPath DIF support (Adam Radford) [Orabug: 17940378]  
- megaraid: Revert driver update (Martin K. Petersen) [Orabug: 17940378]  
- cciss: fix broken mutex usage in ioctl (Stephen M. Cameron) [Orabug: 17763620]  
- cciss: add cciss_mutex (Arnd Bergmann) [Orabug: 17763620]  
- cciss: remove cciss_kernel_compat.h (Vaughan Cao) [Orabug: 17763620]  
- block: add and use scsi_blk_cmd_ioctl (Paolo Bonzini) [Orabug: 17763620]  
- cciss: add small delay when using PCI Power Management to reset for kump (Mike Miller) [Orabug: 17763620]  
- cciss: set max scatter gather entries to 32 on P600 (Mike Miller) [Orabug: 17763620]  
- cciss: bug fix to prevent cciss from loading in kdump crash kernel (Mike Miller) [Orabug: 17763620]  
- cciss: change lowercase to uppercase for P700M def in products (Vaughan Cao) [Orabug: 17763620]  
- cciss: remove __dev* markings (Vaughan Cao) [Orabug: 17763620]  
- cciss: upgrade to 4.6.28 (Vaughan Cao) [Orabug: 17763620]  
- Revert "SPEC: Fix xen multiboot support" (Jerry Snitselaar) [Orabug: 17792303]  
- kbuild: Set objects.builtin dependency to bzImage for CONFIG_CTF (Jerry Snitselaar) [Orabug: 17510915]  
- ubifs: wait for page writeback to provide stable pages (Jan Kara) [Orabug: 17939878]  
- ocfs2: wait for page writeback to provide stable pages (Jan Kara) [Orabug: 17939878]  
- block: optionally snapshot page contents to provide stable pages during write (Darrick J. Wong) [Orabug: 17939878]  
- mm: only enforce stable page writes if the backing device requires it (Darrick J. Wong) [Orabug: 17939878]  
- bdi: allow block devices to say that they require stable page writes (Darrick J. Wong) [Orabug: 17939878]  
- netfilter: enable log target (Jerry Snitselaar) [Orabug: 17885348]  
- qla4xxx: Updated driver version to 5.04.00.00.06.02-uek3 (Tej Parkash) [Orabug: 17960427]  
- qla4xxx: overflow in qla4xxx_set_chap_entry() (Dan Carpenter) [Orabug: 17960427]  
- qla4xxx: Add support for additional network parameters settings (Harish Zunjarrao) [Orabug: 17960427]  
- iscsi_transport: Additional parameters for network settings (Harish Zunjarrao) [Orabug: 17960427]  
- iscsi_transport: Remove net param enum values (Harish Zunjarrao) [Orabug: 17960427]  
- qla4xxx: Add support to get CHAP details for flash target session (Adheer Chandravanshi) [Orabug: 17960427]  
- qla4xxx: Add support to set CHAP entries (Adheer Chandravanshi) [Orabug: 17960427]  
- scsi_transport_iscsi: Add support to set CHAP entries (Adheer Chandravanshi) [Orabug: 17960427]  
- qla4xxx: Use offset based on adapter type to set CHAP entry in flash (Adheer Chandravanshi) [Orabug: 17960427]  
- qla4xxx: Populate local CHAP credentials for flash target sessions (Adheer Chandravanshi) [Orabug: 17960427]  
- qla4xxx: Support setting of local CHAP index for flash target entry (Adheer Chandravanshi) [Orabug: 17960427]  
- qla4xxx: Correct the check for local CHAP entry type (Adheer Chandravanshi) [Orabug: 17960427]  
- qla4xxx: correctly update session discovery_parent_idx. (Manish Rangankar) [Orabug: 17960427]  
- qla4xxx: Return error if minidump data collection fails (Vikas Chaudhary) [Orabug: 17960427]  
- qla4xxx: Fix the minidump data collection check in for loop (Santosh Vernekar) [Orabug: 17960427]  
- qla4xxx: Add pex-dma support for capturing minidump (Santosh Vernekar) [Orabug: 17960427]  
- qla4xxx: Update Copyright header (Vikas Chaudhary) [Orabug: 17960427]  
- qla4xxx: Implementation of ACB configuration during Loopback for ISP8042 (Nilesh Javali) [Orabug: 17960427]  
- qla4xxx: Added support for ISP8042 (Vikas Chaudhary) [Orabug: 17960427]  
- ip_output: do skb ufo init for peeked non ufo skb as well (Jiri Pirko) [Orabug: 17951078] {CVE-2013-4470} 
- ip6_output: do skb ufo init for peeked non ufo skb as well (Jiri Pirko) [Orabug: 17951080] {CVE-2013-4470} 
- KVM: x86: fix guest-initiated crash with x2apic (CVE-2013-6376) (Gleb Natapov) [Orabug: 17951067] {CVE-2013-6376} 
- KVM: x86: Convert vapic synchronization to _cached functions (CVE-2013-6368) (Andy Honig) [Orabug: 17951071] {CVE-2013-6368} 
- KVM: x86: Fix potential divide by 0 in lapic (CVE-2013-6367) (Andy Honig) [Orabug: 17951073] {CVE-2013-6367} 
- SUNRPC: don't map EKEYEXPIRED to EACCES in call_refreshresult (Andy Adamson) [Orabug: 17931738]  
- NFSv4: Fix state reference counting in _nfs4_opendata_reclaim_to_nfs4_state (Trond Myklebust) [Orabug: 17931293]  
- NFSv4: don't reprocess cached open CLAIM_PREVIOUS (Weston Andros Adamson) [Orabug: 17931292]  
- NFSv4: don't fail on missing fattr in open recover (Weston Andros Adamson) [Orabug: 17931290]  
- NFSv4: fix NULL dereference in open recover (Weston Andros Adamson) [Orabug: 17931281]  
- NFSv4: Fix a use-after-free situation in _nfs4_proc_getlk() (Trond Myklebust) [Orabug: 17931272]  
- xen/blkback: fix reference counting (Vegard Nossum) [Orabug: 17931209]  
- blk-core: Fix memory corruption if blkcg_init_queue fails (Mikulas Patocka) [Orabug: 17931205]  
- xfs: add capability check to free eofblocks ioctl (Dwight Engen) [Orabug: 17931096]  
- compiler-gcc.h: Add gcc-recommended GCC_VERSION macro (Daniel Santos) [Orabug: 17882877]  
- fix kabi breakage (Darrick J. Wong) [Orabug: 14548775]  
- direct-io: Handle O_(D)SYNC AIO (Darrick J. Wong) [Orabug: 14548775]  
- direct-io: Implement generic deferred AIO completions for ext4 (Darrick J. Wong) [Orabug: 14548775]  
- direct-io: Implement generic deferred AIO completions (Darrick J. Wong) [Orabug: 14548775]  

* Mon Nov 25 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-20.el6uek] 
- KVM: Fix iommu map/unmap to handle memory slot moves (Alex Williamson) [Orabug: 17841960] {CVE-2013-4592} 
- ansi_cprng: Fix off by one error in non-block size request (Jerry Snitselaar) [Orabug: 17837997] {CVE-2013-4345} 
- ixgbe: update from 3.15.1 to 3.18.7 (ethan.zhao) [Orabug: 17718073]  
- x86, mtrr: Fix original mtrr range get for mtrr_cleanup (Yinghai Lu) [Orabug: 17812759]  
- SUNRPC: Fix a data corruption issue when retransmitting RPC calls (Trond Myklebust) [Orabug: 17821884]  
- [SCSI] hpsa: remove unneeded variable (Tomas Henzl) [Orabug: 17719404]  
- [SCSI] hpsa: housekeeping patch for device_id and product arrays (Mike Miller) [Orabug: 17719404]  
- hpsa: add HP Smart Array Gen8 name P822se (Vaughan Cao) [Orabug: 17719404]  
- [SCSI] hpsa: add HP Smart Array Gen9 PCI ID's (Mike Miller) [Orabug: 17719404]  
- hpsa: Convert retrun typos to return (Joe Perches) [Orabug: 17719404]  
- [SCSI] hpsa: fix warning with smp_processor_id() in preemptible (John Kacur) [Orabug: 17719404]  
- [SCSI] hpsa: fix a race in cmd_free/scsi_done (Tomas Henzl) [Orabug: 17719404]  
- hpsa: fix compilation error of __dev* markings (Vaughan Cao) [Orabug: 17719404]  
- hpsa: upgrade to 3.4.2-5 (Vaughan Cao) [Orabug: 17719404]  

* Fri Nov 15 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-19.el6uek] 
- net: fix cipso packet validation when !NETLABEL (Seif Mazareeb) [Orabug: 17806518]  
- can: dev: fix nlmsg size calculation in can_get_size() (Marc Kleine-Budde) [Orabug: 17806517]  
- ipv4: fix ineffective source address selection (Jiri Benc) [Orabug: 17806516]  
- ecryptfs: Fix memory leakage in keystore.c (Geyslan G. Bem) [Orabug: 17806513]  
- connector: use nlmsg_len() to check message length (Mathias Krause) [Orabug: 17806512]  
- net: vlan: fix nlmsg size calculation in vlan_get_size() (Marc Kleine-Budde) [Orabug: 17806510]  
- SPEC: Fix xen multiboot support (Zhigang Wang) [Orabug: 17792303]  
- config: enable CONFIG_PANIC_ON_OOPS on sparc (Jerry Snitselaar) [Orabug: 17762461]  
- NFSv4.1: Don't lose locks when a server reboots during delegation return (Trond Myklebust) [Orabug: 17419831]  
- NFSv4.1 end back channel session draining (Andy Adamson) [Orabug: 17419831]  
- NFSv4.1 Fix a pNFS session draining deadlock (Andy Adamson) [Orabug: 17419831]  
- NFSv4.1: Ensure that we free the lock stateid on the server (Trond Myklebust) [Orabug: 17419831]  
- NFSv4: Convert nfs41_free_stateid to use an asynchronous RPC call (Trond Myklebust) [Orabug: 17419831]  
- NFSv4: Don't recheck permissions on open in case of recovery cached open (Trond Myklebust) [Orabug: 17419831]  
- NFSv4: Record the OPEN create mode used in the nfs4_opendata structure (Trond Myklebust) [Orabug: 17419831]  
- NFSv4: Fix another open/open_recovery deadlock (Trond Myklebust) [Orabug: 17419831]  
- NLM: Ensure that we resend all pending blocking locks after a reclaim (Trond Myklebust) [Orabug: 17419831]  
- NFSv4: Fix a reboot recovery race when opening a file (Trond Myklebust) [Orabug: 17419831]  
- NFSv4: Ensure delegation recall and byte range lock removal don't conflict (Trond Myklebust) [Orabug: 17419831]  
- NFSv4: Fix up the return values of nfs4_open_delegation_recall (Trond Myklebust) [Orabug: 17419831]  
- NFSv4.1: Don't lose locks when a server reboots during delegation return (Trond Myklebust) [Orabug: 17419831]  
- NFSv4.1: Prevent deadlocks between state recovery and file locking (Trond Myklebust) [Orabug: 17419831]  
- NFSv4: Allow the state manager to mark an open_owner as being recovered (Trond Myklebust) [Orabug: 17419831]  
- drivers/base/core.c: Always output device renaming messages. (ethan.zhao) [Orabug: 17477783]  
- ixgbevf: Don't output NIC name before registered. (ethan.zhao) [Orabug: 17477783]  
- xen/smp: initialize IPI vectors before marking CPU online (Chuck Anderson) [Orabug: 17800009]  
- cpu: make sure that cpu/online file created before KOBJ_ADD is emitted (Igor Mammedov) [Orabug: 17800009]  
- cpu: fix "crash_notes" and "crash_notes_size" leaks in register_cpu() (Igor Mammedov) [Orabug: 17800009]  
- sysfs: fix crash_notes_size build warning (Arnd Bergmann) [Orabug: 17800009]  
- sysfs: Add crash_notes_size to export percpu note size (Zhang Yanfei) [Orabug: 17800009]  
- PCI: Init NumVFs register to zero in sriov_init() (ethan.zhao) [Orabug: 17799296]  
- PCI: Update NumVFs register when disabling SR-IOV (Yijing Wang) [Orabug: 17799296]  
- xen/balloon: Set balloon's initial state to number of existing RAM pages (Boris Ostrovsky) [Orabug: 17798521]  
- xfs: fix possible NULL dereference in xlog_verify_iclog (Geyslan G. Bem) [Orabug: 17799962]  
- xfs: prevent stack overflows from page cache allocation (Dave Chinner) [Orabug: 17799962]  
- Fix wrong flag ASSERT in xfs_attr_shortform_getvalue (Eric Sandeen) [Orabug: 17799962]  
- xfs: check correct status variable for xfs_inobt_get_rec() call (Brian Foster) [Orabug: 17799962]  
- xfs: avoid double-free in xfs_attr_node_addname (Eric Sandeen) [Orabug: 17799962]  
- xfs: fix assertion failure in xfs_vm_write_failed() (Jie Liu) [Orabug: 17799962]  
- inet: fix possible memory corruption with UDP_CORK and UFO (Hannes Frederic Sowa) [Orabug: 17791997]  
- tcp: do not forget FIN in tcp_shifted_skb() (Eric Dumazet) [Orabug: 17791998]  
- NFSv4.1: nfs4_fl_prepare_ds - fix bugs when the connect attempt fails (Trond Myklebust) [Orabug: 17791995]  
- NFS4.1 Fix data server connection race (Andy Adamson) [Orabug: 17791994]  
- ipv6: udp packets following an UFO enqueued packet need also be handled by UFO (Hannes Frederic Sowa) [Orabug: 17791993]  
- ip: generate unique IP identificator if local fragmentation is allowed (Ansis Atteka) [Orabug: 17791991]  
- workqueue: cond_resched() after processing each work item (Tejun Heo) [Orabug: 17791990]  
- SCSI: sg: Fix user memory corruption when SG_IO is interrupted by a signal (Roland Dreier) [Orabug: 17791989]  
- block: Add bio_for_each_segment_all() (Kent Overstreet) [Orabug: 17791988]  
- writeback: fix negative bdi max pause (Fengguang Wu) [Orabug: 17791986]  
- proc connector: fix info leaks (Mathias Krause) [Orabug: 17791985]  
- net: heap overflow in __audit_sockaddr() (Dan Carpenter) [Orabug: 17791984]  
- l2tp: fix kernel panic when using IPv4-mapped IPv6 addresses (François CACHEREUL) [Orabug: 17791982]  
- x86: avoid remapping data in parse_setup_data() (Linn Crosetto) [Orabug: 17791983]  
- drm/radeon: forever loop on error in radeon_do_test_moves() (Dan Carpenter) [Orabug: 17791981]  
- drm/i915: Only apply DPMS to the encoder if enabled (Chris Wilson) [Orabug: 17791980]  
- compiler/gcc4: Add quirk for 'asm goto' miscompilation bug (Ingo Molnar) [Orabug: 17791979]  
- ext4: fix memory leak in xattr (Dave Jones) [Orabug: 17791977]  
- ACPI / IPMI: Fix atomic context requirement of ipmi_msg_handler() (Lv Zheng) [Orabug: 17791978]  
- mm: avoid reinserting isolated balloon pages into LRU lists (Rafael Aquini) [Orabug: 17791976]  
- esp_scsi: Fix tag state corruption when autosensing. (David S. Miller) [Orabug: 17791974]  
- fs/binfmt_elf.c: prevent a coredump with a large vm_map_count from Oopsing (Dan Aloni) [Orabug: 17792144]  
- ipv4 igmp: use in_dev_put in timer handlers instead of __in_dev_put (Salam Noureddine) [Orabug: 17791973]  
- bridge: fix NULL pointer deref of br_port_get_rcu (Hong Zhiguo) [Orabug: 17791972]  
- net: sctp: fix ipv6 ipsec encryption bug in sctp_v6_xmit (Daniel Borkmann) [Orabug: 17791970] {CVE-2013-4350} 
- netpoll: fix NULL pointer dereference in netpoll_cleanup (Nikolay Aleksandrov) [Orabug: 17791971]  
- net: sctp: fix smatch warning in sctp_send_asconf_del_ip (Daniel Borkmann) [Orabug: 17791969]  
- net: fib: fib6_add: fix potential NULL pointer dereference (Daniel Borkmann) [Orabug: 17791967]  
- cciss: fix info leak in cciss_ioctl32_passthru() (Dan Carpenter) [Orabug: 17791968] {CVE-2013-2147} 
- cpqarray: fix info leak in ida_locked_ioctl() (Dan Carpenter) [Orabug: 17791963] {CVE-2013-2147} 
- dm snapshot: workaround for a false positive lockdep warning (Mikulas Patocka) [Orabug: 17791964]  
- driver core : Fix use after free of dev->parent in device_shutdown (Benson Leung) [Orabug: 17791961]  
- xhci: Fix oops happening after address device timeout (Mathias Nyman) [Orabug: 17791960]  
- serial: pch_uart: fix tty-kref leak in dma-rx path (Johan Hovold) [Orabug: 17791959]  
- cfq: explicitly use 64bit divide operation for 64bit arguments (Anatol Pomozov) [Orabug: 17791958]  
- HID: logitech-dj: validate output report details (Kees Cook) [Orabug: 17791957] {CVE-2013-2895} 
- HID: zeroplus: validate output report details (Kees Cook) [Orabug: 17791956] {CVE-2013-2889} 
- HID: LG: validate HID output report details (Kees Cook) [Orabug: 17791955] {CVE-2013-2893} 
- HID: provide a helper for validating hid reports (Kees Cook) [Orabug: 17791954]  
- HID: multitouch: validate indexes details (Benjamin Tissoires) [Orabug: 17791953] {CVE-2013-2897} 
- HID: validate feature and input report details (Benjamin Tissoires) [Orabug: 17791952] {CVE-2013-2897} 
- sched/fair: Fix small race where child->se.parent,cfs_rq might point to invalid ones (Daisuke Nishimura) [Orabug: 17791951]  
- cifs: fix filp leak in cifs_atomic_open() (Miklos Szeredi) [Orabug: 17791950]  
- fuse: readdir: check for slash in names (Miklos Szeredi) [Orabug: 17791949]  
- fuse: postpone end_page_writeback() in fuse_writepage_locked() (Maxim Patlasov) [Orabug: 17791947]  
- proc: Restrict mounting the proc filesystem (Eric W. Biederman) [Orabug: 17791948]  
- memcg: fix multiple large threshold notifications (Greg Thelen) [Orabug: 17791946]  
- ocfs2: fix the end cluster offset of FIEMAP (Jie Liu) [Orabug: 17791945]  
- pidns: fix vfork() after unshare(CLONE_NEWPID) (Oleg Nesterov) [Orabug: 17791944]  
- pidns: Fix hang in zap_pid_ns_processes by sending a potentially extra wakeup (Eric W. Biederman) [Orabug: 17791943]  
- intel-iommu: Fix leaks in pagetable freeing (Alex Williamson) [Orabug: 17791941]  
- Btrfs: don't allow the replace procedure on read only filesystems (Stefan Behrens) [Orabug: 17791942]  
- HID: check for NULL field when setting values (Kees Cook) [Orabug: 17791938]  
- HID: hidraw: correctly deallocate memory on device disconnect (Manoj Chourasia) [Orabug: 17791939]  
- HID: battery: don't do DMA from stack (Jiri Kosina) [Orabug: 17791937]  
- HID: picolcd: Prevent NULL pointer dereference on _remove() (Bruno Prémont) [Orabug: 17791935]  
- HID: ntrig: validate feature report details (Kees Cook) [Orabug: 17791932] {CVE-2013-2896} 
- HID: picolcd_core: validate output report details (Kees Cook) [Orabug: 17791930] {CVE-2013-2899} 
- HID: validate HID report id size (Kees Cook) [Orabug: 17791929] {CVE-2013-2888} 
- HID: sensor-hub: validate feature report details (Kees Cook) [Orabug: 17791927] {CVE-2013-2898} 
- HID: pantherlord: validate output report details (Kees Cook) [Orabug: 17791928] {CVE-2013-2892} 
- rculist: list_first_or_null_rcu() should use list_entry_rcu() (Tejun Heo) [Orabug: 17791925]  
- usb: config->desc.bLength may not exceed amount of data returned by the device (Hans de Goede) [Orabug: 17791926]  
- usb: ehci-mxc: check for pdata before dereferencing (Daniel Mack) [Orabug: 17791924]  
- net: Check the correct namespace when spoofing pid over SCM_RIGHTS (Andy Lutomirski) [Orabug: 17791922]  
- CIFS: Fix a memory leak when a lease break comes (Pavel Shilovsky) [Orabug: 17791921]  
- cifs: ensure that srv_mutex is held when dealing with ssocket pointer (Jeff Layton) [Orabug: 17791920]  
- cpuidle: coupled: fix race condition between pokes and safe state (Colin Cross) [Orabug: 17791919]  
- cpuidle: coupled: abort idle if pokes are pending (Colin Cross) [Orabug: 17791918]  
- xen-gnt: prevent adding duplicate gnt callbacks (Roger Pau Monne) [Orabug: 17791917]  
- crypto: api - Fix race condition in larval lookup (Herbert Xu) [Orabug: 17791914]  
- SCSI: sd: Fix potential out-of-bounds access (Alan Stern) [Orabug: 17791915]  
- UBI: Fix PEB leak in wear_leveling_worker() (Richard Weinberger) [Orabug: 17791912]  
- net: ipv6: tcp: fix potential use after free in tcp_v6_do_rcv (Daniel Borkmann) [Orabug: 17791911]  
- ipv6: remove max_addresses check from ipv6_create_tempaddr (Hannes Frederic Sowa) [Orabug: 17791910] {CVE-2013-0343} 
- fib_trie: remove potential out of bound access (Eric Dumazet) [Orabug: 17791909]  
- htb: fix sign extension bug (stephen hemminger) [Orabug: 17791907]  
- drivers/misc/hpilo: Correct panic when an AUX iLO is detected (Mark Rusk) [Orabug: 17791906]  
- memcg: check that kmem_cache has memcg_params before accessing it (Andrey Vagin) [Orabug: 17791904]  
- drivers/base/memory.c: fix show_mem_removable() to handle missing sections (Russ Anderson) [Orabug: 17791905]  
- jfs: fix readdir cookie incompatibility with NFSv4 (Dave Kleikamp) [Orabug: 17791902]  
- iwlwifi: dvm: fix calling ieee80211_chswitch_done() with NULL (Stanislaw Gruszka) [Orabug: 17792147]  
- jbd2: Fix use after free after error in jbd2_journal_dirty_metadata() (Jan Kara) [Orabug: 17791900]  
- wusbcore: fix kernel panic when disconnecting a wireless USB->serial device (Thomas Pugliese) [Orabug: 17792149]  
- USB: keyspan: fix null-deref at disconnect and release (Johan Hovold) [Orabug: 17791898]  
- fs/proc/task_mmu.c: fix buffer overflow in add_page_map() (yonghua zheng) [Orabug: 17792152]  
- memcg: don't initialize kmem-cache destroying work for root caches (Andrey Vagin) [Orabug: 17791896]  
- cifs: extend the buffer length enought for sprintf() using (Chen Gang) [Orabug: 17791897]  
- virtio: console: clean up port data immediately at time of unplug (Amit Shah) [Orabug: 17791894]  
- virtio: console: fix race in port_fops_open() and port unplug (Amit Shah) [Orabug: 17791893]  
- virtio: console: fix race with port unplug and open/close (Amit Shah) [Orabug: 17791892]  
- virtio/console: Add pipe_lock/unlock for splice_write (Yoshihiro YUNOMAE) [Orabug: 17791891]  
- virtio/console: Quit from splice_write if pipe->nrbufs is 0 (Yoshihiro YUNOMAE) [Orabug: 17791890]  
- LOCKD: Don't call utsname()->nodename from nlmclnt_setlockargs (Trond Myklebust) [Orabug: 17791889]  
- ACPI / PM: Walk physical_node_list under physical_node_lock (Rafael J. Wysocki) [Orabug: 17791888]  
- ext4: destroy ext4_es_cachep on module unload (Eric Sandeen) [Orabug: 17791887]  
- net_sched: info leak in atm_tc_dump_class() (Dan Carpenter) [Orabug: 17791886]  
- af_key: more info leaks in pfkey messages (Dan Carpenter) [Orabug: 17791885]  
- net_sched: Fix stack info leak in cbq_dump_wrr(). (David S. Miller) [Orabug: 17791883]  
- ipv6: take rtnl_lock and mark mrt6 table as freed on namespace cleanup (Hannes Frederic Sowa) [Orabug: 17791882]  
- userns: unshare_userns(&cred) should not populate cred on failure (Oleg Nesterov) [Orabug: 17791884]  
- cgroup: fix umount vs cgroup_cfts_commit() race (Li Zefan) [Orabug: 17791881]  
- fanotify: info leak in copy_event_to_user() (Dan Carpenter) [Orabug: 17791880] {CVE-2013-2148} 
- zram: protect sysfs handler from invalid memory access (Jiang Liu) [Orabug: 17791879]  
- zram: avoid access beyond the zram device (Jiang Liu) [Orabug: 17791878]  
- zram: destroy all devices on error recovery path in zram_init() (Jiang Liu) [Orabug: 17791877]  
- zram: use zram->lock to protect zram_free_page() in swap free notify path (Jiang Liu) [Orabug: 17791876]  
- xen/evtchn: avoid a deadlock when unbinding an event channel (David Vrabel) [Orabug: 17791875]  
- livelock avoidance in sget() (Al Viro) [Orabug: 17791873]  
- mm: mempolicy: fix mbind_range() && vma_adjust() interaction (Oleg Nesterov) [Orabug: 17791874]  
- ACPI / memhotplug: Fix a stale pointer in error path (Toshi Kani) [Orabug: 17791872]  
- nfsd: nfsd_open: when dentry_open returns an error do not propagate as struct file (Harshula Jayasuriya) [Orabug: 17791871]  
- crypto: caam - Fixed the memory out of bound overwrite issue (Vakul Garg) [Orabug: 17791870]  
- md/raid10: remove use-after-free bug. (NeilBrown) [Orabug: 17791869]  
- md/raid5: fix interaction of 'replace' and 'recovery'. (NeilBrown) [Orabug: 17791868]  
- x86, suspend: Handle CPUs which fail to #GP on RDMSR (H. Peter Anvin) [Orabug: 17791866]  
- USB: mos7840: fix memory leak in open (Johan Hovold) [Orabug: 17791867]  
- xhci: Avoid NULL pointer deref when host dies. (Sarah Sharp) [Orabug: 17791865]  
- xhci: fix null pointer dereference on ring_doorbell_for_active_rings (Oleksij Rempel) [Orabug: 17791864]  
- SCSI: sd: fix crash when UA received on DIF enabled device (Ewan D. Milne) [Orabug: 17791863]  
- SCSI: isci: Fix a race condition in the SSP task management path (Jeff Skirvin) [Orabug: 17791862]  
- iscsi-target: Fix tfc_tpg_nacl_auth_cit configfs length overflow (Joern Engel) [Orabug: 17791859]  
- hrtimers: Move SMP function call to thread context (Thomas Gleixner) [Orabug: 17791860]  
- lockd: protect nlm_blocked access in nlmsvc_retry_blocked (David Jeffery) [Orabug: 17791858]  
- PM / Sleep: avoid 'autosleep' in shutdown progress (Liu ShuoX) [Orabug: 17791855]  
- SCSI: megaraid_sas: fix memory leak if SGL has zero length entries (Bjørn Mork) [Orabug: 17791854]  
- ifb: fix oops when loading the ifb failed (dingtianhong) [Orabug: 17791853]  
- dummy: fix oops when loading the dummy failed (dingtianhong) [Orabug: 17791852]  
- 9p: fix off by one causing access violations and memory corruption (Sasha Levin) [Orabug: 17791851]  
- ifb: fix rcu_sched self-detected stalls (dingtianhong) [Orabug: 17791850]  
- sunvnet: vnet_port_remove must call unregister_netdev (Dave Kleikamp) [Orabug: 17791847]  
- vti: remove duplicated code to fix a memory leak (Cong Wang) [Orabug: 17791849]  
- perf: Fix perf_lock_task_context() vs RCU (Peter Zijlstra) [Orabug: 17791846]  
- perf: Remove WARN_ON_ONCE() check in __perf_event_enable() for valid scenario (Jiri Olsa) [Orabug: 17791845]  
- perf: Clone child context from parent context pmu (Jiri Olsa) [Orabug: 17791842]  
- iommu/amd: Only unmap large pages from the first pte (Alex Williamson) [Orabug: 17791843]  
- svcrpc: fix handling of too-short rpc's (J. Bruce Fields) [Orabug: 17791840]  
- printk: Fix rq->lock vs logbuf_lock unlock lock inversion (Bu, Yitian) [Orabug: 17791841]  
- mac80211: close AP_VLAN interfaces before unregistering all (Johannes Berg) [Orabug: 17791777]  
- md/raid10: fix two bugs affecting RAID10 reshape. (NeilBrown) [Orabug: 17791837]  
- timer: Fix jiffies wrap behavior of round_jiffies_common() (Bart Van Assche) [Orabug: 17791835]  
- PCI: Fix refcount issue in pci_create_root_bus() error recovery path (Jiang Liu) [Orabug: 17791834]  
- genirq: Fix can_request_irq() for IRQs without an action (Ben Hutchings) [Orabug: 17791833]  
- cgroup: fix umount vs cgroup_event_remove() race (Li Zefan) [Orabug: 17791832]  
- xhci: check for failed dma pool allocation (Mathias Nyman) [Orabug: 17791829]  
- ext3,ext4: don't mess with dir_file->f_pos in htree_dirblock_to_tree() (Al Viro) [Orabug: 17791826]  
- jbd2: fix theoretical race in jbd2__journal_restart (Theodore Ts'o) [Orabug: 17791828]  
- jbd2: move superblock checksum calculation to jbd2_write_superblock() (Theodore Ts'o) [Orabug: 17791824]  
- crypto: sanitize argument for format string (Kees Cook) [Orabug: 17791822]  
- charger-manager: Ensure event is not used as format string (Kees Cook) [Orabug: 17791823]  
- netfilter: nf_conntrack_ipv6: Plug sk_buff leak in fragment handling (Phil Oester) [Orabug: 17791821]  
- libata-acpi: add back ACPI based hotplug functionality (Aaron Lu) [Orabug: 17791820]  
- UBIFS: fix a horrid bug (Artem Bityutskiy) [Orabug: 17791819]  
- UBIFS: prepare to fix a horrid bug (Artem Bityutskiy) [Orabug: 17791818]  
- crypto: algboss - Hold ref count on larval (Herbert Xu) [Orabug: 17791817]  
- dlci: validate the net device in dlci_del() (Zefan Li) [Orabug: 17791815]  
- dlci: acquire rtnl_lock before calling __dev_get_by_name() (Zefan Li) [Orabug: 17791814]  
- hw_breakpoint: Use cpu_possible_mask in {reserve,release}_bp_slot() (Oleg Nesterov) [Orabug: 17791816]  
- hw_breakpoint: Fix cpu check in task_bp_pinned(cpu) (Oleg Nesterov) [Orabug: 17791812]  
- Bluetooth: Fix crash in l2cap_build_cmd() with small MTU (Anderson Lizardo) [Orabug: 17791811]  
- target/iscsi: don't corrupt bh_count in iscsit_stop_time2retain_timer() (Joern Engel) [Orabug: 17791809]  
- l2tp: Fix PPP header erasure and memory leak (Guillaume Nault) [Orabug: 17791808]  
- packet: packet_getname_spkt: make sure string is always 0-terminated (Daniel Borkmann) [Orabug: 17791807]  
- vhost_net: clear msg.control for non-zerocopy case during tx (Jason Wang) [Orabug: 17791806]  
- net: Block MSG_CMSG_COMPAT in send(m)msg and recv(m)msg (Andy Lutomirski) [Orabug: 17791805]  
- ip_tunnel: fix kernel panic with icmp_dest_unreach (Eric Dumazet) [Orabug: 17791804]  
- ipv6: fix possible crashes in ip6_cork_release() (Eric Dumazet) [Orabug: 17791801]  
- mm: mmu_notifier: re-fix freed page still mapped in secondary MMU (Xiao Guangrong) [Orabug: 17791802]  
- x86: Fix typo in kexec register clearing (Kees Cook) [Orabug: 17791798]  
- md/raid1,raid10: use freeze_array in place of raise_barrier in various places. (NeilBrown) [Orabug: 17791797]  
- md/raid1,5,10: Disable WRITE SAME until a recovery strategy is in place (H. Peter Anvin) [Orabug: 17791795]  
- md/raid1: consider WRITE as successful only if at least one non-Faulty and non-rebuilding drive completed it. (Alex Lyakas) [Orabug: 17791794]  
- swap: avoid read_swap_cache_async() race to deadlock while waiting on discard I/O completion (Rafael Aquini) [Orabug: 17791792]  
- cciss: fix broken mutex usage in ioctl (Stephen M. Cameron) [Orabug: 17791791]  
- rbd: don't destroy ceph_opts in rbd_add() (Alex Elder) [Orabug: 17791793]  
- libceph: must hold mutex for reset_changed_osds() (Alex Elder) [Orabug: 17791790]  
- audit: wait_for_auditd() should use TASK_UNINTERRUPTIBLE (Oleg Nesterov) [Orabug: 17791788]  
- drm: fix a use-after-free when GPU acceleration disabled (Huacai Chen) [Orabug: 17791787]  
- eCryptfs: Check return of filemap_write_and_wait during fsync (Tyler Hicks) [Orabug: 17791789]  
- ecryptfs: fixed msync to flush data (Paul Taysom) [Orabug: 17791785]  
- cifs: fix off-by-one bug in build_unc_path_to_root (Jeff Layton) [Orabug: 17791786]  
- acpi-cpufreq: set current frequency based on target P-State (Ross Lagerwall) [Orabug: 17792155]  
- x86/PCI: Map PCI setup data with ioremap() so it can be in highmem (Matt Fleming) [Orabug: 17791783]  
- xhci: fix list access before init (Vladimir Murzin) [Orabug: 17791782]  
- xhci-mem: init list heads at the beginning of init (Sergio Aguirre) [Orabug: 17791780]  
- cfg80211: check wdev->netdev in connection work (Johannes Berg) [Orabug: 17791779]  
- jfs: fix a couple races (Dave Kleikamp) [Orabug: 17791776]  
- iscsi-target: fix heap buffer overflow on error (Kees Cook) [Orabug: 17791775] {CVE-2013-2850} 
- cgroup: initialize xattr before calling d_instantiate() (Li Zefan) [Orabug: 17791774]  
- cifs: fix potential buffer overrun when composing a new options string (Jeff Layton) [Orabug: 17791773]  
- module: don't unlink the module until we've removed all exposure. (Rusty Russell) [Orabug: 17791772]  
- x86, range: fix missing merge during add range (Yinghai Lu) [Orabug: 17791771]  
- mm/pagewalk.c: walk_page_range should avoid VM_PFNMAP areas (Cliff Wickman) [Orabug: 17791770]  
- drivers/block/brd.c: fix brd_lookup_page() race (Brian Behlendorf) [Orabug: 17791768]  
- klist: del waiter from klist_remove_waiters before wakeup waitting process (wang, biao) [Orabug: 17791766]  
- fat: fix possible overflow for fat_clusters (OGAWA Hirofumi) [Orabug: 17791767]  
- random: fix accounting race condition with lockless irq entropy_count update (Jiri Kosina) [Orabug: 17791764]  
- drivers/char/random.c: fix priming of last_data (Jarod Wilson) [Orabug: 17791763]  
- cifs: only set ops for inodes in I_NEW state (Jeff Layton) [Orabug: 17791762]  
- virtio_console: fix uapi header (Michael S. Tsirkin) [Orabug: 17791761]  
- usermodehelper: check subprocess_info->path != NULL (Oleg Nesterov) [Orabug: 17791759]  
- drm/radeon: check incoming cliprects pointer (Kees Cook) [Orabug: 17791760]  
- drivers/char/ipmi: memcpy, need additional 2 bytes to avoid memory overflow (Chen Gang) [Orabug: 17791758]  
- target: close target_put_sess_cmd() vs. core_tmr_abort_task() race (Joern Engel) [Orabug: 17791757]  
- drbd: fix memory leak (Lars Ellenberg) [Orabug: 17791756]  
- watchdog: Fix race condition in registration code (Guenter Roeck) [Orabug: 17791755]  
- pch_dma: Use GFP_ATOMIC because called from interrupt context (Tomoya MORINAGA) [Orabug: 17791752]  
- ipv6,gre: do not leak info to user-space (Amerigo Wang) [Orabug: 17791751]  
- ipv6: do not clear pinet6 field (Eric Dumazet) [Orabug: 17791750]  
- macvlan: fix passthru mode race between dev removal and rx path (Jiri Pirko) [Orabug: 17791753]  
- virtio: don't expose u16 in userspace api (stephen hemminger) [Orabug: 17791749]  
- packet: tpacket_v3: do not trigger bug() on wrong header status (Daniel Borkmann) [Orabug: 17792159]  
- bridge: fix race with topology change timer (stephen hemminger) [Orabug: 17791740]  
- drm/mm: fix dump table BUG (Daniel Vetter) [Orabug: 17791739]  
- ext4: limit group search loop for non-extent files (Lachlan McIlroy) [Orabug: 17791737]  
- tracing: Fix leaks of filter preds (Steven Rostedt (Red Hat)) [Orabug: 17791736]  
- tick: Cleanup NOHZ per cpu data on cpu down (Thomas Gleixner) [Orabug: 17791735]  
- timer: Don't reinitialize the cpu base lock during CPU_UP_PREPARE (Tirupathi Reddy) [Orabug: 17791733]  
- shm: fix null pointer deref when userspace specifies invalid hugepage size (Li Zefan) [Orabug: 17791731]  
- nfsd: fix oops when legacy_recdir_name_error is passed a -ENOENT error (Jeff Layton) [Orabug: 17791730]  
- ALSA: HDA: Fix Oops caused by dereference NULL pointer (Wang YanQing) [Orabug: 17791729]  
- ACPICA: Fix possible buffer overflow during a field unit read operation (Bob Moore) [Orabug: 17792164]  
- Btrfs: release path before starting transaction in can_nocow_extent (Josef Bacik) [Orabug: 17790692]  
- Btrfs: use right root when checking for hash collision (Josef Bacik) [Orabug: 17790692]  
- Btrfs: fix transid verify errors when recovering log tree (Josef Bacik) [Orabug: 17790692]  
- Btrfs: add the missing mutex unlock in write_all_supers() (Stefan Behrens) [Orabug: 17790692]  
- Revert "Btrfs: rework the overcommit logic to be based on the total size" (Josef Bacik) [Orabug: 17790692]  
- Btrfs: replay dir_index items before other items (Josef Bacik) [Orabug: 17790692]  
- Btrfs: actually log directory we are fsync()'ing (Josef Bacik) [Orabug: 17790692]  
- Btrfs: do not add replace target to the alloc_list (Ilya Dryomov) [Orabug: 17790692]  
- Btrfs: stop refusing the relocation of chunk 0 (Ilya Dryomov) [Orabug: 17790692]  
- Btrfs: change how we queue blocks for backref checking (Josef Bacik) [Orabug: 17790692]  
- Btrfs: set lockdep class before locking new extent buffer (Josef Bacik) [Orabug: 17790692]  
- Btrfs: release both paths before logging dir/changed extents (Josef Bacik) [Orabug: 17790692]  
- Btrfs: make sure the backref walker catches all refs to our extent (Josef Bacik) [Orabug: 17790692]  
- Btrfs: fix backref walking when we hit a compressed extent (Josef Bacik) [Orabug: 17790692]  
- Btrfs: do not offset physical if we're compressed (Josef Bacik) [Orabug: 17790692]  
- Btrfs: fix extent buffer leak after backref walking (Liu Bo) [Orabug: 17790692]  
- Btrfs: fix wrong write offset when replacing a device (Stefan Behrens) [Orabug: 17790692]  
- drivers/char/random.c: fix priming of last_data (Jarod Wilson) [Orabug: 17776875]  
- RDMA CM: Add reason code for IB_CM_REJ_CONSUMER_DEFINED (Bang Nguyen) [Orabug: 17484686]  
- net: Update the sysctl permissions handler to test effective uid/gid (Eric W. Biederman) [Orabug: 17433948]  
- be2net: pass if_id for v1 and V2 versions of TX_CREATE cmd (asundhara Volam) [Orabug: 17583192]  
- dtrace: remove functionality of dtrace_os_exit() as deprecated (Kris Van Hees) [Orabug: 17717401]  
- dtrace: fix mutex_owned() implementation (Kris Van Hees) [Orabug: 17624236]  
- dtrace: new cyclic implementation (Kris Van Hees) [Orabug: 17553446]  
- xen-netfront: convert to GRO API (Wei Liu) [Orabug: 17759432]  
- xen-netfront: pull on receive skb may need to happen earlier (Jan Beulich) [Orabug: 17759399]  
- xen-netback: enable IPv6 TCP GSO to the guest (Paul Durrant)   
- xen-netback: handle IPv6 TCP GSO packets from the guest (Paul Durrant)   
- xen-netback: Unconditionally set NETIF_F_RXCSUM (Paul Durrant)   
- xen-netback: add support for IPv6 checksum offload from guest (Paul Durrant)   
- xen-netback: add support for IPv6 checksum offload to guest (Paul Durrant)   
- xen-netback: transition to CLOSED when removing a VIF (David Vrabel)   
- xen-netback: Handle backend state transitions in a more robust way (Paul Durrant)   
- xen-netback: Don't destroy the netdev until the vif is shut down (Paul Durrant)   
- xen-netback: count number required slots for an skb more carefully (David Vrabel)   
- xen-netback: fix possible format string flaw (Kees Cook)   
- xen-netback: rename functions (Wei Liu)   
- xen-netback: switch to NAPI + kthread 1:1 model (Wei Liu)   
- xen-netback: remove page tracking facility (Wei Liu)   
- core/xen: Use _PAGE_IOMAP when mmaping PCI BARs. (Konrad Rzeszutek Wilk) [Orabug: 17753790]  
- xen/p2m: Export set_phys_to_machine. (Konrad Rzeszutek Wilk)   
- Update lpfc version for 8.3.7.34.2p driver release (Gairy Grannum) [Orabug: 17746696]  
- scsi: rename random32() to prandom_u32() (Akinobu Mita) [Orabug: 17746696]  
- lseek(fd, n, SEEK_END) does *not* go to eof - n (Al Viro) [Orabug: 17746696]  
- [SCSI] lpfc: remove unnecessary read of PCI_CAP_ID_EXP (Jon Mason) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.43: Fixed not processing task management IOCB response status (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.43: Fixed spinlock hang. (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.43: Fixed invalid fcp_rsp length fir FCP_ICMND (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.43: Fixed invalid Total_Data_Placed value received for els and ct command responses (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.43: Fixed invalid fcp_rsp length fir FCP_ICMND (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.43: Fixed invalid mailbox timeouts (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.43: Fixed spinlock inversion problem. (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.43: Fix crash after xri limit is reached. (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed issue of task management commands having a fixed timeout (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed inconsistent spin lock usage. (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fix driver's abort loop functionality to skip IOs already getting aborted (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed failure to allocate SCSI buffer on PPC64 platform for SLI4 devices (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fix WARN_ON when driver unloads (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fix crash on driver load due to cpu affinity logic (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Avoided making pci bar ioremap call during dual-chute WQ/RQ pci bar selection (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed driver iocbq structure's iocb_flag field running out of space (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fix crash on driver load due to cpu affinity logic (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed logging format of setting driver sysfs attributes hard to interpret (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed back to back RSCNs discovery failure. (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed race condition between BSG I/O dispatch and timeout handling (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed function mode field defined too small for not recognizing dual-chute mode (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Back out data count,(residual fcfi_parm) fix for bad target. (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed mailbox memory leak. (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fix random errors using first burst (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed not able to log informational messages at early stage of driver init time (James Smart) [Orabug: 17746696]  
- [SCSI] lpfc 8.3.42: Fixed using unsafe linked list macro for walking and deleting linked list (James Smart) [Orabug: 17746696]  
- ext4: no need to remove extent if len is 0 in ext4_es_remove_extent() (Eryu Guan) [Orabug: 17721117]  
- config: add OVN (xsigo) config options (Ajaykumar Hotchandani) [Orabug: 17705097]  
- OVN: Kconfig and Makefile updates (Ajaykumar Hotchandani) [Orabug: 17705097]  
- OVN: Merge OVN release 7565 in UEK3 (Ankit Darsi) [Orabug: 17705097]  
- xfs: manually calculate ndquots if mp->m_quotainfo is not initialized (Guangyu Sun) [Orabug: 17544192]  
- PCI: Update NumVFs register when disabling SR-IOV (Yijing Wang) [Orabug: 17633548]  
- mlx4_en: fix tear down warning on Ubuntu 12.04 (Noa Osherovich) [Orabug: 17713165]  
- RDS: Port of UEK2 changes between 400.107.0 and 400.124.1 (Venkat Venkatsubra) [Orabug: 17713165]  
- iser: panic on iser login/logout (Shamir Rabinovitch) [Orabug: 16313854]  
- rdma_cm: add ability to control the QP timeout value (Saeed Mahameed) [Orabug: 17713165]  
- rdma_cm: adding the RDMA_CM_EVENT_ALT_PATH_LOADED event (Dotan Barak) [Orabug: 17713165]  
- rdma_cm: rdma_create_qp not setting up client context correctly (Saeed Mahameed) [Orabug: 17713165]  
- mlx4_en: Align timestamping support with upstream kernel (Saeed Mahameed) [Orabug: 17713165]  
- IB: Introduce Shared PD support (Saeed Mahameed) [Orabug: 17713165]  
- ib_core: IB providers/ULPs Relaxed (User) FMR set to NULL (Saeed Mahameed) [Orabug: 17713165]  
- ib_core: Enable usermode FMR (Saeed Mahameed) [Orabug: 17713165]  
- rmda_cm: add APM support to rdma_cm. (rdma_enable_apm) (Saeed Mahameed) [Orabug: 17713165]  
- mlx4_en: update driver version to 2.1.8 (Eugenia Emantayev) [Orabug: 17713165]  
- mlx4_en: update driver version to 2.1.7 (Eugenia Emantayev) [Orabug: 17713165]  
- mlx4_en: Fix LLS after rx path overhaul (Amir Vadai) [Orabug: 17713165]  
- mlx4_en: Update busy poll (LLS) to new API (Amir Vadai) [Orabug: 17713165]  
- mlx5: ensure proper synchronization accessing memory (Eli Cohen) [Orabug: 17713165]  
- ib/ipoib: add lock to ipoib_neigh_dtor function (Tal Alon) [Orabug: 17713165]  
- IB/iser: Fix redundant pointer check in dealloc flow (Roi Dayan) [Orabug: 17713165]  
- IB/iser: Fix possible memory leak in iser_create_frwr_pool (Roi Dayan) [Orabug: 17713165]  
- mlx5_ib: Change log_max_qp in profile 2 (Moshe Lazer) [Orabug: 17713165]  
- ib/ipoib: 1.add error mesage when qp creation failed 	  2.add error number to print when destroy qp (Tal Alon) [Orabug: 17713165]  
- net/mlx4: do not use DEV_ID to find max supported VLs (Moni Shoua) [Orabug: 17713165]  
- mlx5: Fix alignment of reg umr gather buffers (Eli Cohen) [Orabug: 17713165]  
- Add support for using mlx4_multicast_attach on RAW QP with unicast (Shani Michaelli) [Orabug: 17713165]  
- mlx4_en: fix typo in ETS capability (Eugenia Emantayev) [Orabug: 17713165]  
- ib/ipoib: force skb clean after timeout in ipoib_cm_tx_destroy (Erez Shitrit) [Orabug: 17713165]  
- mlx4: avoid hard lockup in resize CQ (Eli Cohen) [Orabug: 17713165]  
- mlx5_core: support PRM changes in MANAGE_PAGES and QUERY_PAGES commands (Moshe Lazer) [Orabug: 17713165]  
- mlx4_core: fix no valid MAC entry warning (Eugenia Emantayev) [Orabug: 17713165]  
- eth_ipoib: fix compilation warnning. (Erez Shitrit) [Orabug: 17713165]  
- mlx5: handle failure in async create mkey (Eli Cohen) [Orabug: 17713165]  
- eth_ipoib:decrease print messages. (Erez Shitrit) [Orabug: 17713165]  
- mlx4_en: replace ETH_SCHED capability flag by ETS_CFG (Eugenia Emantayev) [Orabug: 17713165]  
- mlx4_core: add a label to allow addition of a new steering entry (Noa Osherovich) [Orabug: 17713165]  
- mlx4_ib: Add RAW ETH support which was abandoned (Shani Michaelli) [Orabug: 17713165]  
- mlx4_en: don't alloc coalescing change if port is down (Eugenia Emantayev) [Orabug: 17713165]  
- mlx4_core: fix, lost comm channel events (Saeed Mahameed) [Orabug: 17713165]  
- mlx5: fix cleanup flow when DMA mapping fails (Eli Cohen) [Orabug: 17713165]  
- mlx5_ib: Improve description for prof_sel module param (Moshe Lazer) [Orabug: 17713165]  
- mlx5_ib: fix srq free in destroy qp (Moshe Lazer) [Orabug: 17713165]  
- mlx5: fix broken enforcement on send queue size (Eli Cohen) [Orabug: 17713165]  
- mlx5: Fix error code translation from firmware to driver (Eli Cohen) [Orabug: 17713165]  
- mlx5: fix opt param mask according to PRM definitions (Eli Cohen) [Orabug: 17713165]  
- mlx5: fix opt param mask for sqerr to rts transition (Eli Cohen) [Orabug: 17713165]  
- mlx4: add DMFS to dump device capabilities (Eugenia Emantayev) [Orabug: 17713165]  
- ib/ipoib: synchronaize neigh deletion while uninitializing device (Tal Alon) [Orabug: 17713165]  
- mlx4_en: Handle unassigned VF MAC address correctly (Eugenia Emantayev) [Orabug: 17713165]  
- mlx4_core: Don't give VFs MAC addresses which are derived from the PF MAC (Eugenia Emantayev) [Orabug: 17713165]  
- net/mlx4: start with 8 VLs for ConnectX3-Pro (Moni Shoua) [Orabug: 17713165]  
- Revert "mlx5: add git version to mlx5_ib" (Vladimir Sokolovsky) [Orabug: 17713165]  
- IB/mlx5: fix eq names to display nicely in /proc/interrupts (Sagi Grimberg) [Orabug: 17713165]  
- mlx5_ib: On destroy qp remove pending cqe only by their qpn (Moshe Lazer) [Orabug: 17713165]  
- mlx5: add git version to mlx5_ib (Eli Cohen) [Orabug: 17713165]  
- mlx5: simplify mlx5_ib_destroy_srq (Eli Cohen) [Orabug: 17713165]  
- mlx5: disable atomic operations (Eli Cohen) [Orabug: 17713165]  
- ib/ipoib: update bc object ufter pkey value was changed in index 0 (Erez Shitrit) [Orabug: 17713165]  
- mlx4_core: Slaves must ignore module param enable_64b_cqe_eqe (Jack Morgenstein) [Orabug: 17713165]  
- eth_ipoib: netdev_rx_handler_unregister should be called out of locking (Erez Shitrit) [Orabug: 17713165]  
- eth_ipoib: prepare the right space for sscanf (Erez Shitrit) [Orabug: 17713165]  
- mlx4_en: enable DCB and ETS only when FW supports (Eugenia Emantayev) [Orabug: 17713165]  
- ib_core: XRC reference counting handling (Yishai Hadas) [Orabug: 17713165]  
- mlx4_core: changes to gain compatibility with upstream mlx4 drivers (Jack Morgenstein) [Orabug: 17713165]  
- eth_ipoib: Add support for broadcast packet. (Erez Shitrit) [Orabug: 17713165]  
- mlx5: return -EFAULT instead of -EPERM (Dan Carpenter) [Orabug: 17713165]  
- mlx5: qp: variable may be used uninitialized (Eli Cohen) [Orabug: 17713165]  
- IB/iser: Fix error flow in alloc_frwr_pool (Sagi Grimberg) [Orabug: 17713165]  
- mlx4_en: disable global flow control when PFC enabled (Eugenia Emantayev) [Orabug: 17713165]  
- ib_core: XRC sync event on target QP (Yishai Hadas) [Orabug: 17713165]  
- mlx4_vnic: remove mlx4_vnic_helper module (Saeed Mahameed) [Orabug: 17713165]  
- mlx5: fix layout of struct mlx5_init_seg (Eli Cohen) [Orabug: 17713165]  
- mlx5: Fix overflow check in IB_WR_FAST_REG_MR (Eli Cohen) [Orabug: 17713165]  
- SRIOV: fix XRC recognition (Yishai Hadas) [Orabug: 17713165]  
- mlx5: add protection against ghost command completions (Eli Cohen) [Orabug: 17713165]  
- ib/ipoib: reorder devices which call to dev_uninit, dev_stop and dev_uninit must keep the same order of devices call (Tal Alon) [Orabug: 17713165]  
- mlx4_core: do not allow WoL command on slave (Eugenia Emantayev) [Orabug: 17713165]  
- mlx5: remove histogram profiling code on create mkey (Eli Cohen) [Orabug: 17713165]  
- mlx5: modify spinlock types in cmdif flow (Eli Cohen) [Orabug: 17713165]  
- mlx5_ib: fix mr_perf array overflow (Moshe Lazer) [Orabug: 17713165]  
- mlx5: fix spin lock usage in mr callback (Moshe Lazer) [Orabug: 17713165]  
- Revert "mlx5: fix 2 issues in mr callback usage" (Moshe Lazer) [Orabug: 17713165]  
- mlx4_en: update driver version to 2.1.6 (Eugenia Emantayev) [Orabug: 17713165]  
- IB/iser: fix rdma reg resources cleanup (Sagi Grimberg) [Orabug: 17713165]  
- IB/iser: rename goto tag with proper name (Sagi Grimberg) [Orabug: 17713165]  
- IB/iser: don't use iser_err for info messages (Sagi Grimberg) [Orabug: 17713165]  
- IB/iser: dump bounce buffer only if debug level > 0 (Sagi Grimberg) [Orabug: 17713165]  
- IB/iser: remove redundant check if fmr pool is not NULL (Sagi Grimberg) [Orabug: 17713165]  
- IB/iser: Fix memory registration model selection (Sagi Grimberg) [Orabug: 17713165]  
- mlx5: fix 2 issues in mr callback usage (Moshe Lazer) [Orabug: 17713165]  
- Revert "ib/ipoib: separate receive queue size module parameter for CM and UD modes set CM default queue size to 64" (Tal Alon) [Orabug: 17713165]  
- mlx4/core - add imidiate activate for VGT->VST->VGT (Rony Efraim) [Orabug: 17713165]  
- mlx4_en: remove 2QPs feature since it causes TX timeout (Eugenia Emantayev) [Orabug: 17713165]  
- mlx4_core: fix kernel panic when getting operation request from FW before MCG table is initialized (Eugenia Emantayev) [Orabug: 17713165]  
- mlx5_ib: replace find_last_bit with local implementation (Moshe Lazer) [Orabug: 17713165]  
- mlx5: multithreaded create mr with statistics (Eli Cohen) [Orabug: 17713165]  
- IB/mlx4: fix compilaiton warning (Matan Barak) [Orabug: 17713165]  
- ib/ipoib: separate receive queue size module parameter for CM and UD modes set CM default queue size to 64 (Tal Alon) [Orabug: 17713165]  
- ib/ipoib: enable msb bit in pkey-change-event handler (Erez Shitrit) [Orabug: 17713165]  
- eth_ipoib: live migration sync before zero the slave mac (Erez Shitrit) [Orabug: 17713165]  
- IB/iser: Introduce fast memory registration model (Sagi Grimberg) [Orabug: 17713165]  
- IB/iser: make fmr pool and page_vec to union in ib_conn (Sagi Grimberg) [Orabug: 17713165]  
- IB/iser: export bounce buffer code to a routine and generalize iser_sg_to_page_vec (Sagi Grimberg) [Orabug: 17713165]  
- IB/iser: make rdma routines function handles per device (Sagi Grimberg) [Orabug: 17713165]  
- mlx4_ib(rocee): Fix gid table population when using bonding over vlan (Matan Barak) [Orabug: 17713165]  
- IB/iser: Accept session->cmds_max from user space (Shlomo Pongratz) [Orabug: 17713165]  
- IB/iser: Restructure allocation/deallocation of connection resources (Shlomo Pongratz) [Orabug: 17713165]  
- IB/iser: Use proper debug level value for info prints (Or Gerlitz) [Orabug: 17713165]  
- ib_ipoib: fix Oops in ipoib_ib_dev_open error flow (Jack Morgenstein) [Orabug: 17713165]  
- IB/mlx4: Allow IB flow steering only when capability bit is set (Matan Barak) [Orabug: 17713165]  
- eth_ipoib: ignore error message when ip 0 tried to be added. (Erez Shitrit) [Orabug: 17713165]  
- mlx5: keep polling to reclaim pages while any returned (Eli Cohen) [Orabug: 17713165]  
- mlx4_core: Fix GEN_EQE accessing uninitialixed mutex (Jack Morgenstein) [Orabug: 17713165]  
- mlx4_en: alloc RX buffers always with GFP_ATOMIC (Eugenia Emantayev) [Orabug: 17713165]  
- mlx5: avoid async events on invalid port number (Eli Cohen) [Orabug: 17713165]  
- mlx5: decrease memory consumption of mr caches (Eli Cohen) [Orabug: 17713165]  
- ib/ipoib: remove trace over debug kernel when false alarm over read_lock (Erez Shitrit) [Orabug: 17713165]  
- mlx5_core: resolve race condition in mlx5_cmd_comp_handler (Moshe Lazer) [Orabug: 17713165]  
- ib/ipoib: unlock dev_start_xmit() on ipoib_cm_rep_handler() (Tal Alon) [Orabug: 17713165]  
- ib/ipoib: on start xmit at cm mode when a cm neigh oper is down the skb doesn't send so it must free (Tal Alon) [Orabug: 17713165]  
- ulp/ipoib: IB_QP_CREATE_NETIF_QP flag should be set for IPoIB qp only if FS is supoprted (Matan Barak) [Orabug: 17713165]  
- mlx4/net: couldn't add flow steering rules for all vlans (Matan Barak) [Orabug: 17713165]  
- eth_ipoib: after dev_queue_xmit the skb should not be freed. (Erez Shitrit) [Orabug: 17713165]  
- eth_ipoib: decrease debug level for few messages (Erez Shitrit) [Orabug: 17713165]  
- mlx4_ib: Use default pkey when creating tunnel QPs (Jack Morgenstein) [Orabug: 17713165]  
- ib_core: create QP1 using the pkey index which contains the default pkey (Jack Morgenstein) [Orabug: 17713165]  
- eth_ipoib: update parent hw address only when was zero. (Erez Shitrit) [Orabug: 17713165]  
- mlx4_ib: clear comp mask bit of deleted GUID entries after deletion (Saeed Mahameed) [Orabug: 17713165]  
- ib/ipoib: fix illegal locking on ipoib_cm_rep_handler (Tal Alon) [Orabug: 17713165]  
- eth_ipoib: When releasing slave no trafic should be on the air (Erez Shitrit) [Orabug: 17713165]  
- eth_ipoib: Use RCU api in slave's list (Erez Shitrit) [Orabug: 17713165]  
- mlx4_core: use mcg mutex after initialization only (Eugenia Emantayev) [Orabug: 17713165]  
- mlx5_core: remove command signature (Moshe Lazer) [Orabug: 17713165]  
- mlx4_en: Fix CORE_CLOCK_MASK definition (Gideon Naim) [Orabug: 17713165]  
- mlx4_en: Fix the return value when setting an invalid MTU size (Gideon Naim) [Orabug: 17713165]  
- mlx4_en: use GFP_KERNEL allocations in initialization path (Eugenia Emantayev) [Orabug: 17713165]  
- eth_ipoib: pv interface should not track over ip 0 (Erez Shitrit) [Orabug: 17713165]  
- mlx4_en: prevent SKB from being freed twice during loopback test (Gideon Naim) [Orabug: 17713165]  
- IB/[core,mlx4]: Eliminate flow_context void pointer from struct ib_flow (Matan Barak) [Orabug: 17713165]  
- IB/uverbs: Eliminated struct ib_kern_flow which isn't used, needs f (Matan Barak) [Orabug: 17713165]  
- mlx5_ib: fix memory leak in mlx5_ib_create_srq (Moshe Lazer) [Orabug: 17713165]  
- mlx5_ib: flush cache workqueue before destroying it (Moshe Lazer) [Orabug: 17713165]  
- IB/core,mlx4: Remove cpu_to_be conversion in DMFS user verbs flow (Matan Barak) [Orabug: 17713165]  
- mlx4_ib: vlan removal issues (Yishai Hadas) [Orabug: 17713165]  
- mlx4_en: update driver version to 2.1.5 (Eugenia Emantayev) [Orabug: 17713165]  
- ib/ipoib: reduce warn message when not needed (Erez Shitrit) [Orabug: 17713165]  
- eth_ipoib: sync access to emac_ip_info data structure. (Erez Shitrit) [Orabug: 17713165]  
- mlx4_en: Copy new mac addr to field dev_addr under mutex_lock (Shani Michaelli) [Orabug: 17713165]  
- mlx4_en: Copy new mac addr to field prev_mac also when port is down (Shani Michaelli) [Orabug: 17713165]  
- ib/ipoib: ipoib_cm_rep_handler lock skb queue while dequeue before xmit (Tal Alon) [Orabug: 17713165]  
- ib/ipoib: limit the max number of TX queues to 16 (Tal Alon) [Orabug: 17713165]  
- mlx4_en: don't allow cq moderation when port is down (Eugenia Emantayev) [Orabug: 17713165]  
- Revert "rmda_cm: add APM support to rdma_cm. (rdma_enable_apm)" (Ajaykumar Hotchandani) [Orabug: 17713165]  
- Revert "rdma_cm: rdma_create_qp not setting up client context correctly" (Ajaykumar Hotchandani) [Orabug: 17713165]  
- Revert "rdma_cm: add ability to control the QP timeout value" (Ajaykumar Hotchandani) [Orabug: 17713165]  
- Revert "RDS: Port of UEK2 changes between 400.107.0 and 400.124.1" (Ajaykumar Hotchandani) [Orabug: 17713165]  
- Revert "iser: panic on iser login/logout" (Ajaykumar Hotchandani) [Orabug: 17713165]  
- Revert "rdma_cm: adding the RDMA_CM_EVENT_ALT_PATH_LOADED event" (Ajaykumar Hotchandani) [Orabug: 17713165]  
- Revert "ib_core: Enable usermode FMR" (Ajaykumar Hotchandani) [Orabug: 17713165]  
- Revert "ib_core: IB providers/ULPs Relaxed (User) FMR set to NULL" (Ajaykumar Hotchandani) [Orabug: 17713165]  
- Revert "IB: Introduce Shared PD support" (Ajaykumar Hotchandani) [Orabug: 17713165]  
- Revert "mlx4_ib: clear comp mask bit of deleted GUID entries after deletion" (Ajaykumar Hotchandani) [Orabug: 17713165]  
- Revert "mlx4_en: Align timestamping support with upstream kernel" (Ajaykumar Hotchandani) [Orabug: 17713165]  

* Fri Nov 1 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-18.el6uek] 
- sparc: tsb must be flushed before tlb (Dave Kleikamp) [Orabug: 17724439]  
- config: update config for sparc (Allen Pais) [Orabug: 17715697]  
- dm mpath: disable WRITE SAME if it fails (Mike Snitzer) [Orabug: 17617256]  
- Btrfs: dir_inode_operations should use btrfs_update_time also (Guangyu Sun) [Orabug: 17437471]  
- xfs: fix sgid inheritance for subdirectories inheriting default acls [V3] (Carlos Maiolino) [Orabug: 17354234]  
- crypto: xor - Check for osxsave as well as avx in crypto/xor (John Haxby) [Orabug: 17066724]  
- fs: protect write with sb_start/end_write in generic_file_write_iter (Guangyu Sun) [Orabug: 17487738]  
- bonding: If IP route look-up to send an ARP fails, mark in bonding structure as no ARP sent. (Rama Nichanamatlu) [Orabug: 17557056]  
- dm snapshot: fix data corruption (Mikulas Patocka) [Orabug: 17617582] {CVE-2013-4299} 
- Audit: do not print error when LSMs disabled (Eric Paris) [Orabug: 17537769]  
- oracleasm: Compat changes for 3.5 (Dwight Engen)   
- megaraid_sas: addded support for big endian architecture (Martin K. Petersen)   
- ext4: introduce reserved space (Lukas Czerner)   

* Tue Oct 8 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-17.el6uek] 
- dtrace: Use tasklet_hrtimer_*() instead of hrtimer_*() for cyclics (Kris Van Hees) [Orabug: 17553446]  

* Thu Sep 19 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-16.el6uek] 
- oracleasm: Add support for new error return codes from block/SCSI (Martin K. Petersen) [Orabug: 17484923]  
- RDS: protocol negotiation fails during reconnect (Bang Nguyen) [Orabug: 17484877]  
- ocfs2/dlm: ocfs2 dlm umount skip migrating lockres (Srinivas Eeda) [Orabug: 16859627]  
- ocfs2/dlm: Fix list traversal in dlm_process_recovery_data (Srinivas Eeda) [Orabug: 17432400]  
- ocfs2: fix error handling in ocfs2_ioctl_move_extents() (Srinivas Eeda) [Orabug: 16631951]  
- ocfs2: btrfs: aio-dio-loop changes broke setrlimit behavior (Srinivas Eeda) [Orabug: 14207636]  
- ocfs2: xattr: fix inlined xattr reflink (Junxiao Bi) [Orabug: 15914937]  
- ocfs2: goto out_unlock if ocfs2_get_clusters_nocache() failed in ocfs2_fiemap() (Joseph Qi) [Orabug: 16963812]  
- ocfs2: Don't log error message when removing non-empty directory (Xiaowei.Hu) [Orabug: 16790405]  
- ocfs2: Suppress the error message from being printed in ocfs2_rename (Xiaowei.Hu) [Orabug: 16790405]  
- ocfs2: ocfs2_prep_new_orphaned_file return ret (Xiaowei.Hu) [Orabug: 16823825]  
- ocfs2: Fix NULL dereference for moving extents (Dan Carpenter) [Orabug: 16631951]  
- ocfs2: This is a fix on dlm_clean_master_list() (Xiaowei.Hu) [Orabug: 12798517]  
- ocfs2: submit disk heartbeat bio using WRITE_SYNC (Srinivas Eeda) [Orabug: 17342255]  
- ocfs2: fix NULL pointer dereference in ocfs2_duplicate_clusters_by_page v2 (Xiaowei.Hu) [Orabug: 14752693]  
- ocfs2: Fix oops in ocfs2_fast_symlink_readpage() code path (Xiaowei.Hu) [Orabug: 17342255]  
- ocfs2: ->rl_count endianness breakage (Al Viro) [Orabug: 17342255]  
- ocfs2: ->rl_used breakage on big-endian (Al Viro) [Orabug: 17342255]  
- Revert "ocfs2: Push out dropping of dentry lock to ocfs2_wq" (Sunil Mushran) [Orabug: 17342255]  
- Revert "ocfs2: Fix deadlock on umount" (Sunil Mushran) [Orabug: 17342255]  
- Revert "ocfs2: Don't oops in ocfs2_kill_sb on a failed mount" (Sunil Mushran) [Orabug: 17342255]  
- ocfs2/cluster: Fix o2net_fill_node_map() (Sunil Mushran) [Orabug: 17342255]  
- ocfs2: Tighten free bit calculation in the global bitmap (Sunil Mushran) [Orabug: 17342255]  
- ocfs2/trivial: Limit unaligned aio+dio write messages to once per day (Sunil Mushran) [Orabug: 17342255]  
- ocfs2/trivial: Print message indicating unaligned aio+dio write (Sunil Mushran) [Orabug: 17342255]  
- ocfs2: update ocfs2 version (Tiger Yang) [Orabug: 17342255]  
- spec: only require libdtrace-ctf for kernel-uek-devel if with_dtrace is set (Jerry Snitselaar) [Orabug: 17477312]  
- dtrace: fix for psinfo allocation during execve (Kris Van Hees) [Orabug: 17407069]  
- kbuild/ctf: Use shell expansion, not $(wildcard ...), for CTF section copying. (Nick Alcock) [Orabug: 17445637]  
- kbuild/ctf: always build vmlinux when building CTF. (Jamie Iles) [Orabug: 17397200]  
- kbuild/dtrace: don't assume that bash is the shell. (Jamie Iles) [Orabug: 17397234]  
- block: Rate-limit failed I/O error message (Dave Kleikamp) [Orabug: 17370630]  
- block: Disable autoprotect (Martin K. Petersen) [Orabug: 17370630]  
- cdc-acm: Increase number of devices to 64 (Joe Jin) [Orabug: 17370630]  
- Parallel mtrr init between cpus (Zhenzhong Duan) [Orabug: 17370630]  
- sg: push file descriptor list locking down to per-device locking (Vaughan Cao) [Orabug: 17370630]  
- sg: checking sdp->detached isn't protected when open (Vaughan Cao) [Orabug: 17370630]  
- sg: no need sg_open_exclusive_lock (Vaughan Cao) [Orabug: 17370630]  
- sg: use rwsem to solve race during exclusive open (Vaughan Cao) [Orabug: 17370630]  
- Support checksum and gso offload of ipv6 in netback (Annie Li) [Orabug: 17370630]  
- net: init perm_addr in register_netdevice() (Jiri Pirko) [Orabug: 17370630]  
- drivers/cdrom/cdrom.c: use kzalloc() for failing hardware (Jonathan Salwan) [Orabug: 17370630] {CVE-2013-2164} 
- af_key: fix info leaks in notify messages (Mathias Krause) [Orabug: 17370630] {CVE-2013-2234} 

* Wed Sep 11 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-15.el6uek] 
- sparc64: strict_devmem configs (bob picco) [Orabug: 17442487]  
- sparc64: retry domain service registration (chris hyser) [Orabug: 17375532]  
- Btrfs: make the chunk allocator completely tree lockless (Josef Bacik) [Orabug: 17329252]  
- config: Disable memory hotplug support for Xen balloon driver (Daniel Kiper) [Orabug: 17343739]  
- Revert "SPEC: Do not sign modules, pro tem." (Jerry Snitselaar) [Orabug: 17410371]  
- config: enable snd-tea575x-tuner driver (Jerry Snitselaar) [Orabug: 17346564]  
- config: add missing wireless drivers to debug config (Jerry Snitselaar) [Orabug: 17346564]  
- Btrfs: set/change the label of a mounted file system (jeff.liu) [Orabug: 16745716]  
- Btrfs: Add a new ioctl to get the label of a mounted file system (jeff.liu) [Orabug: 16745716]  
- sparc64: __init code no longer called during non __init (chris hyser)   
- RDS: Port of UEK2 changes between 400.107.0 and 400.124.1 (Venkat Venkatsubra) [Orabug: 17320357]  

* Tue Sep 3 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-14.el6uek] 
- dm: allow error target to replace either bio-based and request-based targets (Joe Jin) [Orabug: 17405032]  
- dtrace: remove unnecessary exported symbol (Kris Van Hees) [Orabug: 17346878]  
- dtrace: Ensure that USDT probes are carried over correctly across fork(). (Kris Van Hees) [Orabug: 17346878]  
- dtrace: fix retrieval of arg5 through arg9 (Kris Van Hees) [Orabug: 17368166]  
- dtrace: Ensure that task_struct members are initialized correctly (Kris Van Hees)   
- Two efficiency fixes for audit mechanism (Dan Duval) [Orabug: 16765434]  
- Three fixes to audit_log_start() mechanism (Dan Duval) [Orabug: 167654341]  
- dtrace: ensure that builds in a separate objdir work (Kris Van Hees) [Orabug: 17369799]  
- config: align config options with uek2 (Jerry Snitselaar) [Orabug: 17346564]  
- dwarf2ctf: Ensure the CTF directory exists before writing the filelist. (Nick Alcock) [Orabug: 17363469]  
- dwarf2ctf: avoid command-line length limits by passing .o filenames via a file. (Nick Alcock) [Orabug: 17363469]  
- xen: initialize xen panic handler for PVHVM (Vaughan Cao) [Orabug: 17200031]  
- af_key: initialize satype in key_notify_policy_flush() (Nicolas Dichtel) [Orabug: 17370760] {CVE-2013-2237} 
- RDS: RDS NETFILTER SUPPORT (Ahmed Abbas) [Orabug: 17285666]  
- mods: don't put regular modules under extra/ (Jerry Snitselaar) [Orabug: 17347419]  
- b43: stop format string leaking into error msgs (Kees Cook) [Orabug: 16993114] {CVE-2013-2852} 

* Wed Aug 21 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-13.el6uek] 
- config: more updates (Jerry Snitselaar) [Orabug: 17248299]  

* Wed Aug 21 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-12.el6uek] 
- config: update configs (Jerry Snitselaar) [Orabug: 17248299]  
- fuse: return -EGAIN if not connected (Srinivas Eeda) [Orabug: 17337480]  
- fuse: split fuse queues to help numa systems (Srinivas Eeda) [Orabug: 17336449]

Signed-off-by: Jerry Snitselaar <jerry.snitselaar@oracle.com>  
- fuse: add fuse numa node struct (Srinivas Eeda) [Orabug: 17336449]

Signed-off-by: Jerry Snitselaar <jerry.snitselaar@oracle.com>  
- fuse: add numa mount option (Srinivas Eeda) [Orabug: 17336449]

Signed-off-by: Jerry Snitselaar <jerry.snitselaar@oracle.com>  
- config: remove lm80 driver to avoid possible crash (Jerry Snitselaar) [Orabug: 17337318]  
- kabi: update Module.kabi and kabi_whitelist for UEK3 (Jerry Snitselaar) [Orabug: 17335510]  
- config: clean up config files (Jerry Snitselaar) [Orabug: 17335515]  
- dtrace: DT_FASTTRAP should select UPROBE_EVENT (Jerry Snitselaar) [Orabug: 17325699]  
- turn on panic on oops and align configs (Maxim Uvarov)   
- acpi_i2c: set MODULE_LICENSE, MODULE_AUTHOR, and MODULE_DESCRIPTION (Jerry Snitselaar) [Orabug: 17321212]  
- Revert "cpuidle: Quickly notice prediction failure for repeat mode" (ethan.zhao) [Orabug: 17315729]  
- Revert "cpuidle: Quickly notice prediction failure in general case" (Rafael J. Wysocki) [Orabug: 17315729]  
- mm/vmalloc.c: fix an overflow bug in alloc_vmap_area() (Zhang Yanfei) [Orabug: 17315488]  
- ioat: Add alignment workaround for IVB platforms (Dave Jiang) [Orabug: 16495543]  
- cpufreq: Fix governor start/stop race condition (ethan.zhao) [Orabug: 17071478]  

* Thu Aug 15 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-11.el6uek] 
- sparc: sparc64_task_unmmaped_base and sparc64_task_size_max fix (Jerry Snitselaar)   
- config: remove unneeded ib config options in sparc build (Jerry Snitselaar) [Orabug: 17315304]  
- rds: fix build error for ib_recv.c (Jerry Snitselaar) [Orabug: 17315304]  
- kabi: Fix up Module.kabi_x86_64 (Jerry Snitselaar) [Orabug: 17309389]  
- Revert "dtrace: only do kallsyms build on x86_64" (Jerry Snitselaar) [Orabug: 17314140]  
- dtrace: Fix formatting mistake in spec file. (Kris Van Hees) [Orabug: 17313687]  
- dtrace: Fix for the argument validation code. (Kris Van Hees) [Orabug: 17313687]  
- dtrace: Include asm/current.h for the mutex_owned() fucntion. (Kris Van Hees) [Orabug: 17313687]  
- dtrace: Fix build requirements for the new kallsyms util; add requirements to -devel. (Kris Van Hees) [Orabug: 17313687]  
- dtrace: Bug fix for logic to determine the (inode, offset) pair for uprobes. (Kris Van Hees)   

* Tue Aug 13 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-10.el6uek] 
- mptfusion: fix kernel-doc build errors (Jerry Snitselaar) [Orabug: 17308655]  
- kabi: fix kabi check for builds (Jerry Snitselaar) [Orabug: 17308516]  

* Tue Aug 13 2013 Jerry Snitselaar <jerry.snitselaar@oracle.com> [3.8.13-9.el6uek] 
- dtrace: only do kallsyms build on x86_64 (Jerry Snitselaar) [Orabug: 17308256]  
- kabi: Update Module.kabi_x86_64 (Jerry Snitselaar) [Orabug: 17302224]  
- Update lpfc version for 8.3.7.26.2p driver release (Gairy Grannum)   
- Enable BlockGuard Support (Vaios Papadimitriou)   
- Removed obsolete fcp_eq_count and fcp_wq_count driver attributes (James Smart)   
- Update copyrights for 8.3.41 modifications (James Smart)   
- Removed obsolete fcp_eq_count and fcp_wq_count driver attributes (James Smart)   
- Add first burst support to driver (James Smart)   
- Fixed the format of some log message fields (James Smart)   
- Add first burst support to driver (James Smart)   
- Fixed not able to perform PCI function reset when board was not in online mode (James Smart)   
- Fixed failure in setting SLI3 board mode (James Smart)   
- Fixed SLI3 failing FCP write on check-condition no-sense with residual zero (James Smart)   
- Fixed support for 128 byte WQEs (James Smart)   
- Ensure driver properly zeros unused fields in SLI4 mailbox commands (James Smart)   
- Fixed max value of lpfc_lun_queue_depth (James Smart)   
- Fixed Receive Queue varied frame size handling (James Smart)   
- Fix mailbox byteswap issue on PPC (James Smart)   
- Fixed freeing of iocb when internal loopback times out (James Smart)   
- lpfc 8.3.40: Update Copyrights to 2013 for 8.3.38, 8.3.39, and 8.3.40 modifications (James Smart)   
- lpfc 8.3.40: Fixed a race condition between SLI host and port failed FCF rediscovery (James Smart)   
- lpfc 8.3.40: Fixed issue mailbox wait routine failed to issue dump memory mbox command (James Smart)   
- treewide: Fix typos in kernel messages (Masanari Iida)   
- lpfc 8.3.40: Fixed system panic due to unsafe walking and deleting linked list (James Smart)   
- lpfc 8.3.40: Fixed FCoE connection list vlan identifier and add FCF list debug (James Smart)   
- lpfc 8.3.40: Clarified the behavior of the lpfc_max_luns module parameter (James Smart)   
- lpfc 8.3.40: Fix to allow OCM to report FEC status (James Smart)   
- lpfc 8.3.40: Fixed a missing return code in a logging message (James Smart)   
- lpfc 8.3.40: Fixed some logging message fields (James Smart)   
- lpfc 8.3.40: Fixed list corruption when lpfc_drain_tx runs (James Smart)   
- lpfc 8.3.40: Fix starting reference tag when calculating BG error (James Smart)   
- lpfc 8.3.40: Fix inconsistent list removal causes crash (James Smart)   
- lpfc 8.3.40: Fixed system panic during handling unsolicited receive buffer error condition (James Smart)   
- lpfc 8.3.40: Fix BlockGuard error checking (James Smart)   
- lpfc 8.3.40: Fixed crash during FCoE failover testing. (James Smart)   
- lpfc 8.3.40: Fix lpfc_used_cpu to be more dynamic (James Smart)   
- lpfc 8.3.39: Fixed driver handling of CLEAR_LA with NPIV enabled causing SID=0 frames out (James Smart)   
- scsi: fix lpfc build when wmb() is defined as mb() (Randy Dunlap)   
- lpfc 8.3.39: Reduced tmo value set to FLOGI WQE for quick recovery from FLOGI sequence timeout (James Smart)   
- lpfc 8.3.39: Add log message when completes with clean address bit set to zero (James Smart)   
- lpfc 8.3.39: Fixed driver vector mapping to CPU affinity (James Smart)   
- lpfc 8.3.39: Fixed driver vector mapping to CPU affinity (James Smart)   
- lpfc 8.3.39: Fixed iocb flags not being reset for scsi commands (James Smart)   
- lpfc 8.3.39: Fixed system panic during EEH recovery due to midlayer acting on outstanding I/O (James Smart)   
- lpfc 8.3.39: Fixed system panic during EEH recovery due to midlayer acting on outstanding I/O (James Smart)   
- lpfc 8.3.39: Fixed not returning FAILED status when SCSI invoking host reset handler failed (James Smart)   
- lpfc 8.3.39: Fixed bad book keeping in posting els sgls to port (James Smart)   
- lpfc 8.3.39: Fixed deadlock between hbalock and nlp_lock use (James Smart)   
- [SCSI] lpfc 8.3.39: Fixed BlockGuard to take advantage of rdprotect/wrprotect info when available (James Smart)   
- lpfc 8.3.39: Reduced spinlock contention on SCSI buffer list (James Smart)   
- lpfc 8.3.39: Fixed crash when processing bsg's sg list with high memory pages (James Smart)   
- lpfc 8.3.39: Remove lpfc_fcp_look_ahead module parameter (James Smart)   
- lpfc 8.3.39: Fix driver issues with SCSI Host reset (James Smart)   
- lpfc 8.3.39: Doorbell formation information logged in dual-chute mode WQ and RQ setup (James Smart)   
- lpfc 8.3.39: Fix driver issues with large s/g lists for BlockGuard (James Smart)   
- lpfc 8.3.39: Fix driver issues with large lpfc_sg_seg_cnt values (James Smart)   
- lpfc 8.3.39: Fixed pt2pt and loop discovery problems on topology changes. (James Smart)   
- lpfc 8.3.39: Remove driver dependency on HZ (James Smart)   
- lpfc 8.3.38: Fixed async FCF modified event to in-use FCF failure to trigger recovery (James Smart)   
- lpfc 8.3.39: Fixed BlockGuard error reporting (James Smart)   
- lpfc 8.3.39: Fixed VPI allocation issues after firmware dump is performed (James Smart)   
- lpfc 8.3.38: Fixed potential mis-interpretation of READ_TOPOLOGY reserved fields (James Smart)   
- lpfc 8.3.38: Fix default value for lpfc_enable_rrq. (James Smart)   
- lpfc 8.3.38: Fixed circular locking dependency and inconsistent lock state issues (James Smart)   
- lpfc 8.3.38: Fixed PT2PT bring up problem for FC SLI4. (James Smart)   
- lpfc 8.3.38: Fixed OXID reuse issue. (James Smart)   
- lpfc 8.3.38: Fixed async FCF modified event to in-use FCF failure to trigger recovery (James Smart)   
- lpfc 8.3.38: Fixed deadlock condition in FCF round robin handling (James Smart)   
- scsilpfc 8.3.38: Fixed bsg timeout handling issues that would result in crashes (James Smart)   
- lpfc 8.3.38: Fixed NMI watch dog panic's when resetting the hba. (James Smart)   
- lpfc 8.3.38: Fixed degraded performance after cable pulls (James Smart)   
- lpfc 8.3.37: Provide support for change_queue_type (James Smart)   
- lpfc: fix potential NULL pointer dereference in lpfc_sli4_rq_put() (Wei Yongjun)   
- lpfc 8.3.37: Fixed infinite loop in lpfc_sli4_fcf_rr_next_index_get. (James Smart)   
- lpfc 8.3.37: Fixed crash due to SLI Port invalid resource count (James Smart)   
- lpfc 8.3.37: Provide support for FCoE protocol dual-chute (ULP) operation (James Smart)   
- lpfc 8.3.37: Fixed stale ndlp state when the node is marked for deferred removal. (James Smart)   
- lpfc 8.3.37: Fix potential memory corruption bug (James Smart)   
- lpfc 8.3.37: Fixed no-context ABTS failed with BA_RJT (James Smart)   
- lpfc 8.3.37: Removed use of NOP mailboxes for interrupt verification (James Smart)   
- lpfc 8.3.37: Fixed exhausted retry for plogi to nameserver. (James Smart)   
- lpfc 8.3.37: Fixed ELS_REC received on the unsolicited receive queue (James Smart)   
- mptfusion: update to LSI version 4.28.20.03 (Jerry Snitselaar) [Orabug: 17307187]  
- turn on kabi check for x86 (Maxim Uvarov)   
- config: CONFIG_X86_INTERNODE_CACHE_SHIFT=7 (Maxim Uvarov)   
- kabi_whitelist_x86_64 (Maxim Uvarov)   
- Ensure memory allocation results are checked throughout the code. (Kris Van Hees)   
- net: sctp: fix NULL pointer dereference in socket destruction (Daniel Borkmann) [Orabug: 17071059]  
- mm: leave pmd_huge_pte when CONFIG_TRANSPARENT_HUGEPAGE disabled (Jerry Snitselaar) [Orabug: 17301856]  
- sparc64 - read_persistent_clock (bob picco)   
- ipv6: call udp_push_pending_frames when uncorking a socket with AF_INET pending data (Hannes Frederic Sowa) [Orabug: 17296551] {CVE-2013-4162} 
- ipv6: ip6_append_data_mtu did not care about pmtudisc and frag_size (Hannes Frederic Sowa) [Orabug: 17296420] {CVE-2013-4163} 
- dm mpath: fix ioctl deadlock when no paths (Hannes Reinecke)   
- dm mpath: enable WRITE SAME support (Mike Snitzer)   
- dm table: fix write same support (Mike Snitzer)   
- dm: rename request variables to bios (Alasdair G Kergon)   
- dm: clean up clone_bio (Alasdair G Kergon)   
- NVMe: Add MSI support (Ramachandra Rao Gajula)   
- NVMe: Use dma_set_mask() correctly (Matthew Wilcox)   
- Return the result from user admin command IOCTL even in case of failure (Chayan Biswas)   
- NVMe: Do not cancel command multiple times (Keith Busch)   
- NVMe: fix error return code in nvme_submit_bio_queue() (Wei Yongjun)   
- NVMe: check for integer overflow in nvme_map_user_pages() (Dan Carpenter)   
- NVMe: Fix a signedness bug in nvme_trans_modesel_get_mp (Vishal Verma)   
- NVMe: Remove redundant version.h header include (Sachin Kamat)   
- NVMe: Use user defined admin ioctl timeout (Keith Busch)   
- NVMe: Simplify Firmware Activate code slightly (Matthew Wilcox)   
- NVMe: Only clear the enable bit when disabling controller (Matthew Wilcox)   
- NVMe: Wait for device to acknowledge shutdown (Matthew Wilcox)   
- NVMe: Schedule timeout for sync commands (Keith Busch)   
- NVMe: Meta-data support in NVME_IOCTL_SUBMIT_IO (Keith Busch)   
- NVMe: Device specific stripe size handling (Keith Busch)   
- NVMe: Split non-mergeable bio requests (Keith Busch)   
- NVMe: Remove dead code in nvme_dev_add (Keith Busch)   
- NVMe: Check for NULL memory in nvme_dev_add (Keith Busch)   
- NVMe: Fix error clean-up on nvme_alloc_queue (Keith Busch)   
- NVMe: Free admin queue on request_irq error (Keith Busch)   
- NVMe: Add scsi unmap to SG_IO (Keith Busch)   
- NVMe: queue usage fixes in nvme-scsi (Keith Busch)   
- NVMe: Set TASK_INTERRUPTIBLE before processing queues (Arjan van de Ven)   
- NVMe: Add a character device for each nvme device (Keith Busch)   
- NVMe: Fix endian-related problems in user I/O submission path (Matthew Wilcox)   
- NVMe: Fix I/O cancellation status on big-endian machines (Matthew Wilcox)   
- NVMe: Fix sparse warnings in scsi emulation (Vishal Verma)   
- NVMe: Don't fail initialisation unnecessarily (Matthew Wilcox)   
- NVMe: Abstract out sector to block number conversion (Matthew Wilcox)   
- NVMe: Use round_jiffies_relative() for the periodic, once-per-second timer (Arjan van de Ven)   
- NVMe: Add nvme-scsi.c (Vishal Verma)   
- NVMe: Add definitions for format command (Vishal Verma)   
- NVMe: Move structures & definitions to header file (Vishal Verma)   
- NVMe: Rename nvme.c to nvme-core.c (Vishal Verma)   
- NVMe: Add discard support for capable devices (Keith Busch)   
- NVMe: Add namespaces with no LBA range feature (Keith Busch)   
- NVMe: Initialize iod nents to 0 (Keith Busch)   
- NVMe: Define SMART log (Keith Busch)   
- NVMe: Add result to nvme_get_features (Keith Busch)   
- NVMe: Set result from user admin command (Keith Busch)   
- NVMe: End queued bio requests when freeing queue (Keith Busch)   
- NVMe: Free cmdid on nvme_submit_bio error (Keith Busch)   
- oracleasm: Compat changes for 3.8 (Martin K. Petersen)   
- oracleasm: Introduce module parameter for block size selection (Martin K. Petersen) [Orabug: 15924773]  
- oracleasm: Data integrity support (Martin K. Petersen)   
- oracleasm: Fix two merge errors (Martin K. Petersen)   
- Oracle ASM Kernel Driver (Martin K. Petersen)   
- megaraid_sas: Big endian support (Martin K. Petersen)   
- megaraid: fix BUG_ON() from incorrect use of delayed work (Xiaotian Feng)   
- aerdrv: Enhanced AER logging (Lance Ortiz) [Orabug: 17293976]  
- aerdrv: Trace Event for PCI Express Advanced Error Reporting (Lance Ortiz) [Orabug: 17293976]  
- [SCSI] scsi_dh_alua: Add module parameter to allow failover to non preferred path without STPG (Stewart, Sean)   
- [SCSI] Don't attempt to send extended INQUIRY command if skip_vpd_pages is set (Martin K. Petersen)   
- [SCSI] sd: Update WRITE SAME heuristics (Martin K. Petersen)   
- [SCSI] 3w-xxxx: Create sense buffer for unsupported commands (Martin K. Petersen)   
- [SCSI] Workaround for disks that report bad optimal transfer length (Martin K. Petersen)   
- [SCSI] Allow error handling timeout to be specified (Martin K. Petersen)   
- [SCSI] scsi_dh_alua: fix stpg sense handling (Mike Christie)   
- [SCSI] sd_dif: problem with verify of type 1 protection information (PI) (Jeremy Higdon)   
- [SCSI] sd: avoid deadlocks when running under multipath (Hannes Reinecke)   
- x86/mce: Rework cmci_rediscover() to play well with CPU hotplug (Srivatsa S. Bhat) [Orabug: 17293976]  
- ACPI / APEI: fix error return code in ghes_probe() (Wei Yongjun) [Orabug: 17293976]  
- hwmon: (adm1021) Strengthen chip detection for ADM1021, LM84 and MAX1617 (Guenter Roeck) [Orabug: 17293976]  
- fnic: update from mainline 1.5.0.2 to cisco 1.5.0.45 (Jerry Snitselaar) [Orabug: 17293525]  
- cgroup: fix bogus kernel warnings when cgroup_create() failed (Li Zefan) [Orabug: 16448051]  
- cgroup: remove a NULL check in cgroup_exit() (Li Zefan) [Orabug: 16448051]  
- cgroup: fix cgroup_path() vs rename() race (Li Zefan) [Orabug: 16448051]  
- cgroup: fix cgroup_rmdir() vs close(eventfd) race (Li Zefan) [Orabug: 16448051]  
- cgroup: fail if monitored file and event_control are in different cgroup (Li Zefan) [Orabug: 16448051]  
- cgroup: fix a subtle bug in descendant pre-order walk (Tejun Heo) [Orabug: 16448051]  
- memcg: do not create memsw files if swap accounting is disabled (Michal Hocko) [Orabug: 16448051]  
- memcg: initialize kmem-cache destroying work earlier (Konstantin Khlebnikov) [Orabug: 16448051]  
- mm: memcg: remove incorrect VM_BUG_ON for swap cache pages in uncharge (Johannes Weiner) [Orabug: 16448051]  
- memcg: fix memcg_cache_name() to use cgroup_name() (Michal Hocko) [Orabug: 16448051]  
- blkcg: fix "scheduling while atomic" in blk_queue_bypass_start (Jun'ichi Nomura) [Orabug: 16448051]  
- device_cgroup: don't grab mutex in rcu callback (Jerry Snitselaar) [Orabug: 16448051]  
- l2tp: prevent tunnel creation on netns mismatch (Tom Parkin) [Orabug: 16448051]  
- netns: fdb: allow unprivileged users to add/del fdb entries (Gao feng) [Orabug: 16448051]  
- netns: ebtable: allow unprivileged users to operate ebtables (Gao feng) [Orabug: 16448051]  
- netns: bridge: allow unprivileged users add/delete mdb entry (Gao feng) [Orabug: 16448051]  
- netns: bond: allow unprivileged users to control bond device (Gao feng) [Orabug: 16448051]  
- netfilter: nf_ct_reasm: fix per-netns sysctl initialization (Michal Kubeček) [Orabug: 16448051]  
- config: enable CONFIG_XFS_WARN for debug builds (Jerry Snitselaar) [Orabug: 17271899]  
- xfs: introduce CONFIG_XFS_WARN (Dave Chinner) [Orabug: 17271899]  
- xfs: recheck buffer pinned status after push trylock failure (Brian Foster) [Orabug: 17271899]  
- xfs: remove log force from xfs_buf_trylock() (Brian Foster) [Orabug: 17271899]  
- xfs: ensure we capture IO errors correctly (Dave Chinner) [Orabug: 17271899]  
- xfs: fallback to vmalloc for large buffers in xfs_attrlist_by_handle (Eric Sandeen) [Orabug: 17271899]  
- xfs: fallback to vmalloc for large buffers in xfs_compat_attrlist_by_handle (Eric Sandeen) [Orabug: 17271899]  
- ext4: fix corruption when online resizing a fs with 1K block size (Maarten ter Huurne) [Orabug: 17279036]  
- ext4: fix data integrity for ext4_sync_fs (Jerry Snitselaar) [Orabug: 17279036]  
- ext4: fix overflow when counting used blocks on 32-bit architectures (Jan Kara) [Orabug: 17279036]  
- ext4: fix data offset overflow in ext4_xattr_fiemap() on 32-bit archs (Jan Kara) [Orabug: 17279036]  
- ext4: fix overflows in SEEK_HOLE, SEEK_DATA implementations (Jerry Snitselaar) [Orabug: 17279036]  
- ext4: fix data offset overflow on 32-bit archs in ext4_inline_data_fiemap() (Jan Kara) [Orabug: 17279036]  
- ext4: fix type-widening bug in inode table readahead code (Theodore Ts'o) [Orabug: 17279036]  
- ext4: mext_insert_extents should update extent block checksum (Darrick J. Wong) [Orabug: 17279036]  
- ext4: fix deadlock with quota feature (Jan Kara) [Orabug: 17279036]  
- qlcnic: update from 5.0.30 to 5.2.43 (Jerry Snitselaar) [Orabug: 17267160]  
- Remove pre-alpha features for release. (Kris Van Hees) [Orabug: 17076008]  
- CONFIG_UPROBES is needed by CONFIG_DT_FASTTRAP, not CONFIG_DTRACE. (Nick Alcock) [Orabug: 17076008]  
- CONFIG_DTRACE should depend on CONFIG_UPROBES. (Nick Alcock) [Orabug: 17076008]  
- SPEC: Include all sources regardless of arch. (Nick Alcock) [Orabug: 17076008]  
- SPEC: Changes for UEK merge. (Nick Alcock) [Orabug: 17076008]  
- Fix loss of error code from waitid() when info is provided. (Nick Alcock) [Orabug: 17076008]  
- Make old_rsp available to kernel modules. (Kris Van Hees) [Orabug: 17076008]  
- waitfd selftest: dike out some dead code. (Nick Alcock) [Orabug: 17076008]  
- Introduce poll_wait_fixed(), and use it in waitfds. (Nick Alcock) [Orabug: 17076008]  
- No longer reference 'ctf.ko.unsigned' in CTF debuginfo stripping machinery. (Nick Alcock) [Orabug: 17076008]  
- SPEC: Do not sign modules, pro tem. (Nick Alcock) [Orabug: 17076008]  
- SPEC: Fix the -g1 debuginfo hack. (Nick Alcock) [Orabug: 17076008]  
- Add waitfd(), and a testcase for it. (Nick Alcock) [Orabug: 17076008]  
- Ensure that arg6 through arg9 get retrieved correctly for USDT probes. (Kris Van Hees) [Orabug: 17076008]  
- Finish the implementation of is-enabled USDT probes. (Kris Van Hees) [Orabug: 17076008]  
- Fixes for tracepoint cleanup. (Kris Van Hees) [Orabug: 17076008]  
- Remove unnecessary debugging output. (Kris Van Hees) [Orabug: 17076008]  
- Update syscall tracing in view of Linux 3.8 changes. (Kris Van Hees) [Orabug: 17076008]  
- USDT implementation (phase 2). (Kris Van Hees) [Orabug: 17076008]  
- Revamp and split up DTrace headers.  Add ioctl() debugging machinery. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: blacklist certain structure members entirely. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Repair faulty indentation. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Split the absolute-file-name caching machinery out of type_id(). (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: sentinelize str_appendn(). (Nick Alcock) [Orabug: 17076008]  
- ptrace: Add PTRACE_GETMAPFD. (Nick Alcock) [Orabug: 17076008]  
- Update execve() syscall probe support. (Kris Van Hees) [Orabug: 17076008]  
- Add support for an SDT probe getting called from multiple functions. (Kris Van Hees) [Orabug: 17076008]  
- Move SDT call location for surrender probe. (Kris Van Hees) [Orabug: 17076008]  
- USDT implementation (Phase 1). (Kris Van Hees) [Orabug: 17076008]  
- Remove incorrect FBT support code. (Kris Van Hees) [Orabug: 17076008]  
- Move psinfo to its own header file. (Kris Van Hees) [Orabug: 17076008]  
- Update copyright statements. (Kris Van Hees) [Orabug: 17076008]  
- dwarf2ctf: Update the shared CTF file right after initialization. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Improve debugging and indentation fixes. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf doc revisions. (Nick Alcock) [Orabug: 17076008]  
- Internal performance measurement support code. (Kris Van Hees) [Orabug: 17076008]  
- Disable KVM steal-time accounting when DTrace is in use. (Nick Alcock) [Orabug: 17076008]  
- Cosmetic improvements to CTF linking. (Nick Alcock) [Orabug: 17076008]  
- Remove a few obsolete probes. (Kris Van Hees) [Orabug: 17076008]  
- Cater for changes in the way the kernel is linked. (Kris Van Hees) [Orabug: 17076008]  
- Miscellaneous 3.6 porting work. (Kris Van Hees) [Orabug: 17076008]  
- Fix up rq.dtrace_cpu_info member. (Kris Van Hees) [Orabug: 17076008]  
- gitignore: Ignore objects.builtin and dwarf2ctf. (Nick Alcock) [Orabug: 17076008]  
- Fix outright typos in the 3.6 forward-port. (Nick Alcock) [Orabug: 17076008]  
- Remove obsolete static probe documentation. (Kris Van Hees) [Orabug: 17076008]  
- DTrace-independent CTF. (Nick Alcock) [Orabug: 17076008]  
- Do not build in CTF data for no-longer-built-in modules. (Nick Alcock) [Orabug: 17076008]  
- Document dwarf2ctf. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Extend the deduplication blacklist. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Improve error message on internal deduplication error. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Note a future enhancement. (Nick Alcock) [Orabug: 17076008]  
- Document parameters to die_to_ctf(). (Nick Alcock) [Orabug: 17076008]  
- Do not construct objects.builtin if CTF is not being built. (Nick Alcock) [Orabug: 17076008]  
- Do not build dwarf2ctf nor attempt to use it if !CONFIG_DTRACE. (Nick Alcock) [Orabug: 17076008]  
- SPEC: Rename the DTrace kernel to kernel-uek-dtrace-. (Nick Alcock) [Orabug: 17076008]  
- SPEC: strip kernel modules using objcopy, not eu-strip (Nick Alcock) [Orabug: 17076008]  
- SPEC: do not strip non-debugging sections from kernel modules. (Nick Alcock) [Orabug: 17076008]  
- SPEC: build firmware. (Nick Alcock) [Orabug: 17076008]  
- Additional action support (and bug fixes). (Kris Van Hees) [Orabug: 17076008]  
- Get rid of debugging code. (Kris Van Hees) [Orabug: 17076008]  
- Add psinfo/cpuinfo OS level support. (Kris Van Hees) [Orabug: 17076008]  
- Removed debugging output (1 line). (Kris Van Hees) [Orabug: 17076008]  
- Change the DTrace startup handling (at boot time) for SDT. (Kris Van Hees) [Orabug: 17076008]  
- Cleanup (and adding) of SDT probe points. (Kris Van Hees) [Orabug: 17076008]  
- Write the CTF files for standalone modules to a subdir of the module directory. (Nick Alcock) [Orabug: 17076008]  
- Adapt to the libdtrace-ctf devel package split. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: unnamed structure/union support. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: recurse_ctf() -> die_to_ctf(). (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: fix the signed-modules case. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: correctly propagate IDs for array types. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: fix off-by-one in emitted array bounds. (Nick Alcock) [Orabug: 17076008]  
- Fix tiny comment typo. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: blacklist certain modules from deduplication. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: include enumeration types inside functions. (Nick Alcock) [Orabug: 17076008]  
- New IO provider probes: start, done, wait-start, wait-done New sched provides probes: enqueue, dequeue, wakeup, preempt, remain-cpu, change-pri, surrender (Note that the preempt probe currently passes a debugging argument that will be removed in the future to match the argument-less version in the documentation.) (Kris Van Hees) [Orabug: 17076008]  
- Fix to handle multiple SDT-based probes in a single function. (Kris Van Hees) [Orabug: 17076008]  
- DTrace: require assembler symbol stripping and debug info. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: Fix array dimensions. (Nick Alcock) [Orabug: 17076008]  
- Change the name of the CTF section in kernel modules. (Nick Alcock) [Orabug: 17076008]  
- Fix a bug in the SDT probe location generator, where it could accidentally add the address of a non-function identifier to the SDT list (e.g. watchdog occurs both in the uninitialised data section (BSS) and the text section). (Kris Van Hees) [Orabug: 17076008]  
- dwarf2ctf: major duplicate detection fixes. (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: optimize type_id() and fix array dimension lookup. (Nick Alcock) [Orabug: 17076008]  
- Changed the logic for determining SDT probe point locations because the previous version did not account for probes that might be placed in non-.text segments.  New code also avoids extra passes that were not necessary. (Kris Van Hees) [Orabug: 17076008]  
- dwarf2ctf: store away the types and names of non-static global variables. (Nick Alcock) [Orabug: 17076008]  
- Set the name of the parent of child modules to "dtrace_ctf". (Nick Alcock) [Orabug: 17076008]  
- dwarf2ctf: clarify comments, improve a type name. (Nick Alcock) [Orabug: 17076008]  
- Force dtrace_ctf.ko to be loaded whenever dtrace.ko is. (Nick Alcock) [Orabug: 17076008]  
- Generate CTF information for the kernel. (Nick Alcock) [Orabug: 17076008]  
- Drop rogue debugging statements. (Nick Alcock) [Orabug: 17076008]  
- Provide symbol sizes in /proc/kallmodsyms. (Nick Alcock) [Orabug: 17076008]  
- Add a dummy dtrace_ctf.ko module. (Nick Alcock) [Orabug: 17076008]  
- Fix /proc/kallmodsyms population bugs. (Nick Alcock) [Orabug: 17076008]  
- kallsyms: work in a clean tree, and a non-modular tree. (Nick Alcock) [Orabug: 17076008]  
- kallsyms: work with older glibc. (Nick Alcock) [Orabug: 17076008]  
- Don't depend on dtrace-user. (Nick Alcock) [Orabug: 17076008]  
- Add /proc/kallmodsyms. (Nick Alcock) [Orabug: 17076008]  
- - sched-tick SDT probe. - FBT probe point discovery and probe creation. - Moving code around for the kernel pseudo-module handling since it gets used   by both the SDT code and the FBT code. (Kris Van Hees) [Orabug: 17076008]  
- Delete an obsolete release script. (Nick Alcock) [Orabug: 17076008]  
- Changed from using mutex_is_locked() to a new mutex_owned(), in support of the Solaris MUTEX_HELD() macro.  The former was merely testing whether the mutex was locked, whereas the real test needed here is whether the mutex is held by the current thread. (Kris Van Hees) [Orabug: 17076008]  
- Fix signed division and modulo operations in DIF. Ensure that SDT probe points are patched with a NOP sequence at boot time. Remove debugging output during SDT registration. (Kris Van Hees) [Orabug: 17076008]  
- Make sure the insn length is initialized in the right branch of the die notifier. (Nick Alcock) [Orabug: 17076008]  
- Ensure that the trap handler is regisstered only once. Register with first use, (Kris Van Hees) [Orabug: 17076008]  
- Ensure that the die notifier hook is installed whenever DTrace is enabled, since page fault and general protection fault handling depends on it, and that is needed for safe memory access support in DTrace. (Kris Van Hees) [Orabug: 17076008]  
- Adding missing files for PF/GPF support. (Kris Van Hees) [Orabug: 17076008]  
- Support for page fault and general protection fault detection for DTrace, to ensure that DTrace memory access faults are non-fatal. (Kris Van Hees) [Orabug: 17076008]  
- Fix incorrect probe point name. (Kris Van Hees) [Orabug: 17076008]  
- Added lwp-exit and lwp-create SDT probe points. Change the DRELOC tag in make output to DT-SDT. (Kris Van Hees) [Orabug: 17076008]  
- SDT implementation (core kernel support for providing a list of static probe points for the kernel pseudo-module, dtrace SDT meta-provider support, ...). Also, new script (dtrace_sdt.sh) to extract locations of SDT probe points in the core kernel. (Kris Van Hees) [Orabug: 17076008]  
- Enable processing the SDT probe point info at boot time (before SMP is actually enabled), if DTrace SDT support has been enabled (built-in or as module).  For now, provide some verbose info on the probe points getting resolved. (Kris Van Hees) [Orabug: 17076008]  
- Fix resolving addresses of relocation records for SDT probe points.  The addresses were being calculated based on the wrong starting point (_stext whereas it ought to be _text), and the base was not taken into account. Fixed the writing of NOPs in the location of the probe point calls, since the existing case was causing kernel paging faults.  Made the add_nops() function in alternative.c non-static so it can be used in sdt_register. Use add_nops() to select the most appropriate NOP sequence for replacing the probe point call, and write the NOPs using text_poke(). (Kris Van Hees) [Orabug: 17076008]  
- Fixed the allocation of cyclics that was the cuase for some obscure crashes during the testsuite execution.  Problem was that cyclics were being allocated in chunks, with a new array being allocated as (prev-size + chink-size), and then the old entries being copied over.  However, because the hrtimer struct is embedded in the cyclic struct, this meant that hrtimer structs were being moved outside the hrtimer code. (Kris Van Hees) [Orabug: 17076008]  
- Removed dead code (was #if 0 ... #endif).  Cleaned up ;; -> ;. (Kris Van Hees) [Orabug: 17076008]  
- Implementation for tracing stub-based system calls.  Due to the need for specialized code handling (mainly passing in a pt_regs structure as one of the arguments), some syscalls are called through a stub in assembly code. We duplicate the stub cdode in dtrace_stubs_x86_64.S, but instead of calling the actual syscall implementation code call our own syscall-specific handler, which ensures that entry and return probes are called as enabled, and then call the underlying implementation directly for handling the syscall. (Kris Van Hees) [Orabug: 17076008]  
- Allow for pushes of multiple branches and pushes of merged-back branches. (Nick Alcock) [Orabug: 17076008]  
- Remove some debugging that crept in. (Nick Alcock) [Orabug: 17076008]  
- Fix git commit URL. (Nick Alcock) [Orabug: 17076008]  
- push-dtrace-release: Fix argument checking. (Nick Alcock) [Orabug: 17076008]  
- Do not rely on 'git clone --branch'. (Nick Alcock) [Orabug: 17076008]  
- Release-pushing script. (Nick Alcock) [Orabug: 17076008]  
- Stacktrace dumping has been moved to the GPL-licensed dtrace_os.c because it depends on a symbol that is exported as GPL-only.  Functionality in dtrace_isa that requires stacktrace dumping can now use dtrace_stacktrace(). (Kris Van Hees) [Orabug: 17076008]  
- Fix porting issues from 2.6.32 to 2.6.39. Disable stub_* based syscalls (for now). (Kris Van Hees) [Orabug: 17076008]  
- Move cyclic.h into include/linux. (Nick Alcock) [Orabug: 17076008]  
- Finish GPL/CDDL splitting work. (Nick Alcock) [Orabug: 17076008]  
- CDDL copyrights for everything needing it. (Nick Alcock) [Orabug: 17076008]  
- Migrate dtrace to a standalone module, situated at the top level of the tree. (Nick Alcock) [Orabug: 17076008]  
- Fix walltimestamp. (Nick Alcock) [Orabug: 17076008]  
- Changes in how we collect the names o system calls.  Used to use the ftrace syscall meta info and the nr-to-meta functionality.  Now populates the systrace info structure statically at kernel compile time.  This means that the DTrace code no longer depends on ftrace. (Kris Van Hees) [Orabug: 17076008]  
- No more use for ktime_get_nongpl().  We an now use dtrace_gethrtime(). (Kris Van Hees) [Orabug: 17076008]  
- Implementation for syscall entry/return probes.  Makes the sys call table writable, and replaces the function pointer for select syscalls with the address of a wrapper function to enable entry and return probe firing. (Kris Van Hees) [Orabug: 17076008]  
- Conflict with CONFIG_DEBUG_LOCK_ALLOC. (Nick Alcock) [Orabug: 17076008]  
- Dependency fixes for dtrace. (Nick Alcock) [Orabug: 17076008]  
- Added CONFIG_DT_DEBUG_MUTEX option to enable printing all locations where a mutex is locked and unlocked. Implemented aggregations using the idr mechanism rather than the Solaris-based 1-byte allocation technique to get unique IDs. Various cleanup and small changes. (Kris Van Hees) [Orabug: 17076008]  
- Update sdt provider (sdt_mod.c) with lots of functions. NOTES: - module loadcnt may need more work. - kernel_searchsym() is incomplete (see FIXMEs). Add sdt_subr.c and build it in Makefile. Add str_impl.h for internal sdt use. Add more fields to linux/module.h for static probe bookkeeping. (Randy Dunlap) [Orabug: 17076008]  
- Add dtrace_module_loaded() and dtrace_module_unloaded(). Give the static probes in the kernel image a module name of   "kernel_builtins" and a module state of LIVE. Fix an extra-paren typo in dtrace_dev.c. NOTE:  This is incomplete.  There are a few TBDs and FIXMEs   in this patch. (Randy Dunlap) [Orabug: 17076008]  
- Turn on gcov profiliing for the RPM builds by default. (Nick Alcock) [Orabug: 17076008]  
- Turn on gcov profiling in the kernel/dtrace directory by default. (Nick Alcock) [Orabug: 17076008]  
- Adding framework for a test provider that fires a specific probe on request. Adding previously missing (and unused) exported functions: (Kris Van Hees) [Orabug: 17076008]  
- File needed for rpm builds to ensure DTrace is enabled as modules. (Kris Van Hees) [Orabug: 17076008]  
- add Documentation/dtrace_static_probes.txt, which is a directory of all static probes in the kernel tree. (Randy Dunlap) [Orabug: 17076008]  
- Remove license and add copyright. (Randy Dunlap) [Orabug: 17076008]  
- Build sdt_register.c into the kernel. (Nick Alcock) [Orabug: 17076008]  
- Add missing include needed for DTrace probes. (Nick Alcock) [Orabug: 17076008]  
- - convert relative probepoint relocation addresses to absolute:   this should have been done by the top-level Makefile, but it must   have a dependency problem since the generated vmlinux_info.S has   the correct info in it but the vmlinux_info.o file does not AND   the .S file was created AFTER the .o file. - convert calls to dtrace stub RETs to NOPs; (Randy Dunlap) [Orabug: 17076008]  
- Add some dtrace static probes that are easy to trigger. See the static probes directory listing for a summary of all dtrace static probes. (Randy Dunlap) [Orabug: 17076008]  
- Added dependency for FTRACE and FTRACE_SYSCALLS for the SYSTRACE provider. (Kris Van Hees) [Orabug: 17076008]  
- Remove debugging statements. (Kris Van Hees) [Orabug: 17076008]  
- Reduce the unintended ordering dependency (_text before _stext) when scanning the relocs info file. (Randy Dunlap) [Orabug: 17076008]  
- Adding debug code to track probe processing through BEGIN probe enabling. Adding minimal implementation of cyclic functionality (based on hrtimer) as an additional to the core kernel, linked in when dtrace is enabled (be it as module, or compiled in).  Exports cyclic_add() and cyclic_remove(). Removed former cyclic stub implementation (cyclic.c). (Kris Van Hees) [Orabug: 17076008]  
- The systrace provider depends on the FTRACE_SYSCALLS kernel feature. The systrace provider is actually called syscall on Solaris, so it has been renamed on the Linux side (i.e. it registers itself as syscall). Added some debug statements to track probe searches better. The probes/probematch ioctl handling should return -ESRCH when the last hit has been returned already. (Kris Van Hees) [Orabug: 17076008]  
- Reading the dtrace relocation info table could fail on a boundary condition. Fix by counting the string terminator (null) byte.  Now works for my 4 test cases. (Randy Dunlap) [Orabug: 17076008]  
- Read and use the _stext value for adding to relative relocation info to make it absolute. This works for my 4 test cases.  It was derived by examination and discovery.  There could be cases where it does not work, e.g. in other text sections. (Randy Dunlap) [Orabug: 17076008]  
- Removed || CONFIG_DT_SDT_MODULE from conditional surrounding call to dtrace_register_builtins() because that function does not exist in the kernel proper when DTrace is compiled as kernel modules. (Kris Van Hees) [Orabug: 17076008]  
- Add missing files (present in the CVS repo but not in git). (Kris Van Hees) [Orabug: 17076008]  
- systrace uses syscall_nr_to_meta, which is only available when FTRACE_SYSCALLS is enabled, so make systrace depend on FTRACE_SYSCALLS. (Randy Dunlap) [Orabug: 17076008]  
- Test push. (Kris Van Hees) [Orabug: 17076008]  
- Test commit (reverting previous test commit). (Kris Van Hees) [Orabug: 17076008]  
- Just a very small change to check whether git push will work fine by someone other than Nix. (Kris Van Hees) [Orabug: 17076008]  
- Initial import of DTrace kernelspace code. (Nick Alcock) [Orabug: 17076008]  

* Thu Aug 8 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-8.el6uek] 
- ipoib fix compilation if rcu debug enabled (Maxim Uvarov)   
- qlge: update from v1.00.00.31 to v1.00.00.32 (Jerry Snitselaar) [Orabug: 17267206]  
- qla2xxx: update from mainline 8.04.00.08-k to qlogic version 8.05.00.03.39.0-k (Saurav Kashyap) [Orabug: 17277380]  
- config file change for eIPoIB (Ajaykumar Hotchandani)   
- bnx2i: update from mainline version 2.7.2.2 to broadcom version 2.7.6.1d (Jerry Snitselaar) [Orabug: 17024889]  
- bnx2fc: update from mainline version 1.0.12 to broadcom version 2.3.4 (Jerry Snitselaar) [Orabug: 17024889]  
- bnx2x: update from mainline version 1.78.00-0 to broadcom version 1.76.54 (Jerry Snitselaar) [Orabug: 17024889]  
- cnic: update from mainline version 2.5.16 to broadcom version 2.5.16g (Jerry Snitselaar) [Orabug: 17024889]  
- bnx2: update from mainline version 2.2.3 to broadcom version 2.2.3n (Jerry Snitselaar) [Orabug: 17024889]  
- tg3: update from mainline version 3.128 to broadcom version 3.131d (Jerry Snitselaar) [Orabug: 17024889]  
- tmpfs: add support for read_iter and write_iter (Hugh Dickins) [Orabug: 16371286]
- ubifs: convert file ops from aio_read/write to read/write_iter (Dave Kleikamp) [Orabug: 16371286]
- ecrpytfs: Convert aio_read/write ops to read/write_iter (Dave Kleikamp) [Orabug: 16371286]
- afs: add support for read_iter and write_iter (Dave Kleikamp) [Orabug: 16371286]
- udf: convert file ops from aio_read/write to read/write_iter (Dave Kleikamp) [Orabug: 16371286]
- gfs2: Convert aio_read/write ops to read/write_iter (Dave Kleikamp) [Orabug: 16371286]
- xfs: add support for read_iter and write_iter (Dave Kleikamp) [Orabug: 16371286]
- block_dev: add support for read_iter, write_iter (Asias He) [Orabug: 16371286]
- btrfs: add support for read_iter and write_iter (Dave Kleikamp) [Orabug: 16371286]
- nfs: simplify swap (Dave Kleikamp) [Orabug: 16371286]
- nfs: add support for read_iter, write_iter (Dave Kleikamp) [Orabug: 16371286]
- ext4: add support for read_iter and write_iter (Dave Kleikamp) [Orabug: 16371286]
- ocfs2: add support for read_iter, write_iter, and direct_IO_bvec (Zach Brown) [Orabug: 16371286]
- fs: add read_iter and write_iter to several file systems (Dave Kleikamp) [Orabug: 16371286]
- fs: use read_iter and write_iter rather than aio_read and aio_write (Dave Kleikamp) [Orabug: 16371286]
- fs: create file_readable() and file_writable() functions (Dave Kleikamp) [Orabug: 16371286]
- loop: use aio to perform io on the underlying file (Zach Brown) [Orabug: 16371286]
- bio: add bvec_length(), like iov_length() (Zach Brown) [Orabug: 16371286]
- aio: add aio support for iov_iter arguments (Zach Brown) [Orabug: 16371286]
- aio: add aio_kernel_() interface (Zach Brown) [Orabug: 16371286]
- fs: pull iov_iter use higher up the stack (Zach Brown) [Orabug: 16371286]
- dio: add bio_vec support to __blockdev_direct_IO() (Dave Kleikamp) [Orabug: 16371286]
- dio: Convert direct_IO to use iov_iter (Dave Kleikamp) [Orabug: 16371286]
- iov_iter: let callers extract iovecs and bio_vecs (Zach Brown) [Orabug: 16371286]
- iov_iter: add a shorten call (Zach Brown) [Orabug: 16371286]
- iov_iter: add bvec support (Zach Brown) [Orabug: 16371286]
- iov_iter: ii_iovec_copy_to_user should pre-fault user pages (Dave Kleikamp) [Orabug: 16371286]
- iov_iter: hide iovec details behind ops function pointers (Zach Brown) [Orabug: 16371286]
- fuse: convert fuse to use iov_iter_copy_[to|from]_user (Dave Kleikamp) [Orabug: 16371286]
- iov_iter: add __iovec_copy_to_user() (Dave Kleikamp) [Orabug: 16371286]
- iov_iter: add copy_to_user support (Zach Brown) [Orabug: 16371286]
- iov_iter: iov_iter_copy_from_user() should use non-atomic copy (Dave Kleikamp) [Orabug: 16371286]
- iov_iter: move into its own file (Zach Brown) [Orabug: 16371286]
- sparc64 - color correction (bob picco)   
- [ixgbe] hold rcu_read_lock() when derefencing rcu (Maxim Uvarov) [Orabug: 17213023]  
- mutex: Back out architecture specific check for negative mutex count (Waiman Long) [Orabug: 17237224]  
- mutex: Queue mutex spinners with MCS lock to reduce cacheline contention (Waiman Long) [Orabug: 17237224]  
- mutex: Make more scalable by doing less atomic operations (Waiman Long) [Orabug: 17237224]  
- mutex: Move mutex spinning code from sched/core.c back to mutex.c (Waiman Long) [Orabug: 17237224]  
- ipc/sem.c: Fix missing wakeups in do_smart_update_queue() (Manfred Spraul) [Orabug: 17237239]  
- ipc,sem: fix semctl(..., GETNCNT) (Rik van Riel) [Orabug: 17237239]  
- ipc,sem: fix semctl(..., GETZCNT) (Rik van Riel) [Orabug: 17237239]  
- ipc: simplify rcu_read_lock() in semctl_nolock() (Linus Torvalds) [Orabug: 17237239]  
- ipc: simplify semtimedop/semctl_main() common error path handling (Linus Torvalds) [Orabug: 17237239]  
- ipc: move sem_obtain_lock() rcu locking into the only caller (Linus Torvalds) [Orabug: 17237239]  
- ipc: fix double sem unlock in semctl error path (Linus Torvalds) [Orabug: 17237239]  
- ipc: move the rcu_read_lock() from sem_lock_and_putref() into callers (Linus Torvalds) [Orabug: 17237239]  
- ipc: sem_putref() does not need the semaphore lock any more (Linus Torvalds) [Orabug: 17237239]  
- ipc: move rcu_read_unlock() out of sem_unlock() and into callers (Linus Torvalds) [Orabug: 17237239]  
- ipc: fix GETALL/IPC_RM race for sysv semaphores (Al Viro) [Orabug: 17237239]  
- ipc/msg.c: use list_for_each_entry_[safe] for list traversing (Nikola Pajkovsky) [Orabug: 17237239]  
- ipc,sem: fine grained locking for semtimedop (Rik van Riel) [Orabug: 17237239]  
- ipc,sem: have only one list in struct sem_queue (Rik van Riel) [Orabug: 17237239]  
- ipc,sem: open code and rename sem_lock (Rik van Riel) [Orabug: 17237239]  
- ipc,sem: do not hold ipc lock more than necessary (Davidlohr Bueso) [Orabug: 17237239]  
- ipc: introduce lockless pre_down ipcctl (Davidlohr Bueso) [Orabug: 17237239]  
- ipc: introduce obtaining a lockless ipc object (Davidlohr Bueso) [Orabug: 17237239]  
- ipc: remove bogus lock comment for ipc_checkid (Davidlohr Bueso) [Orabug: 17237239]  
- ipc/msgutil.c: use linux/uaccess.h (HoSung Jung) [Orabug: 17237239]  
- ipc: refactor msg list search into separate function (Peter Hurley) [Orabug: 17237239]  
- ipc: simplify msg list search (Peter Hurley) [Orabug: 17237239]  
- ipc: implement MSG_COPY as a new receive mode (Peter Hurley) [Orabug: 17237239]  
- ipc: remove msg handling from queue scan (Peter Hurley) [Orabug: 17237239]  
- ipc: set EFAULT as default error in load_msg() (Peter Hurley) [Orabug: 17237239]  
- ipc: tighten msg copy loops (Peter Hurley) [Orabug: 17237239]  
- ipc: separate msg allocation from userspace copy (Peter Hurley) [Orabug: 17237239]  
- ipc: clamp with min() (Peter Hurley) [Orabug: 17237239]  
- rwsem: check counter to avoid cmpxchg calls (Davidlohr Bueso) [Orabug: 17237186]  
- rwsem: no need for explicit signed longs (Davidlohr Bueso) [Orabug: 17237186]  
- x86 rwsem: avoid taking slow path when stealing write lock (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: do not block readers at head of queue if other readers are active (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: implement support for write lock stealing on the fastpath (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: simplify __rwsem_do_wake (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: skip initial trylock in rwsem_down_write_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: avoid taking wait_lock in rwsem_down_write_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: use cmpxchg for trying to steal write lock (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: more agressive lock stealing in rwsem_down_write_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: simplify rwsem_down_write_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: simplify rwsem_down_read_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: move rwsem_down_failed_common code into rwsem_down_{read,write}_failed (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: shorter spinlocked section in rwsem_down_failed_common() (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: make the waiter type an enumeration rather than a bitmask (Michel Lespinasse) [Orabug: 17237186]  
- rwsem: Implement writer lock-stealing for better scalability (Alex Shi) [Orabug: 17237186]  
- rwsem-spinlock: Implement writer lock-stealing for better scalability (Yuanhan Liu) [Orabug: 17237186]  
- mpt3sas: update from v02.100.00.00 to v3.00.00.00 (Sreekanth Reddy) [Orabug: 17249239]  
- sched: Change position of resched_cpu() in load_balance() (Joonsoo Kim) [Orabug: 16988083]  
- sched: Move up affinity check to mitigate useless redoing overhead (Joonsoo Kim) [Orabug: 16988083]  
- sched: Prevent to re-select dst-cpu in load_balance() (Joonsoo Kim) [Orabug: 16988083]  
- sched: Explicitly cpu_idle_type checking in rebalance_domains() (Joonsoo Kim) [Orabug: 16988083]  
- sched: Rename load_balance_tmpmask to load_balance_mask (Joonsoo Kim) [Orabug: 16988083]  
- sched: Don't consider other cpus in our group in case of NEWLY_IDLE (Joonsoo Kim) [Orabug: 16988083]  
- sched: Fix init NOHZ_IDLE flag (Vincent Guittot) [Orabug: 16988083]  
- sched: Fix select_idle_sibling() bouncing cow syndrome (Mike Galbraith) [Orabug: 16988083]  
- disable mlx5 compilation (Ajaykumar Hotchandani)   
- xfs: Fix the logic check for all quotas being turned off (Chandra Seetharaman)   
- xfs: return FIEMAP_EXTENT_UNKNOWN for delayed allocation extent (Jie Liu)   
- xfs: Don't keep silent if sunit/swidth can not be changed via mount (Jie Liu)   
- xfs: fix rounding in xfs_free_file_space (Dave Chinner)   
- FSX on 512 byte block size filesystems has been failing for some time with corrupted data. The fault dates back to the change in the writeback data integrity algorithm that uses a mark-and-sweep approach to avoid data writeback livelocks. (Dave Chinner)   
- xfs: don't free EFIs before the EFDs are committed (Dave Chinner)   
- xfs: Fix WARN_ON(delalloc) in xfs_vm_releasepage() (Jan Kara)   
- xfs: fix potential infinite loop in xfs_iomap_prealloc_size() (Brian Foster)   
- hxge: add support for Oracle 10Gb Ethernet adapter (James Puthukattukaran) [Orabug: 16443155]  
- rds: complete port of RDS from UEK2 (2.6.39-400.107.0.el5uek) (Venkat Venkatsubra)   
- rds: RDS files of UEK2 (2.6.39-400.107.0.el5uek) as is (Venkat Venkatsubra)   
- rds: Add rds.h file (Ajaykumar Hotchandani)   
- Enable SDP build in config file. (Ajaykumar Hotchandani)   
- remove drivers/infiniband/debug (Ajaykumar Hotchandani)   
- Removed srp_1.5.3 (Ajaykumar Hotchandani)   
- Revert "mlx4_core: use __cancel_delayed_work in IRQ context" (Ajaykumar Hotchandani)   
- sdp: fix cpu lock-up when sdp call ib_fmr_pool_map_phys (Shamir Rabinovitch)   
- sdp: IB_CQ_VECTOR_LEAST_ATTACHED will not be supported in ofed-2.0 (Shamir Rabinovitch)   
- sdp: port sdp to latest devel branch (Shamir Rabinovitch)   
- sdp: copy sdp from uek-2.0 to ofed-2.0 (Shamir Rabinovitch)   
- iser: panic on iser login/logout (Shamir Rabinovitch) [Orabug: 16313854]  
- mlx4_en: Align timestamping support with upstream kernel (Saeed Mahameed)   
- mlx4_ib: clear comp mask bit of deleted GUID entries after deletion (Saeed Mahameed)   
- ib_core: fixed resource leak in case of error (Saeed Mahameed)   
- IB: Introduce Shared PD support (Saeed Mahameed)   
- ib_core: IB providers/ULPs Relaxed (User) FMR set to NULL (Saeed Mahameed)   
- mlx4_ib: Enable usermode FMR (Saeed Mahameed)   
- ib_core: Enable usermode FMR (Saeed Mahameed)   
- rdma_cm: add ability to control the QP timeout value (Saeed Mahameed)   
- rdma_cm: adding the RDMA_CM_EVENT_ALT_PATH_LOADED event (Dotan Barak)   
- mlx4_ib: 6305 bugfix: set the counter sets of the alternate path in the QP (Dotan Barak)   
- mlx4_ib: Fix the attribute sq_sig_type value in query qp (Saeed Mahameed)   
- rdma_cm: rdma_create_qp not setting up client context correctly (Saeed Mahameed)   
- rmda_cm: add APM support to rdma_cm. (rdma_enable_apm) (Saeed Mahameed)   
- mlx5: Update CMD_IF_REV to 4 (Moshe Lazer)   
- mlx4_core: resource tracker fix error flow in add_res_range (Saeed Mahameed)   
- mlx5: Implement new intialization sequeuenc (Moshe Lazer)   
- ib/ipoib: change mode only when interface is down. (Erez Shitrit)   
- ib/ipoib: avoid pkey value 0 in child interface. (Erez Shitrit)   
- ib/ipoib: Fix index 0 pkey value in ipoib sriov env. (Erez Shitrit)   
- ib/ipoib: limit the max number of receive/transmit queues to 16 (Tal Alon)   
- mlx4_en: reuse mapped memory in RX flow (v2) (Eugenia Emantayev)   
- mlx5: Fix check of number of entries in create CQ (Eli Cohen)   
- mlx5: fix uninitialized var warning (Eli Cohen)   
- mlx5: fix send work queue size calculation (Eli Cohen)   
- ib/core: Fix cleanup of user resources (Eli Cohen)   
- mlx5_ib: fix compilation issues in ubuntu 12.4 The driver uses 2 different enum types in 'switch' and in 'if' statements. This is causing compilation warnings. This patch resolves the issues by replacing the enum with int. (Moshe Lazer)   
- eth_ipoib: fix hw update in sr-iov interfaces. (Erez Shitrit)   
- ib/ipoib: handle failure on ipoib_cm_dev_init() for init flow (Tal Alon)   
- mlx4_core: resolvs kernel panic when connectx_port_config fail to set ports (Moshe Lazer)   
- mlx5: modify mr cache sizes (Eli Cohen)   
- Update driver release date (Eli Cohen)   
- mlx5: fix manipulation of device in healt list (Eli Cohen)   
- mlx5: fix failure to load on 32 bit archs (Eli Cohen)   
- mlx5: Add DC support (Eli Cohen)   
- ib/core: Add support for DC (Eli Cohen)   
- mlx4_core: implement loopback prevention for ETH qps (Jack Morgenstein)   
- ib_umad: keep devnum of port cdev and sm_cdev until they are freed (Moshe Lazer)   
- mlx5: Use UMR based registration directly on mlx5 (Eli Cohen)   
- mlx5: allow to clear commands stats (Eli Cohen)   
- ib/ipoib: change skb memory allocation for init process from GFP_ATOMIC to GFP_KERNEL (Tal Alon)   
- net/mlx4_en: LLS statistics (Amir Vadai)   
- net/mlx4_en: Add Low Latency Socket (LLS) support (Amir Vadai)   
- mlx4_core: Free memory only if UNMAP succeeded. (Majd Dibbiny)   
- eth_ipoib: fix bug in add new vif. (Erez Shitrit)   
- eth_ipoib: remove unneeded tag (Erez Shitrit)   
- IB/mlx4: Fetch XRC SRQ in the CQ polling code (Shlomo Pongratz)   
- mlx4_core: Implement SRQ object lookup from srqn (Shlomo Pongratz)   
- IB/core: Verify that QP handler is valid before dispatching events (Shlomo Pongratz)   
- net/mlx4: Add sysFS for vf link state support (Rony Efraim)   
- net/mlx4: Add vf link state support (Rony Efraim)   
- Revert "mlx4_en: reuse mapped memory in RX flow" (Vladimir Sokolovsky)   
- mlx5: improve mr caches (Eli Cohen)   
- mlx4_core: Dynamic VST to VST vlan/qos changes (Jack Morgenstein)   
- mlx4_en: reuse mapped memory in RX flow (Eugenia Emantayev)   
- mlx4: add pci domain to module params that use bdf-to-value format (Moshe Lazer)   
- mlx5: Add support to measure average command time (Eli Cohen)   
- ib/core: add means to measure average time of a command (Eli Cohen)   
- net/mlx4_core eSwitch - add support VST with priority tag+ remove debug prints (Rony Efraim)   
- mlx4_en: Use state_lock to protect ethtool rules database (Hadar Hen Zion)   
- IB/core: Remove DMFS rules from uobject rule_list when ib_destroy_flow() fails (Hadar Hen Zion)   
- IB/core: Do not access flow_id after destroy_flow() is called (Hadar Hen Zion)   
- mlx4_ib: Free mailbox after create flow is done (Hadar Hen Zion)   
- mlx4_ib: Check index before access the array in create/destroy flow (Hadar Hen Zion)   
- mlx4_core : implemented a function ib_rate_to_mlx4 that checks if the 	    static_rate is a valid value before assigning it to the 	    ah_attr in mlx4_set_path. (majd@mellanox.com)   
- mlx4: add means to measure command execution time (Eli Cohen)   
- mlx5: Add health plugin support (Eli Cohen)   
- mlx4_en: fix skb leakage (Eugenia Emantayev)   
- ib/ipoib: add call to dev_set_mtu when setting mode to connect (Tal Alon)   
- ib/ipoib: update broadcast record according to the new bcast from the sm. (Erez Shitrit)   
- ib/ipoib: fix hard_header return value (Erez Shitrit)   
- Fix broken previous commit (Eli Cohen)   
- mlx5: fix query of max rd atomic (Eli Cohen)   
- mlx5: Fix offsets in query hca cap (Eli Cohen)   
- mlx5: Add descriptive strings to health bufer reports (Eli Cohen)   
- mlx5: Add fast registraton support (Eli Cohen)   
- eth_ipoib: fix neigh hash in each slave (Erez Shitrit)   
- ib/ipoib: add parameters range description to driver info validates received parameters (Tal Alon)   
- mlx5: Fix fast path configuration (Eli Cohen)   
- ib_core: xrc cleanup (Yishai Hadas)   
- kernel-uek.spec: Remove pesign >= 0.10-4 as build requirement (Ajaykumar Hotchandani)   
- config file change (Ajaykumar Hotchandani)   
- Kconfig and Makefile specific changes (Ajaykumar Hotchandani)   
- mlx4_vnic: Fix reference path to hw/mlx4 header files (Ajaykumar Hotchandani)   
- mlx4: Fix compilation error for mlx4_get_vf_config (Ajaykumar Hotchandani)   
- Fix IPoIB compilation issue. (Ajaykumar Hotchandani)   
- mlx5: remove __dev* attributes (Ajaykumar Hotchandani)   
- mlx4_core: remove __dev* attributes (Bill Pemberton)   
- IB/srp: Fail I/O requests if the transport is offline (Bart Van Assche)   
- IB/srp: Avoid endless SCSI error handling loop (Bart Van Assche)   
- IB/srp: Avoid sending a task management function needlessly (Bart Van Assche)   
- IB/srp: Track connection state properly (Bart Van Assche)   
- IB/srp: send disconnect request without waiting for CM timewait exit (Vu Pham)   
- IB/srp: destroy and recreate QP and CQs when reconnecting (Ishai Rabinovitz)   
- IB/srp: Eliminate state SRP_TARGET_DEAD (Bart Van Assche)   
- IB/srp: Allow SRP disconnect through sysfs (Bart Van Assche)   
- IB/srp: Suppress superfluous error messages (Bart Van Assche)   
- IB/srp: Introduce the helper function srp_remove_target() (Bart Van Assche)   
- IB/srp: Process all error completions (Bart Van Assche)   
- IB/srp: Introduce srp_handle_qp_err() (Bart Van Assche)   
- IB/srp: Simplify SCSI error handling (Bart Van Assche)   
- IB/srp: Keep processing commands during host removal (Bart Van Assche)   
- IB/srp: Eliminate state SRP_TARGET_CONNECTING (Bart Van Assche)   
- IB/srp: Increase block layer timeout (Bart Van Assche)   
- net/mlx4_core: Disallow releasing QPs before steering rules are detached (Hadar Hen Zion)   
- mlx4_core: Fix error flow in the flow steering wrapper (Hadar Hen Zion)   
- mlx4_core: Fix potential deadlock in mlx4_eq_int() (Jack Morgenstein)   
- mlx4_core: Add QPN enforcement for flow steering rules set by VFs (Hadar Hen Zion)   
- Revert "net/mlx4_core: Disallow releasing QPs before steering rules are detached" (Ajaykumar Hotchandani)   
- mlx4_en: update driver version to 2.1.3 (Eugenia Emantayev)   
- mlx4_core: Fix advertisement of wrong PF context behaviour (Or Gerlitz)   
- net/mlx4_en: Use generic etherdevice.h functions. (Yan Burman)   
- net/mlx4_en: Can set maxrate only for TC0 (Amir Vadai)   
- IB/mlx4: Fix spinlock order to avoid lockdep warnings (Jack Morgenstein)   
- Revert "mlx4_en: fix QoS in old kernels" (Ajaykumar Hotchandani)   
- mlx4_core: use __cancel_delayed_work in IRQ context (Saeed Mahameed)   
- eth_ipoib:  use hash for managing the neighs in each slave. (Erez Shitrit)   
- IB/iser: fix device removal flow (Roi Dayan)   
- Fix compliation issue on 32 bit systems (Eli Cohen)   
- mlx5: move UMR completions to event driven (Eli Cohen)   
- eth_ipoib: add bh lock in order to avoid soft-lockups (Erez Shitrit)   
- mlx4_vnic: align with OFED2 upstream 3.7 kernel (Saeed Mahameed)   
- mlx4_vnic: adapt vnic to ofed2 mlx4 implementation (Saeed Mahameed)   
- mlx4_vnic: add mlx4_vnic (Saeed Mahameed)   
- ib/ipoib: add sysfs for tss/rss over child interface (Saeed Mahameed)   
- ib/ipoib: fix memory leak in error flow (Saeed Mahameed)   
- mlx4_ib: Fix connection of UD QPs in rdmacm for SRIOV/RoCE (Shani Michaelli)   
- mlx4_core: fix error introduced in a merge from upstream (Jack Morgenstein)   
- Fix compliation issue on 32 bit systems (Eli Cohen)   
- mlx4_en: fix statistics view in SRIOV mode (Eugenia Emantayev)   
- mlx5: change SRQ limit event msg to debug (Eli Cohen)   
- mlx5: dump selected error CQEs (Eli Cohen)   
- mlx5: move UMR completions to event driven (Eli Cohen)   
- mlx4_core: Avoid setting ports for auto when only one port type is supported (Moshe Lazer)   
- mlx4_core: cleared the mailbox->buf (memset 0) before using it.            mlx4_set_port_general_context struct is smaller than the mailbox->buf            therefore clearing only it was not enough and we had to clear the whole            mailbox->buf in order to ensure garbage-free buffer. (majd@mellanox.com)   
- mlx4_en: setting number of rings resulted in deadlock (Matan Barak)   
- mlx5: fix query of max rdma/atomics (Eli Cohen)   
- mlx4_en: update driver version to 2.1.2 (Eugenia Emantayev)   
- mlx4_en: update driver version to 2.1.1 (Eugenia Emantayev)   
- IB/iser: Fix coverity errors (Roi Dayan)   
- mlx5: update modinfo string for mlx5_ib (Eli Cohen)   
- ib/ipoib: fix panic at cm tx creation. (Erez Shitrit)   
- mlx5: fix opt param mlx5 translation table (Eli Cohen)   
- mlx4_core: sysfs, fix usage of log_num_mtt module parameter (Yishai Hadas)   
- ib/ipoib: in additional to commit 2bf6943f4f9ea9f1f69b4ef5acb4ece11bf50bc0 (Erez Shitrit)   
- mlx5: fix opt parameters usage (Eli Cohen)   
- ib/ipoib: fix kernel panic after mode changing. (Erez Shitrit)   
- mlx5: add missing spare EQEs in create EQ (Eli Cohen)   
- Revert "ib/ipoib: enhance interop between TSS device to non-TSS device." (Erez Shitrit)   
- mlx5: mark mlx5_ib QPs how they were created (Eli Cohen)   
- mlx5: Fix alignement of data buffers for umr registration (Eli Cohen)   
- ib/ipoib: fix for missing ping reply issue. (Erez Shitrit)   
- ib/ipoib: Call skb_dst_drop() once skb is enqueued for sending (Erez Shitrit)   
- net/mlx4_core : update enforce QP param in VST (Rony Efraim)   
- net/mlx4_core: Always use __mlx4_un/register_vlan for VST (Rony Efraim)   
- mlx4_ib: set link type for the primary path (Eli Cohen)   
- mlx4_core: Fix mem leak in SRIOV mlx4_init_one error flow (Jack Morgenstein)   
- mlx4_core: Add wrapper for mlx4_DIAG_RPRT command to return BAD_OP (Jack Morgenstein)   
- mlx4_en: do not allow certain ethtool options when alloc resources failed (Eugenia Emantayev)   
- mlx4_en: restore ring inflight atomic variable (Eugenia Emantayev)   
- ib/ipoib: move (one more) message to be at debug level instead of warn (Erez Shitrit)   
- ib/ipoib: move message to be at debug level instead of warn (Erez Shitrit)   
- mlx5: change message from warn to debug (Eli Cohen)   
- mlx4_en: No_wqes counter should only be reported via Ethtool (Yevgeny Petrilin)   
- mlx4_en: inline threshold must be unsigned (Eugenia Emantayev)   
- mlx4_en: make receive flow more readable (Eugenia Emantayev)   
- ib/ipoib: fix skb true size (Erez Shitrit)   
- mlx5: fix offset to health buffer (Eli Cohen)   
- mlx4_en: fix kernel panic on XenServer hypervisor (Eugenia Emantayev)   
- mlx4_core: Ignore bf flag in mlx4_qp_reserve_range when count is too large (Jack Morgenstein)   
- mlx4_core: use kernel to allocate and release umad cdevs (Moshe Lazer)   
- mlx4_ib: used uninitialized compilation warning (Moshe Lazer)   
- mlx4_en: change driver version to 2.1 and add date (Eugenia Emantayev)   
- mlx4_en: remove TX shifting (Eugenia Emantayev)   
- memtrack: handle umem put page (Yishai Hadas)   
- mlx4_en: fix wrong MAC address (Eugenia Emantayev)   
- ib_srp: update module version to 1.2 (Alex Tabachnik)   
- mlx4_core: fix ib_uverbs_get_context flow (Yishai Hadas)   
- IB/core: Fix memory leaks in ib_uverbs_create_flow (Hadar Hen Zion)   
- mlx4_core: Fix Coverity issue (Hadar Hen Zion)   
- IB/core: Fix Coverity issue (Hadar Hen Zion)   
- ib/ipoib: remove compilation warning (Erez Shitrit)   
- mlx4_en: get timestamp request from correct packet info (Eugenia Emantayev)   
- mlx4_en: make alignment generic (Eugenia Emantayev)   
- Revert "DEBUG PATCH" (Moshe Lazer)   
- Revert "DEBUG PATCH update" (Moshe Lazer)   
- ib/ipoib: allocate always one linear buffer at the RX flow (Erez Shitrit)   
- ib/ipoib: enhance interop between TSS device to non-TSS device. (Erez Shitrit)   
- mlx4_en: fix DCB_ENABLE flag (Eugenia Emantayev)   
- IB/iser: Move important debug prints to debug level 1 (Roi Dayan)   
- mlx4_en: add check for DMA mapping error (Eugenia Emantayev)   
- mlx4_en: align dma to 64 (Eugenia Emantayev)   
- ib_mad: Avoid looking into mad struct before finding it in list (Moshe Lazer)   
- net/mlx4_core: Translate guest B0 steering rules to DMFS (Hadar Hen Zion)   
- net/mlx4_core: Add helper function to translate B0 steering to DMFS (Hadar Hen Zion)   
- net/mlx4_core: Disallow releasing QPs before steering rules are detached (Hadar Hen Zion)   
- net/mlx4_core: Use 64 bit resource ID when doing lookup (Hadar Hen Zion)   
- net/mlx4_en: Remove ethtool flow steering rules before releasing QPs (Hadar Hen Zion)   
- ib_uverbs: added ref_cnt to sysfs (Marcel Apfelbaum)   
- ib/ipoib: disable reinit at the middle of driver down. (Erez Shitrit)   
- mlx4_core: change warn msg to dbg msg (Moshe Lazer)   
- mlx4_core: Fix Coverity issues. (Hadar Hen Zion)   
- IB/mlx4: Fix Coverity issues (Hadar Hen Zion)   
- IB/core: Fix Coverity issues (Hadar Hen Zion)   
- mlx4_en, mlx4_ib: show VSD string through sysfs (Hadar Hen Zion)   
- mlx4_core: Enhance flow steering validation checks (Hadar Hen Zion)   
- IB/mlx4: use ARRAY_SIZE kernel macro (Hadar Hen Zion)   
- net/mlx4_core: Fix wrong order of flow steering resources removal (Hadar Hen Zion)   
- mlx4_core: map eq inconsistency with prm (Moshe Lazer)   
- net/mlx4_core: Preparation + workaround for the UPDATE_QP FW cmd (Rony Efraim)   
- mlx4_ib: assign all dev numbers in low-level driver when dev_assign_str param is active (Jack Morgenstein)   
- mlx4_core: fix the method to get phys func from its virt func (Moshe Lazer)   
- ib_iser: move some error prints to debug prints (Roi Dayan)   
- ib_iser Fix kernel crash on ib_iser module unload immediately after initiator logout (Alex Tabachnik)   
- ib_srp: simplifying handle port down, cm dreq, scsi error recovery (Alex Tabachnik)   
- ib_srp: check for error return to avoid garbage gid in initiator_id (Alex Tabachnik)   
- ib_srp: bail out when scsi command in req is NULL (Alex Tabachnik)   
- mlx4: Allow RAW PACKET QPs on mlx4 (Eli Cohen)   
- ib/ipoib: fix for ib_unregister_event_handler (Erez Shitrit)   
- mlx4_en: fix memory leak in mlx4_en_activate_rx_rings (Eugenia Emantayev)   
- mlx4_en: verify mlx4_en module parameters (Eugenia Emantayev)   
- mlx4_en: change ethtool specifications for 1G, 10G, 40G support in advertising and supported fields (Rana Shahout)   
- IB/core: Fix raw Ethernet qp bug (Hadar Hen Zion)   
- IB/core: add module parameter check to allow a non-root user to attach DMFS rules (Hadar Hen Zion)   
- IB/mlx4: Add support for Flow Steering (Hadar Hen Zion)   
- IB/core: Export ib_create/destroy_flow through uverbs (Hadar Hen Zion)   
- IB/core: Implement ib_create/destroy_flow (Hadar Hen Zion)   
- net/mlx4_core: Add flow steering support to be used by mlx4_ib (Hadar Hen Zion)   
- mlx4_core: Directly expose fields of HW flow steering rule control segment (Hadar Hen Zion)   
- mlx4_core: Replace flow steering fields names to match the PRM (Hadar Hen Zion)   
- mlx4_core: Expose flow steering HW structs to be used by mlx4_ib module (Hadar Hen Zion)   
- mlx4_ib: Remove attach/detach flow API implementation (Hadar Hen Zion)   
- ib_uverbs: Remove ib_uverbs_attach/detach_flow leftovers (Hadar Hen Zion)   
- Revert "ib_core: Implement ib_attach_flow ib_detach_flow" (Hadar Hen Zion)   
- Revert "mlx4_ib: Add support for ib_attach_flow and ib_detach_flow." (Hadar Hen Zion)   
- Revert "ib_uverbs: Export ib_attach_flow and ib_detach_flow to userspace." (Hadar Hen Zion)   
- Revert "rdma_cm: Implement rdma_get_l2" (Hadar Hen Zion)   
- mlx4_en: add port state test before operate mlx4_en_set_cq_moder in mlx4_en_set_ringparam function. (Rana Shahout)   
- mlx4_en: avoid loosing statistics (Eugenia Emantayev)   
- ib_iser: add module version (Roi Dayan)   
- mlx5: fix health counter read (Eli Cohen)   
- mlx4_en: set correct MTU in SRIOV (Eugenia Emantayev)   
- Release Date is updated to __DATE__ instead of a static string (Alex Markuze)   
- mlx4_core: use msi_x module param to limit num of MSI-X irqs (Moshe Lazer)   
- Seting ring size to default when module param set incorrectly (Alex Markuze)   
- eth_ipoib: move task from rx flow to workqueue (Erez Shitrit)   
- mlx5: fix health polling race (Eli Cohen)   
- DEBUG PATCH update To provide more info on kernel panic in mad layer. (Moshe Lazer)   
- memtrack: add tracking for kfree_rcu (Eugenia Emantayev)   
- mlx4_en: Set number of rx/tx channels using ethtool (Amir Vadai)   
- mlx4_en: fix incorrect timestamp (Eugenia Emantayev)   
- mlx4_en: remove explicit call to skb_reset_mac_header (Eugenia Emantayev)   
- ib/ipoib: move global client_data_lock spin_lock init to module_init (Erez Shitrit)   
- mlx5: use MPI profile as default (Eli Cohen)   
- ib/ipoib: protect client data with spin-lock. (Erez Shitrit)   
- ib/ipoib: disable lro over pv interface. (Erez Shitrit)   
- eth_ipoib: change lock over bh, use regular lock. (Erez Shitrit)   
- mlx4_core: CQE/EQE by default is 64B (Yishai Hadas)   
- mlx5: change fw health polling to new definition (Eli Cohen)   
- mlx5: fix missing symbols in 32 bit platforms (Eli Cohen)   
- mlx5: use separate EQ of command interface (Eli Cohen)   
- mlx5: change scatter to cqe to new PRM (Eli Cohen)   
- net/mlx4: Update FW DEV CAP bits of VST and FSM (Yan Burman)   
- net/mlx4: Add support to get VF config (Yan Burman)   
- net/mlx4: Fix the VF numbering from 0 (instead of 1) (Yan Burman)   
- mlx4_en: fix no vlan traffic on vlan interface (Eugenia Emantayev)   
- DEBUG PATCH To provide info on kernel panic in mad layer. (Moshe Lazer)   
- mlx5: fix warning on out of array bounds (Eli Cohen)   
- mlx5: DEBUG PATCH (Eli Cohen)   
- mlx4_en: reset mac_header (Eugenia Emantayev)   
- mlx4_core: fix counters leak as part of slave down (Yishai Hadas)   
- mlx4_ib, ib_core: UP setting for Raw Eth QP (Amir Vadai)   
- mlx4_en: help disperse interrupts workload in TX flow (Eugenia Emantayev)   
- mlx4_en: help disperse interrupts workload in RX flow (Eugenia Emantayev)   
- mlx4_en: optimize inline logic in TX flow (Eugenia Emantayev)   
- mlx4_en: remove atomic from transmit flow (Eugenia Emantayev)   
- mlx4_en: use unlikely when checking for bounce in en_xmit (Eugenia Emantayev)   
- mlx4_en: code cleanup (Eugenia Emantayev)   
- Issue: 170150 mlx4: Allow to set CQ Ignore Overrun under capability check (Igor Ivanov)   
- Issue: 170150 IB/mlx4: Add Cross-channel functionality (Igor Ivanov)   
- Issue: 170150 IB/core: Add ib_uverbs_modify_cq_ex (Igor Ivanov)   
- Issue: 170150 IB/core: Add ib_uverbs_create_qp_ex (Igor Ivanov)   
- Issue: 170150 IB/core: Add Infrastructure to support verbs extensions through uverbs (Igor Ivanov)   
- Issue: 170150 IB/core: Add support for Cross Channel operations (Igor Ivanov)   
- Issue: 170150 IB/mlx5: Change CQ modify to have attributes/mask and flags param (Igor Ivanov)   
- Issue: 170150 IB: Change CQ modify to have attributes/mask and flags param (Igor Ivanov)   
- ib/core: change error prints in cm module to debug prints. (Jack Morgenstein)   
- mlx4: bf_qp parameter added to mlx4_qp_reserve_range should be a flags param. (Jack Morgenstein)   
- mlx4_en: use linear skbs in receive flow (Eugenia Emantayev)   
- mlx5: debug patch - freeze on too long completions (Eli Cohen)   
- mlx5: debug patch for umr problem (Eli Cohen)   
- mlx4_core: Add support for different value formats in BDF-Val params (Moshe Lazer)   
- mlx4_core: Add more info to mlx4_cmd_post failure error messages (Jack Morgenstein)   
- mlx4_en: ignore init and shutdown hypervisor events (Eugenia Emantayev)   
- mlx5: fix false compilation error in qp.c (Eli Cohen)   
- Fix format specifier for printk (Eli Cohen)   
- mlx4_ib: in SRIOV, should not reserve QP range for IPoIB use when DMFS is enabled. (Jack Morgenstein)   
- mlx4_core: use symbolic name for FW commands in warnings (Jack Morgenstein)   
- mlx5: fix race in destroy CQ (Eli Cohen)   
- mlx5: fix error flow in destroy SRQ (Eli Cohen)   
- mlx4_core: Support setting a different port_type_array for each HCA (Moshe Lazer)   
- mlx4_en: use div_u64 for division (Eugenia Emantayev)   
- mlx4_core: disable mlx4_QP_ATTACH calls from guests if master is doing flow steering. (Jack Morgenstein)   
- Adding parametre validation to ipoib_printk (Alex Markuze)   
- eth_ipoib: enable GRO on the pv interface (Erez Shitrit)   
- mlx4_en: release QP when destroying TX ring (Eugenia Emantayev)   
- mlx5: add profie selection of mr cache sizes (Eli Cohen)   
- memtrack: fix broken memtrack on vzalloc (Eli Cohen)   
- Add mlx5 driver support (Eli Cohen)   
- ib/core: add UMR support for verbs (Eli Cohen)   
- ib/core: Add means to measure command execution times (Eli Cohen)   
- mlx4_core: Don't fail reg/unreg vlan for upstream guests to 3.8 (Jack Morgenstein)   
- mlx4_core: Turn off device-managed FS bit in dev-cap wrapper if DMFS is not enabled (Jack Morgenstein)   
- mlx4_core: change resource quotas to enable supporting upstream-kernel guests (Jack Morgenstein)   
- mlx4_core: Support setting a different num_vfs and probe_vf for each HCA (Moshe Lazer)   
- ib/ipoib: fix ipoib_neigh index calculation (Shlomo Pongratz)   
- mlx4_en: split outgoing traffic to two different rings (Eugenia Emantayev)   
- Flsu WQ should come after flush_paths in CM mode (Alex Markuze)   
- net/mlx4_en: Synchronize unicast MAC filter implementation with upstream (Yan Burman)   
- ib/iser: add BullseyeCoverage pragma lines around ilog2 calls (Roi Dayan)   
- ib_srp: fix oops during module unload on OEL 6.2 (Alex Tabachnik)   
- Moved the tx ethtoll counters to ipoib_send (Alex Markuze)   
- ib/ipoib: fix deadlock between dev_change_flags to __ipoib_dev_flush (Erez Shitrit)   
- Adding flush WQ for ipoib_ib_dev_cleanup to avoid cm_create_tx_qp handling bad pointers Issue: 111256, 168923 (Alex Markuze)   
- mlx4: change QP allocation scheme (Eugenia Emantayev)   
- ib/ipoib: avoid loading the kernel when rtnl is locked. (Erez Shitrit)   
- ib/ipoib: fix deadlock between ipoib_mcast_dev_flush to ipoib_mcast_join_finish (Erez Shitrit)   
- mlx4_ib: use correct device for XRC (Yishai Hadas)   
- net/mlx4_en: Fix resource leak on module unload (Yan Burman)   
- net/mlx4_en: Fix race in set_mac_address regression (Yan Burman)   
- ib/ipoib: fix panic on ipoib_get_stats (Erez Shitrit)   
- mlx4_core: device revision support (Yishai Hadas)   
- mlx4_core: print more info when command times out (Jack Morgenstein)   
- ib/ipoib: Fix ipoib_neigh hashing to use the correct daddr octets (Shlomo Pongratz)   
- ib/ipoib: : Fix race condition in neigh creation under MQ (Shlomo Pongratz)   
- ib/ipoib: rtnl_unlock cannot come after free_netdev (Erez Shitrit)   
- ib/ipoib: fix deadlock over vlan_mutex. (Erez Shitrit)   
- 	This is a partial fix for bad flow when ipoib_reinit fails to ipoib_dev_init. 	This fix enables the driver to call ib_unregister_event_handler in ipoib_remove_one, without crushing, 	though ib_register_event_handler was not called. (Alex Markuze)   
- eth_ipoib: fix compilation over xen-server. (Erez Shitrit)   
- ib/ipoib: remove netlink code till further support. (Erez Shitrit)   
- mlx4_core: move out label to the right place (Eugenia Emantayev)   
- IB/mlx4: Do reg/unreg vlan for RoCE (Jack Morgenstein)   
- {IB,EN}/mlx4: In RoCE allow guests to have multiple GIDS (Jack Morgenstein)   
- IB/mlx4: prepare update_gids flow for multiple gids (Jack Morgenstein)   
- mlx4_en: add check for QoS capability bit (Eugenia Emantayev)   
- EN/mlx4: use vlan id in mlx4_unregister_vlan instead of vlan index (Jack Morgenstein)   
- mlx4_core: fix reg/unreg vlan and reg/unreg mac to conform to the PRM (Jack Morgenstein)   
- memtrack: alloc/free pages handle size inconsistency (Yishai Hadas)   
- mlx4_en: use num_possible_cpus instead of num_default_rss_queues (Eugenia Emantayev)   
- mlx4_en: memory leak in loading driver (Matan Barak)   
- net/mlx4_en: Add support for destination MAC in steering rules (Yan Burman)   
- net/mlx4_en: Implement fdb ndo_fdb_{add,del,dump} (Yan Burman)   
- net/mlx4_en: Add unicast MAC filtering (Yan Burman)   
- net/mlx4_en: Manage hash of MAC addresses per port (Yan Burman)   
- net/mlx4_en: Save old MAC address of the port so we can replace it later (Yan Burman)   
- net/mlx4_en: Re-arrange ndo_set_rx_mode related code (Yan Burman)   
- net/mlx4: Move ethernet related functionality to mlx4_en out of mlx4_core (Yan Burman)   
- net/mlx4_en: Cleanup multiline strings (Yan Burman)   
- net/mlx4_en: Optimize loopback related checks in data path (Yan Burman)   
- net/mlx4_core: Set number of msix vectors under SRIOV mode to firmware defaults (Or Gerlitz)   
- ib/ipoib: fix possible deadlock on pkey_poll task. (Erez Shitrit)   
- mlx4_en: fix BlueFlame race (Eugenia Emantayev)   
- ib_mad: Add SA MADs congestion control (Moshe Lazer)   
- ib/ipoib: add robust to ipoib_mcast_join_finish (Erez Shitrit)   
- ib/ipoib: fix deadlock between ipoib_mcast_dev_flush and ipoib_mcast_join_finish (Erez Shitrit)   
- IB/iser: Enable iser to work when FMRs are not supported (Or Gerlitz)   
- mlx4_en: ethtool should return error on turning on autoneg (Matan Barak)   
- IB/mlx4: deprecate "failed to alloc bf reg" message from err to debug (Jack Morgenstein)   
- mlx4_en: fix bad english in modprobe and ethtool (Amir Vadai)   
- mlx4_en: Move initalizations to beginning of init_netdev (Amir Vadai)   
- mlx4_en: pad ethernet packets smaller than 17 bytes (Amir Vadai)   
- mlx4_en: print error message on cqe error (Amir Vadai)   
- mlx4_en: fix set port ratelimit. (Sagi Grimberg)   
- mlx4_en: fix MLX4_RATELIMIT_DEFAULT define include (Sagi Grimberg)   
- mlx4_en: report number of rings in RSS as a power of 2 (Amir Vadai)   
- mlx4_en: fix UP limit in ieee_ets->prio_tc (Amir Vadai)   
- mlx4_core: Do not allow mlx4_bitmap_init to reserve more slots than available (Amir Vadai)   
- mlx4_en: fix open-lldp DCB support (Sagi Grimberg)   
- remove dead code - mlx4_en_can_lro (Sagi Grimberg)   
- mlx4_en: add support for debugfs (Shani Michaelli)   
- mlx4_en: TX ring size default to 1024 (Yevgeny Petrilin)   
- ib/ipoib: Fix deadlock between rmmod and set_mode (Erez Shitrit)   
- ib/ipoib: fine tune commit aee8f48642fb83820463d042ca80fd5372947cb5 (Erez Shitrit)   
- In 4K mtu Rx, adding 128 bytes to linear part (Alex Markuze)   
- ib/ipoib: getout whenever failed to load port. (Erez Shitrit)   
- ib_ipoib: Fixing issue with delayed work running after child is killed. (Erez Shitrit)   
- mlx4_en: extract changes to compat from backport (Amir Vadai)   
- IB/mlx4: in RoCE, report network-view of number of GIDS in query_port. (Jack Morgenstein)   
- srp: Create additioal tree with srp code from mofed 1.5.3, separated to two parts one for all the distributions and one for sles11sp2 and kernels bigger then 3.0. Original srp code remaine as is and when will be needed will be used for developement (Alex Tabachnik)   
- mlx4_en: fix QoS in old kernels (Amir Vadai)   
- ib_core: contig allocation use NOWARN flag (Yishai Hadas)   
- ib_core: fix memory leak in contig error flow (Yishai Hadas)   
- mlx4_core: Fixed IPoIB flow steering (Hadar Hen Zion)   
- ib/ipoib: Add print log for debug. (Erez Shitrit)   
- ib/ipoib: Fix mess in the select queue in TSS flow. (Erez Shitrit)   
- ipoib: fix mcast dead-lock (Yishai Hadas)   
- Fixing RHL6.2 memtrack backports for alloc_worqueue (Alex Markuze)   
- mlx4_core: additional fix for qp_detach_common (Eugenia Emantayev)   
- mlx4_core: fix broken logic when removing promisc qp (Eugenia Emantayev)   
- ib/ipoib: doesn't allow num of tx channel to be 2. (Erez Shitrit)   
- net/eipoib: sys/fs show of "served" should give the new member as it does with the valid members (Erez Shitrit)   
- mlx4_en: counters init to non-index (Yishai Hadas)   
- mlx4_core: Do not guarantee counter availability in SRIOV (Jack Morgenstein)   
- mlx4_en: counters fine-tuned (Yishai Hadas)   
- mlx4_core: max counters support (Yishai Hadas)   
- mlx4_core: change code to endian safe (Hadar Hen Zion)   
- mlx4_ib: allow FS rules attachments with missing headers (Hadar Hen Zion)   
- mlx4_en/mlx4_ib: move BE_SHORT/WORD_MASK macro from private to common place (Hadar Hen Zion)   
- mlx4_core: configure flow steering hash to L4 mode (Hadar Hen Zion)   
- mlx4_en: Fixed ethtool rules leftovers after mlx4_en unload (Hadar Hen Zion)   
- mlx4_en: block insertion of FS ethtool rules while port is down (Hadar Hen Zion)   
- mlx4_en: Remove FS promisc rules removal from mlx4_en_start_port (Hadar Hen Zion)   
- mlx4_en: fix ethtool vlan range validation (Hadar Hen Zion)   
- mlx4_ib: Add VLAN support to RawEth QP flow steering (Hadar Hen Zion)   
- mlx4_en: fixed ip/tcp/udp multicast mac rules when inserted via ethtool (Hadar Hen Zion)   
- mlx4_en: counters moderation support (Yishai Hadas)   
- memtrack: add missing untrackable functions for EN under RH6.3 (Yishai Hadas)   
- mlx4_core: Resource wrapper for reg/unreg vlans (Jack Morgenstein)   
- mlx4_core: fix register/unreg vlan flow (Jack Morgenstein)   
- mlx4_core: fix call to __mlx4_unregister_mac (Jack Morgenstein)   
- mlx4_core: Implement resource quota enforcement when allocating various resources (Jack Morgenstein)   
- {IB,EN}/mlx4: structures and init/teardown for VF resource quotas (Jack Morgenstein)   
- memtrack: fix report (Yishai Hadas)   
- net/mlx4: Add support for MAC spoof checking (Rony Efraim)   
- net/mlx4: Add support to set default vlan id and priority for VF NIC (Rony Efraim)   
- net/mlx4: Add support the set mac address for VF NIC (Rony Efraim)   
- {IB,EN}/mlx4: Replace mlx4_en_mac_to_u64() with mlx4_mac_to_u64() (Rony Efraim)   
- net/mlx4: Add admin and oper DB (Rony Efraim)   
- mlx4_en: fix some dead-locks as of flow steering mode (Yishai Hadas)   
- mlx4_en: Do not query ethernet stats when a device port is down. (Jack Morgenstein)   
- extended counters use correct reserved bytes (Yishai Hadas)   
- mlx4_core: fix endianness bug in set_param_l (Jack Morgenstein)   
- ib/ipoib: fix the failure to delete  clone child interface. (Erez Shitrit)   
- net/mlx4_core: Fix racy flow in the driver CQ completion handler (Jack Morgenstein)   
- net/eipoib: Support bonding (active-passive mode) for eIPoIB driver. (Erez Shitrit)   
- ib/ipoib: Changes in ipoib in order to support the latest version of eIPoIB. (Erez Shitrit)   
- net/eipoib: Add ethtool file support (Erez Shitrit)   
- net/eipoib: Add sysfs support (Erez Shitrit)   
- net/eipoib: Add main driver functionality (Erez Shitrit)   
- net/eipoib: Add private header file (Erez Shitrit)   
- mlx4_en: report extra rx counters for SRIOV (Yishai Hadas)   
- mlx4_ib: add extended counters support (Yishai Hadas)   
- mlx4_en: support extended counters (Yishai Hadas)   
- mlx4_core: set device to use extended counters (Yishai Hadas)   
- fix NULL pointer assignment in the disconnection flow (Alex Tabachnik)   
- mlx4_ib: mlx4_set_path() wrote the port number into the MAC address field under RoCE (Jack Morgenstein)   
- mlx4_ib: Called rdma_port_get_link_layer with wrong port number. (Jack Morgenstein)   
- add support for CQ moderation (Alex Tabachnik)   
- mlx4_en: fix IPv6 traffic (Eugenia Emantayev)   
- ipoib: move set_skb_oob_cb_data body to ipoib.h (Vladimir Sokolovsky)   
- ib/ipoib: Fix deadlock at the release of child_interfaces. (Erez Shitrit)   
- mlx4: verify port number in __mlx4_unregister_mac (Eli Cohen)   
- ipoib: improve poll mechanism for better performance (Yishai Hadas)   
- ipoib: Replace write_lock with rw semaphore (Jack Morgenstein)   
- mlx4_core: Do not enable flow steering by default (Jack Morgenstein)   
- mlx4_core: Adjustments to Flow Steering activation logic for SRIOV (Jack Morgenstein)   
- ipoib: adapt code to netlink changes (Yishai Hadas)   
- ib/ipoib: debug prints instead of warn in tx_wc function (Erez Shitrit)   
- ib/ipoib: fix possible race between  ipoib_cm_skb_too_long call to skb free. (Erez Shitrit)   
- ib/ipoib: Fix race in the TX flow at CM mode. (Erez Shitrit)   
- ib/ipoib: change list_del to list_del_init in the tx object. (Erez Shitrit)   
- ib/ipoib: repalce list_del of the neigh->list with  list_del_init (Erez Shitrit)   
- ib/ipoib: add detailed error message on  dev_queue_xmit (Erez Shitrit)   
- ib/ipoib: adding completion to ipoib_mc (Erez Shitrit)   
- ib/ipoib: start mcast_join process only on port active. (Erez Shitrit)   
- ib/ipoib: Move QP to ERROR only when the QP is not at REST state (Erez Shitrit)   
- ib_ipoib: always mark QP as NETIF_QP (Amir Vadai)   
- ib/ipoib: fix ipoib lock is not freed issue (Shlomo Pongratz)   
- ipoib: fix a deadlock at "carrier on task" (Yishai Hadasa)   
- ib/ipoib: fix kernel panic when restarting with vma  flag (Shlomo Pongratz)   
- ib/ipoib: force cleaning of ah's in driver unloading (Erez Shitrit)   
- IB/ipoib: Remove datagram mode check for ipoib flow steering (Hadar Hen Zion)   
- ipoib: adaptive moderation fine tuned (Yishai Hadas)   
- ib/ipoib: fix access to stale cm rx context (Shlomo Pongratz)   
- ib/ipoib: Change the comparison of tx_outstanding and the timeout function. (Yishai Hadas)   
- ipoib/ib: don't release resources if the add_one failed (Dotan Barak)   
- ib/ipoib: Fix removing call for update_pmtu from  spin-lock context. (Erez Shitrit)   
- ipoib: start_xmit - RSS/TSS adaptations (Yishai Hadas)   
- ib/ipoib: attach multicast address after RSS/TSS qp num change. (Shlomo Pongratz)   
- ipoib: flow steering with TSS/RSS support (Hadar Hen Zion)   
- ipoib: adaptive moderation adaptations to RSS (Yishai Hadas)   
- ib/ipoib: Added adaptive moderation algorithm for  better latency. (Yishai Hadas)   
- ipoib: arp snooping for gid cache sync. (Erez Shitrit)   
- ipoib: add inline/blue flame support (Yishai Hadas)   
- IB/IPoIB: fix cm tx path index and strenght locking (Shlomo Pongratz)   
- ipoib: fixed NULL dereferencing in case of error flow (Dotan Barak)   
- IB/ipoib: add support for ethtool set/get_channels (Shlomo Pongratz)   
- IB/ipoib: Add RSS and TSS support for datagram mode (Shlomo Pongratz)   
- IB/ipoib: Implement vectorization restructure as  pre-step for TSS/RSS (Shlomo Pongratz)   
- eipoib: addon flags (Yishai Hadas)   
- ib/ipoib: Add support in IPoIB instance (netdevice) functions as a VIF (Erez Shitrit)   
- ib/ipoib: add support for clones / multiple childs  on the same partitions (Or Gerlitz)   
- mlx4_core: Fix flow steering backword compatability to old FW's (Amir Vadai)   
- RDMA/ucm: disable tuning the max listen backlog in debug kernel (Dotan Barak)   
- mlx4_core: fix memtrack algoritm to identify non trackable mem allocation (Moshe Lazer)   
- core, srp, mlx4_en: Adjustments to patch set which rebased to kernel 3.7 (Jack Morgenstein)   
- mlx4_core, mlx4_ib, mlx4_en: match fs promisc enums to new PRM names (Hadar Hen Zion)   
- RDMA/ib_core: add support for iWarp multicast acceleration over IB_QPT_RAW_PACKET QP type (Solves RM #100087) (Marcel Apfelbaum)   
- mlx4_core, mlx4_ib: Adding flow steering ibdump support (Hadar Hen Zion)   
- mlx4_core: Update minimum size for log_num_qp to 18 (Moshe Lazer)   
- mlx4_en: fix race in join/leave multicast flow (Eugenia Emantayev)   
- mlx4_ib: allow_loopback flag shouldn't set hardcoded (Hadar Hen Zion)   
- mlx4_ib:Add ipoib qpn for IB unicast flow steering (Hadar Hen Zion)   
- net/mlx4: remove BUG_ON in case of an error (Dotan Barak)   
- mlx4_core: allow_loopback flag is corrupted (Amir Vadai)   
- mlx4_ib : add module parameter that maps IB device index to device function number (Eli Cohen)   
- sys_tune: enable sys_tune only if APM MODULE configured (Eugenia Emantayev)   
- mlx4_en: add defines for supported link speed (Eugenia Emantayev)   
- mlx4_en: fill truesize field in skb (Eugenia Emantayev)   
- sys_tune: add sys_tune for cpu tuning for better performance (Eugenia Emantayev)   
- net/mlx4: fix memory leaks in guest OS in case of error flow (Dotan Barak)   
- mlx4_core, mlx4_ib: Have enough room in steering range for pkey interfaces (Amir Vadai)   
- mlx4_ib: fix kernel crash when steering QPN's range is big (Amir Vadai)   
- mlx4_en: remove all queues empty condition for loopback test (Eugenia Emantayev)   
- mlx4_en: correct calculation of mtu size (Yishai Hadas)   
- mlx4_en: merge adaptive moderation logic/values from 1.5.9 (Eugenia Emantayev)   
- mlx4_ib: Adapt driver to changes in steering range API changes in firmware (Eitan Rabin)   
- mlx4_en, mlx4_ib: make QP steering range hardcoded (Amir Vadai)   
- net/mlx4: return bad error status to caller function in case of error (Dotan Barak)   
- mlx4_en: avoid cache miss in GRO flow (Eugenia Emantayev)   
- mlx4_en: no IP_ALIGN for scatter entries (Eugenia Emantayev)   
- mlx4_en: selecting neighbour core for TX interrupts (Eugenia Emantayev)   
- mlx4_en: NAPI on TX side (Eugenia Emantayev)   
- mlx4_en: fix kernel panic when accessing uninitialized mutex (Eugenia Emantayev)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- net/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- IB/mlx4: replace printk() with suitable logging function (Dotan Barak)   
- net/mlx4: print return values in-case of called function failures (Dotan Barak)   
- net/mlx4: add explicit message if user ask too few QPs (Dotan Barak)   
- ib_core: fix contig overflow over 2GB (Yishai Hadas)   
- mlx4/IB: disables user mode RAW QP VLAN stripping in the RX (Dotan Barak)   
- mlx4_en: fix kernel panic caused by null pointer dereference (Eugenia Emantayev)   
- ib/core: Remove annoying message. (Erez Shitrit)   
- mlx4_core: Fixing leackage of SW multicast entries. (Yevgeny Petrilin)   
- mlx4_en: set netif_carrier off when port stopped (Eugenia Emantayev)   
- mlx4_en: Adding info when TX timeout ocures (Yevgeny Petrilin)   
- mlx4_en: Fixing race when closing TX queue (Eugenia Emantayev)   
- mlx4_en: fix timestamping for gro flow (Eugenia Emantayev)   
- mlx4_en: fix a race between napi poll function and RX ring cleanup (Eugenia Emantayev)   
- mlx4_en: Removed failed adding vlan and not found vlan prints. (Eugenia Emantayev)   
- mlx4_en: move register_netdev() to the end of mlx4_en_init_netdev() (Eugenia Emantayev)   
- mlx4_en: Fixed no traffic bug when disable port during promisc mode in a loop. (Aviad Yehezkel)   
- mlx4_en: Do not disable vlan filter during promisc. (Eugenia Emantayev)   
- mlx4_core: open 4 msi-x vectors for multifunction (Eugenia Emantayev)   
- et/mlx4_core: make sure that err is non-zero in __mlx4_add_one error flow. (Jack Morgenstein)   
- mlx4_core: check that number of QP per MCG entry was not exceeded when adding to the default MCG entry (Alexander Guller)   
- mlx4_core: Expose mlx4_net_trans_rule_hw_ctrl structure fields (Hadar Hen Zion)   
- net/mlx4_core: fix memory leak in error flow of flow_spec_to_net_rule() (Dotan Barak)   
- net/mlx4_core: If memory allocation failed, return error to upper function (Dotan Barak)   
- mlx4_ib: fix memory leak if QP creation failed (Dotan Barak)   
- mlx4_ib: Fix IPoIB flow steering after broken by the TSS/RSS support commit (Hadar Hen Zion)   
- mlx4_ib: Bug fix - allow attaching L2 and L3 rules using ibv_attach_flow (Hadar Hen Zion)   
- net/mlx4_core: reduce the stack usage of the function mlx4_init_hca() (Dotan Barak)   
- ib/core: add prints to the cm module. (Erez Shitrit)   
- rds: fix error flow handling (Dotan Barak)   
- mlx4/IB: add a message print when the logical link goes up/down (Dotan Barak)   
- mlx4/ib: clean memory for EQs in case of error flow (Dotan Barak)   
- mlx4/IB: remove proc entries in case of bad flow (Dotan Barak)   
- net/mlx4_core: set used number of MTTs when using auto-detection (Dotan Barak)   
- net/mlx4_core: the number of MTTs should consider log_mtts_per_seg (Dotan Barak)   
- mlx4/IB: remove RD diagnostics counters (Dotan Barak)   
- ib_core: check that DMA mapping was successful (Dotan Barak)   
- mlx4_en: remove an unnecessary test if maxrate is NULL (Dotan Barak)   
- ib: cmem rlimit support (Yishai Hadas)   
- net/mlx4_core: limit to 4TB of memory registration (Yishai Hadas)   
- net/mlx4_core: enable 8TB of memory registration (Yishai Hadas)   
- net/mlx4_core: num mtt issues (Yishai Hadas)   
- mlx4_en: do dump eth statistics under mutex (Eugenia Emantayev)   
- net/mlx4_core: make sure that negative array index isn't used (Dotan Barak)   
- mlx4_en: fixing the condition before releasing resources (Dotan Barak)   
- IB/mlx4: fix compilation warning (Dotan Barak)   
- IB/mlx4: Prevent from all of the users in the system to clear the diag counters (Dotan Barak)   
- IB/core: Fix compilation warning in kernel 3.5+ (Dotan Barak)   
- mlx4_ib: Partial fix for ipoib SRIOV (Hadar Hen Zion)   
- mlx4_ib: prevent mixing enum mlx4_ib_qp_flags type with enum ib_qp_create_flags type (Saeed Mahameed)   
- IB/core: add module parameter to allow a non-root user to open a RAW QP (Dotan Barak)   
- mlx4_en: returning NETIF_F_GRO flag to dev->features (Yevgeny Petrilin)   
- mlx4_ib: add blue flame support for kernel consumers (Eli Cohen)   
- net/mlx4_core: add sanity check when creating bitmap structure (Dotan Barak)   
- mlx4_core: supporting 64b counters (Vu Pham)   
- ib_core: supporting 64b counters using PMA_COUNTERS_EXT mad (Vu Pham)   
- mlx4_core: fix error flow in case mlx4_reset failed (Dotan Barak)   
- net/mlx4_core: unmap clear register in case of error flow (Dotan Barak)   
- mlx4_core: support suspend/resume events (Eli Cohen)   
- srp: don't release resources if the add_one failed (Dotan Barak)   
- mlx4_en: Fixed memory leak in case of error flow (Dotan Barak)   
- ib_core: fix NULL pointer dereference (Dotan Barak)   
- mlx4_en: queue stop/start counters per ring (Yevgeny Petrilin)   
- mlx4_en: Using atomic counter to decide when queue is full. (Yevgeny Petrilin)   
- IB/mlx4: Add support for RSS and TSS QP groups (Shlomo Pongratz)   
- IB/core: Add RSS and TSS QP groups (Shlomo Pongratz)   
- mlx4_en: Data path structures are allocated per numa node. (Yevgeny Petrilin)   
- mlx4_core: ICM pages are allocated on device NUMA node (Yevgeny Petrilin)   
- mlx4_en: Datapath resources allocated separately (Yevgeny Petrilin)   
- mlx4_en: fix compilation error on 3.5 (Eugenia Emantayev)   
- mlx4_en: add timestamp support (Eugenia Emantayev)   
- mlx4_core: read hca frequency and map internal clock (Eugenia Emantayev)   
- mlx4_core: add timestamp device capability (Eugenia Emantayev)   
- mlx4_core: For flow steering unicast ipoib support added new flag to IB header check (Hadar Hen Zion)   
- mlx4_ib: contig support for control objects (Yishai Hadas)   
- mlx4: Setting Ethernet port even if interface is not being brought up (Yevgeny Petrilin)   
- mlx4: Enable fast_drop option (Yevgeny Petrilin)   
- mlx4_en: suppress page allocation failure warnings (Yevgeny Petrilin)   
- mlx4_en: Allocation order is 0 on 32 bit systems to avoid allocation failures (Yevgeny Petrilin)   
- mlx4: Allow high_rate_steer (A0 mode) (Yevgeny Petrilin)   
- mlx4: Respond to operation request by FW. (Yevgeny Petrilin)   
- mlx4_core: fix wrong comment about the reason of subtract one from the max_cqes (Dotan Barak)   
- ib/core: change module_param to module_param_named call. (Erez Shitrit)   
- ib_core: Use weak ordering for data registered memory (Eli Cohen)   
- IB/core - Don't modify outgoing DR SMP if first part is LID routed (Ralph Campbell)   
- mlx4_core: remove use_prio module parameter (Eugenia Emantayev)   
- net/mlx4: adjust initial value of vl_cap in mlx4_SET_PORT (Or Gerlitz)   
- mlx4_core: Error message on mtt allocation failure (Marcel Apfelbaum)   
- mlx4_core: fail device init if num_vfs is negative. (Jack Morgenstein)   
- IB/core: Control number of retries for SA to leave an MCG (Dotan Barak)   
- mlx4: More mverbs support (Dotan Barak)   
- mlx4: add warning prints in case of command timeouts (Dotan Barak)   
- mlx4_core: Increased Command Timeout for NOP operation (Yevgeny Petrilin)   
- mlx4: Disable BF on PPC (Dotan Barak)   
- mlx4: reducing wait during SW reset for 500 msecs (Dotan Barak)   
- mlx4_ib: check for FW version which properly supports resize_cq. (Dotan Barak)   
- mlx4_ib: Do not enable blueflame sends if write combining is not available (Jack Morgenstein)   
- IB/core: Fix create_qp issue relates to qp group type (Yishai Hadas)   
- mlx4_core: log_num_mtt handling (Yishai Hadas)   
- mlx4_core: adding 'set_4k_mtu' module parameter as an obsolete one (Yishai Hadas)   
- mlx4_ib: Fix the SQ size of an RC QP to support masked atomic operation (Dotan Barak)   
- {NET,IB}/mlx4: 64 byte CQE/EQE support (Or Gerlitz)   
- ib_core: cmem handling to prevent redundant WARN (Yishai Hadas)   
- ib_core: rlimit fix when cmem alloc has failed (Yishai Hadas)   
- IB/mlx4_ib: use 8 bits in mlx4_ib_mmap for command ID instead of 3 (Yishai Hadas)   
- IB: enable shared mr functionality (Yishai Hadas)   
- IB/mlx4_ib: shared mr initial handling (Yishai Hadas)   
- IB/core: infrastructure extensions to be used for shared mr functionality (Yishai Hadas)   
- IB/mlx4_ib: 'proc' handling (Yishai Hadas)   
- IB: reg_user_mr changes to include a new field named mr_id (Yishai Hadas)   
- IB/core: ib_uverbs_reg_mr flow change (Yishai Hadas)   
- ib_core: symmetric issues with user space. (Yishai Hadas)   
- mlx4_ib: Use optimal numbers of MTT entries. (Yishai Hadas)   
- mlx4_ib: implement get_unmapped_area (Yishai Hadas)   
- ib_core: Exporting capability to control the alignment of the virtual address returned by mmap. (Yishai Hadas)   
- mlx4_ib: Exporting to user space the contiguous allocation capability by mmap extension (Yishai Hadas)   
- ib_core: Extending umem to support contiguous memory operations. (Yishai Hadas)   
- mlx4: make firmware diagnostic counters available via sysfs (Dotan Barak)   
- mlx4: enable discarding/passing multicast loopback packets by FW/HW. (Dotan Barak)   
- mlx4_ib: set write-combining flag for userspace blueflame pages (Dotan Barak)   
- mlx4_core: limit min profile numbers (Dotan Barak)   
- mlx4_core: allow to use 0 in log_mtts_per_seg (Dotan Barak)   
- mlx4_core: enable changing default max HCA resource limits. (Dotan Barak)   
- cma: add module parameter to the response timeout (Arlin Davis)   
- mlx4: Add mverbs support (Dotan Barak)   
- mlx4_core: replace sscanf() with simple_strtol() (Dotan Barak)   
- mlx4: increase the command timeout to 60 seconds (Dotan Barak)   
- mlx4_core, mlx4_ib, cma, ipoib: Add IB UC flow steering for datagram QP's. (Amir Vadai)   
- mlx4_ib: add support to flow steering attach with rdmacm applications. (Hadar Hen Zion)   
- rdma_cm: Implement rdma_get_l2 (Nir Muchtar)   
- ib_uverbs: Export ib_attach_flow and ib_detach_flow to userspace. (Nir Muchtar)   
- mlx4_ib: Add support for ib_attach_flow and ib_detach_flow. (Nir Muchtar)   
- ib_core: Implement ib_attach_flow ib_detach_flow (Nir Muchtar)   
- mlx4_core: enable RoCE under SRIOV (Jack Morgenstein)   
- mlx4_core: Adjust update-gids task for RoCE running under SRIOV (Jack Morgenstein)   
- mlx4_ib: In sysfs, do not allow changing the paravirtualization mapping for pkeys (Jack Morgenstein)   
- {IB,ETH}/mlx4: Adjust QP1 multiplexing and QP creation for RoCE/SRIOV (Jack Morgenstein)   
- en/mlx4_core: For RoCE, allow slaves to set the GID entry at that slave's index (Jack Morgenstein)   
- {IB,ETH}/mlx4: Add ref counting to port MAC table for RoCE (Jack Morgenstein)   
- mlx4_core: Add mechanism for non trackable mem free (Moshe Lazer)   
- memtrack: fix get_page/put_page tracking (Jack Morgenstein)   
- Added memtrack (Vladimir Sokolovsky)   
- Revert "mlx4_en: fix allocation of CPU affinity reverse-map" (Ajaykumar Hotchandani)   
- Revert "IPoIB: Call skb_dst_drop() once skb is enqueued for sending" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Increase block layer timeout" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Eliminate state SRP_TARGET_CONNECTING" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Keep processing commands during host removal" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Simplify SCSI error handling" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Introduce srp_handle_qp_err()" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Process all error completions" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Introduce the helper function srp_remove_target()" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Suppress superfluous error messages" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Eliminate state SRP_TARGET_DEAD" (Ajaykumar Hotchandani)   
- Revert "IB/srp: destroy and recreate QP and CQs when reconnecting" (Ajaykumar Hotchandani)   
- Revert "IB/srp: send disconnect request without waiting for CM timewait exit" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Allow SRP disconnect through sysfs" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Track connection state properly" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Avoid sending a task management function needlessly" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Avoid endless SCSI error handling loop" (Ajaykumar Hotchandani)   
- Revert "IB/srp: Fail I/O requests if the transport is offline" (Ajaykumar Hotchandani)   
- Revert "rds: limit the size allocated by rds_message_alloc()" (Ajaykumar Hotchandani)   
- Revert "net: rds: use this_cpu_* per-cpu helper" (Ajaykumar Hotchandani)   
- Revert "IB/rds: Correct ib_api use with gs_dma_address/sg_dma_len" (Ajaykumar Hotchandani)   
- Revert "IB/rds: suppress incompatible protocol when version is known" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: remove __dev* attributes" (Ajaykumar Hotchandani)   
- Revert "mlx4: change TX coalescing defaults" (Ajaykumar Hotchandani)   
- Revert "IPoIB: Fix send lockup due to missed TX completion" (Ajaykumar Hotchandani)   
- Revert "mlx4: 64-byte CQE/EQE support" (Ajaykumar Hotchandani)   
- Revert "mlx4_en: Remove remnants of LRO support" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Can set maxrate only for TC0" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Set number of rx/tx channels using ethtool" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Use generic etherdevice.h functions." (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Add support for destination MAC in steering rules" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Add QPN enforcement for flow steering rules set by VFs" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Fix error flow in the flow steering wrapper" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Adjustments to Flow Steering activation logic for SR-IOV" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Allow choosing flow steering mode" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_core: Set number of msix vectors under SRIOV mode to firmware defaults" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Fix advertisement of wrong PF context behaviour" (Ajaykumar Hotchandani)   
- Revert "mlx4_en: fix allocation of device tx_cq" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Initialize RFS filters lock and list in init_netdev" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Disable RFS when running in SRIOV mode" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Fix bridged vSwitch configuration for non SRIOV mode" (Ajaykumar Hotchandani)   
- Revert "net/mlx4_en: Fix TX moderation info loss after set_ringparam is called" (Ajaykumar Hotchandani)   
- Revert "mlx4_core: Fix potential deadlock in mlx4_eq_int()" (Ajaykumar Hotchandani)   
- Revert "IPoIB: Fix crash due to skb double destruct" (Ajaykumar Hotchandani)   
- Revert "IB/mlx4: Fix spinlock order to avoid lockdep warnings" (Ajaykumar Hotchandani)   
- Revert "RDMA/cm: Change return value from find_gid_port()" (Ajaykumar Hotchandani)   

* Fri Aug 2 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-7.el6uek] 
- qla4xxx: Updated driver version to 5.03.00.03.06.02-uek3 (Tej Parkash) [Orabug: 17220566]  
- libiscsi: Add missing prints for session and connection sysfs attrs (Adheer Chandravanshi) [Orabug: 17220566]  
- libiscsi: Add a missing break statement (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Export more firmware info in sysfs (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Only BIOS boot target entries should be at index 0 and 1. (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: discovery_parent_idx can be shown without any check. (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Set IPv6 traffic class if device type is IPv6. (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Use discovery_parent_idx instead of discovery_parent_type (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Allow removal of failed session using logout. (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Exporting new attrs for iscsi session and connection in sysfs (Adheer Chandravanshi) [Orabug: 17220566]  
- libiscsi: Exporting new attrs for iscsi session and connection in sysfs (Adheer Chandravanshi) [Orabug: 17220566]  
- scsi_transport_iscsi: Exporting new attrs for iscsi session and connection in sysfs (Adheer Chandravanshi) [Orabug: 17220566]  
- libiscsi: Added new boot entries in the session sysfs (Eddie Wai) [Orabug: 17220566]  
- treewide: Fix typo in printk (Masanari Iida) [Orabug: 17220566]  
- iscsi class, qla4xxx: fix sess/conn refcounting when find fns are used (Mike Christie) [Orabug: 17220566]  
- qla4xxx: Fix iocb_cnt calculation in qla4xxx_send_mbox_iocb() (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Assign values using correct datatype (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Fix smatch warnings (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Fix sparse warning for qla4xxx_sysfs_ddb_tgt_create (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Silence gcc warning (Vikas Chaudhary) [Orabug: 17220566]  
- iscsi_tcp: support PF_MEMALLOC/__GFP_MEMALLOC (Mike Christie) [Orabug: 17220566]  
- libiscsi: avoid unnecessary multiple NULL assignments (Masatake YAMATO) [Orabug: 17220566]  
- qla4xxx: Added print statements to display AENs (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Use correct value for max flash node entries (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Restrict logout from boot target session using session id (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Use correct flash ddb offset for ISP40XX (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Replace dev type macros with generic portal type macros (Adheer Chandravanshi) [Orabug: 17220566]  
- scsi_transport_iscsi: Declare portal type string macros for generic use (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Add flash node mgmt support (Adheer Chandravanshi) [Orabug: 17220566]  
- libiscsi: export function iscsi_switch_str_param (Adheer Chandravanshi) [Orabug: 17220566]  
- scsi_transport_iscsi: Add flash node mgmt support (Adheer Chandravanshi) [Orabug: 17220566]  
- qla4xxx: Skip retry of initialize_adapter for ISP80XX (Nilesh Javali) [Orabug: 17220566]  
- qla4xxx: Assign correct CHAP table address to FLT (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Added missing check for ISP83XX in CHAP related functions (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Fixed request queue count manipulation on response path (Tej Parkash) [Orabug: 17220566]  
- qla4xxx: Fix debug level to avoid floods of same message (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Pass correct LUN address to firmware in case of lun_reset (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Fix double reset in case of firmware hung for ISP83XX (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Set graceful reset bit for ISP83XX (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Boot from SAN fix for ISP83XX (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Take E-port out of reset before disabling pause frames (Manish Dusane) [Orabug: 17220566]  
- scsi: replace obsolete NLMSG_* with type safe nlmsg_* (Hong zhi guo) [Orabug: 17220566]  
- treewide: Fix typos in printk and comment (Masanari Iida) [Orabug: 17220566]  
- qla4xxx: don't free NULL dma pool (Dan Carpenter) [Orabug: 17220566]  
- qla4xxx: Fix return code for qla4xxx_session_get_param. (Manish Rangankar) [Orabug: 17220566]  
- qla4xxx: wait for boot target login response during probe. (Manish Rangankar) [Orabug: 17220566]  
- qla4xxx: Added support for force firmware dump (Vikas Chaudhary) [Orabug: 17220566]  
- qla4xxx: Re-register IRQ handler while retrying initialize of adapter (Poornima Vonti) [Orabug: 17220566]  
- qla4xxx: Throttle active IOCBs to firmware limits (Karen Higgins) [Orabug: 17220566]  
- qla4xxx: Remove unnecessary code from qla4xxx_init_local_data (Karen Higgins) [Orabug: 17220566]  
- qla4xxx: Quiesce driver activities while loopback (Nilesh Javali) [Orabug: 17220566]  
- qla4xxx: Rename MBOX_ASTS_IDC_NOTIFY to MBOX_ASTS_IDC_REQUEST_NOTIFICATION (Nilesh Javali) [Orabug: 17220566]  
- qla4xxx: Add spurious interrupt messages under debug level 2 (Nilesh Javali) [Orabug: 17220566]  
- qla4xxx: Correct the validation to check in get_sys_info mailbox (Nilesh Javali) [Orabug: 17220566]  
- qla4xxx: Pass correct function param to qla4_8xxx_rd_direct (Vikas Chaudhary) [Orabug: 17220566]  
- scsi_transport_iscsi: export iscsi class session's target_id in sysfs. (Manish Rangankar) [Orabug: 17220566]  
- qla4xxx: Fix memory corruption issue in qla4xxx_get_ep_fwdb. (Manish Rangankar) [Orabug: 17220566]  
- qla4xxx: Allow reset in link down case (Harish Zunjarrao) [Orabug: 17220566]  
- qla4xxx: Fix MBOX intr switching from polling to intr mode for ISP83XX (Vikas Chaudhary) [Orabug: 17220566]  
- config: enable numa balancing (Jerry Snitselaar) [Orabug: 17018504]  
- config: disable Transparent Hugepages (Jerry Snitselaar) [Orabug: 17251843]  
- be2net: Updating version number (Sarveshwar Bandi) [Orabug: 17252720]  
- be2net: Fix to avoid hardware workaround when not needed (Sarveshwar Bandi) [Orabug: 17252720]  
- net/trivial: replace numeric with standard PM state macros (Yijing Wang) [Orabug: 17252720]  
- be2net: Fix 32-bit DMA Mask handling (Somnath Kotur) [Orabug: 17252720]  
- be2net: Implement initiate FW dump feature for Lancer (Somnath Kotur) [Orabug: 17252720]  
- be2net: Fix crash on 2nd invocation of PCI AER/EEH error_detected hook (Somnath Kotur) [Orabug: 17252720]  
- be2net: Mark checksum fail for IP fragmented packets (Somnath Kotur) [Orabug: 17252720]  
- be2net: Trim padded packets for Lancer (Somnath Kotur) [Orabug: 17252720]  
- be2net: Pad skb to meet min Tx pkt size in lancer (Somnath Kotur) [Orabug: 17252720]  
- be2net: cleanup be_get_drvinfo() (Somnath Kotur) [Orabug: 17252720]  
- be2net: refactor HW workarounds in be_xmit() (Sathya Perla) [Orabug: 17252720]  
- be2net: bug fix on returning an invalid nic descriptor (Wei Yang) [Orabug: 17252720]  
- be2net: Avoid double insertion of vlan tags. (Sarveshwar Bandi) [Orabug: 17252720]  
- be2net: disable TX in be_close() (Sathya Perla) [Orabug: 17252720]  
- be2net: fix EQ from getting full while cleaning RX CQ (Sathya Perla) [Orabug: 17252720]  
- be2net: fix payload_len value for GET_MAC_LIST cmd req (Sathya Perla) [Orabug: 17252720]  
- be2net: provision VF resources before enabling SR-IOV (Sathya Perla) [Orabug: 17252720]  
- be2net: Fix to fail probe if MSI-X enable fails for a VF (Somnath Kotur) [Orabug: 17252720]  
- be2net: avoid napi_disable() when it has not been enabled (Somnath Kotur) [Orabug: 17252720]  
- be2net: Fix firmware download for Lancer (Somnath Kotur) [Orabug: 17252720]  
- be2net: Fix to receive Multicast Packets when Promiscuous mode is enabled on certain devices (Ajit Khaparde) [Orabug: 17252720]  
- be2net: Fix to show tx priority pause counter in ethtool -S (Ajit Khaparde) [Orabug: 17252720]  
- be2net: Fix to use 32-bit stats to report rx_drops_no_fragment (Ajit Khaparde) [Orabug: 17252720]  
- be2net: Fix to use version 2 of cq_create for SkyHawk-R devices (Ajit Khaparde) [Orabug: 17252720]  
- be2net: FLR must be first cmd issued to Lancer FW (Kalesh AP) [Orabug: 17252720]  
- be2net: Use GET_FUNCTION_CONFIG V1 cmd (Kalesh AP) [Orabug: 17252720]  
- be2net: Fix to show wol disabled/enabled state correctly. (Sarveshwar Bandi) [Orabug: 17252720]  
- be2net: Fixed memory leak (Suresh Reddy) [Orabug: 17252720]  
- be2net: Avoid diagnostic test in certain versions of firmware to avoid NIC freeze. (Suresh Reddy) [Orabug: 17252720]  
- be2net: Renamed rx_address_mismatch_errors to rx_address_filtered (Suresh Reddy) [Orabug: 17252720]  
- be2net: Add support for setting and getting rx flow hash options (Suresh Reddy) [Orabug: 17252720]  
- be2net: Fix PVID tag offload for packets with inline VLAN tag. (Ajit Khaparde) [Orabug: 17252720]  
- be2net: fix a Tx stall bug caused by a specific ipv6 packet (Ajit Khaparde) [Orabug: 17252720]  
- be2net: Remove an incorrect pvid check in Tx (Ajit Khaparde) [Orabug: 17252720]  
- be2net: enable IOMMU pass through for be2net (Craig Hada) [Orabug: 17252720]  
- be2net: Use GET_PROFILE_CONFIG V1 cmd for BE3-R (Vasundhara Volam) [Orabug: 17252720]  
- be2net: Avoid flashing BE3 UFI on BE3-R chip. (Vasundhara Volam) [Orabug: 17252720]  
- be2net: Don't log "Out of MCCQ wrbs" error (Vasundhara Volam) [Orabug: 17252720]  
- be2net: Use TXQ_CREATE_V2 cmd (Vasundhara Volam) [Orabug: 17252720]  
- be2net: take care of __vlan_put_tag return value (Ivan Vecera) [Orabug: 17252720]  
- be2net: remove unused variable 'sge' (Ivan Vecera) [Orabug: 17252720]  
- drivers:net: dma_alloc_coherent: use __GFP_ZERO instead of memset(, 0) (Joe Perches) [Orabug: 17252720]  
- drivers:net: Remove dma_alloc_coherent OOM messages (Joe Perches) [Orabug: 17252720]  
- be2net: Use new F/W mailbox cmd to manipulate interrupts. (Somnath Kotur) [Orabug: 17252720]  
- be2net: enable interrupts in be_probe() (RoCE and other ULPs need them) (Somnath Kotur) [Orabug: 17252720]  
- be2net: Update copyright year (Vasundhara Volam) [Orabug: 17252720]  
- be2net: use CSR-BAR SEMAPHORE reg for BE2/BE3 (Sathya Perla) [Orabug: 17252720]  
- benet: Wait f/w POST until timeout (Gavin Shan) [Orabug: 17252720]  
- be2net: remove BUG_ON() in be_mcc_compl_is_new() (Sathya Perla) [Orabug: 17252720]  
- be2net: update driver version to 4.6.x (Sathya Perla) [Orabug: 17252720]  
- be2net: fix re-loaded PF driver to re-gain control of its VFs (Sathya Perla) [Orabug: 17252720]  
- ethtool: fix drvinfo strings set in drivers (Jiri Pirko) [Orabug: 17252720]  
- block: do not pass disk names as format strings (Kees Cook) [Orabug: 17230056] {CVE-2013-2851} 
- libceph: Fix NULL pointer dereference in auth client code (Tyler Hicks) [Orabug: 17230095] {CVE-2013-1059} 
- Btrfs: re-add root to dead root list if we stop dropping it (Josef Bacik)   
- Btrfs: fix lock leak when resuming snapshot deletion (Josef Bacik)   
- Btrfs: only do the tree_mod_log_free_eb if this is our last ref (Josef Bacik)   
- Btrfs: hold the tree mod lock in __tree_mod_log_rewind (Josef Bacik)   
- Btrfs: fix oops when recovering the file data by scrub function (Miao Xie)   
- Btrfs: unlock extent range on enospc in compressed submit (Josef Bacik)   
- btrfs: do away with non-whole_page extent I/O (Alexandre Oliva)   
- btrfs: don't stop searching after encountering the wrong item (Gabriel de Perthuis)   
- Btrfs: don't call readahead hook until we have read the entire eb (Josef Bacik)   
- Btrfs: fix possible infinite loop in slow caching (Josef Bacik)   
- Btrfs: fix lockdep warning (Josef Bacik)   
- Btrfs: don't force pages under writeback to finish when aborting (Josef Bacik)   
- Btrfs: fix unlock after free on rewinded tree blocks (Jan Schmidt)   
- Btrfs: fix accessing the root pointer in tree mod log functions (Jan Schmidt)   
- Btrfs: fix tree mod log regression on root split operations (Jan Schmidt)   
- Btrfs: fix bad extent logging (Josef Bacik)   
- Btrfs: log ram bytes properly (Josef Bacik)   
- Btrfs: fix memory leak in btrfs_create_tree() (Tsutomu Itoh)   
- Btrfs: fix warning of free_extent_map (Liu Bo)   
- Btrfs: fix warning when creating snapshots (Liu Bo)   
- Btrfs: fix missing deleted items in btrfs_clean_quota_tree (Wang Shilong)   
- Btrfs: fix memory leak of log roots (Liu Bo)   
- Btrfs: fix NULL pointer after aborting a transaction (Liu Bo)   
- Btrfs: do not change inode flags in rename (Liu Bo)   
- Btrfs: use reserved space for creating a snapshot (Liu Bo)   
- Btrfs: make sure NODATACOW also gets NODATASUM set (Josef Bacik)   
- Btrfs: fix backref walking race with tree deletions (Jan Schmidt)   
- Btrfs: fix wrong outstanding_extents when doing DIO write (Miao Xie)   
- Btrfs: fix cleaner thread not working with inode cache option (Liu Bo)   
- Btrfs: fix the deadlock between the transaction start/attach and commit (Miao Xie)   
- Btrfs: eliminate a use-after-free in btrfs_balance() (Ilya Dryomov)   
- Btrfs: fix deadlock due to unsubmitted (Miao Xie)   
- Btrfs: fix memory leak of pending_snapshot->inherit (Miao Xie)   
- Btrfs: fix the race between bio and btrfs_stop_workers (Miao Xie)   
- Btrfs: handle errors in compression submission path (Josef Bacik)   
- Btrfs: rework the overcommit logic to be based on the total size (Josef Bacik)   
- Btrfs: unreserve space if our ordered extent fails to work (Josef Bacik)   
- Btrfs: fix how we discard outstanding ordered extents on abort (Josef Bacik)   
- Btrfs: fix freeing delayed ref head while still holding its mutex (Josef Bacik)   
- Btrfs: do not overcommit if we don't have enough space for global rsv (Josef Bacik)   
- Btrfs: remove extent mapping if we fail to add chunk (Josef Bacik)   
- Btrfs: fix chunk allocation error handling (Josef Bacik)   
- Btrfs: fix crash in log replay with qgroups enabled (Arne Jansen)   

* Tue Jul 30 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-6.el6uek] 
- mpt2sas: update from 16.05.01.00 to 17.00.00.00 (Jerry Snitselaar) [Orabug: 17237382]  
- enable VMware module vsock,vmw_vmci,vmw_vsock_vmci_transport (Vaughan Cao) [Orabug: 16957210]  
- Backport VMCI and vSockets from 3.10 (Andy King) [Orabug: 16957210]  
- vmxnet3: prevent div-by-zero panic when ring resizing uninitialized dev (Bhavesh Davda) [Orabug: 17215008]  
- ipv6: ip6_sk_dst_check() must not assume ipv6 dst (Eric Dumazet) [Orabug: 17079717]  
- build,drm: enable building of vmwgfx driver (Jerry Snitselaar) [Orabug: 17158893]  
- be2iscsi: Bump the driver version to 10.0.467.0 (John Soni Jose) [Orabug: 17233074]  
- be2iscsi: Fix issue in passing the exp_cmdsn and max_cmdsn (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix possible reentrancy issue in be_iopoll (Shlomo Pongratz) [Orabug: 17233074]  
- be2scsi: Update copyright dates to 2013 (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix checking Adapter state while establishing CXN (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix dynamic CID allocation Mechanism in driver (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi : Fix the NOP-In handling code path (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix the Port Link Status issue (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix displaying the Active Session Count from driver (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix displaying the FW Version from driver. (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix support for DEFQ extension (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix MACRO for checking the adapter type (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix freeing CXN specific driver resources. (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix MSIX support in SKH-R to 32 (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix MBX Command issues (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix returning Failure when MBX fails with Insufficient buffer error (Jayamohan Kallickal) [Orabug: 17233074]  
- be2iscsi: Fix lack of uninitialize pattern to FW (Jayamohan Kallickal) [Orabug: 17233074]  
- treewide: Fix typo in printk and comments (Masanari Iida) [Orabug: 17233074]  
- neighbour: fix a race in neigh_destroy() (Eric Dumazet)   
- mpt3sas: Bump driver version to v02.100.00.00 (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: when async scanning is enabled then while scanning, devices are removed but their transport layer entries are not removed (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: MPI2.5 Rev F v2.5.1.1 specification (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: Infinite loops can occur if MPI2_IOCSTATUS_CONFIG_INVALID_PAGE is not returned (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: fix for kernel panic when driver loads with HBA conected to non LUN 0 configured expander (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: Updated the Hardware timing requirements (Sreekanth Reddy) [Orabug: 17187623]  
- mpt3sas: 2013 source code copyright (Sreekanth Reddy) [Orabug: 17187623]  
- fib_trie: potential out of bounds access in trie_show_stats() (Jerry Snitselaar) [Orabug: 17215539]  
- Revert "xen/pat: Disable PAT using pat_enabled value." (Jerry Snitselaar) [Orabug: 17176404]  
- sxge: Check link state before xmit (Joe Jin) [Orabug: 17201220]  

* Tue Jul 23 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-5.el6uek] 
- writeback fix bdi thread race in mark_inode_dirty (UEK3) (Srinivas Eeda)   
- mpt2sas: update to LSI version 16.05.01.00 (Maxim Uvarov) [Orabug: 16730165]  
- megaraid_sas driver update from 06.504.01.00-rc1 to version 06.600.18.00 (Maxim Uvarov) [Orabug: 17177382]  
- Specfile changes for sparc (Dave Kleikamp)   
- sunvdc: fix typo and remove unused function (Dave Kleikamp)   
- sparc: rcu_needs_cpu() needs second argument (Dave Kleikamp)   
- sparc: add back TIF_FREEZE to fix a build break (Dave Kleikamp)   
- sparc: fix typo in smp_64.h (Dave Kleikamp)   
- writeback: Fix periodic writeback after fs mount (Jan Kara) [Orabug: 17185874]  
- [SCSI] scsi_transport_iscsi: fix error return code in iscsi_transport_init() (Wei Yongjun) [Orabug: 17153681]  

* Fri Jul 19 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-4.el6uek] 
- configs: turn on sxge (Maxim Uvarov)   
- [net] add sxge and sxgevf drivers (Maxim Uvarov) [Orabug: 16443168]  
- sparc64 - userspace VA layout (bob picco)   
- kernel: freezer: restore TIF_FREEZE (Sasha Levin)   
- Revert "megaraid_sas: Big endian support" (Maxim Uvarov) [Orabug: 17167688]  
- bnx2x correct firmwares ihex (Maxim Uvarov) [Orabug: 17034501]  
- config changes from uek2 (Allen Pais)   
- sparc64: fatal trap should stop all cpus (Dave Kleikamp)   
- sunvdc TX TEMPORARY workaround (Allen Pais)   
- vdisk geometry (Allen Pais)   
- sunvet (Allen Pais)   
- sunvdc cdrom support (Allen Pais)   
- xen-netfront: use skb_partial_csum_set() to simplify the codes (Li RongQing)   
- xen-netfront: split event channels support for Xen frontend driver (Wei Liu)   
- xen-netfront: avoid leaking resources when setup_netfront fails (Wei Liu)   
- xen-netfront: reduce gso_max_size to account for max TCP header (Wei Liu)   
- xen-netfront: frags -> slots in log message (Wei Liu)   
- xen-netfront: frags -> slots in xennet_get_responses (Wei Liu)   
- xen-netfront: remove unused variable `extra' (Wei Liu)   
- xen-netback: xenbus.c: use more current logging styles (Wei Liu)   
- xen: Use more current logging styles (Joe Perches)   
- xen-netback: double free on unload (Dan Carpenter)   
- xen-netback: don't de-reference vif pointer after having called xenvif_put() (Jan Beulich)   
- perf sparc4 dwarf (Allen Pais)   
- xen-netback: split event channels support for Xen backend driver (Wei Liu)   
- xen-netback: enable user to unload netback module (Wei Liu)   
- xen-netback: remove dead code (Wei Liu)   
- xen-netback: better names for thresholds (Wei Liu)   
- xen-netback: avoid allocating variable size array on stack (Wei Liu)   
- xen-netback: remove redundent parameter in netbk_count_requests (Wei Liu)   
- xen-netback: don't disconnect frontend when seeing oversize packet (Wei Liu)   
- xen-netback: coalesce slots in TX path and fix regressions (Wei Liu)   
- xen-netback: fix sparse warning (stephen hemminger)   
- do_rt_sigreturn - minor clean up (bob picco)   
- remove sparc support (bob picco)   
- cpu_idle - add rcu needs cpu to yield decision (bob picco)   
- sparc64_yield - consolidate conditions for enter  yield (Allen Pais)   
- small clean up - isolate CPU_HOTPLUG in include file (Allen Pais)   
- xen-netback: remove skb in xen_netbk_alloc_page (Wei Liu)   
- Revert "xen: netback: remove redundant xenvif_put" (David S. Miller)   
- xen: netback: remove redundant xenvif_put (Andrew Jones)   
- xen-netback: allow changing the MAC address of the interface (Matt Wilson)   

* Wed Jul 10 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-3.el6uek] 
- xen/netback: correctly calculate required slots of skb. (Annie Li) [Orabug: 16934362]  
- megaraid_sas: Big endian support (Martin K. Petersen)   
- sparc/ldom sysfs now shows only CPUs assigned to VM, not all in MD (Allen Pais)   
- ixgbe: Look up MAC address on SPARC systems (Allen Pais)   
- bnx2x: update fw to 7.8.2 (Yuval Mintz)   
- x86 idle: remove mwait_idle() and "idle=mwait" cmdline param (Len Brown) [Orabug: 17034508]  
- Revert "xen/pci: Use PCI_MSIX_TABLE_BIR, not PCI_MSIX_FLAGS_BIRMASK" (Konrad Rzeszutek Wilk)   
- Revert "xen/pci: Used cached MSI-X capability offset" (Konrad Rzeszutek Wilk)   
- Revert "xen-pciback: more uses of cached MSI-X capability offset" (Konrad Rzeszutek Wilk)   
- xen-blkback: check the number of iovecs before allocating a bios (Roger Pau Monne)   
- xen: Convert printks to pr_<level> (Joe Perches)   
- xen/time: remove blocked time accounting from xen "clockchip" (Laszlo Ersek)   
- xen: ifdef CONFIG_HIBERNATE_CALLBACKS xen_*_suspend (Stefano Stabellini)   
- xen/pcifront: Deal with toolstack missing 'XenbusStateClosing' state. (Konrad Rzeszutek Wilk)   
- xen/time: Free onlined per-cpu data structure if we want to online it again. (Konrad Rzeszutek Wilk)   
- xen/time: Check that the per_cpu data structure has data before freeing. (Konrad Rzeszutek Wilk)   
- xen/time: Don't leak interrupt name when offlining. (Konrad Rzeszutek Wilk)   
- xen/time: Encapsulate the struct clock_event_device in another structure. (Konrad Rzeszutek Wilk)   
- xen/spinlock: Don't leak interrupt name when offlining. (Konrad Rzeszutek Wilk)   
- xen/smp: Don't leak interrupt name when offlining. (Konrad Rzeszutek Wilk)   
- xen/smp: Set the per-cpu IRQ number to a valid default. (Konrad Rzeszutek Wilk)   
- xen/smp: Introduce a common structure to contain the IRQ name and interrupt line. (Konrad Rzeszutek Wilk)   
- xen/smp: Coalesce the free_irq calls in one function. (Konrad Rzeszutek Wilk)   
- xen-pciback: fix error return code in pcistub_irq_handler_switch() (Wei Yongjun)   
- microcode_xen: Add support for AMD family >= 15h (Ian Campbell)   
- x86/microcode: check proper return code. (Ben Guthro)   
- xen: add CPU microcode update driver (Jeremy Fitzhardinge)   
- x86/cpa: Use pte_attrs instead of pte_flags on CPA/set_p.._wb/wc operations. (Konrad Rzeszutek Wilk)   
- Revert "xen/pat: Disable PAT support for now." (Konrad Rzeszutek Wilk)   
- Revert "xen/pat: Disable PAT using pat_enabled value." (Konrad Rzeszutek Wilk)   
- xen / ACPI / sleep: Register an acpi_suspend_lowlevel callback. (Konrad Rzeszutek Wilk)   
- x86 / ACPI / sleep: Provide registration for acpi_suspend_lowlevel. (Konrad Rzeszutek Wilk)   
- xen/smp: Fixup NOHZ per cpu data when onlining an offline CPU. (Konrad Rzeszutek Wilk)   
- xenbus_client.c: correct exit path for xenbus_map_ring_valloc_hvm (Wei Liu)   
- xen-pciback: more uses of cached MSI-X capability offset (Jan Beulich)   
- xen: Clean up apic ipi interface (Stefan Bader)   
- xenbus: save xenstore local status for later use (Aurelien Chartier)   
- xenbus: delay xenbus frontend resume if xenstored is not running (Aurelien Chartier)   
- xen: Fixed assignment error in if statement (Lisa Nguyen)   
- xen/xenbus: Fixed over 80 character limit issue (Lisa Nguyen)   
- xen/xenbus: Fixed indentation error in switch case (Lisa Nguyen)   
- xen/privcmd: fix condition in privcmd_close() (Dan Carpenter)   
- xen/pci: Used cached MSI-X capability offset (Bjorn Helgaas)   
- xen/pci: Use PCI_MSIX_TABLE_BIR, not PCI_MSIX_FLAGS_BIRMASK (Bjorn Helgaas)   
- xen: clear IRQ_NOAUTOEN and IRQ_NOREQUEST (Julien Grall)   
- xen: mask x2APIC feature in PV (Zhenzhong Duan)   
- xen: SWIOTLB is only used on x86 (Arnd Bergmann)   
- xen/spinlock: Fix check from greater than to be also be greater or equal to. (Konrad Rzeszutek Wilk)   
- xen/smp/pvhvm: Don't point per_cpu(xen_vpcu, 33 and larger) to shared_info (Konrad Rzeszutek Wilk)   
- xen/vcpu: Document the xen_vcpu_info and xen_vcpu (Konrad Rzeszutek Wilk)   
- xen/vcpu/pvhvm: Fix vcpu hotplugging hanging. (Konrad Rzeszutek Wilk)   
- xen: resolve section mismatch warnings in xen-acpi-processor (Ben Guthro)   
- xen: Re-upload processor PM data to hypervisor after S3 resume (v2) (Ben Guthro)   
- xen/smp: Unifiy some of the PVs and PVHVM offline CPU path (Konrad Rzeszutek Wilk)   
- xen/smp/pvhvm: Don't initialize IRQ_WORKER as we are using the native one. (Konrad Rzeszutek Wilk)   
- xen/spinlock: Disable IRQ spinlock (PV) allocation on PVHVM (Konrad Rzeszutek Wilk)   
- xen/spinlock: Check against default value of -1 for IRQ line. (Konrad Rzeszutek Wilk)   
- xen/time: Add default value of -1 for IRQ and check for that. (Konrad Rzeszutek Wilk)   
- xen/events: Check that IRQ value passed in is valid. (Konrad Rzeszutek Wilk)   
- xen/time: Fix kasprintf splat when allocating timer%d IRQ line. (Konrad Rzeszutek Wilk)   
- xen/smp/spinlock: Fix leakage of the spinlock interrupt line for every CPU online/offline (Konrad Rzeszutek Wilk)   
- xen/smp: Fix leakage of timer interrupt line for every CPU online/offline. (Konrad Rzeszutek Wilk)   
- xen kconfig: fix select INPUT_XEN_KBDDEV_FRONTEND (Andrew Jones)   
- xen: drop tracking of IRQ vector (Jan Beulich)   
- x86/xen: populate boot_params with EDD data (David Vrabel)   
- xen-blkfront: set blk_queue_max_hw_sectors correctly (Roger Pau Monne)   
- xen-blkback: workaround compiler bug in gcc 4.1 (Roger Pau Monne)   
- xen/blkback: Check for insane amounts of request on the ring (v6). (Konrad Rzeszutek Wilk)   
- xen/io/ring.h: new macro to detect whether there are too many requests on the ring (Jan Beulich)   
- xen/blkback: Check device permissions before allowing OP_DISCARD (Konrad Rzeszutek Wilk)  {CVE-2013-2140} 
- xen/blkback: Use physical sector size for setup (Stefan Bader)   
- xen-blkback/sysfs: Move the parameters for the persistent grant features (Konrad Rzeszutek Wilk)   
- xen-blkfront: Introduce a 'max' module parameter to alter the amount of indirect segments. (Konrad Rzeszutek Wilk)   
- xen-blkfront: use a different scatterlist for each request (Roger Pau Monne)   
- xen-blkback: allocate list of pending reqs in small chunks (Roger Pau Monne)   
- xen-block: implement indirect descriptors (Roger Pau Monne)   
- xen-blkback: expand map/unmap functions (Roger Pau Monne)   
- xen-blkback: make the queue of free requests per backend (Roger Pau Monne)   
- xen-blkback: move pending handles list from blkbk to pending_req (Roger Pau Monne)   
- xen-blkback: implement LRU mechanism for persistent grants (Roger Pau Monne)   
- xen-blkback: use balloon pages for all mappings (Roger Pau Monne)   
- xen-blkback: print stats about persistent grants (Roger Pau Monne)   
- xen/mmu: On early bootup, flush the TLB when changing RO->RW bits Xen provided pagetables. (Konrad Rzeszutek Wilk)   
- xen/events: Handle VIRQ_TIMER before any other hardirq in event loop. (Keir Fraser)   
- xen/events: avoid race with raising an event in unmask_evtchn() (David Vrabel)   
- xen/mmu: Move the setting of pvops.write_cr3 to later phase in bootup. (Konrad Rzeszutek Wilk)   
- xen/acpi-stub: Disable it b/c the acpi_processor_add is no longer called. (Konrad Rzeszutek Wilk)   
- xen-pciback: notify hypervisor about devices intended to be assigned to guests (Jan Beulich)   
- xen/acpi-processor: Don't dereference struct acpi_processor on all CPUs. (Konrad Rzeszutek Wilk)   
- xen/acpi: remove redundant acpi/acpi_drivers.h include (Liu Jinsong)   
- xen: arm: mandate EABI and use generic atomic operations. (Ian Campbell)   
- acpi: Export the acpi_processor_get_performance_info (Konrad Rzeszutek Wilk)   
- xen/pciback: Don't disable a PCI device that is already disabled. (Konrad Rzeszutek Wilk)   
- xenbus: fix compile failure on ARM with Xen enabled (Steven Noonan)   
- xen/pci: We don't do multiple MSI's. (Konrad Rzeszutek Wilk)   
- xen/pat: Disable PAT using pat_enabled value. (Konrad Rzeszutek Wilk)   
- xen/acpi: xen cpu hotplug minor updates (Liu Jinsong)   
- xen/acpi: xen memory hotplug minor updates (Liu Jinsong)   
- xen: event channel arrays are xen_ulong_t and not unsigned long (Ian Campbell)   
- xen: Send spinlock IPI to all waiters (Stefan Bader)   
- xen: introduce xen_remap, use it instead of ioremap (Stefano Stabellini)   
- xen: close evtchn port if binding to irq fails (Wei Liu)   
- xen-evtchn: correct comment and error output (Wei Liu)   
- xen/tmem: Add missing %s in the printk statement. (Konrad Rzeszutek Wilk)   
- xen/acpi: move xen_acpi_get_pxm under CONFIG_XEN_DOM0 (Liu Jinsong)   
- xen/acpi: ACPI cpu hotplug (Liu Jinsong)   
- xen/acpi: Move xen_acpi_get_pxm to Xen's acpi.h (Liu Jinsong)   
- xen/stub: driver for CPU hotplug (Liu Jinsong)   
- xen/acpi: ACPI memory hotplug (Liu Jinsong)   
- xen/stub: driver for memory hotplug (Liu Jinsong)   
- xen: implement updated XENMEM_add_to_physmap_range ABI (Ian Campbell)   
- xen/smp: Move the common CPU init code a bit to prep for PVH patch. (Konrad Rzeszutek Wilk)   
- xen-blkfront: remove frame list from blk_shadow (Roger Pau Monne)   
- xen-blkfront: pre-allocate pages for requests (Roger Pau Monne)   
- xen-blkback: don't store dev_bus_addr (Roger Pau Monne)   
- xen-blkfront: switch from llist to list (Roger Pau Monne)   
- xen-blkback: fix foreach_grant_safe to handle empty lists (Roger Pau Monne)   
- xen-blkfront: replace kmalloc and then memcpy with kmemdup (Mihnea Dobrescu-Balaur)   
- xen-blkback: fix dispatch_rw_block_io() error path (Jan Beulich)   
- xen/blkback: Change statistics counter types to unsigned (Zoltan Kiss)   
- xen/blkback: correctly respond to unknown, non-native requests (David Vrabel)   
- xen/xen-blkback: preq.dev is used without initialized (Chen Gang)   
- xen-blkback: use balloon pages for persistent grants (Roger Pau Monne)   
- xen-blkfront: drop the use of llist_for_each_entry_safe (Konrad Rzeszutek Wilk) [Orabug: 16263164]  
- xen/blkback: Don't trust the handle from the frontend. (Konrad Rzeszutek Wilk)   
- xen-blkback: do not leak mode property (Jan Beulich)   

* Wed Jun 26 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-2.el6uek] 
- scsi_prep_fn() check for empty queue (Maxim Uvarov) [Orabug: 17015179]  
- CONFIG_SCSI_VIRTIO=m (Maxim Uvarov) [Orabug: 17002820]  
- kernel spec: comment out pesign requirement (Maxim Uvarov)   
- remove i686 build files (Maxim Uvarov)   
- ixgbevf driver update from 2.7.12-k to 2.8.7 (Maxim Uvarov)   
- ixgbe update from 3.11.33-k to 3.15.1 (Maxim Uvarov)   
- igbvf driver update from 2.0.2-k to 2.3.2 (Maxim Uvarov)   
- e1000e driver update from 2.1.4-k to 2.4.14-NAPI (Maxim Uvarov)   
- spec: change kernel version to uek3 (Maxim Uvarov)   
- igb driver update from 4.1.2-k to 4.3.0 (Maxim Uvarov)   
- support sparc64x chip type in cpumap (Allen Pais)   
- cpu hw caps support for sparc64x (Allen Pais)   
- correctly recognize SPARC64-X chips (Allen Pais)   
- OVPMAI: modified files to include ovmapi driver. (Cathy Avery) Merge OVMAPI
[Orabug: 16443145]  
- OVMAPI: Added uek2 driver to build. (Cathy Avery) Merge OVMAPI
[Orabug: 16443145]  

* Fri Jun 14 2013 Maxim Uvarov <maxim.uvarov@oracle.com> [3.8.13-1.el6uek] 
- kconfig: turn on rcu_trace and rcu_torture_test (Maxim Uvarov) 
- sparc64 Kconfig and configs V1 (bob picco) 
- sparc64 irq_64 section mismatch fix (bob picco) 
- sparc64 sparse irq (bob picco) 
- sparc64 boot option open up /dev/mem again (bob picco) 
- sparc64 add mem to iomem resource (bob picco) 
- sparc64 strict_devmem (bob picco) 
- sparc64 find_node LDOM (bob picco) 
- sparc64 address-congruence property (bob picco) 
- sparc64 kconfig four level page table (bob picco) 
- sparc64 four level page table support (bob picco) 
- sparc64 move three level page table scheme (bob picco) 
- sparc64 expand linear mapping region (bob picco) 
- ioat3: add missing DMA unmap to ioat_xor_val_self_test() (Bartlomiej Zolnierkiewicz) [Orabug: 16495543] 
- perf/x86: Add Intel IvyBridge event scheduling constraints (Stephane Eranian) [Orabug: 16495525] 
- ksplice: Clear garbage data on the kernel stack when handling signals (Nelson Elhage) 
- spec: ol6 add multipath version deps (Maxim Uvarov) [Orabug: 16763586] 
- spec: fix suffix order of a directory name (Guangyu Sun) [Orabug: 16682371] 
- SPEC: add x86_energy_perf_policy tool Add tools/power/x86/x86_energy_perf_policy/x86_energy_perf_policy to ol5 ol6 uek kernel rpmbuild spec file and create shell wrapper for this tool. (ethan.zhao) [Orabug: 16036151] 
- spec: fix instalation if hardlink is installed (Maxim Uvarov) 
- SPEC: fix doc build (Guru Anbalagane) 
- spec: unique debuginfo (Maxim Uvarov) [Orabug: 16245366] 
- Enable CONFIG_SUNRPC_DEBUG by default. (Todd Vierling) [Orabug: 16879097] 
- x86: Add Xen kexec control code size check to linker script (Daniel Kiper) 
- drivers/xen: Export vmcoreinfo through sysfs (Daniel Kiper) 
- x86/xen/enlighten: Add init and crash kexec/kdump hooks (Daniel Kiper) 
- x86/xen: Add kexec/kdump makefile rules (Daniel Kiper) 
- x86/xen: Add x86_64 kexec/kdump implementation (Daniel Kiper) 
- x86/xen: Add i386 kexec/kdump implementation (Daniel Kiper) 
- x86/xen: Register resources required by kexec-tools (Daniel Kiper) 
- x86/xen: Introduce architecture dependent data for kexec/kdump (Daniel Kiper) 
- xen: Introduce architecture independent data for kexec/kdump (Daniel Kiper) 
- x86/kexec: Add extra pointers to transition page table PGD, PUD, PMD and PTE (Daniel Kiper) 
- kexec: introduce kexec_ops struct (Daniel Kiper) 
- spec: inc sublevel to 13 (Maxim Uvarov) 
- spec: add /boot/vmlinuz*.hmac needed for fips mode (John Haxby) [Orabug: 16807114] 
- spec: baselevel 12 (Maxim Uvarov) 
- Fix version.h include due to UAPI change in 3.7 (Dwight Engen) [Orabug: 16526862] 
- mtip32xx: set config option to enable build (Jerry Snitselaar) [Orabug: 16745449] 
- mpt3sas: set config options to enable build (Jerry Snitselaar) [Orabug: 16745449] 
- spec: baselevel 8 (Maxim Uvarov) 
- xen/mmu: On early bootup, flush the TLB when changing RO->RW bits Xen provided pagetables. (Konrad Rzeszutek Wilk) 
- Fix problem in Xen pvhugepages where page table walk to lock/unlock page table pages needed to be taught about hugepages. (Dave McCracken) 
- Add support for pv hugepages and support for huge balloon pages. (Dave McCracken) 
- update-el use 6.4 (Maxim Uvarov) 
- Spec: uek3/v3.8 initial build scripts (Maxim Uvarov) 
- scripts/sign-file fix typo (Maxim Uvarov) 
- kbuild: AFTER_LINK (Roland McGrath) 
- MODSIGN: Simplify Makefile with a Kconfig helper (Michal Marek) 
- MODSIGN: Add option to not sign modules during modules_install (Michal Marek) 
- MODSIGN: Specify the hash algorithm on sign-file command line (Michal Marek) 
- bnx2: Update driver to use new mips firmware. (Joe Jin) 
- ipmi: make kcs timeout parameters as module options (Pavel Bures) 
- perf: fix x86 compilation fix (Maxim Uvarov) 
- ocfs2: Add datavolume mount option (Guru Anbalagane) [Orabug: 16533805] 
- update-el use 6.4 (Maxim Uvarov) 
- Spec: uek3/v3.8 initial build scripts (Maxim Uvarov) 
- scripts/sign-file fix typo (Maxim Uvarov) 
- kbuild: AFTER_LINK (Roland McGrath) 
- MODSIGN: Simplify Makefile with a Kconfig helper (Michal Marek) 
- MODSIGN: Add option to not sign modules during modules_install (Michal Marek) 
- MODSIGN: Specify the hash algorithm on sign-file command line (Michal Marek) 
- bnx2: Update driver to use new mips firmware. (Joe Jin) 
- ipmi: make kcs timeout parameters as module options (Pavel Bures) 
- perf: fix x86 compilation fix (Maxim Uvarov) 
- Linux 3.8.13 (Greg Kroah-Hartman) This is the 3.8.13 stable release 

